OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Будучыя заданні",
    "Today" : "Сёння",
    "All" : "Усе",
    "Tasks" : "Заданні",
    "The Tasks app for Nextcloud" : "Праграма Заданні для Nextcloud",
    "Tasks settings" : "Налады Заданняў",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Can edit" : "Можа рэдагаваць",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Гэта выдаліць каляндар \"{calendar}\" і ўсе адпаведныя падзеі і заданні.",
    "This will unshare the calendar \"{calendar}\"." : "Каляндар \"{calendar}\" перастане абагульвацца.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Гэта выдаліць спіс \"{list}}\" і ўсе адпаведныя заданні.",
    "This will unshare the list \"{list}\"." : "Спіс \"{list}\" перастане абагульвацца.",
    "Edit" : "Рэдагаваць",
    "Copy private link" : "Капіяваць прыватную спасылку",
    "Copied" : "Скапіявана",
    "Export" : "Экспарт",
    "Delete" : "Выдаліць",
    "Unshare" : "Cкасаваць абагульванне",
    "Untitled task" : "Заданне без назвы",
    "Untitled event" : "Падзея без назвы",
    "Trash bin" : "Сметніца",
    "Loading deleted calendars, tasks and events." : "Загрузка выдаленых календароў, заданняў і падзей.",
    "You do not have any deleted calendars, tasks or events." : "У вас няма выдаленых календароў, заданняў або падзей.",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Cancel" : "Скасаваць",
    "This is a todo reminder." : "Гэта напамін пра задачу.",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "Before the task starts" : "Да пачатку задання",
    "Before the task is due" : "Да тэрміну выканання задання",
    "Go back" : "Назад",
    "Do you want to keep related reminders?" : "Вы хочаце пакінуць звязаныя напаміны?",
    "Discard reminders" : "Адхіліць напаміны",
    "Keep reminders" : "Пакінуць напаміны",
    "Set a reminder relative to your tasks start date:" : "Задайце напамін адносна даты пачатку заданняў:",
    "Set a reminder relative to your tasks due date:" : "Усталюйце напамін адносна тэрміну выканання заданняў:",
    "Create new tasks" : "Стварыць новыя заданні",
    "Create tasks" : "Стварыць заданні",
    "Creating new tasks…" : "Стварэнне новых заданняў…",
    "Close" : "Закрыць",
    "Delete all completed tasks." : "Выдаліць усе выкананыя заданні.",
    "Delete completed tasks." : "Выдаліць выкананыя заданні.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Выдалены ўсе выкананыя заданні. з календара \"{calendar}\".",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Гэта выдаліць {taskCount} выкананае заданне і падзаданні з календара \"{calendar}\".","Гэта выдаліць {taskCount} выкананыя заданні і падзаданні з календара \"{calendar}\".","Гэта выдаліць {taskCount} выкананых заданняў і падзаданні з календара \"{calendar}\".","Гэта выдаліць{taskCount} выкананых заданняў і падзаданні з календара \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Не ўдалося выдаліць {failedCount} заданне.","Не ўдалося выдаліць {failedCount} заданні.","Не ўдалося выдаліць {failedCount} заданняў.","Не ўдалося выдаліць {failedCount} заданняў."],
    "Add a task to \"{calendar}\"…" : "Дадаць заданне ў \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Загрузіць выкананыя заданні з усіх спісаў.",
    "Loading the completed tasks of all lists might slow down the app." : "Загрузка выкананых заданняў з усіх спісаў можа запаволіць працу праграмы.",
    "Load the completed tasks of list \"{calendar}\"." : "Загрузіць выкананыя заданні са спісу \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Загрузка выкананых заданняў можа запаволіць працу праграмы.",
    "Start date" : "Дата пачатку",
    "Priority" : "Прыярытэт",
    "Tags" : "Тэгі",
    "[Tomorrow]" : "[Заўтра]",
    "[Tomorrow at] LT" : "[Заўтра ў] LT",
    "Add a subtask to \"{task}\"…" : "Дадаць падзаданне да \"{task}\"…",
    "Task has hidden subtasks" : "Заданне мае схаваныя падзаданні",
    "Task is pinned" : "Заданне замацавана",
    "Add subtask" : "Дадаць падзаданне",
    "Show subtasks" : "Паказаць падзаданні",
    "Hide subtasks" : "Сзаваць падзаданні",
    "Show closed subtasks" : "Паказаць закрытыя падзаданні",
    "Hide closed subtasks" : "Схаваць закрытыя падзаданні",
    "Delete task" : "Выдаліць заданне",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Заданне будзе выдалена праз {countdown} секунду","Заданне будзе выдалена праз {countdown} секунды","Заданне будзе выдалена праз {countdown} секунд","Заданне будзе выдалена праз {countdown} секунд"],
    "Task is cancelled" : "Заданне скасавана",
    "Task is completed" : "Заданне выканана",
    "Task is read-only" : "Заданне толькі для чытання",
    "Task is not completed" : "Заданне не выканана",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" дададзена ў \"{calendar}\"",
    "Create a new task" : "Стварыць новае заданне",
    "Create task" : "Стварыць заданне",
    "Creating the new task…" : "Стварэнне новага задання…",
    "Open task" : "Адкрыць заданне",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n выкананае заданне","%n выкананыя заданні","%n выкананых заданняў","%n выкананых заданняў"],
    "Tomorrow" : "Заўтра",
    "An error occurred, unable to create the list." : "Узнікла памылка, немагчыма стварыць спіс.",
    "Add List…" : "Дадаць спіс…",
    "New list" : "Новы спіс",
    "Canceled" : "Скасавана",
    "Loading task from server." : "Загрузка задання з сервера.",
    "Task not found!" : "Заданне не знойдзена!",
    "All day" : "Увесь дзень",
    "Details" : "Падрабязнасці",
    "Notes" : "Нататкі",
    "No upcoming tasks" : "Няма будучых заданняў",
    "upcoming tasks" : "будучыя заданні",
    "No tasks today" : "Сёння няма заданняў",
    "Successfully created the task." : "Заданне паспяхова створана.",
    "Could not delete the task." : "Не атрымалася выдаліць заданне.",
    "Task successfully saved to server." : "Заданне паспяхова захавана на сервер.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не атрымалася абнавіць заданне, бо яно было зменена на серверы. Націсніце, каб абнавіць яго. Лакальныя змены будуць адхілены.",
    "Could not update the task." : "Не атрымалася абнавіць заданне.",
    "Successfully updated the task." : "Заданне паспяхова абноўлена.",
    "Task successfully moved to new calendar." : "Заданне паспяхова перамешчана ў новы каляндар.",
    "An error occurred" : "Узнікла памылка",
    "Create a task" : "Стварыць заданне",
    "Message from {author} in {conversationName}" : "Паведамленне ад {author} у {conversationName}",
    "[Starts tomorrow]" : "[Пачынаецца заўтра]",
    "[Starts tomorrow at] LT" : "[Пачынаецца заўтра ў]"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
