OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tâches à venir",
    "Important" : "Important",
    "Today" : "Aujourd'hui",
    "Week" : "Cette semaine",
    "All" : "Tout",
    "Current" : "Maintenant",
    "Completed" : "Terminé",
    "Tasks" : "Tâches",
    "The Tasks app for Nextcloud" : "Application Tasks pour Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Une fois activé, un nouveau menu Tâches apparaîtra dans le menu de vos applications Nextcloud. De là, vous pouvez ajouter et supprimer des tâches, modifier leur titre, leur description, leurs dates de début et d'échéance et les marquer comme étant importantes. Les tâches peuvent être partagées entre les utilisateurs. Les tâches peuvent être synchronisées en utilisant CalDav (chaque liste de tâches est liée à un calendrier Nextcloud, pour le synchroniser avec votre client local - Thunderbird, Evolution, KDE Kontact, iCal... - il suffit d'ajouter le calendrier comme un calendrier distant dans votre client). Vous pouvez télécharger vos tâches sous forme de fichiers ICS en utilisant le bouton de téléchargement pour chaque calendrier.",
    "Hidden" : "Masqué",
    "Visible" : "Visible",
    "Automatic" : "Automatique",
    "Tasks settings" : "Paramètres de Tâches",
    "Default list" : "Liste par défaut",
    "Visibility of Smart Collections" : "Visibilité des rubriques intelligentes",
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "No users or groups" : "Aucun utilisateur ou groupe",
    "Unable to delete the share." : "Impossible de supprimer le partage.",
    "Unable to change permissions." : "Impossible de modifier les autorisations.",
    "Can edit" : "Peut modifier",
    "Unshare with {displayName}" : "Ne plus partager avec {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Cela va supprimer l'agenda \"{calendar}\" ainsi que tous les évènements et tâches associés.",
    "This will unshare the calendar \"{calendar}\"." : "L'agenda \"{calendar}\" ne sera plus partagé.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Cette action va supprimer la liste \"{list}\" et toutes les tâches associées.",
    "This will unshare the list \"{list}\"." : "Cette action va supprimer le partage de la liste \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Suppression de l'agenda dans {countdown} secondes","Suppression de l'agenda dans {countdown} secondes","Suppression de l'agenda dans {countdown} secondes"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fin de partage de l'agenda dans {countdown} secondes.","Fin de partage de l'agenda dans {countdown} secondes.","Fin de partage de l'agenda dans {countdown} secondes."],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Suppression de la liste dans {countdown} seconde","Suppression de la liste dans {countdown} secondes","Suppression de la liste dans {countdown} secondes"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Suppression du partage de la liste dans {countdown} seconde","Suppression du partage de la liste dans {countdown} secondes","Suppression du partage de la liste dans {countdown} secondes"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Partagé avec {num} entité","Partagé avec {num} entités","Partagé avec {num} entités"],
    "Share this calendar" : "Partager cet agenda",
    "Share this list" : "Partager cette liste",
    "Calendar link copied to clipboard." : "Lien de l'agenda copié dans le presse-papier.",
    "List link copied to clipboard." : "Lien vers la liste copié dans le presse-papiers.",
    "Calendar link could not be copied to clipboard." : "Impossible de copier le lien de l'agenda dans le presse-papier.",
    "List link could not be copied to clipboard." : "Le lien vers la liste n'a pas pu être copié dans le presse-papiers.",
    "The name \"{calendar}\" is already used." : "Le nom \"{calendar}\" est déjà utilisé.",
    "An empty name is not allowed." : "Un nom vide n'est pas autorisé.",
    "An error occurred, unable to delete the calendar." : "Une erreur est survenue, impossible de supprimer l'agenda.",
    "An error occurred, unable to delete the list." : "Une erreur est survenue, impossible de supprimer la liste.",
    "Edit" : "Modifier",
    "Copy private link" : "Copier le lien privé",
    "Copied" : "Copié",
    "Cannot copy" : "Copie impossible",
    "Export" : "Exporter",
    "Delete" : "Supprimer",
    "Unshare" : "Ne plus partager",
    "List name" : "Nom de la liste",
    "Untitled task" : "Tâche sans titre",
    "Untitled event" : "Événement sans titre",
    "Untitled journal" : "Journal sans titre",
    "Untitled item" : "Élément sans titre",
    "Unknown calendar" : "Agenda inconnu",
    "Could not load deleted calendars and objects" : "Impossible de charger les calendriers et objets supprimés",
    "Could not delete calendar or event" : "Impossible de supprimer le calendrier ou l'événement",
    "Could not restore calendar or event" : "Impossible de restaurer l'agenda ou l'événement",
    "Do you really want to empty the trash bin?" : "Voulez-vous vraiment vider la corbeille?",
    "Empty trash bin" : "Vider la corbeille",
    "Trash bin" : "Corbeille",
    "Loading deleted calendars, tasks and events." : "Chargement des calendriers, tâches et événements effacés.",
    "You do not have any deleted calendars, tasks or events." : "Vous n'avez aucun agenda, tâche ou événement effacé.",
    "Name" : "Nom",
    "Deleted" : "Effacé",
    "Restore" : "Restaurer",
    "Delete permanently" : "Supprimer définitivement",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Les éléments dans la corbeille sont supprimés après {numDays} jour","Les éléments dans la corbeille sont supprimés après {numDays} jours","Les éléments dans la corbeille sont supprimés après {numDays} jours"],
    "Create reminder" : "Créer un rappel",
    "Update reminder" : "Mettre à jour le rappel",
    "Set a reminder at a custom date and time:" : "Définir un rappel à une date et une heure personnalisées.",
    "Cancel" : "Annuler",
    "This is a todo reminder." : "Ceci est un rappel de tâche à faire",
    "No reminders" : "Aucun rappel",
    "Notification" : "Notification",
    "Email" : "E-mail",
    "Audio notification" : "Notification sonore",
    "Other notification" : "Autre notification",
    "Edit time" : "Modifier le rappel",
    "Remove reminder" : "Retirer le rappel",
    "Add reminder" : "Ajouter un rappel",
    "Before the task starts" : "Avant le début de la tâche",
    "Before the task is due" : "Avant l'échéance de la tâche",
    "Select date and time" : "Sélectionner la date et l'heure",
    "Go back" : "Revenir en arrière",
    "Set a reminder relative to your tasks start date:" : "Définir un rappel par rapport au début de la tâche :",
    "Set a reminder relative to your tasks due date:" : "Définir un rappel par rapport à l'échéance de la tâche :",
    "before at" : "avant",
    "_second_::_seconds_" : ["seconde","secondes","secondes"],
    "_minute_::_minutes_" : ["minute","minutes","minutes"],
    "_hour_::_hours_" : ["heure","heures","heures"],
    "_day_::_days_" : ["jour","jours","jours"],
    "_week_::_weeks_" : ["semaine","semaines","semaines"],
    "Select a calendar" : "Sélectionnez un agenda",
    "No calendar matches the search." : "Aucun agenda ne correspond à la recherche.",
    "Set date" : "Définir la date",
    "Set time" : "Définir l'heure",
    "Delete date" : "Supprimer la date",
    "Click here to add a note." : "Cliquez ici pour ajouter une remarque.",
    "Set value" : "Définir l'entrée",
    "Delete value" : "Supprimer l'entrée",
    "Add this as a new tag" : "Ajoutez ceci en tant que nouveau tag",
    "No tag available. Create one!" : "Aucune étiquette disponible. Créez-en une !",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} tâches ont été ajoutées à \"{calendar}\"",
    "Create new tasks" : "Créer de nouvelles tâches",
    "Create {numberOfTasks} tasks from pasted text" : "Créer {numberOfTasks} tâches à partir d'un texte collé",
    "Create tasks" : "Créer des tâches",
    "Creating new tasks…" : "Création de nouvelles tâches...",
    "Close" : "Fermer",
    "Delete all completed tasks." : "Supprimer toutes les tâches terminées.",
    "Delete completed tasks." : "Supprimer les tâches terminées.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Supprimer toutes les tâches terminées de l'agenda \"{calendar}\".",
    "No errors" : "Aucune erreur",
    "Open your browser console for more details" : "Ouvrez la console de votre navigateur pour plus d'informations",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Cela va supprimer {taskCount} tâche terminée et ses sous-tâches de l'agenda \"{calendar}\".","Cela va supprimer {taskCount} tâches terminées et ses sous-tâches de l'agenda \"{calendar}\".","Cela va supprimer {taskCount} tâches terminées et ses sous-tâches de l'agenda \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Impossible de supprimer {failedCount} tâche.","Impossible de supprimer {failedCount} tâches.","Impossible de supprimer {failedCount} tâches."],
    "Active filter" : "Filtre actif",
    "Filter by tags" : "Filtrer par étiquette",
    "Select tags to filter by" : "Indiquez les étiquettes à filtrer",
    "Reset filter" : "Réinitialiser le filtre",
    "Add an important task to \"{calendar}\"…" : "Ajouter une tâche importante dans l'agenda \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Ajouter une tâche pour aujourd'hui dans \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Ajouter une tâche courante dans \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Ajouter une tâche dans \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Charger les tâches accomplies pour toutes les listes.",
    "Loading the completed tasks of all lists might slow down the app." : "Charger les tâches accomplies de toutes les listes pourrait ralentir l'application.",
    "Load the completed tasks of list \"{calendar}\"." : "Charger les tâches accomplies de la liste \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Charger les tâches accomplies pourrait ralentir l'application.",
    "Relevance" : "Pertinence",
    "Sort by completed state, due date, priority, start date and summary." : "Trier par état d'avancement, date d'échéance, priorité, date de début et ordre alphabétique.",
    "Start date" : "Date de début",
    "Sort by start date, priority and summary." : "Classer par date de début, priorité et résumé",
    "Due date" : "Date d'échéance",
    "Sort by due date, priority and summary." : "Classer par date d'échéance, priorité et résumé.",
    "Created date" : "Date de création",
    "Sort by created date, priority and summary." : "Classer par date de création, priorité et résumé.",
    "Last modified" : "Dernière modification",
    "Sort by last-modified date, priority and summary." : "Classer par date de dernière modification, priorité et résumé.",
    "Completed date" : "Date de fin",
    "Sort by completed date, priority and summary." : "Classer par date d'achèvement, priorité et résumé.",
    "Priority" : "Priorité",
    "Sort by priority and summary." : "Trier par priorité puis par ordre alphabétique.",
    "Alphabetically" : "Ordre alphabétique",
    "Sort by summary and priority." : "Trier par ordre alphabétique puis par priorité.",
    "Tags" : "Étiquettes",
    "Sort by tags." : "Trier par tags.",
    "Manually" : "Manuellement",
    "Sort by manual order." : "Trier par ordre manuel.",
    "Change sort order" : "Modifier l'ordre de tri",
    "[Yesterday]" : "[Hier]",
    "[Today]" : "[Aujourd'hui]",
    "[Tomorrow]" : "[Demain]",
    "[Completed yesterday]" : "[Terminé hier]",
    "[Completed today]" : "[Terminé aujourd'hui]",
    "[Completed tomorrow]" : "[Terminé demain]",
    "[Yesterday at] LT" : "[Hier à] LT",
    "[Today at] LT" : "[Aujourd'hui à] LT",
    "[Tomorrow at] LT" : "[Demain à] LT",
    "L [at] LT" : "L [à] LT",
    "[Completed yesterday at] LT" : "[Terminé hier à] LT",
    "[Completed today at] LT" : "[Terminé aujourd'hui à] LT",
    "[Completed tomorrow at] LT" : "[Terminé demain à] LT",
    "[Completed] L [at] LT" : "[Terminé] L [à] LT",
    "Add a subtask to \"{task}\"…" : "Ajouter une sous-tâche dans \"{task}\"…",
    "Task has hidden subtasks" : "La tâche comporte des sous-tâches cachées",
    "Task is pinned" : "La tâche est épinglée",
    "Task has a note" : "La tâche comporte une note",
    "{complete} % completed" : "{complete} % terminé",
    "Add subtask" : "Ajouter une sous-tâche",
    "Show subtasks" : "Afficher les sous-tâches",
    "Hide subtasks" : "Masquer les sous-tâches",
    "Show closed subtasks" : "Afficher les sous-tâches fermées",
    "Hide closed subtasks" : "Masquer les sous-tâches fermées",
    "Delete task" : "Supprimer la tâche",
    "Toggle starred" : "Épingler/Désépingler",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Cette tâche a un rappel","Cette tâche a {n}rappels ","Cette tâche a {n}rappels"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Suppression de la tâche dans {countdown} seconde","Suppression de la tâche dans {countdown} secondes","Suppression de la tâche dans {countdown} secondes"],
    "Task is cancelled" : "La tâche est annulée",
    "Task is completed" : "La tâche est terminée",
    "Task is read-only" : "La tâche est en lecture seule",
    "Task is not completed" : "La tâche n'est pas terminée",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" a été ajoutée à \"{calendar}\"",
    "Create a new task" : "Créer une nouvelle tâche",
    "Task summary" : "Résumé de la tâche",
    "Create task" : "Créer une tâche",
    "Creating the new task…" : "Création de la nouvelle tâche…",
    "Open task" : "Ouvrir la tâche",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tâche terminée","%n tâches terminées","%n tâches terminées"],
    "Tomorrow" : "Demain",
    "An error occurred, unable to create the list." : "Une erreur est survenue, impossible de créer la liste.",
    "Add List…" : "Ajouter une liste...",
    "New list" : "Nouvelle liste",
    "When shared show full event" : "En cas de partage, afficher l’évènement complet",
    "When shared show only busy" : "En cas de partage, afficher la plage horaire comme occupée",
    "When shared hide this event" : "En cas de partage, masquer l’évènement",
    "[Completed] L" : "[Terminé] L",
    "[Completed last] dddd [at] LT" : "[Terminé le] dddd [à] LT",
    "[Completed] dddd [at] LT" : "[Terminé le] dddd [à] LT",
    "[Last modified yesterday at] LT" : "[Dernière modification hier à] LT",
    "[Last modified today at] LT" : "[Dernière modification aujourd'hui à] LT",
    "[Last modified] L" : "[Dernière modification] L",
    "[Last modified last] dddd [at] LT" : "[Dernière modification le] dddd [à] LT",
    "[Last modified] dddd [at] LT" : "[Dernière modification le] dddd [à] LT",
    "[Created yesterday at] LT" : "[Créé hier à] LT",
    "[Created today at] LT" : "[Créé aujourd'hui à] LT",
    "[Created] L" : "[Créé] L",
    "[Created last] dddd [at] LT" : "[Créé le] dddd [à] LT",
    "[Created] dddd [at] LT" : "[Créé le] dddd [à] LT",
    "Needs action" : "Nécessite une action",
    "In process" : "En cours",
    "Canceled" : "Annulé",
    "Clear status" : "Effacer le statut",
    "Loading task from server." : "Chargement de la tâche depuis le serveur.",
    "Task not found!" : "Tâche non trouvée !",
    "Set start date" : "Indiquer la date de début",
    "Set due date" : "Indiquer la date d'échéance",
    "Priority {priority}: low" : "Priorité {priority} : basse",
    "Priority {priority}: medium" : "Priorité {priority} : moyenne",
    "Priority {priority}: high" : "Priorité {priority} : haute",
    "No priority assigned" : "Aucune priorité",
    "{percent} % completed" : "Terminé à {percent} %",
    "All day" : "Toute la journée",
    "Unpin" : "Détacher",
    "Pin" : "Épingler",
    "Show in Calendar" : "Afficher dans l’agenda",
    "Show in Deck" : "Afficher dans le Deck",
    "Edit summary" : "Modifier le résumé",
    "Details" : "Détails",
    "Selecting a classification is forbidden, because the task was shared with you." : "Choisir une catégorie est interdit parce que cette tâche a été partagée avec vous.",
    "Select a classification" : "Sélectionner une catégorie",
    "Select a status" : "Sélectionner un statut",
    "Set a location" : "Définir un lieu",
    "Set a URL" : "Définir une URL",
    "Select tags" : "Sélectionner les étiquettes",
    "Notes" : "Remarques",
    "Mark as done" : "Marquer comme fait",
    "No due date assigned" : "Aucune date d’échéance attribuée",
    "[Due yesterday]" : "[Échéance hier]",
    "[Due today]" : "[Pour aujourd'hui]",
    "[Due tomorrow]" : "[Pour demain]",
    "[Due] L" : "[Échéance] L",
    "[Due yesterday at] LT" : "[Échéance hier à] LT",
    "[Due today at] LT" : "[Pour aujourd'hui à] LT",
    "[Due tomorrow at] LT" : "[Pour demain à] LT",
    "[Due] L [at] LT" : "[Échéance] L [à] LT",
    "No upcoming tasks" : "Pas de tâches à venir",
    "upcoming tasks" : "Tâches à venir",
    "No tasks today" : "Aucune tâche aujourd'hui",
    "Completion date must be in the past." : "La date d'achèvement doit être dans le passé",
    "Successfully created the task." : "Tâche créée avec succès.",
    "Could not delete the task." : "Impossible de supprimer la tâche.",
    "Synchronizing to the server." : "Synchronisation en cours avec le serveur.",
    "Task successfully saved to server." : "Tâche enregistrée sur le serveur.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "La tâche ne peut pas être mise à jour car elle a été modifiée sur le serveur. Merci de cliquer pour la recharger, les modifications locales seront perdues.",
    "Could not update the task." : "Impossible de mettre à jour la tâche.",
    "Successfully updated the task." : "Tâche modifiée avec succès.",
    "Task successfully moved to new calendar." : "Tâche déplacée avec succès vers le nouvel agenda.",
    "An error occurred" : "Une erreur est survenue",
    "Create a task" : "Créer une tâche",
    "Message from {author} in {conversationName}" : "Message de {author} dans {conversationName}",
    "[Due on] LL" : "[Pour le] LL",
    "[Was due yesterday]" : "[Était pour hier]",
    "[Was due on] LL" : "[Était pour le] LL",
    "[Was due today at] LT" : "[Était pour aujourd'hui à] LT",
    "[Due on] LL [at] LT" : "[Pour le] LL [à] LT",
    "[Was due yesterday at] LT" : "[Était pour hier à] LT",
    "[Was due on] LL [at] LT" : "[Était pour le] LL [à] LT",
    "[Starts today]" : "[Débute aujourd'hui]",
    "[Starts tomorrow]" : "[Débute demain]",
    "[Starts on] LL" : "[Débute le] LL",
    "[Started yesterday]" : "[Débutées hier]",
    "[Started on] LL" : "[Démarré le] LL",
    "[Started today at] LT" : "[Démarré aujourd'hui à] LT",
    "[Starts today at] LT" : "[Débute aujourd'hui à] LT",
    "[Starts tomorrow at] LT" : "[Débute demain à] LT",
    "[Starts on] LL [at] LT" : "[Débute le] LL [à] LT",
    "[Started yesterday at] LT" : "[Débuté hier à] LT",
    "[Started on] LL [at] LT" : "[Débuté le] LL [à] LT",
    "Midnight on the day the task starts" : "Dès minuit le jour où débute la tâche",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["Un jour avant le début de la tâche à {formattedHourMinute}","%n jours avant le début de la tâche à {formattedHourMinute}","%n jours avant le début de la tâche à {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["La semaine précédent le début de la tâche à {formattedHourMinute}","%n semaines avant le début de la tâche à {formattedHourMinute}","%n semaines avant le début de la tâche à {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "le jour de la tâche à {formattedHourMinute}",
    "at the task's start" : "au début de la tâche",
    "when the task is due" : "quand la tâche doit être terminée",
    "{time} before the task starts" : "{time} avant le début de la tâche",
    "{time} before the task is due" : "{time} avant l'échéance de la tâche",
    "{time} after the task starts" : "{time} après le début de la tâche",
    "{time} after the task is due" : "{time} après l'échéance de la tâche"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
