OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Aanstaande taken",
    "Important" : "Belangrijk",
    "Today" : "Vandaag",
    "Week" : "Week",
    "All" : "Alle",
    "Current" : "Huidige",
    "Completed" : "Afgerond",
    "Tasks" : "Taken",
    "The Tasks app for Nextcloud" : "De Taken app voor Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Wanneer ingeschakeld, verschijnt een nieuw Taken-menu in je Nextcloud-apps-menu. Vanaf daar kan je taken toevoegen en verwijderen, de titel, beschrijving, begin- en vervaldatums aanpassen en ze markeren als belangrijk. Taken kunnen door gebruikers worden gedeeld. Taken kunnen worden gesynchroniseerd met CalDav (elke takenlijst is gekoppeld aan een Nextcloud-agenda, om deze te synchroniseren met de lokale client: Thunderbird, Evolution, KDE Kontact, iCal ... - voeg je de agenda in je programma gewoon toe als een externe agenda). Je kunt je taken voor elke agenda als ICS-bestanden downloaden met behulp van de downloadknop.",
    "Hidden" : "Verborgen",
    "Visible" : "Zichtbaar",
    "Automatic" : "Automatisch",
    "Tasks settings" : "Taak instellingen",
    "Default list" : "Standaardlijst",
    "Visibility of Smart Collections" : "Zichtbaarheid van Slimme Verzamelingen",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "No users or groups" : "Geen gebruikers of groepen",
    "Unable to delete the share." : "Kan de share niet verwijderen.",
    "Unable to change permissions." : "Kan de machtigingen niet wijzigen.",
    "Can edit" : "Kan bewerken",
    "Unshare with {displayName}" : "Stop delen met {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Dit verwijdert agenda \"{calendar}\" en alle bijbehorende afspraken en taken.",
    "This will unshare the calendar \"{calendar}\"." : "Dit zorg voor beëindigen van delen van agenda \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Dit verwijdert lijst \"{list}\" en alle bijbehorende taken.",
    "This will unshare the list \"{list}\"." : "Dit zorg voor beëindigen van delen van lijst \"{lijst}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Agenda wordt verwijderd over {countdown} seconde","Agenda wordt verwijderd over {countdown} seconden"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Het delen van de agenda wordt over {countdown} seconde gestopt","Het delen van de agenda wordt over {countdown} seconden gestopt"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["De lijst wordt verwijderd over {countdown} seconde","De lijst wordt verwijderd over {countdown} seconden"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Het delen van de lijst wordt over {countdown} seconde gestopt","Het delen van de lijst wordt over {countdown} seconden gestopt"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Gedeeld met {num} object","Gedeeld met {num} objecten"],
    "Share this calendar" : "Deel deze agenda",
    "Share this list" : "Deel deze lijst",
    "Calendar link copied to clipboard." : "Kalenderlink gekopieerd naar klembord.",
    "List link copied to clipboard." : "Lijst-link gekopieerd naar klembord.",
    "Calendar link could not be copied to clipboard." : "Kalenderlink kon niet worden gekopieerd naar klembord.",
    "List link could not be copied to clipboard." : "Lijst-link kon niet worden gekopieerd naar klembord.",
    "The name \"{calendar}\" is already used." : "De naam \"{calendar}\" is al in gebruik.",
    "An empty name is not allowed." : "Een lege naam is niet toegestaan.",
    "An error occurred, unable to delete the calendar." : "Er is een fout opgetreden waardoor de agenda niet kan worden verwijderd.",
    "An error occurred, unable to delete the list." : "Er is een fout opgetreden, lijst kan niet verwijderd worden.",
    "Edit" : "Bewerk",
    "Copy private link" : "Kopieer privé-link",
    "Copied" : "Gekopieerd",
    "Cannot copy" : "Kan niet kopiëren",
    "Export" : "Exporteren",
    "Delete" : "Verwijderen",
    "Unshare" : "Delen stoppen",
    "List name" : "Lijstnaam",
    "Untitled task" : "Naamloze taak",
    "Untitled event" : "Naamloos evenement",
    "Untitled journal" : "Naamloos logboek",
    "Untitled item" : "Object zonder titel",
    "Unknown calendar" : "Onbekende kalender",
    "Could not load deleted calendars and objects" : "Kon de verwijderde agenda en objecten niet laden",
    "Could not delete calendar or event" : "Kon kalender of afspraak niet verwijderen",
    "Could not restore calendar or event" : "Kon de agenda of afspraak niet herstellen",
    "Do you really want to empty the trash bin?" : "Wil je de prullenbak echt legen?",
    "Empty trash bin" : "Prullenbak legen",
    "Trash bin" : "Prullenbak",
    "Loading deleted calendars, tasks and events." : "Laden verwijderde agenda's, taken en afspraken.",
    "You do not have any deleted calendars, tasks or events." : "Je hebt geen verwijderde agenda, taken of afspraken.",
    "Name" : "Naam",
    "Deleted" : "Verwijderd",
    "Restore" : "Herstellen",
    "Delete permanently" : "Permanent verwijderen",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Objecten in de prullenbak worden na {numDays} dag verwijderd","Objecten in de prullenbak worden na {numDays} dagen verwijderd"],
    "Cancel" : "Annuleren",
    "Notification" : "Melding",
    "Email" : "E-mail",
    "Audio notification" : "Audio melding",
    "Other notification" : "Andere melding",
    "Edit time" : "Bewerk tijd",
    "Remove reminder" : "Verwijder herinnering",
    "Add reminder" : "Voeg herinnering toe",
    "Go back" : "Ga terug",
    "before at" : "ervoor om",
    "_second_::_seconds_" : ["seconde","seconden"],
    "_minute_::_minutes_" : ["minuut","minuten"],
    "_hour_::_hours_" : ["uur","uren"],
    "_day_::_days_" : ["dag","dagen"],
    "_week_::_weeks_" : ["week","weken"],
    "Select a calendar" : "Selecteer een kalender",
    "No calendar matches the search." : "Geen enkele kalender komt overeen met de zoekopdracht.",
    "Set date" : "Instellen datum",
    "Set time" : "Instellen tijd",
    "Delete date" : "Verwijderdatum",
    "Click here to add a note." : "Klik hier om een notitie toe te voegen.",
    "Set value" : "Waarde instellen",
    "Delete value" : "Verwijder waarde",
    "Add this as a new tag" : "Voeg dit toe als een nieuwe tag",
    "No tag available. Create one!" : "Geen tag beschikbaar. Maak er eentje!",
    "Close" : "Sluiten",
    "Delete all completed tasks." : "Verwijder alle voltooide taken.",
    "Delete completed tasks." : "Verwijder voltooide taken.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Verwijder alle voltooide taken uit agenda \"{calendar}\".",
    "No errors" : "Geen foutmeldingen.",
    "Open your browser console for more details" : "Open je browserconsole voor meer details.",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Dit verwijdert {taskCount} voltooide taak en subtaken uit agenda \"{calendar}\".","Dit verwijdert {taskCount} voltooide taken en subtaken uit agenda \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kon {failedCount} taak niet verwijderen.","Kon {failedCount} taken niet verwijderen."],
    "Filter by tags" : "Filter op tags",
    "Select tags to filter by" : "Selecteer markering om op te filteren",
    "Add an important task to \"{calendar}\"…" : "Voeg een belangrijke taak toe aan \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Voeg een taak voor vandaag toe aan \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Voeg een actuele taak toe aan \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Voeg een taak toe aan \"{calendar}\"…",
    "Loading the completed tasks of all lists might slow down the app." : "Het laden van afgewerkte taken van alle lijsten kan de app vertragen.",
    "Relevance" : "Relevantie",
    "Sort by completed state, due date, priority, start date and summary." : "Sorteren op status, vervaldatum, prioriteit, startdatum en samenvatting.",
    "Start date" : "Startdatum",
    "Sort by start date, priority and summary." : "Sorteer op startdatum, prioriteit en samenvatting.",
    "Due date" : "Vervaldatum",
    "Sort by due date, priority and summary." : "Sorteer op vervaldatum, prioriteit en samenvatting.",
    "Created date" : "Datum gemaakt",
    "Sort by created date, priority and summary." : "Sorteer op datum gemaakt, prioriteit en samenvatting.",
    "Last modified" : "Laatst bewerkt",
    "Sort by last-modified date, priority and summary." : "Sorteer op laatst bewerkte datum, prioriteit en samenvatting.",
    "Completed date" : "Datum afgerond",
    "Sort by completed date, priority and summary." : "Sorteer op voltooidatum, prioriteit en samenvatting.",
    "Priority" : "Prioriteit",
    "Sort by priority and summary." : "Sorteer op prioriteit en samenvatting.",
    "Alphabetically" : "Alfabetisch",
    "Sort by summary and priority." : "Sorteer op samenvatting en prioriteit.",
    "Tags" : "Tags",
    "Manually" : "Handmatig",
    "Sort by manual order." : "Sorteer op handmatige volgorde.",
    "Change sort order" : "Volgorde wijzigen",
    "[Yesterday]" : "[Gisteren]",
    "[Today]" : "[Vandaag]",
    "[Tomorrow]" : "[Morgen]",
    "[Completed yesterday]" : "[Gisteren afgewerkt]",
    "[Completed today]" : "[Vandaag afgewerkt]",
    "[Completed tomorrow]" : "[Morgen afgewerkt]",
    "[Yesterday at] LT" : "[Gisteren om] LT",
    "[Today at] LT" : "[Vandaag om] LT",
    "[Tomorrow at] LT" : "[morgen om] LT",
    "L [at] LT" : "L [om] LT",
    "[Completed yesterday at] LT" : "[Gisteren afgewerkt om] LT",
    "[Completed today at] LT" : "[Vandaag afgewerkt om] LT",
    "[Completed tomorrow at] LT" : "[Morgen afgewerkt om] LT",
    "[Completed] L [at] LT" : "[Afgewerkt op] L [om] LT",
    "Add a subtask to \"{task}\"…" : "Voeg een subtaak toe aan \"{task}\"…",
    "Task has hidden subtasks" : "Taak heeft verborgen subtaken",
    "Task is pinned" : "Taak is gepind",
    "Task has a note" : "Taak heeft een notitie",
    "{complete} % completed" : "{complete} % gereed",
    "Add subtask" : "Subtaak toevoegen",
    "Show subtasks" : "Subtaken weergeven",
    "Hide subtasks" : "Subtaken verbergen",
    "Show closed subtasks" : "Toon afgesloten subtaken",
    "Hide closed subtasks" : "Verberg afgesloten subtaken",
    "Delete task" : "Verwijder taak",
    "Toggle starred" : "Omschakelen gesterd",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["De taak wordt verwijderd over {countdown} seconde","De taak wordt verwijderd over {countdown} seconden"],
    "Task is cancelled" : "Taak geannuleerd",
    "Task is completed" : "Taak is gereed",
    "Task is read-only" : "Taak is alleen-lezen",
    "Task is not completed" : "Taak is niet gereed",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" is toegevoegd aan \"{calendar}\"",
    "Create a new task" : "Maak een nieuwe taak aan",
    "Task summary" : "Taakoverzicht",
    "Create task" : "Aanmaken taak",
    "Creating the new task…" : "Nieuwe taak aan het aanmaken...",
    "Open task" : "Open taak",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n afgeronde taak","%n afgeronde taken"],
    "Tomorrow" : "Morgen",
    "Add List…" : "Lijst toevoegen",
    "When shared show full event" : "Toon gehele afspraak wanneer gedeeld",
    "When shared show only busy" : "Toon alleen onbeschikbaarheid wanneer gedeeld",
    "When shared hide this event" : "Verberg deze afspraak wanneer gedeeld",
    "[Completed] L" : "[Afgewerkt] L",
    "[Completed last] dddd [at] LT" : "[Afgelopen] dddd [afgewerkt om] LT",
    "[Completed] dddd [at] LT" : "[Afgewerkt op] L [om] LT",
    "[Last modified yesterday at] LT" : "[Gisteren laatst aangepast om] LT",
    "[Last modified today at] LT" : "[Vandaag laatst aangepast om] LT",
    "[Last modified] L" : "[Laatst gewijzigd] L",
    "[Last modified last] dddd [at] LT" : "[Afgelopen] dddd [laatst aangepast om] LT",
    "[Last modified] dddd [at] LT" : "[Laatst aangepast op] dddd [om] LT",
    "[Created yesterday at] LT" : "[Gisteren aangemaakt om] LT",
    "[Created today at] LT" : "[Vanaag aangemaakt om] LT",
    "[Created] L" : "[Aangemaakt] L",
    "[Created last] dddd [at] LT" : "[Laatst aangemaakt] dddd [om] LT",
    "[Created] dddd [at] LT" : "[Aangemaakt] dddd [om] LT",
    "Needs action" : "Actie vereist",
    "In process" : "In behandeling",
    "Canceled" : "Geannuleerd",
    "Clear status" : "Status leegmaken",
    "Loading task from server." : "Taak van de server aan het laden.",
    "Task not found!" : "Taak niet gevonden!",
    "Set start date" : "Instellen begindatum ",
    "Set due date" : "Vervaldatum instellen",
    "Priority {priority}: low" : "Prioriteit {priority}: laag",
    "Priority {priority}: medium" : "Prioriteit {priority}: gemiddeld",
    "Priority {priority}: high" : "Prioriteit {priority}: hoog",
    "No priority assigned" : "Geen prioriteit toegewezen",
    "{percent} % completed" : "{percent} % gereed",
    "All day" : "Hele dag",
    "Unpin" : "Losmaken",
    "Pin" : "Pin",
    "Show in Calendar" : "In agenda tonen",
    "Details" : "Details",
    "Selecting a classification is forbidden, because the task was shared with you." : "Het kiezen van een cassificatie is niet toegelaten, omdat de taak met u gedeeld was.",
    "Select a classification" : "Selecteer een classificatie",
    "Select a status" : "Selecteer een status",
    "Select tags" : "Kies tags",
    "Notes" : "Notities",
    "Mark as done" : "Markeer als voltooid",
    "No due date assigned" : "Geen vervaldatum toegewezen",
    "[Due yesterday]" : "[Gisteren vervallen]",
    "[Due today]" : "[Vervalt vandaag]",
    "[Due tomorrow]" : "[Vervalt morgen]",
    "[Due] L" : "[Vervalt] L",
    "[Due yesterday at] LT" : "[Gisteren vervallen om] LT",
    "[Due today at] LT" : "[Vervalt vandaag om] LT",
    "[Due tomorrow at] LT" : "[Vervalt morgen om] LT",
    "[Due] L [at] LT" : "[Vervalt op] L [om] LT",
    "No upcoming tasks" : "Geen aanstaande taken",
    "upcoming tasks" : "aanstaande taken",
    "No tasks today" : "Geen taken vandaag",
    "Successfully created the task." : "Taak succesvol aangemaakt",
    "Could not delete the task." : "Kon de taak niet verwijderen.",
    "Synchronizing to the server." : "Synchroniseren met de server.",
    "Task successfully saved to server." : "Taak succesvol opgeslagen naar de server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Kon de taak niet bijwerken omdat die was gewijzigd op de server. Klik om te verversen, lokale wijzigingen worden genegeerd.",
    "Could not update the task." : "Kon de taak niet bewerken.",
    "Successfully updated the task." : "Taak succesvol bijgewerkt.",
    "Task successfully moved to new calendar." : "Taak succesvol verplaatst naar de nieuwe agenda.",
    "An error occurred" : "Er is een fout opgetreden",
    "Create a task" : "Maak een taak aan",
    "Message from {author} in {conversationName}" : "Bericht van {author} in {conversationName}",
    "[Due on] LL" : "[Vervalt op] LL",
    "[Was due yesterday]" : "[Is gisteren vervallen]",
    "[Was due on] LL" : "[Is vervallen op] LL",
    "[Was due today at] LT" : "[Is vandaag vervallen om] LT",
    "[Due on] LL [at] LT" : "[Vervalt op] LL [om] LT",
    "[Was due yesterday at] LT" : "[Is gisteren vervallen om] LT",
    "[Was due on] LL [at] LT" : "[Is vervallen op] LL [om] LT",
    "[Starts today]" : "[Begint vandaag]",
    "[Starts tomorrow]" : "[Begint morgen]",
    "[Starts on] LL" : "[Begint op] LL",
    "[Started yesterday]" : "[Gisteren begonnen]",
    "[Started on] LL" : "[Begonnen op] LL",
    "[Started today at] LT" : "[Vandaag begonnen om] LT",
    "[Starts today at] LT" : "[Begint vandaag om] LT",
    "[Starts tomorrow at] LT" : "[Begint morgen om] LT",
    "[Starts on] LL [at] LT" : "[Begint op] LL [om] LT",
    "[Started yesterday at] LT" : "[Gisteren begonnen om] LT",
    "[Started on] LL [at] LT" : "[Begonnen op] LL [om] LT"
},
"nplurals=2; plural=(n != 1);");
