OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Nadcházející úkoly",
    "Important" : "Důležité",
    "Today" : "Dnes",
    "Week" : "Týden",
    "All" : "Vše",
    "Current" : "Stávající",
    "Completed" : "Dokončeno",
    "Tasks" : "Úkoly",
    "The Tasks app for Nextcloud" : "Aplikace Úkoly pro Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Jakmile je zapnuto, zobrazí se nová nabídky Úkoly v nabídce Nextcloud aplikací. Odtud je možné přidávat a mazat úkoly, upravovat jejich nadpis, popis, data zahájení a termínu a označovat  je jako důležité. Úkoly je možné sdílet mezi uživateli. Úkoly je možné synchronizovat pomocí CalDav (každý seznam úkolů je připojen jako Nextcloud kalendář, pro synchronizaci na místního klienta: Thunderbird, Evolution, KDE Kontact, iCal… – stačí v klientovi přidat kalendář jako vzdálený kalendář). Své úkoly si můžete stáhnout jako ICS soubory pomocí tlačítka stahování u každého kalendáře.",
    "Hidden" : "Skrytý",
    "Visible" : "Viditelný",
    "Automatic" : "Automatický",
    "Tasks settings" : "Nastavení pro Úkoly",
    "Default list" : "Výchozí seznam",
    "Visibility of Smart Collections" : "Viditelnost Inteligenžních kolekcí",
    "Share with users or groups" : "Sdílet s uživateli či skupinami",
    "No users or groups" : "Žádní uživatelé či skupiny",
    "Unable to delete the share." : "Sdílení se nedaří smazat.",
    "Unable to change permissions." : "Oprávnění se nedaří změnit",
    "Can edit" : "Může upravovat",
    "Unshare with {displayName}" : "Přestat sdílet s {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Toto smaže kalendář „{calendar}“ a všechny odpovídající události a úkoly.",
    "This will unshare the calendar \"{calendar}\"." : "Toto zruší sdílení kalendáře „{calendar}“.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Toto smaže seznam „{list}“ a všechny úkoly na něm.",
    "This will unshare the list \"{list}\"." : "Toto zruší sdílení seznamu „{list}“.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendář bude smazán za {countdown} sekundu","Kalendář bude smazán za {countdown} sekundy","Kalendář bude smazán za {countdown} sekund","Kalendář bude smazán za {countdown} sekundy"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Sdílení kalendáře bude zrušeno za {countdown} sekundu","Sdílení kalendáře bude zrušeno za {countdown} sekundy","Sdílení kalendáře bude zrušeno za {countdown} sekund","Sdílení kalendáře bude zrušeno za {countdown} sekundy"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Seznam bude smazán za {countdown} sekundu","Seznam bude smazán za {countdown} sekundy","Seznam bude smazán za {countdown} sekund","Seznam bude smazán za {countdown} sekundy"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Sdílení seznamu bude zrušeno za {countdown} sekundu","Sdílení seznamu bude zrušeno za {countdown} sekundy","Sdílení seznamu bude zrušeno za {countdown} sekund","Sdílení seznamu bude zrušeno za {countdown} sekundy"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Sdíleno s {num} entitou","Sdíleno s {num} entitami","Sdíleno s {num} entitami","Sdíleno s {num} entitami"],
    "Share this calendar" : "Nasdílet tento kalendář",
    "Share this list" : "Nasdílet tento seznam",
    "Calendar link copied to clipboard." : "Odkaz do kalendáře zkopírován do schránky.",
    "List link copied to clipboard." : "Odkaz na seznam zkopírován do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz do kalendáře se nepodařilo zkopírovat do schránky.",
    "List link could not be copied to clipboard." : "Odkaz na seznam se nepodařilo zkopírovat do schránky.",
    "The name \"{calendar}\" is already used." : "Název „{calendar}“ už je používán.",
    "An empty name is not allowed." : "Prázdný název není povolen.",
    "An error occurred, unable to delete the calendar." : "Došlo k chybě, kalendář se nepodařilo smazat.",
    "An error occurred, unable to delete the list." : "Došlo k chybě – seznam se nedaří smazat.",
    "Edit" : "Upravit",
    "Copy private link" : "Zkopírovat soukromý odkaz",
    "Copied" : "Zkopírováno",
    "Cannot copy" : "Nelze kopírovat",
    "Export" : "Exportovat",
    "Delete" : "Smazat",
    "Unshare" : "Zrušit sdílení",
    "List name" : "Název seznamu",
    "Untitled task" : "Nepojmenovaný úkol",
    "Untitled event" : "Nepojmenovaná událost",
    "Untitled journal" : "Nepojmenovaný žurnál",
    "Untitled item" : "Nepojmenovaná položka",
    "Unknown calendar" : "Neznámý kalendář",
    "Could not load deleted calendars and objects" : "Nedaří se načíst smazané kalendáře a objekty",
    "Could not delete calendar or event" : "Kalendář či událost se nepodařilo smazat",
    "Could not restore calendar or event" : "Kalendář nebo událost se nepodařilo obnovit",
    "Do you really want to empty the trash bin?" : "Opravdu chcete koš vyprázdnit?",
    "Empty trash bin" : "Vyprázdnit koš",
    "Trash bin" : "Koš",
    "Loading deleted calendars, tasks and events." : "Načítají se smazané kalendáře, úkoly a události.",
    "You do not have any deleted calendars, tasks or events." : "Nemáte žádné smazané kalendáře, úkoly nebo události.",
    "Name" : "Název",
    "Deleted" : "Smazáno",
    "Restore" : "Obnovit",
    "Delete permanently" : "Trvale odstranit",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Prvky v koši jsou smazány po uplynutí {numDays} dne","Prvky v koši jsou smazány po uplynutí {numDays} dnů","Prvky v koši jsou smazány po uplynutí {numDays} dnů","Prvky v koši jsou smazány po uplynutí {numDays} dnů"],
    "Create reminder" : "Vytvořit připomínku",
    "Update reminder" : "Aktualizovat připomínku",
    "Set a reminder at a custom date and time:" : "Nastavit připomínku na uživatelsky určené datum a čas:",
    "Cancel" : "Storno",
    "This is a todo reminder." : "Toto je připomínka úkolu.",
    "No reminders" : "Žádné připomínky",
    "Notification" : "Upozornění",
    "Email" : "E-mail",
    "Audio notification" : "Zvuková upozornění",
    "Other notification" : "Ostatní upozornění",
    "Edit time" : "Upravit čas",
    "Remove reminder" : "Odebrat připomínku",
    "Add reminder" : "Přidat připomínku",
    "Before the task starts" : "Před zahájením úkolu",
    "Before the task is due" : "Před termínem úkolu",
    "Select date and time" : "Vybrat datum a čas",
    "Go back" : "Jít zpět",
    "Do you want to keep related reminders?" : "Chcete ponechat související připomínky?",
    "Discard reminders" : "Zahodit připomínky",
    "Keep reminders" : "Ponechat připomínky",
    "Set a reminder relative to your tasks start date:" : "Nastavit připomínku vtaženou k datu zahájení úkolu:",
    "Set a reminder relative to your tasks due date:" : "Nastavit připomínku vtaženou k datu termínu úkolu:",
    "before at" : "před v",
    "_second_::_seconds_" : ["sekunda","sekundy","sekund","sekundy"],
    "_minute_::_minutes_" : ["minuta","minuty","minut","minuty"],
    "_hour_::_hours_" : ["hodina","hodiny","hodin","hodiny"],
    "_day_::_days_" : ["den","dny","dnů","dny"],
    "_week_::_weeks_" : ["týden","týdny","týdnů","týdny"],
    "Select a calendar" : "Vybrat kalendář",
    "No calendar matches the search." : "Vyhledávanému neodpovídá žádný z kalendářů.",
    "Set date" : "Nastavit datum",
    "Set time" : "Nastavit čas",
    "Delete date" : "Smazat datum",
    "Click here to add a note." : "Pokud chcete přidat poznámku, klikněte sem.",
    "Set value" : "Nastavit hodnotu",
    "Delete value" : "Smazat hodnotu",
    "Add this as a new tag" : "Přidat toto jako nový štítek",
    "No tag available. Create one!" : "Není k dispozici žádný štítek. Nějaký vytvořte!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} úkolů bylo přidáno do „{calendar}“",
    "Create new tasks" : "Vytvořit nové úkoly",
    "Create {numberOfTasks} tasks from pasted text" : "Vytvořit {numberOfTasks} úkolů z vloženého textu",
    "Create tasks" : "Vytvořit úkoly",
    "Creating new tasks…" : "Vytváření nových úkolů…",
    "Close" : "Zavřít",
    "Delete all completed tasks." : "Smazat všechny dokončené úlohy.",
    "Delete completed tasks." : "Smazat dokončené úkoly.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Smazány všechny dokončené úkoly z kalendáře „{calendar}“.",
    "No errors" : "Bez chyb",
    "Open your browser console for more details" : "Další podrobnosti získáte otevřením konzole webového prohlížeče",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Toto vymaže {taskCount} dokončený úkol a jeho dílčí úkoly z „{calendar}“.","Toto vymaže {taskCount} dokončené úkoly a jejich dílčí úkoly z „{calendar}“.","Toto vymaže {taskCount} dokončených úkolů a jejich dílčí úkoly z „{calendar}“.","Toto vymaže {taskCount} dokončené úkoly a jejich dílčí úkoly z „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nedaří se smazat {failedCount} úkol.","Nedaří se smazat {failedCount} úkoly.","Nedaří se smazat {failedCount} úkolů.","Nedaří se smazat {failedCount} úkoly."],
    "Active filter" : "Aktivní filtr",
    "Filter by tags" : "Filtrovat podle štítků",
    "Select tags to filter by" : "Vybrat štítky pro filtr",
    "Reset filter" : "Resetovat filtr",
    "Add an important task to \"{calendar}\"…" : "Přidat důležitý úkol do „{calendar}“…",
    "Add a task due today to \"{calendar}\"…" : "Přidat úkol s termínem dnes do „{calendar}“…",
    "Add a current task to \"{calendar}\"…" : "Přidat stávající úkol do „{calendar}“…",
    "Add a task to \"{calendar}\"…" : "Přidat úkol do „{calendar}“…",
    "Load the completed tasks of all lists." : "Načíst dokončené úkoly ze všech seznamů.",
    "Loading the completed tasks of all lists might slow down the app." : "Načítání dokončených úkolů ze všech seznamů může aplikaci zpomalit.",
    "Load the completed tasks of list \"{calendar}\"." : "Načíst dokončené úkoly ze seznamu „{calendar}“.",
    "Loading the completed tasks might slow down the app." : "Načítání dokončených úkolů může aplikaci zpomalit.",
    "Relevance" : "Relevantnost",
    "Sort by completed state, due date, priority, start date and summary." : "Seřadit podle stupně dokončenosti, termínu, priority, data zahájení a shrnutí.",
    "Start date" : "Datum počátku",
    "Sort by start date, priority and summary." : "Seřadit podle data, priority a shrnutí.",
    "Due date" : "Datum ukončení",
    "Sort by due date, priority and summary." : "Seřadit podle termínu, priority a shrnutí.",
    "Created date" : "Datum vytvoření",
    "Sort by created date, priority and summary." : "Seřadit podle data vytvoření, priority a shrnutí.",
    "Last modified" : "Naposledy upraveno",
    "Sort by last-modified date, priority and summary." : "Seřadit podle data poslední úpravy, priority a shrnutí.",
    "Completed date" : "Datum dokončení",
    "Sort by completed date, priority and summary." : "Seřadit podle data, priority a shrnutí.",
    "Priority" : "Priorita",
    "Sort by priority and summary." : "Seřadit podle priority a shrnutí.",
    "Alphabetically" : "Abecedně",
    "Sort by summary and priority." : "Seřadit podle shrnutí a priority.",
    "Tags" : "Štítky",
    "Sort by tags." : "Seřadit podle štítků.",
    "Manually" : "Ručně",
    "Sort by manual order." : "Seřadit ručně.",
    "Change sort order" : "Změnit řazení",
    "[Yesterday]" : "[Včera]",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zítra]",
    "[Completed yesterday]" : "[Dokončeno včera]",
    "[Completed today]" : "[Dokončeno dnes]",
    "[Completed tomorrow]" : "[Bude dokončeno zítra]",
    "[Yesterday at] LT" : "[Včera v] LT",
    "[Today at] LT" : "[Dnes v] LT",
    "[Tomorrow at] LT" : "[Zítra v] LT",
    "L [at] LT" : "L [v] LT",
    "[Completed yesterday at] LT" : "[Dokončeno včera v] LT",
    "[Completed today at] LT" : "[Dokončeno dnes v] LT",
    "[Completed tomorrow at] LT" : "[Bude dokončeno zítra v] LT",
    "[Completed] L [at] LT" : "[Dokončeno] L [v] LT",
    "Add a subtask to \"{task}\"…" : "Přidat dílčí úkol k „{task}“…",
    "Task has hidden subtasks" : "Úkol má skryté dílčí úkoly",
    "Task is pinned" : "Úkol je připnut",
    "Task has a note" : "Úkol má poznámku",
    "{complete} % completed" : "{complete}% dokončeno",
    "Add subtask" : "Přidat dílčí úkol",
    "Show subtasks" : "Zobrazit dílčí úkoly",
    "Hide subtasks" : "Skrýt dílčí úkoly",
    "Show closed subtasks" : "Zobrazit uzavřené dílčí úkoly",
    "Hide closed subtasks" : "Skrýt uzavřené dílčí úkoly",
    "Delete task" : "Smazat úkol",
    "Toggle starred" : "Přidat/odebrat označení hvězdičkou",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Úkol má jednu připomínku","Úkol má {n} připomínky","Úkol má {n} připomínek","Úkol má {n} připomínky"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Úkol bude smazán za {countdown} sekundu","Úkol bude smazán za {countdown} sekundy","Úkol bude smazán za {countdown} sekund","Úkol bude smazán za {countdown} sekundy"],
    "Task is cancelled" : "Úkol je zrušen",
    "Task is completed" : "Úkol je dokončen",
    "Task is read-only" : "Úkol je pouze pro čtení",
    "Task is not completed" : "Úkol není dokončen",
    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ bylo přidáno do „{calendar}“",
    "Create a new task" : "Vytvořit nový úkol",
    "Task summary" : "Souhrn úkolu",
    "Create task" : "Vytvořit úkol",
    "Creating the new task…" : "Vytváření nového úkolu…",
    "Open task" : "Otevřít úkol",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončený úkol","%n dokončené úkoly","%n dokončených úkolů","%n dokončené úkoly"],
    "Tomorrow" : "Zítra",
    "An error occurred, unable to create the list." : "Doško k chybě – seznam se nepodařilo vytvořit.",
    "Add List…" : "Přidat seznam…",
    "New list" : "Nový seznam",
    "When shared show full event" : "Když sdíleno zobrazit úplnou událost",
    "When shared show only busy" : "Když sdíleno zobrazit pouze zaneprázdněno",
    "When shared hide this event" : "Když sdíleno skrýt tuto událost",
    "[Completed] L" : "[Dokončeno] L",
    "[Completed last] dddd [at] LT" : "[Dokončeno minulé] dddd [v] LT",
    "[Completed] dddd [at] LT" : "[Dokončeno] dddd [v] LT",
    "[Last modified yesterday at] LT" : "[Naposledy změněno včera v] LT",
    "[Last modified today at] LT" : "[Naposledy změněno dnes v] LT",
    "[Last modified] L" : "[Naposledy změněno] L",
    "[Last modified last] dddd [at] LT" : "[Naposledy změněno] dddd [v] LT",
    "[Last modified] dddd [at] LT" : "[Naposledy změněno] dddd [v] LT",
    "[Created yesterday at] LT" : "[Vytvořeno včera v] LT",
    "[Created today at] LT" : "[Vytvořeno dnes v] LT",
    "[Created] L" : "[Vytvořeno] L",
    "[Created last] dddd [at] LT" : "[Vytvořeno minulé] dddd [v] LT",
    "[Created] dddd [at] LT" : "[Vytvořeno] dddd [v] LT",
    "Needs action" : "Vyžaduje akci",
    "In process" : "V procesu",
    "Canceled" : "Zrušeno",
    "Clear status" : "Vyčistit stav",
    "Loading task from server." : "Načítání úkolů ze serveru.",
    "Task not found!" : "Úkol nenalezen!",
    "Set start date" : "Nastavit počáteční datum",
    "Set due date" : "Nastavit datum termínu",
    "Priority {priority}: low" : "Priorita {priority}: nízká",
    "Priority {priority}: medium" : "Priorita {priority}: střední",
    "Priority {priority}: high" : "Priorita {priority}: vysoká",
    "No priority assigned" : "Nepřiřazena žádná priorita",
    "{percent} % completed" : "{percent} % dokončeno",
    "All day" : "Celý den",
    "Unpin" : "Uvolnit",
    "Pin" : "Připnout",
    "Show in Calendar" : "Zobrazit v kalendáři",
    "Show in Deck" : "Zobrazit v Deck",
    "Edit summary" : "Upravit souhrn",
    "Details" : "Podrobnosti",
    "Selecting a classification is forbidden, because the task was shared with you." : "Nemůžete vybrat stupeň důvěrnosti, protože úkol vám je pouze nasdílen.",
    "Select a classification" : "Vybrat klasifikaci",
    "Select a status" : "Vybrat stav",
    "Set a location" : "Nastavit umístění",
    "Set a URL" : "Nastavit URL",
    "Select tags" : "Výběr štítků",
    "Notes" : "Poznámky",
    "Mark as done" : "Označit jako hotové",
    "No due date assigned" : "Nepřiřazen žádný termín",
    "[Due yesterday]" : "[Termín včera]",
    "[Due today]" : "[Termín dnes]",
    "[Due tomorrow]" : "[Termín zítra]",
    "[Due] L" : "[Termín] L",
    "[Due yesterday at] LT" : "[Termín včera v] LT",
    "[Due today at] LT" : "[Termín dnes v] LT",
    "[Due tomorrow at] LT" : "[Termín zítra v] LT",
    "[Due] L [at] LT" : "[Termín] L [v] LT",
    "No upcoming tasks" : "Žádné nadcházející úkoly",
    "upcoming tasks" : "nadcházející úkoly",
    "No tasks today" : "Na dnešek žádné úkoly",
    "Completion date must be in the past." : "Je třeba, aby datum skončení platnosti bylo v minulosti.",
    "Successfully created the task." : "Úkol úspěšně vytvořen.",
    "Could not delete the task." : "Úkol se nedaří smazat.",
    "Synchronizing to the server." : "Synchronizování se serverem.",
    "Task successfully saved to server." : "Úkol úspěšně uložen na server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Úkol se nepodařilo zaktualizovat, protože byl mezitím změněn na serveru. Kliknutím ho opětovně načtěte. Lokálně provedené změny žel budou ztraceny.",
    "Could not update the task." : "Úkol se nedaří aktualizovat.",
    "Successfully updated the task." : "Úkol úspěšně zaktualizován.",
    "Task successfully moved to new calendar." : "Úkol úspěšně přesunut do nového kalendáře.",
    "An error occurred" : "Došlo k chybě",
    "Create a task" : "Vytvořit úkol",
    "Message from {author} in {conversationName}" : "Zpráva od {author} v {conversationName}",
    "[Due on] LL" : "[Termín] LL",
    "[Was due yesterday]" : "[Termín byl včera]",
    "[Was due on] LL" : "[Termín byl] LL",
    "[Was due today at] LT" : "[Termín byl dnes v] LT",
    "[Due on] LL [at] LT" : "[Termín] LL [v] LT",
    "[Was due yesterday at] LT" : "[Termín byl včera v] LT",
    "[Was due on] LL [at] LT" : "[Termín byl] LL [v] LT",
    "[Starts today]" : "[Začíná dnes]",
    "[Starts tomorrow]" : "[Začíná zítra]",
    "[Starts on] LL" : "[Začíná] LL",
    "[Started yesterday]" : "[Začalo včera]",
    "[Started on] LL" : "[Zahájeno] LL",
    "[Started today at] LT" : "[Zahájeno dnes v] LT",
    "[Starts today at] LT" : "[Začíná dnes v] LT",
    "[Starts tomorrow at] LT" : "[Začíná zítra v] LT",
    "[Starts on] LL [at] LT" : "[Začíná v] LL [v] LT",
    "[Started yesterday at] LT" : "[Zahájeno včera v] LT",
    "[Started on] LL [at] LT" : "[Zahájeno v] LL [v] LT",
    "Midnight on the day the task starts" : "Půlnoc dne kdy úkol začíná",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n den před úkolem v {formattedHourMinute}","%n dny před úkolem v {formattedHourMinute}","%n dnů před úkolem v {formattedHourMinute}","%n dny před úkolem v {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n týden před úkolem v {formattedHourMinute}","%n týdny před úkolem v {formattedHourMinute}","%n týdnů před úkolem v {formattedHourMinute}","%n týdny před úkolem v {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "v den úkolu v {formattedHourMinute}",
    "at the task's start" : "při zahájení úkolu",
    "when the task is due" : "když se blíží termín úkolu",
    "{time} before the task starts" : "{time} před zahájením úkolu",
    "{time} before the task is due" : "{time} před termínem úkolu",
    "{time} after the task starts" : "{time} po zahájení úkolu",
    "{time} after the task is due" : "{time} po termínu úkolu"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
