OC.L10N.register(
    "tasks",
    {
    "Today" : "Today",
    "All" : "Sve",
    "Current" : "Tekuće",
    "Completed" : "Završeno",
    "Can edit" : "Can edit",
    "Edit" : "Uredi",
    "Delete" : "Delete",
    "Unshare" : "Ukini deljenje",
    "Empty trash bin" : "Isprazni kantu",
    "Name" : "Ime",
    "Deleted" : "Obrisano",
    "Delete permanently" : "Obriši zauvek",
    "Cancel" : "Cancel",
    "Close" : "Zatvori",
    "Due date" : "Rok",
    "Tags" : "Oznake",
    "Details" : "Detalji",
    "Notes" : "Beleške"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
