OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tarefas",
    "Important" : "Importante",
    "Today" : "Hoxe",
    "Week" : "Semana",
    "All" : "Todo",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "A aplicación de Tarefas para Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Unha vez activado, aparecerá un novo menú Tarefas no menú de aplicacións Nextcloud. A partir de aí pode engadir e eliminar tarefas, editar o seu título, descrición, datas de inicio e remate e marcalas como importantes. As tarefas pódense compartir entre os usuarios. As tarefas pódense sincronizar usando CalDav (cada lista de tarefas está ligada a un calendario Nextcloud, para sincronizalo co seu cliente local: Thunderbird, Evolution, KDE Kontact, iCal… - abonda engadir o calendario como un calendario remoto no seu cliente). Pode descargar as súas tarefas como ficheiros ICS usando o botón de descarga de cada calendario.",
    "Hidden" : "Agochado",
    "Visible" : "Visíbel",
    "Automatic" : "Automatico",
    "Tasks settings" : "Axustes de Tarefas",
    "Default list" : "Lista predeterminada",
    "Visibility of Smart Collections" : "Visibilidade das coleccións intelixentes",
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "No users or groups" : "Non hai usuarios nin grupos",
    "Unable to delete the share." : "Non é posíbel eliminar a compartición",
    "Unable to change permissions." : "Non é posíbel cambiar os permisos.",
    "Can edit" : "Pode editar",
    "Unshare with {displayName}" : "Deixar de compartir con {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Isto eliminará o calendario «{calendar}» e todos os seus eventos e tarefas correspodentes.",
    "This will unshare the calendar \"{calendar}\"." : "Isto deixará de compartir o calendario «{calendar}».",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Isto eliminará a lista «{list}» e todas as tarefas correspondentes.",
    "This will unshare the list \"{list}\"." : "Isto deixará de compartir a lista «{list}».",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminar o calendario en {countdown} segundo","Eliminar o calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixar de compartir o calendario en {countdown} segundo","Deixar de compartir o calendario en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eliminando a lista en {countdown} segundo","Eliminando a lista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Deixar de compartir a lista en {countdown} segundo","Deixar de compartir a lista en {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidade","Compartido con {num} entidades"],
    "Share this calendar" : "Compartir este calendario",
    "Share this list" : "Compartir esta lista",
    "Calendar link copied to clipboard." : "A ligazón do calendario foi copiada no portapapeis.",
    "List link copied to clipboard." : "A ligazón da lista foi copiada ao portapapeis.",
    "Calendar link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón do calendario no portapapeis.",
    "List link could not be copied to clipboard." : "Non foi posíbel copiar a ligazón da lista no portapapeis.",
    "The name \"{calendar}\" is already used." : "O nome «{calendar}» xa esta a ser usado.",
    "An empty name is not allowed." : "Non está permitido deixar baleiro o campo nome",
    "An error occurred, unable to delete the calendar." : "Produciuse un erro, non é posíbel eliminar o calendario.",
    "An error occurred, unable to delete the list." : "Produciuse un erro, non é posíbel eliminar a lista.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar a ligazón privada",
    "Copied" : "Copiada",
    "Cannot copy" : "Non se pode copiar",
    "Export" : "Exportar",
    "Delete" : "Eliminar",
    "Unshare" : "Deixar de compartir",
    "List name" : "Nome da lista",
    "Untitled task" : "Tarefa sen título",
    "Untitled event" : "Evento sen título",
    "Untitled journal" : "Diario sen título",
    "Untitled item" : "Elemento sen título",
    "Unknown calendar" : "Calendario descoñecido",
    "Could not load deleted calendars and objects" : "Non foi posíbel cargar os calendarios e obxectos eliminados",
    "Could not delete calendar or event" : "Non foi posíbel eliminar o calendario ou o evento",
    "Could not restore calendar or event" : "Non foi posíbel restaurar o calendario ou o evento",
    "Do you really want to empty the trash bin?" : " Confirma que quere baleirar o lixo?",
    "Empty trash bin" : "Baleirar o lixo",
    "Trash bin" : "Cesto do lixo.",
    "Loading deleted calendars, tasks and events." : "Cargando calendarios, tarefas e eventos eliminados.",
    "You do not have any deleted calendars, tasks or events." : "Non ten ningún calendario, tarefa ou evento eliminado.",
    "Name" : "Nome",
    "Deleted" : "Eliminada",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar definitivamente",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Os elementos do cesto do lixo elimínanse após {numDays} día","Os elementos do cesto do lixo elimínanse após {numDays} días"],
    "Create reminder" : "Crear un lembrete",
    "Update reminder" : "Actualizar o lembrete",
    "Set a reminder at a custom date and time:" : "Definir un lembrete nunha data e hora personalizadas:",
    "Cancel" : "Cancelar",
    "This is a todo reminder." : "Este é un lembrete de tarefa pendente",
    "No reminders" : "Non hai lembretes",
    "Notification" : "Notificación",
    "Email" : "Correo-e",
    "Audio notification" : "Notificación de son",
    "Other notification" : "Outra notificación",
    "Edit time" : "Editar a hora",
    "Remove reminder" : "Retirar o lembrete",
    "Add reminder" : "Engadir lembrete",
    "Before the task starts" : "Antes de comezar a tarefa",
    "Before the task is due" : "Antes de que caduque a tarefa",
    "Select date and time" : "Seleccione o día e a hora",
    "Go back" : "Volver",
    "Do you want to keep related reminders?" : "Quere conservar os lembretes relacionados?",
    "Discard reminders" : "Desbotar lembretes",
    "Keep reminders" : "Conservar os lembretes",
    "Set a reminder relative to your tasks start date:" : "Definir un lembrete relativo á data de inicio das súas tarefas:",
    "Set a reminder relative to your tasks due date:" : "Definir un lembrete relativo á data de caducidade das súas tarefas:",
    "before at" : "antes dás",
    "_second_::_seconds_" : ["segundo","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos"],
    "_hour_::_hours_" : ["hora","horas"],
    "_day_::_days_" : ["día","días"],
    "_week_::_weeks_" : ["semana","semanas"],
    "Select a calendar" : "Seleccione un calendario.",
    "No calendar matches the search." : "Ningún calendario coincide coa busca.",
    "Set date" : "Definir a data",
    "Set time" : "Definir a hora",
    "Delete date" : "Eliminar a data",
    "Click here to add a note." : "Prema aquí para engadir unha nota",
    "Set value" : "Definir o valor",
    "Delete value" : "Eliminar o valor",
    "Add this as a new tag" : "Engadir isto como unha nova etiqueta",
    "No tag available. Create one!" : "Non hai ningunha etiqueta dispoñíbel. Cree unha!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "Engadíronse {numberOfTasks} tarefas a «{calendar}»",
    "Create new tasks" : "Crea novas tarefas",
    "Create {numberOfTasks} tasks from pasted text" : "Crear {numberOfTasks} tarefas a partir do texto pegado",
    "Create tasks" : "Crear tarefas",
    "Creating new tasks…" : "Creando novas tarefas…",
    "Close" : "Pechar",
    "Delete all completed tasks." : "Eliminar todas as tarefas completadas.",
    "Delete completed tasks." : "Eliminar as tarefas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminadas todas as tarefas completadas do calendario «{calendar}».",
    "No errors" : "Sen erros",
    "Open your browser console for more details" : "Abra a consola do navegador para obter máis detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Isto eliminará {taskCount} tarefa completada e as súas subtarefas do calendario «{calendar}».","Isto eliminará {taskCount} tarefas completadas e as súas subtarefas do calendario «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Non foi posíbel eliminar {failedCount} tarefa.","Non foi posíbel eliminar {failedCount} tarefas."],
    "Active filter" : "Filtro activo",
    "Filter by tags" : "Filtrar polas etiquetas",
    "Select tags to filter by" : "Seleccionar etiquetas polas que filtrar",
    "Reset filter" : "Restabelecer o filtro",
    "Add an important task to \"{calendar}\"…" : "Engadir unha tarefa importante a «{calendar}»…",
    "Add a task due today to \"{calendar}\"…" : "Engadir unha tarefa que remata hoxe a «{calendar}»…",
    "Add a current task to \"{calendar}\"…" : "Engadir  unha tarefa actual a «{calendar}»…",
    "Add a task to \"{calendar}\"…" : "Engadir unha tarefa a «{calendar}»…",
    "Load the completed tasks of all lists." : "Cargar as tarefas completadas de todas as listas.",
    "Loading the completed tasks of all lists might slow down the app." : "A carga das tarefas completadas de todas as listas pode retardar a aplicación.",
    "Load the completed tasks of list \"{calendar}\"." : "Cargar as tarefas completadas da lista «{calendar}».",
    "Loading the completed tasks might slow down the app." : "A carga das tarefas completadas pode retardar a aplicación.",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenar polo estado de completado, data de remate, prioridade, data de inicio e resumo.",
    "Start date" : "Data de comezo",
    "Sort by start date, priority and summary." : "Ordenar por data de inicio, prioridade e resumo.",
    "Due date" : "Data de remate",
    "Sort by due date, priority and summary." : "Ordenar por data de remate, prioridade e resumo.",
    "Created date" : "Data de creación",
    "Sort by created date, priority and summary." : "Ordenar por data de creación, prioridade e resumo.",
    "Last modified" : "Última modificación",
    "Sort by last-modified date, priority and summary." : "Ordenar por data de última modificación, prioridade e resumo.",
    "Completed date" : "Data de completado",
    "Sort by completed date, priority and summary." : "Ordenar por data de completado, prioridade e resumo.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Ordenar por prioridade e resumo.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por  resumo e prioridade.",
    "Tags" : "Etiquetas",
    "Sort by tags." : "Ordenar polas etiquetas.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar manualmente.",
    "Change sort order" : "Cambiar o criterio de ordenación",
    "[Yesterday]" : "[Onte]",
    "[Today]" : "[Hoxe]",
    "[Tomorrow]" : "[Mañá]",
    "[Completed yesterday]" : "[Completada onte]",
    "[Completed today]" : "[Completada hoxe]",
    "[Completed tomorrow]" : "[Completada mañá]",
    "[Yesterday at] LT" : "[Onte ás] LT",
    "[Today at] LT" : "[Hoxe ás] LT",
    "[Tomorrow at] LT" : "[Mañá ás] LT",
    "L [at] LT" : "L [ás] LT",
    "[Completed yesterday at] LT" : "[Completada onte ás] LT",
    "[Completed today at] LT" : "[Completada hoxe ás] LT",
    "[Completed tomorrow at] LT" : "[Completada mañá ás] LT",
    "[Completed] L [at] LT" : "[Completada] L [ás] LT",
    "Add a subtask to \"{task}\"…" : "Engadir unha subtarefa a «{task}»…",
    "Task has hidden subtasks" : "A tarefa ten subtarefas agochadas",
    "Task is pinned" : "A tarefa está fixada",
    "Task has a note" : "A tarefa ten unha nota",
    "{complete} % completed" : "{complete} % completado",
    "Add subtask" : "Engadir unha subtarefa",
    "Show subtasks" : "Amosar as subtarefas",
    "Hide subtasks" : "Agochar as subtarefas",
    "Show closed subtasks" : "Amosar as subtarefas pechadas",
    "Hide closed subtasks" : "Agocar as subtarefas pechadas",
    "Delete task" : "Eliminar tarefa",
    "Toggle starred" : " Marcar/desmarcar con estrela",
    "_Task has one reminder_::_Task has {n} reminders_" : ["A tarefa ten un lembrete","A tarefa ten {n} lembretes"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Eliminando a tarefa en {countdown} segundo","Eliminando a tarefa en {countdown} segundos"],
    "Task is cancelled" : "A tarefa foi cancelada",
    "Task is completed" : "A tarefa está completada",
    "Task is read-only" : "A tarefa é de só lectura",
    "Task is not completed" : "A tarefa non está completada",
    "\"{task}\" was added to \"{calendar}\"" : "«{task}» foi engdida a «{calendar}»",
    "Create a new task" : "Crear unha nova tarefa",
    "Task summary" : "Resumo da tarefa",
    "Create task" : "Crear tarefa",
    "Creating the new task…" : "Creando unha nova tarefa…",
    "Open task" : "Tarefa aberta",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tarefa completada","%n tarefas completadas"],
    "Tomorrow" : "Mañá",
    "An error occurred, unable to create the list." : "Produciuse un erro, non é posíbel crear a lista.",
    "Add List…" : "Engadir unha lista…",
    "New list" : "Lista nova",
    "When shared show full event" : "Amosar o evento completo ao compartir",
    "When shared show only busy" : "Amosar só o ocupado ao compartir",
    "When shared hide this event" : "Agochar este evento ao compartir",
    "[Completed] L" : "[Completada] L",
    "[Completed last] dddd [at] LT" : "[Completada o último] dddd [ás] LT",
    "[Completed] dddd [at] LT" : "[Completada o] dddd [ás] LT",
    "[Last modified yesterday at] LT" : "[Última modificación onte ás] LT",
    "[Last modified today at] LT" : "[Última modificación hoxe ás] LT",
    "[Last modified] L" : "[Última modificación] L",
    "[Last modified last] dddd [at] LT" : "[Última modificación o pasado] dddd [ás] LT",
    "[Last modified] dddd [at] LT" : "[Última modificación o] dddd [ás] LT",
    "[Created yesterday at] LT" : "[Creada onte ás] LT",
    "[Created today at] LT" : "[Creada hoxe ás] LT",
    "[Created] L" : "[Creada] L",
    "[Created last] dddd [at] LT" : "[Creada o último] dddd [ás] LT",
    "[Created] dddd [at] LT" : "[Creada o] dddd [ás] LT",
    "Needs action" : "Necesita unha acción",
    "In process" : "En proceso",
    "Canceled" : "Cancelado",
    "Clear status" : "Limpar o estado",
    "Loading task from server." : "Cargando tarefas desde o servidor.",
    "Task not found!" : "Non se atopou a tarefa!",
    "Set start date" : "Definir a data de comezo",
    "Set due date" : "Definir a data de remate",
    "Priority {priority}: low" : "Prioridade {priority}: baixa",
    "Priority {priority}: medium" : "Prioridade {priority}: media",
    "Priority {priority}: high" : "Prioridade {priority}: alta",
    "No priority assigned" : "Sen asignar prioridade",
    "{percent} % completed" : "{percent} % completado",
    "All day" : "Todo o día",
    "Unpin" : "Desprender",
    "Pin" : "Fixar",
    "Show in Calendar" : "Amosar no calendario",
    "Show in Deck" : "Amosar na Gabeta",
    "Edit summary" : "Editar o resumo",
    "Details" : "Detalles",
    "Selecting a classification is forbidden, because the task was shared with you." : "Está prohibido seleccionar unha clasificación, porque a tarefa foi compartida contigo.",
    "Select a classification" : "Seleccione unha clasificación",
    "Select a status" : "Seleccionar un estado",
    "Set a location" : "Definir unha localización",
    "Set a URL" : "Definir un URL",
    "Select tags" : "Seleccionar etiquetas",
    "Notes" : "Notas",
    "Mark as done" : "Marcar como feito",
    "No due date assigned" : "Sen data de remate asignada",
    "[Due yesterday]" : "[Rematou onte]",
    "[Due today]" : "[Remata hoxe]",
    "[Due tomorrow]" : "[Remata mañá]",
    "[Due] L" : "[Remata] L",
    "[Due yesterday at] LT" : "[Rematou onte ás] LT",
    "[Due today at] LT" : "[Remata hoxe ás] LT",
    "[Due tomorrow at] LT" : "[Remata mañá ás] LT",
    "[Due] L [at] LT" : "[Remata] LL [ás] LT",
    "No upcoming tasks" : "Non hai tarefas próximas",
    "upcoming tasks" : "próximas tarefas",
    "No tasks today" : "Non hai tarefas para hoxe",
    "Completion date must be in the past." : "A data de conclusión debe ser anterior.",
    "Successfully created the task." : "A tarefa foi creada satisfactoriamente.",
    "Could not delete the task." : "Non foi posíbel eliminar a tarefa",
    "Synchronizing to the server." : "Sincronizando co servidor.",
    "Task successfully saved to server." : "A tarefa foi gardada satisfactoriamente no servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Non foi posíbel actualizar a tarefa porque foi modificada no servidor. Prema para actualizala, os cambios locais serán desbotados.",
    "Could not update the task." : "Non foi posíbel actualizar a tarefa",
    "Successfully updated the task." : "A tarefa foi actualizada satisfactoriamente.",
    "Task successfully moved to new calendar." : "A tarefa foi movida satisfactoriamente ao novo calendario.",
    "An error occurred" : "Produciuse un erro",
    "Create a task" : "Crear unha tarefa",
    "Message from {author} in {conversationName}" : "Mensaxe de {author} en {conversationName}",
    "[Due on] LL" : "[Remata o] LL",
    "[Was due yesterday]" : "[Rematou onte]",
    "[Was due on] LL" : "[Rematou o] LL",
    "[Was due today at] LT" : "[Rematou hoxe ás] LT",
    "[Due on] LL [at] LT" : "[Remata o] LL [ás] LT",
    "[Was due yesterday at] LT" : "[Rematou onte ás] LT",
    "[Was due on] LL [at] LT" : "[Rematou o] LL [ás] LT",
    "[Starts today]" : "[Comeza hoxe]",
    "[Starts tomorrow]" : "[Comeza mañá]",
    "[Starts on] LL" : "[Comeza o] LL",
    "[Started yesterday]" : "[Comezou onte]",
    "[Started on] LL" : "[Comezou o] LL",
    "[Started today at] LT" : "[Comezou hoxe ás] LT",
    "[Starts today at] LT" : "[Comeza hoxe ás] LT",
    "[Starts tomorrow at] LT" : "[Comeza mañá ás] LT",
    "[Starts on] LL [at] LT" : "[Comeza o] LL [ás] LT",
    "[Started yesterday at] LT" : "[Comezou onte ás] LT",
    "[Started on] LL [at] LT" : "[Comezou o] LL [ás] LT",
    "Midnight on the day the task starts" : "Medianoite do día no que comeza a tarefa",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n día antes da tarefa ás {formattedHourMinute}","%n días antes da tarefa ás {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n semana antes da tarefa ás {formattedHourMinute}","%n semanas antes da tarefa ás {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "o día da tarefa ás {formattedHourMinute}",
    "at the task's start" : "no inicio do tarefa",
    "when the task is due" : "Cando caduque a tarefa",
    "{time} before the task starts" : "{time} antes do inicio da tarefa",
    "{time} before the task is due" : "{time} antes de que caduque a tarefa",
    "{time} after the task starts" : "{time} após o inicio da tarefa",
    "{time} after the task is due" : "{time} após que caduque a tarefa"
},
"nplurals=2; plural=(n != 1);");
