OC.L10N.register(
    "tasks",
    {
    "Important" : "សំខាន់",
    "Today" : "ថ្ងៃ​នេះ",
    "Week" : "សប្ដាហ៍",
    "All" : "ទាំងអស់",
    "Tasks" : "ភារកិច្ច",
    "Can edit" : "Can edit",
    "Edit" : "កែប្រែ",
    "Export" : "នាំចេញ",
    "Delete" : "លុប",
    "Unshare" : "លែង​ចែក​រំលែក",
    "Name" : "ឈ្មោះ",
    "Deleted" : "បាន​លុប",
    "Restore" : "ស្ដារ​មក​វិញ",
    "Delete permanently" : "លុប​ជា​អចិន្ត្រៃយ៍",
    "Cancel" : "បោះបង់",
    "Email" : "អ៊ីមែល",
    "Close" : "បិទ",
    "Tags" : "ស្លាក",
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Notes" : "កំណត់​ចំណាំ"
},
"nplurals=1; plural=0;");
