OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tarefas",
    "Important" : "Importante",
    "Today" : "Hoje",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Corrente",
    "Completed" : "Concluído",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "O aplicativo Tarefas para Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Depois da ativação um novo menu Tarefas aparecerá no menu de aplicativos Nextcloud. A partir daí, você pode adicionar e excluir tarefas, editar os títulos, as descrições, as datas de início e vencimento delas e marcá-las como importantes. As tarefas podem ser compartilhadas entre usuários. As tarefas podem ser sincronizadas usando CalDav (cada lista de tarefas está vinculada a um calendário Nextcloud para sincronizá-lo com seu cliente local: Thunderbird, Evolution, KDE Kontact, iCal … - basta adicionar o calendário como um calendário remoto em seu cliente). Você pode baixar suas tarefas como arquivos ICS usando o botão de download de cada calendário.",
    "Hidden" : "Oculto",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Tasks settings" : "Configurações de tarefas",
    "Default list" : "Lista padrão",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "No users or groups" : "Sem usuários ou grupos",
    "Unable to delete the share." : "Não foi possível excluir o compartilhamento.",
    "Unable to change permissions." : "Não foi possível alterar as permissões",
    "Can edit" : "Pode editar",
    "Unshare with {displayName}" : "Descompartilhar com {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Isso excluirá o calendário \"{calendar}\" e todos os eventos e tarefas correspondentes.",
    "This will unshare the calendar \"{calendar}\"." : "Isso irá descompartilhar o calendário \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Issa ação excluirá a lista \"{list}\" e todas as tarefas correspondentes.",
    "This will unshare the list \"{list}\"." : "Essa ação vai descompartilhar a lista \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Excluindo o calendário em {countdown} segundo","Excluindo o calendário em {countdown} segundos","Excluindo o calendário em {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Descompartilhando o calendário em {countdown} segundo","Descompartilhando o calendário em {countdown} segundos","Descompartilhando o calendário em {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Excluindo a lista em {countdown} segundo","Excluindo a lista em {countdown} segundos","Excluindo a lista em {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Descompartilhando a lista em {countdown} segundo","Descompartilhando a lista em {countdown} segundos","Descompartilhando a lista em {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartilhado com {num} entidade","Compartilhado com {num} entidades","Compartilhado com {num} entidades"],
    "Share this calendar" : "Compartilhar este calendário",
    "Share this list" : "Compartilhar esta lista",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "List link copied to clipboard." : "Link para a lista copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "O link do calendário não pôde ser copiado para a área de transferência.",
    "List link could not be copied to clipboard." : "Link para a lista não pôde ser copiado para a área de transferência.",
    "The name \"{calendar}\" is already used." : "O nome \"{calendar}\" já está em uso.",
    "An empty name is not allowed." : "Não é permitido nome em branco",
    "An error occurred, unable to delete the calendar." : "Erro ao excluir o calendário.",
    "An error occurred, unable to delete the list." : "Ocorreu um erro, não foi possível excluir a lista.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar link privado",
    "Copied" : "Copiado",
    "Cannot copy" : "Não pode copiar",
    "Export" : "Exportar",
    "Delete" : "Excluir",
    "Unshare" : "Descompartilhar",
    "List name" : "Nome da lista",
    "Untitled task" : "Tarefa sem título",
    "Untitled event" : "Evento sem título",
    "Untitled journal" : "Diário sem título",
    "Untitled item" : "Item sem título",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos excluídos",
    "Could not delete calendar or event" : "Não foi possível excluir calendário ou evento",
    "Could not restore calendar or event" : "Não foi possível restaurar calendário ou evento",
    "Do you really want to empty the trash bin?" : "Tem certeza de que deseja esvaziar a lixeira?",
    "Empty trash bin" : "Esvaziar lixeira",
    "Trash bin" : "Lixeira",
    "Loading deleted calendars, tasks and events." : "Carregando calendários, tarefas e eventos excluídos.",
    "You do not have any deleted calendars, tasks or events." : "Você não tem calendários, tarefas ou eventos excluídos.",
    "Name" : "Nome",
    "Deleted" : "Excluído",
    "Restore" : "Restaurar",
    "Delete permanently" : "Excluir permanentemente",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Os elementos na lixeira são excluídos após {numDays} dia","Os elementos na lixeira são excluídos após {numDays} dias","Os elementos na lixeira são excluídos após {numDays} dias"],
    "Create reminder" : "Criar lembrete",
    "Update reminder" : "Atualizar lembrete",
    "Set a reminder at a custom date and time:" : "Defina um lembrete em uma data e hora personalizada:",
    "Cancel" : "Cancelar",
    "This is a todo reminder." : "Este é um lembrete de tarefas.",
    "No reminders" : "Nenhum lembrete",
    "Notification" : "Notificação",
    "Email" : "E-mail",
    "Audio notification" : "Notificação por áudio",
    "Other notification" : "Outras notificações",
    "Edit time" : "Editar horário",
    "Remove reminder" : "Remover lembrete",
    "Add reminder" : "Adicionar lembrete",
    "Before the task starts" : "Antes do início da tarefa",
    "Before the task is due" : "Antes do vencimento da tarefa",
    "Select date and time" : "Selecione data e hora",
    "Go back" : "Voltar",
    "Do you want to keep related reminders?" : "Você deseja manter os lembretes relacionados?",
    "Discard reminders" : "Descartar lembretes",
    "Keep reminders" : "Manter lembretes",
    "Set a reminder relative to your tasks start date:" : "Defina um lembrete relativo à data de início da sua tarefa:",
    "Set a reminder relative to your tasks due date:" : "Defina um lembrete relativo à data de vencimento da sua tarefa:",
    "before at" : "antes às",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Select a calendar" : "Selecione um calendário",
    "No calendar matches the search." : "Nenhum calendário corresponde à pesquisa.",
    "Set date" : "Definir data",
    "Set time" : "Definir horário",
    "Delete date" : "Excluir data",
    "Click here to add a note." : "Clique aqui para adicionar uma nota.",
    "Set value" : "Definir valor",
    "Delete value" : "Excluir valor",
    "Add this as a new tag" : "Adicionar isto como uma nova etiqueta",
    "No tag available. Create one!" : "Nenhuma etiqueta disponível. Crie uma!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} tarefas foram adicionadas a \"{calendar}\"",
    "Create new tasks" : "Criar novas tarefas",
    "Create {numberOfTasks} tasks from pasted text" : "Criar {numberOfTasks} tarefas a partir do texto colado",
    "Create tasks" : "Criar tarefas",
    "Creating new tasks…" : "Criando novas tarefas…",
    "Close" : "Fechar",
    "Delete all completed tasks." : "Excluir todas as tarefas concluídas.",
    "Delete completed tasks." : "Excluir tarefas concluídas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Todas as tarefas concluídas foram excluídas do calendário \"{calendar}\".",
    "No errors" : "Sem erros",
    "Open your browser console for more details" : "Abra o console do navegador para mais detalhes",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Isso excluirá {taskCount} tarefa1 concluída e suas subtarefas do calendário \"{calendar}\".","Isso excluirá {taskCount} tarefas concluídas e suas subtarefas do calendário \"{calendar}\".","Isso excluirá {taskCount} tarefas concluídas e suas subtarefas do calendário \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Não foi possível excluir {failedCount} tarefa.","Não foi possível excluir {failedCount} tarefas.","Não foi possível excluir {failedCount} tarefas."],
    "Active filter" : "Filtro ativo",
    "Filter by tags" : "Filtrar por etiquetas",
    "Select tags to filter by" : "Selecione etiquetas para filtrar",
    "Reset filter" : "Redefinir filtro",
    "Add an important task to \"{calendar}\"…" : "Adicionar uma tarefa importante em \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Adicionar uma tarefa para hoje em \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Adicionar uma tarefa atual em \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Adicionar uma tarefa em \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Carregue as tarefas concluídas de todas as listas.",
    "Loading the completed tasks of all lists might slow down the app." : "Carregar as tarefas concluídas de todas as listas pode tornar o aplicativo lento.",
    "Load the completed tasks of list \"{calendar}\"." : "Carregue as tarefas concluídas da lista \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Carregar as tarefas concluídas pode tornar o aplicativo lento.",
    "Relevance" : "Relevância",
    "Sort by completed state, due date, priority, start date and summary." : "Classificar por status, data devida, prioridade, data de início e resumo.",
    "Start date" : "Data de início",
    "Sort by start date, priority and summary." : "Ordenar por data inicial, prioridade e resumo.",
    "Due date" : "Data de vencimento",
    "Sort by due date, priority and summary." : "Ordenar por data de vencimento, prioridade e resumo.",
    "Created date" : "Data de criação",
    "Sort by created date, priority and summary." : "Ordenar por data de criação, prioridade e resumo.",
    "Last modified" : "Última modificação",
    "Sort by last-modified date, priority and summary." : "Ordenar por data de última alteração, prioridade e resumo.",
    "Completed date" : "Data de conclusão",
    "Sort by completed date, priority and summary." : "Ordenar por data de conclusão, prioridade e resumo.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Ordenar por prioridade e resumo.",
    "Alphabetically" : "Alfabeticamente",
    "Sort by summary and priority." : "Ordenar por resumo e prioridade.",
    "Tags" : "Etiquetas",
    "Sort by tags." : "Ordenar por etiquetas.",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar manualmente.",
    "Change sort order" : "Alterar a ordem de classificação",
    "[Yesterday]" : "[Ontem]",
    "[Today]" : "[Hoje]",
    "[Tomorrow]" : "[Amanhã]",
    "[Completed yesterday]" : "[Concluído ontem]",
    "[Completed today]" : "[Concluído hoje]",
    "[Completed tomorrow]" : "[Concluído amanhã]",
    "[Yesterday at] LT" : "[Ontem às] LT",
    "[Today at] LT" : "[Hoje às] LT",
    "[Tomorrow at] LT" : "[Amanhã às] LT",
    "L [at] LT" : "L [às] LT",
    "[Completed yesterday at] LT" : "[Concluído ontem às] LT",
    "[Completed today at] LT" : "[Concluído hoje às] LT",
    "[Completed tomorrow at] LT" : "[Concluído amanhã às] LT",
    "[Completed] L [at] LT" : "[Concluído em] L [às] LT",
    "Add a subtask to \"{task}\"…" : "Adicionar uma subtarefa em \"{task}\"…",
    "Task has hidden subtasks" : "A tarefa tem subtarefas ocultas",
    "Task is pinned" : "Tarefa está fixada",
    "Task has a note" : "A tarefa tem uma nota",
    "{complete} % completed" : "{complete} % completo",
    "Add subtask" : "Adicionar subtarefas",
    "Show subtasks" : "Mostrar subtarefas",
    "Hide subtasks" : "Ocultar subtarefas",
    "Show closed subtasks" : "Mostrar subtarefas concluídas",
    "Hide closed subtasks" : "Ocultar subtarefas concluídas",
    "Delete task" : "Excluir tarefa",
    "Toggle starred" : "Alternar destaque",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Tarefa tem um lembrete","Tarefa tem {n} lembretes","Tarefa tem {n} lembretes"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Excluindo a tarefa em {countdown} segundo","Excluindo a tarefa em {countdown} segundos","Excluindo a tarefa em {countdown} segundos"],
    "Task is cancelled" : "Tarefa foi cancelada",
    "Task is completed" : "Tarefa é concluída",
    "Task is read-only" : "Tarefa é somente leitura",
    "Task is not completed" : "Tarefa não é concluída",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" foi adicionada a \"{calendar}\"",
    "Create a new task" : "Criar uma nova tarefa",
    "Task summary" : "Resumo da tarefa",
    "Create task" : "Criar tarefa",
    "Creating the new task…" : "Criando a nova tarefa…",
    "Open task" : "Abrir tarefa",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas","%n Tarefas Concluídas"],
    "Tomorrow" : "Amanhã",
    "An error occurred, unable to create the list." : "Ocorreu um erro, não foi possível criar a lista.",
    "Add List…" : "Adicionar Lista…",
    "New list" : "Nova lista",
    "When shared show full event" : "Quando compartilhado, mostrar o evento completo",
    "When shared show only busy" : "Quando compartilhado, mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado, ocultar este evento",
    "[Completed] L" : "[Concluído em] L",
    "[Completed last] dddd [at] LT" : "[Concluído último/a] dddd [às] LT",
    "[Completed] dddd [at] LT" : "[Concluído] dddd [às] LT",
    "[Last modified yesterday at] LT" : "[Última modificação ontem às] LT",
    "[Last modified today at] LT" : "[Última modificação hoje às] LT",
    "[Last modified] L" : "[Última modificação] L",
    "[Last modified last] dddd [at] LT" : "[Última modificação último/a] dddd [às] LT ",
    "[Last modified] dddd [at] LT" : "[Última modificação] dddd [às] LT",
    "[Created yesterday at] LT" : "[Criado ontem às] LT",
    "[Created today at] LT" : "[Criado hoje ás] LT",
    "[Created] L" : "[Criado em] L",
    "[Created last] dddd [at] LT" : "[Criado último/a] dddd [às] LT",
    "[Created] dddd [at] LT" : "[Criado] dddd [às] LT",
    "Needs action" : "Necessita ação",
    "In process" : "Em processo",
    "Canceled" : "Cancelado",
    "Clear status" : "Limpar status",
    "Loading task from server." : "Carregando tarefas do servidor.",
    "Task not found!" : "Tarefa não encontrada!",
    "Set start date" : "Definir data de início",
    "Set due date" : "Definir data programada",
    "Priority {priority}: low" : "Prioridade {priority}: baixa",
    "Priority {priority}: medium" : "Prioridade {priority}: média",
    "Priority {priority}: high" : "Prioridade {priority}: alta",
    "No priority assigned" : "Sem prioridade definida",
    "{percent} % completed" : "{percent} % finalizado",
    "All day" : "Dia inteiro",
    "Unpin" : "Desfixar",
    "Pin" : "Fixar",
    "Show in Calendar" : "Mostrar no Calendário",
    "Show in Deck" : "Mostrar no Deck",
    "Edit summary" : "Editar resumo",
    "Details" : "Detalhes",
    "Selecting a classification is forbidden, because the task was shared with you." : "É proibido selecionar uma classificação, pois a tarefa foi compartilhada com você.",
    "Select a classification" : "Selecione uma classificação",
    "Select a status" : "Selecione um status",
    "Set a location" : "Defina um local",
    "Set a URL" : "Defina um URL",
    "Select tags" : "Selecione etiquetas",
    "Notes" : "Notas",
    "Mark as done" : "Marcar como concluído",
    "No due date assigned" : "Sem data de vencimento atribuída",
    "[Due yesterday]" : "[Venceu ontem]",
    "[Due today]" : "[Vence hoje]",
    "[Due tomorrow]" : "[Vencerá amanhã]",
    "[Due] L" : "[Vence em] L",
    "[Due yesterday at] LT" : "[Venceu ontem às] LT",
    "[Due today at] LT" : "[Vence hoje às] LT",
    "[Due tomorrow at] LT" : "[Vencerá amanhã às] LT",
    "[Due] L [at] LT" : "[Vence em] L [às] LT",
    "No upcoming tasks" : "Sem próximas tarefas",
    "upcoming tasks" : "próximas tarefas",
    "No tasks today" : "Sem tarefas hoje",
    "Completion date must be in the past." : "A data de conclusão deve ser no passado.",
    "Successfully created the task." : "Tarefa criada com sucesso.",
    "Could not delete the task." : "Não foi possível excluir a tarefa.",
    "Synchronizing to the server." : "Sincronizando com o servidor.",
    "Task successfully saved to server." : "Tarefa salva no servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Não foi possível atualizar a tarefa porque ela foi alterada no servidor. Clique para atualizá-la. As alterações locais serão descartadas.",
    "Could not update the task." : "Não foi possível atualizar a tarefa.",
    "Successfully updated the task." : "Tarefa atualizada com sucesso.",
    "Task successfully moved to new calendar." : "Tarefa movida para o novo calendário.",
    "An error occurred" : "Ocorreu um erro",
    "Create a task" : "Crie uma tarefa",
    "Message from {author} in {conversationName}" : "Mensagem de {author} em {conversationName}",
    "[Due on] LL" : "[Vence em] LL",
    "[Was due yesterday]" : "[Venceu ontem]",
    "[Was due on] LL" : "[Venceu em] LL",
    "[Was due today at] LT" : "[Venceu hoje às] LT",
    "[Due on] LL [at] LT" : "[Venceu em] LL [às] LT",
    "[Was due yesterday at] LT" : "[Venceu ontem às] LT",
    "[Was due on] LL [at] LT" : "[Venceu em] LL [às] LT",
    "[Starts today]" : "[Iniciará hoje]",
    "[Starts tomorrow]" : "[Iniciará amanhã]",
    "[Starts on] LL" : "[Iniciará em] LL",
    "[Started yesterday]" : "[Iniciou ontem]",
    "[Started on] LL" : "[Iniciou em] LL",
    "[Started today at] LT" : "[Iniciou hoje às] LT",
    "[Starts today at] LT" : "[Iniciará hoje às] LT",
    "[Starts tomorrow at] LT" : "[Iniciará amanhã às] LT",
    "[Starts on] LL [at] LT" : "[Iniciará em] LL [às] LT",
    "[Started yesterday at] LT" : "[Iniciou ontem às] LT",
    "[Started on] LL [at] LT" : "[Iniciou em] LL [às] LT",
    "Midnight on the day the task starts" : "Meia-noite do dia em que a tarefa começa",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n dia antes da tarefa, às {formattedHourMinute}","%n dias antes da tarefa, às {formattedHourMinute}","%n dias antes da tarefa, às {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n semana antes da tarefa, às {formattedHourMinute}","%n semanas antes da tarefa, às {formattedHourMinute}","%n semanas antes da tarefa, às {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "no dia da tarefa, às {formattedHourMinute}",
    "at the task's start" : "no início da tarefa",
    "when the task is due" : "no vencimento da tarefa",
    "{time} before the task starts" : "{time} antes do início da tarefa",
    "{time} before the task is due" : "{time} antes do vencimento da tarefa",
    "{time} after the task starts" : "{time} depois do início da tarefa",
    "{time} after the task is due" : "{time} depois do vencimento da tarefa"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
