OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tareas próximas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "La aplicación Tareas para Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Una vez habilitada, aparecerá un nuevo menú de Tareas en el menú de aplicaciones de Nextcloud. Desde allí, podrás agregar y eliminar tareas, editar su título, descripción, fechas de inicio y vencimiento, y marcarlas como importantes. Las tareas se pueden compartir entre usuarios. Las tareas se pueden sincronizar mediante CalDav (cada lista de tareas está vinculada a un calendario de Nextcloud, para sincronizarlo con tu cliente local: Thunderbird, Evolution, KDE Kontact, iCal, etc. - simplemente agrega el calendario como un calendario remoto en tu cliente). Puedes descargar tus tareas como archivos ICS usando el botón de descarga para cada calendario.",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Tasks settings" : "Configuración de Tareas",
    "Default list" : "Lista predeterminada",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "Sin usuarios ni grupos",
    "Unable to delete the share." : "No se pudo eliminar el recurso compartido.",
    "Unable to change permissions." : "No se pudieron cambiar los permisos.",
    "Can edit" : "Puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Esto eliminará el calendario \"{calendar}\" y todos los eventos y tareas correspondientes.",
    "This will unshare the calendar \"{calendar}\"." : "Esto dejará de compartir el calendario \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Esto eliminará la lista \"{list}\" y todas las tareas correspondientes.",
    "This will unshare the list \"{list}\"." : "Esto dejará de compartir la lista \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejar de compartir el calendario en {countdown} segundo","Dejar de compartir el calendario en {countdown} segundos","Dejar de compartir el calendario en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eliminando la lista en {countdown} segundo","Eliminando la lista en {countdown} segundos","Eliminando la lista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Dejando de compartir la lista en {countdown} segundo","Dejando de compartir la lista en {countdown} segundos","Dejando de compartir la lista en {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Share this calendar" : "Compartir este calendario",
    "Share this list" : "Compartir esta lista",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "List link copied to clipboard." : "Enlace de la lista copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
    "List link could not be copied to clipboard." : "No se pudo copiar el enlace de la lista al portapapeles.",
    "The name \"{calendar}\" is already used." : "El nombre \"{calendar}\" ya está en uso.",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "An error occurred, unable to delete the calendar." : "Ocurrió un error, no se pudo eliminar el calendario.",
    "An error occurred, unable to delete the list." : "Se produjo un error, no se pudo eliminar la lista.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar enlace privado",
    "Copied" : "Copiado",
    "Cannot copy" : "No se puede copiar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "List name" : "Nombre de la lista",
    "Untitled task" : "Tarea sin título",
    "Untitled event" : "Evento sin título",
    "Untitled journal" : "Diario sin título",
    "Untitled item" : "Elemento sin título",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se pudieron cargar los calendarios y objetos eliminados",
    "Could not delete calendar or event" : "No se pudo eliminar el calendario o el evento",
    "Could not restore calendar or event" : "No se pudo restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿Realmente deseas vaciar la papelera?",
    "Empty trash bin" : "Eliminar papelera de reciclaje",
    "Trash bin" : "Papelera",
    "Loading deleted calendars, tasks and events." : "Cargando calendarios, tareas y eventos eliminados.",
    "You do not have any deleted calendars, tasks or events." : "No tienes calendarios, tareas o eventos eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera se eliminan después de {numDays} día","Los elementos en la papelera se eliminan después de {numDays} días","Los elementos en la papelera se eliminan después de {numDays} días"],
    "Cancel" : "Cancelar",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otra notificación",
    "Edit time" : "Editar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "Add reminder" : "Agregar recordatorio",
    "Go back" : "Regresar",
    "before at" : "antes a las",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Select a calendar" : "Seleccionar un calendario",
    "No calendar matches the search." : "Ningún calendario coincide con la búsqueda.",
    "Set date" : "Establecer fecha",
    "Set time" : "Establecer hora",
    "Delete date" : "Eliminar fecha",
    "Click here to add a note." : "Haz clic aquí para agregar una nota.",
    "Set value" : "Establecer valor",
    "Delete value" : "Eliminar valor",
    "Add this as a new tag" : "Agregar esto como una nueva etiqueta",
    "No tag available. Create one!" : "No hay etiquetas disponibles. ¡Crea una!",
    "Close" : "Cerrar",
    "Delete all completed tasks." : "Eliminar todas las tareas completadas.",
    "Delete completed tasks." : "Eliminar tareas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminadas todas las tareas completadas del calendario \"{calendar}\".",
    "No errors" : "Sin errores",
    "Open your browser console for more details" : "Abre la consola de tu navegador para obtener más detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Esto eliminará {taskCount} tarea completada y sus subtareas del calendario \"{calendar}\".","Esto eliminará {taskCount} tareas completadas y sus subtareas del calendario \"{calendar}\".","Esto eliminará {taskCount} tareas completadas y sus subtareas del calendario \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No se pudo eliminar {failedCount} tarea.","No se pudieron eliminar {failedCount} tareas.","No se pudieron eliminar {failedCount} tareas."],
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Add an important task to \"{calendar}\"…" : "Agregar una tarea importante a \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Agregar una tarea con vencimiento para hoy a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Agregar una tarea actual a \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Agregar una tarea a \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Cargar las tareas completadas de todas las listas.",
    "Loading the completed tasks of all lists might slow down the app." : "Cargar las tareas completadas de todas las listas puede ralentizar la aplicación.",
    "Load the completed tasks of list \"{calendar}\"." : "Cargar las tareas completadas de la lista \"{calendar}\".",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenar por estado completado, fecha de vencimiento, prioridad, fecha de inicio y resumen.",
    "Start date" : "Fecha de inicio",
    "Sort by start date, priority and summary." : "Ordenar por fecha de inicio, prioridad y resumen.",
    "Due date" : "Fecha de vencimiento",
    "Sort by due date, priority and summary." : "Ordenar por fecha de vencimiento, prioridad y resumen.",
    "Created date" : "Fecha de creación",
    "Sort by created date, priority and summary." : "Ordenar por fecha de creación, prioridad y resumen.",
    "Last modified" : "Última modificación",
    "Sort by last-modified date, priority and summary." : "Ordenar por fecha de última modificación, prioridad y resumen.",
    "Completed date" : "Fecha de completado",
    "Sort by completed date, priority and summary." : "Ordenar por fecha de completado, prioridad y resumen.",
    "Priority" : "Prioridad",
    "Sort by priority and summary." : "Ordenar por prioridad y resumen.",
    "Alphabetically" : "Alfabéticamente",
    "Sort by summary and priority." : "Ordenar por resumen y prioridad.",
    "Tags" : "Etiquetas",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordenar por orden manual.",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "[Yesterday]" : "[Ayer]",
    "[Today]" : "[Hoy]",
    "[Tomorrow]" : "[Mañana]",
    "[Completed yesterday]" : "[Completada ayer]",
    "[Completed today]" : "[Completada hoy]",
    "[Completed tomorrow]" : "[Completada mañana]",
    "[Yesterday at] LT" : "[Ayer a las] LT",
    "[Today at] LT" : "[Hoy a las] LT",
    "[Tomorrow at] LT" : "[Mañana a las] LT",
    "L [at] LT" : "L [a las] LT",
    "[Completed yesterday at] LT" : "[Completada ayer a las] LT",
    "[Completed today at] LT" : "[Completada hoy a las] LT",
    "[Completed tomorrow at] LT" : "[Completada mañana a las] LT",
    "[Completed] L [at] LT" : "[Completada] L [a las] LT",
    "Add a subtask to \"{task}\"…" : "Agregar una subtarea a \"{task}\"…",
    "Task has hidden subtasks" : "La tarea tiene subtareas ocultas",
    "Task is pinned" : "La tarea está fijada",
    "Task has a note" : "La tarea tiene una nota",
    "{complete} % completed" : "{complete} % completado",
    "Add subtask" : "Agregar subtarea",
    "Show subtasks" : "Mostrar subtareas",
    "Hide subtasks" : "Ocultar subtareas",
    "Show closed subtasks" : "Mostrar subtareas cerradas",
    "Hide closed subtasks" : "Ocultar subtareas cerradas",
    "Delete task" : "Eliminar tarea",
    "Toggle starred" : "Alternar marcado",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Eliminando la tarea en {countdown} segundo","Eliminando la tarea en {countdown} segundos","Eliminando la tarea en {countdown} segundos"],
    "Task is cancelled" : "La tarea está cancelada",
    "Task is completed" : "La tarea ha sido completada",
    "Task is read-only" : "La tarea es de solo lectura",
    "Task is not completed" : "La tarea no está completada",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" fue agregada a \"{calendar}\"",
    "Create a new task" : "Crear una nueva tarea",
    "Task summary" : "Resumen de la tarea",
    "Create task" : "Crear tarea",
    "Creating the new task…" : "Creando la nueva tarea…",
    "Open task" : "Tarea abierta",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Add List…" : "Agregar lista…",
    "New list" : "Nueva lista",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "[Completed] L" : "[Completada] L",
    "[Completed last] dddd [at] LT" : "[Completada la última] dddd [a las] LT",
    "[Completed] dddd [at] LT" : "[Completada] dddd [a las] LT",
    "[Last modified yesterday at] LT" : "[Última modificación ayer a las] LT",
    "[Last modified today at] LT" : "[Última modificación hoy a las] LT",
    "[Last modified] L" : "[Última modificación] L",
    "[Last modified last] dddd [at] LT" : "[Última modificación la última] dddd [a las] LT",
    "[Last modified] dddd [at] LT" : "[Última modificación] dddd [a las] LT",
    "[Created yesterday at] LT" : "[Creada ayer a las] LT",
    "[Created today at] LT" : "[Creada hoy a las] LT",
    "[Created] L" : "[Creada] L",
    "[Created last] dddd [at] LT" : "[Creada la última] dddd [a las] LT",
    "[Created] dddd [at] LT" : "[Creada] dddd [a las] LT",
    "Needs action" : "Requiere acción",
    "In process" : "En proceso",
    "Canceled" : "Cancelada",
    "Clear status" : "Limpiar estado",
    "Loading task from server." : "Cargando tarea desde el servidor.",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "Priority {priority}: low" : "Prioridad {priority}: baja",
    "Priority {priority}: medium" : "Prioridad {priority}: media",
    "Priority {priority}: high" : "Prioridad {priority}: alta",
    "No priority assigned" : "Sin prioridad asignada",
    "{percent} % completed" : "{percent} % completada",
    "All day" : "Todo el día",
    "Unpin" : "Desanclar",
    "Pin" : "Anclar",
    "Show in Calendar" : "Mostrar en el calendario",
    "Details" : "Detalles",
    "Selecting a classification is forbidden, because the task was shared with you." : "Seleccionar una clasificación está prohibido, porque la tarea fue compartida contigo.",
    "Select a classification" : "Seleccionar una clasificación",
    "Select a status" : "Seleccionar un estado",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Mark as done" : "Marcar como hecha",
    "No due date assigned" : "Sin fecha de vencimiento asignada",
    "[Due yesterday]" : "[Vencida ayer]",
    "[Due today]" : "[Vence hoy]",
    "[Due tomorrow]" : "[Vence mañana]",
    "[Due] L" : "[Vence] L",
    "[Due yesterday at] LT" : "[Vencida ayer a las] LT",
    "[Due today at] LT" : "[Vence hoy a las] LT",
    "[Due tomorrow at] LT" : "[Vence mañana a las] LT",
    "[Due] L [at] LT" : "[Vence] L [a las] LT",
    "No upcoming tasks" : "No hay tareas próximas",
    "upcoming tasks" : "tareas próximas",
    "No tasks today" : "Sin tareas para hoy",
    "Successfully created the task." : "Tarea creada exitosamente.",
    "Could not delete the task." : "No se pudo eliminar la tarea.",
    "Synchronizing to the server." : "Sincronizando con el servidor.",
    "Task successfully saved to server." : "Tarea guardada exitosamente en el servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No se pudo actualizar la tarea porque se cambió en el servidor. Haz clic para actualizarla, los cambios locales se descartarán.",
    "Could not update the task." : "No se pudo actualizar la tarea.",
    "Successfully updated the task." : "Tarea actualizada exitosamente.",
    "Task successfully moved to new calendar." : "Tarea movida exitosamente a un nuevo calendario.",
    "An error occurred" : "Se produjo un error",
    "Create a task" : "Crear una tarea",
    "Message from {author} in {conversationName}" : "Mensaje de {author} en {conversationName}",
    "[Due on] LL" : "[Vence el] LL",
    "[Was due yesterday]" : "[Venció ayer]",
    "[Was due on] LL" : "[Venció el] LL",
    "[Was due today at] LT" : "[Venció hoy a las] LT",
    "[Due on] LL [at] LT" : "[Vence el] LL [a las] LT",
    "[Was due yesterday at] LT" : "[Venció ayer a las] LT",
    "[Was due on] LL [at] LT" : "[Venció el] LL [a las] LT",
    "[Starts today]" : "[Comienza hoy]",
    "[Starts tomorrow]" : "[Comienza mañana]",
    "[Starts on] LL" : "[Comienza el] LL",
    "[Started yesterday]" : "[Comenzó ayer]",
    "[Started on] LL" : "[Comenzó el] LL",
    "[Started today at] LT" : "[Comenzó hoy a las] LT",
    "[Starts today at] LT" : "[Comienza hoy a las] LT",
    "[Starts tomorrow at] LT" : "[Comienza mañana a las] LT",
    "[Starts on] LL [at] LT" : "[Comienza el] LL [a las] LT",
    "[Started yesterday at] LT" : "[Comenzó ayer a las] LT",
    "[Started on] LL [at] LT" : "[Comenzó el] LL [a las] LT"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
