OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Kommende opgaver",
    "Important" : "Vigtigt",
    "Today" : "I dag",
    "Week" : "Uge",
    "All" : "Alle",
    "Current" : "Nuværende",
    "Completed" : "Fuldført",
    "Tasks" : "Opgaver",
    "The Tasks app for Nextcloud" : "Opgaver-appen til Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Når den er aktiveret, vises en ny opgavemenu i din Nextcloud-apps-menu. Derfra kan du tilføje og slette opgaver, redigere deres titel, beskrivelse, start- og forfaldsdatoer og markere dem som vigtige. Opgaver kan deles mellem brugere. Opgaver kan synkroniseres ved hjælp af CalDav (hver opgaveliste er knyttet til en Nextcloud-kalender, for at synkronisere den til din lokale klient: Thunderbird, Evolution, KDE Kontact, iCal … - bare tilføj kalenderen som en fjernkalender i din klient). Du kan downloade dine opgaver som ICS-filer ved at bruge download-knappen for hver kalender.",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Tasks settings" : "Opgaveindstillinger",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Synlighed for smarte samlinger",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kan ikke ændre tilladelser.",
    "Can edit" : "Kan redigere",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Dette vil slette kalenderen \"{calendar}\" og alle tilsvarende begivenheder og opgaver.",
    "This will unshare the calendar \"{calendar}\"." : "Dette vil fjerne deling af kalenderen \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Dette vil slette listen \"{list}\" og alle tilsvarende opgaver.",
    "This will unshare the list \"{list}\"." : "Dette vil fjerne deling af listen \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling af kalenderen om {countdown} sekund","Fjerner deling af kalenderen om {countdown} sekunder"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sletter listen om {countdown} sekund","Sletter listen om {countdown} sekunder"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Ophæver deling af listen om {countdown} sekund","Ophæver deling af listen om {countdown} sekunder"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} enhed","Delt med {num} enheder"],
    "Share this calendar" : "Del denne kalender",
    "Share this list" : "Del denne liste",
    "Calendar link copied to clipboard." : "Kalender link kopieret.",
    "List link copied to clipboard." : "Listelink kopieret til udklipsholder.",
    "Calendar link could not be copied to clipboard." : "Kalender link kunne ikke kopieres.",
    "List link could not be copied to clipboard." : "Listelinket kunne ikke kopieres til udklipsholderen.",
    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede brugt.",
    "An empty name is not allowed." : "Et tomt navn er ikke tilladt.",
    "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
    "An error occurred, unable to delete the list." : "Der opstod en fejl. Listen kunne ikke slettes.",
    "Edit" : "Redigér",
    "Copy private link" : "Kopier privat link",
    "Copied" : "opieret",
    "Cannot copy" : "Kan ikke kopiere",
    "Export" : "Eksportér",
    "Delete" : "Slet",
    "Unshare" : "Fjern deling",
    "List name" : "Listenavn",
    "Untitled task" : "Unavngivet opgave",
    "Untitled event" : "Unavngiven begivenhed",
    "Untitled journal" : "Unavngivet journal",
    "Untitled item" : "Unavngiven element",
    "Unknown calendar" : "Ukendt kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke indlæse slettede kalendere og objekter",
    "Could not delete calendar or event" : "Kunne ikke slette kalender eller begivenhed",
    "Could not restore calendar or event" : "Kunne ikke gendanne kalender eller begivenhed",
    "Do you really want to empty the trash bin?" : "Vil du virkelig tømme skraldespanden?",
    "Empty trash bin" : "Tøm papirkurv",
    "Trash bin" : "Skraldespand",
    "Loading deleted calendars, tasks and events." : "Indlæser slettede kalendere, opgaver og begivenheder.",
    "You do not have any deleted calendars, tasks or events." : "Du har ingen slettede kalendere, opgaver eller begivenheder.",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gendan",
    "Delete permanently" : "Slet permanent",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elementer i papirkurven slettes efter {numDays} dag","Elementer i papirkurven slettes efter {numDays} dage"],
    "Cancel" : "Annuller",
    "Email" : "E-mail",
    "Audio notification" : "Lydmeddelelse",
    "Other notification" : "Anden meddelelse",
    "Edit time" : "Redigér tid",
    "Remove reminder" : "Fjern påmindelse",
    "Add reminder" : "Tilføj påmindelse",
    "Go back" : "Gå tilbage",
    "before at" : "før kl",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minutter"],
    "_hour_::_hours_" : ["time","timer"],
    "_day_::_days_" : ["dag","dage"],
    "_week_::_weeks_" : ["uge","uger"],
    "Select a calendar" : "Vælg en kalender",
    "No calendar matches the search." : "Ingen kalender matcher søgningen.",
    "Set date" : "Indstil dato",
    "Set time" : "Indstil tid",
    "Delete date" : "Slet dato",
    "Click here to add a note." : "Klik her for at tilføje en note.",
    "Set value" : "Indstil værdi",
    "Delete value" : "Slet værdi",
    "Add this as a new tag" : "Tilføj dette som et nyt tag",
    "No tag available. Create one!" : "Intet tag tilgængeligt. Lav et!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} opgaver er blevet tilføjet til \"{calendar}\"",
    "Create new tasks" : "Opret en nye opgaver",
    "Create {numberOfTasks} tasks from pasted text" : "Opret {numberOfTasks} opgaver ud fra indsat tekst",
    "Create tasks" : "Opret opgaver",
    "Creating new tasks…" : "Opretter nye opgaver...",
    "Close" : "Luk",
    "Delete all completed tasks." : "Slet alle udførte opgaver.",
    "Delete completed tasks." : "Slet udførte opgaver.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slettede alle udførte opgaver fra kalenderen \"{calendar}\".",
    "No errors" : "Ingen fejl",
    "Open your browser console for more details" : "Åbn din browsers konsol for flejre detaljer",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Dette vil slette {taskCount} fuldført opgave og deres underopgaver fra kalenderen \"{calendar}\".","Dette vil slette {taskCount} fuldførte opgaver og deres underopgaver fra kalenderen \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunne ikke slette {failedCount} opgave.","Kunne ikke slette {failedCount} opgaver."],
    "Active filter" : "Aktivt filter",
    "Filter by tags" : "Filtrer via tags",
    "Select tags to filter by" : "Vælg de mærker, der skal filtreres efter",
    "Reset filter" : "Nulstil filter",
    "Add an important task to \"{calendar}\"…" : "Føj en vigtig opgave til \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Tilføj en opgave i dag til \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Føj en aktuel opgave til \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Føj en opgave til \"{calendar}\"...",
    "Load the completed tasks of all lists." : "Indlæs de udførte opgaver på alle lister.",
    "Loading the completed tasks of all lists might slow down the app." : "Indlæsning af udførte opgaver på alle lister kan gøre appen langsommere.",
    "Load the completed tasks of list \"{calendar}\"." : "Indlæs de udførte opgaver på liste \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Indlæsning af de udførte opgaver kan gøre appen langsommere.",
    "Relevance" : "Relevans",
    "Sort by completed state, due date, priority, start date and summary." : "Sorter efter afsluttet tilstand, forfaldsdato, prioritet, startdato og oversigt.",
    "Start date" : "Start dato",
    "Sort by start date, priority and summary." : "Sorter efter start dato, prioritet og oversigt.",
    "Due date" : "Forfaldsdato",
    "Sort by due date, priority and summary." : "Sorter efter afleverings dato, prioritet og oversigt.",
    "Created date" : "Oprettelsesdato",
    "Sort by created date, priority and summary." : "Sorter efter oprettet dato, prioritet og oversigt.",
    "Last modified" : "Sidst ændret",
    "Sort by last-modified date, priority and summary." : "Sorter efter sidste ændringsdato, prioritet og oversigt.",
    "Completed date" : "Fuldført dato",
    "Sort by completed date, priority and summary." : "Sorter efter afsluttet dato, prioritet og oversigt.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Sorter efter prioritet og oversigt.",
    "Alphabetically" : "Alfabetisk",
    "Sort by summary and priority." : "Sorter efter oversigt og prioritet.",
    "Tags" : "Tags",
    "Sort by tags." : "Sorter efter tags.",
    "Manually" : "Manuelt",
    "Sort by manual order." : "Sorter efter manuel rækkefølge.",
    "Change sort order" : "Skift sorteringsrækkefølge",
    "[Yesterday]" : "[Yesterday]",
    "[Today]" : "[i dag]",
    "[Tomorrow]" : "[I Morgen]",
    "[Completed yesterday]" : "[Afsluttet i går]",
    "[Completed today]" : "[Afsluttet i dag]",
    "[Completed tomorrow]" : "[Udført i morgen]",
    "[Yesterday at] LT" : "[I går kl.] LT",
    "[Today at] LT" : "[I dag kl.] LT",
    "[Tomorrow at] LT" : "[I morgen kl.] LT",
    "L [at] LT" : "L [kl.] LT",
    "[Completed yesterday at] LT" : "[Afsluttet i går kl.] LT",
    "[Completed today at] LT" : "[Afsluttet i dag kl.] LT",
    "[Completed tomorrow at] LT" : "[Afsluttet i morgen kl.] LT",
    "[Completed] L [at] LT" : "[Afsluttet] L [kl.] LT",
    "Add a subtask to \"{task}\"…" : "Føj en underopgave til \"{task}\"...",
    "Task has hidden subtasks" : "Opgaven har skjulte underopgaver",
    "Task is pinned" : "Opgaven er fastgjort",
    "Task has a note" : "Opgaven har en note",
    "{complete} % completed" : "{complete} % fuldført",
    "Add subtask" : "Tilføj underopgave",
    "Show subtasks" : "Vis underopgaver",
    "Hide subtasks" : "Skjul underopgaver",
    "Show closed subtasks" : "Vis lukkede underopgaver",
    "Hide closed subtasks" : "Skjul lukkede underopgaver",
    "Delete task" : "Slet opgave",
    "Toggle starred" : "Toggle stjernemarkeret",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Task has one reminder","Opgaven har {n} påmindelser"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Sletter opgaven om {countdown} sekund","Sletter opgaven om {countdown} sekunder"],
    "Task is cancelled" : "Opgaven er annulleret",
    "Task is completed" : "Denne opgave er udført",
    "Task is read-only" : "Opgaven er skrivebeskyttet",
    "Task is not completed" : "Opgaven er ikke fuldført",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" blev føjet til \"{calendar}\"",
    "Create a new task" : "Opret en ny opgave",
    "Task summary" : "Opgaveoversigt",
    "Create task" : "Opret opgave",
    "Creating the new task…" : "Opretter den nye opgave...",
    "Open task" : "Åben opgave",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n fuldført opgave","%n fuldførte opgaver"],
    "Tomorrow" : "I morgen",
    "An error occurred, unable to create the list." : "Der opstod en fejl, og listen kunne ikke oprettes.",
    "Add List…" : "Tilføj liste...",
    "New list" : "Ny liste",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "[Completed] L" : "[Udført] L",
    "[Completed last] dddd [at] LT" : "[Fuldført sidst] dddd [kl.] LT",
    "[Completed] dddd [at] LT" : "[Udført] dddd [kl.] LT",
    "[Last modified yesterday at] LT" : "[Sidst ændret i går kl.] LT",
    "[Last modified today at] LT" : "[Sidst ændret i dag kl.] LT",
    "[Last modified] L" : "[Sidst ændret] L",
    "[Last modified last] dddd [at] LT" : "[Sidst ændret sidst] dddd [kl.] LT",
    "[Last modified] dddd [at] LT" : "[Sidst ændret] dddd [kl.] LT",
    "[Created yesterday at] LT" : "[Oprettet i går kl.] LT",
    "[Created today at] LT" : "[Oprettet i dag kl.] LT",
    "[Created] L" : "[Oprettet] L",
    "[Created last] dddd [at] LT" : "[Oprettet sidst] dddd [kl.] LT",
    "[Created] dddd [at] LT" : "[Oprettet] dddd [kl.] LT",
    "Needs action" : "Handling påkrævet",
    "In process" : "Under behandling",
    "Canceled" : "Annulleret",
    "Clear status" : "Ryd status",
    "Loading task from server." : "Indlæser opgave fra server.",
    "Task not found!" : "Opgaven blev ikke fundet!",
    "Set start date" : "Angiv startdato",
    "Set due date" : "Angiv en forfaldsdato",
    "Priority {priority}: low" : "Prioritet {priority}: lav",
    "Priority {priority}: medium" : "Prioritet {priority}: medium",
    "Priority {priority}: high" : "Prioritet {priority}: høj",
    "No priority assigned" : "Ingen prioritet tildelt",
    "{percent} % completed" : "{percent} % fuldført",
    "All day" : "Hele dagen",
    "Unpin" : "Frigør",
    "Pin" : "Fastgør",
    "Show in Calendar" : "Vis i Kalender",
    "Show in Deck" : "Vis i Opslag",
    "Edit summary" : "Redigér oversigt",
    "Details" : "Detaljer",
    "Selecting a classification is forbidden, because the task was shared with you." : "Det er forbudt at vælge en klassifikation, fordi opgaven blev delt med dig.",
    "Select a classification" : "Vælg en klassifikation",
    "Select a status" : "Vælg en status",
    "Set a location" : "Sæt en placering",
    "Set a URL" : "Sæt en URL",
    "Select tags" : "Vælg tags",
    "Notes" : "Noter",
    "Mark as done" : "Marker som færdig",
    "No due date assigned" : "Ingen forfaldsdato tildelt",
    "[Due yesterday]" : "[Forfaldt i går]",
    "[Due today]" : "[Forfalder i dag]",
    "[Due tomorrow]" : "[Forfalder i morgen]",
    "[Due] L" : "[Forfalder] L",
    "[Due yesterday at] LT" : "[Forfaldt i går kl.] LT",
    "[Due today at] LT" : "[Forfalder i dag kl.] LT",
    "[Due tomorrow at] LT" : "[Forfalder i morgen kl.] LT",
    "[Due] L [at] LT" : "[Forfalder] L [kl.] LT",
    "No upcoming tasks" : "Ingen kommende opgaver",
    "upcoming tasks" : "kommende opgaver",
    "No tasks today" : "Ingen opgaver i dag",
    "Successfully created the task." : "Opgaven blev oprettet.",
    "Could not delete the task." : "Opgaven kunne ikke slettes.",
    "Synchronizing to the server." : "Synkroniserer til serveren.",
    "Task successfully saved to server." : "Opgaven blev gemt på serveren.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Kunne ikke opdatere opgaven, fordi den blev ændret på serveren. Klik venligst for at opdatere den, lokale ændringer vil blive kasseret.",
    "Could not update the task." : "Opgaven kunne ikke opdateres.",
    "Successfully updated the task." : "Opgaven blev opdateret.",
    "Task successfully moved to new calendar." : "Opgaven blev flyttet til ny kalender.",
    "An error occurred" : "Der var en fejl",
    "Create a task" : "Opret en opgave",
    "Message from {author} in {conversationName}" : "Besked fra {author} i {conversationName}",
    "[Due on] LL" : "[Forfalder den] LL",
    "[Was due yesterday]" : "[Forfaldte i går]",
    "[Was due on] LL" : "[Forfalder den] LL",
    "[Was due today at] LT" : "[Var forfalden i dag kl.] LT",
    "[Due on] LL [at] LT" : "[Forfalder] LL [kl.] LT",
    "[Was due yesterday at] LT" : "[Forfaldt i går kl.] LT",
    "[Was due on] LL [at] LT" : "[Forfalder] LL [kl.] LT",
    "[Starts today]" : "[Starter i dag]",
    "[Starts tomorrow]" : "[Starter i morgen]",
    "[Starts on] LL" : "[Starter på] LL",
    "[Started yesterday]" : "[Begyndte i går]",
    "[Started on] LL" : "[Begyndte den] LL",
    "[Started today at] LT" : "[Begyndte i dag kl.] LT",
    "[Starts today at] LT" : "[Starter i dag kl.] LT",
    "[Starts tomorrow at] LT" : "[Starter i morgen kl.] LT",
    "[Starts on] LL [at] LT" : "[Starter på] LL [kl.] LT",
    "[Started yesterday at] LT" : "[Begyndte i går kl.] LT",
    "[Started on] LL [at] LT" : "[Begyndte den] LL [kl.] LT"
},
"nplurals=2; plural=(n != 1);");
