OC.L10N.register(
    "tasks",
    {
    "Important" : "E rëndësishme",
    "Today" : "Sot",
    "Week" : "Javë",
    "All" : "Krejt",
    "Current" : "E tanishmja",
    "Completed" : "Të plotësuara",
    "Tasks" : "Detyra",
    "Hidden" : "I padukshëm",
    "Visible" : "I dukshëm",
    "Automatic" : "Automatike",
    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Can edit" : "Can edit",
    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
    "Edit" : "Përpunoni",
    "Copied" : "Kopjuar",
    "Export" : "Eksport",
    "Delete" : "Fshije",
    "Unshare" : "Hiqe ndarjen",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "Cancel" : "Anuloje",
    "Email" : "Emaili",
    "Go back" : "Shko prapa",
    "Close" : "Mbylleni",
    "No errors" : "Nuk ka gabime",
    "Open your browser console for more details" : "Hapni panelin e komandimit të shfletuesit tuaj për më shumë detaje",
    "Select tags to filter by" : "Përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "Start date" : "Datë nisjeje",
    "Due date" : "Datë përfundimi",
    "Last modified" : "Ndryshuar së fundmi",
    "Priority" : "Përparësi",
    "Alphabetically" : "Alfabetikisht",
    "Tags" : "Etiketat",
    "Manually" : "Dorazi",
    "Change sort order" : "Ndryshoni rend renditjeje",
    "Task is completed" : "Detyra është e plotësuar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Punë e Plotësuar","%n Punë të Plotësuara"],
    "Tomorrow" : "Nesër",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Canceled" : "Anuluar",
    "Task not found!" : "S’u gjet punë!",
    "Set start date" : "Caktoni datë fillimi",
    "Set due date" : "Caktoni datë mbarimi",
    "All day" : "Gjithë ditën",
    "Details" : "Detajet",
    "Select tags" : "Përzgjidh etiketat",
    "Notes" : "Shënime"
},
"nplurals=2; plural=(n != 1);");
