OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tascanna atá le teacht",
    "Important" : "Tábhachtach",
    "Today" : "Inniu",
    "Week" : "Seachtain",
    "All" : "Gach",
    "Current" : "Reatha",
    "Completed" : "Críochnaithe",
    "Tasks" : "Tascanna",
    "The Tasks app for Nextcloud" : "An aip Tasks do Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Nuair a bheidh sé cumasaithe, beidh roghchlár Tascanna nua le feiceáil i do roghchlár aipeanna Nextcloud. As sin is féidir leat tascanna a chur leis agus a scriosadh, a dteideal, cur síos, dáta tosaithe agus dátaí dlite a chur in eagar agus iad a mharcáil mar thábhachtach. Is féidir tascanna a roinnt idir úsáideoirí. Is féidir tascanna a shioncronú le CalDav (tá gach liosta tascanna nasctha le féilire Nextcloud, chun é a shioncronú le do chliant áitiúil: Thunderbird, Evolution, KDE Kontact, iCal ... - ní gá ach an féilire a chur leis mar fhéilire cianda i do chliant). Is féidir leat do thascanna a íoslódáil mar chomhaid ICS ag baint úsáide as an gcnaipe íoslódáil le haghaidh gach féilire.",
    "Hidden" : "I bhfolach",
    "Visible" : "Infheicthe",
    "Automatic" : "Uathoibríoch",
    "Tasks settings" : "Socruithe tascanna",
    "Default list" : "Liosta réamhshocraithe",
    "Visibility of Smart Collections" : "Infheictheacht Bailiúcháin Chliste",
    "Share with users or groups" : "Roinn le húsáideoirí nó le grúpaí",
    "No users or groups" : "Gan úsáideoirí nó grúpaí",
    "Unable to delete the share." : "Ní féidir an sciar a scriosadh.",
    "Unable to change permissions." : "Ní féidir ceadanna a athrú.",
    "Can edit" : "Is féidir eagarthóireacht a dhéanamh",
    "Unshare with {displayName}" : "Díroinn le {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Scriosfaidh sé seo an féilire \"{calendar}\" agus gach imeacht agus tasc comhfhreagrach.",
    "This will unshare the calendar \"{calendar}\"." : "Déanfaidh sé seo an féilire \"{calendar}\" a dhí-chomhroinnt.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Scriosfaidh sé seo an liosta \"{list}\" agus na tascanna comhfhreagracha go léir.",
    "This will unshare the list \"{list}\"." : "Díroinnfidh sé seo an liosta \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind","An féilire á scriosadh i {countdown} soicind"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Ag dí-roinnt an fhéilire i {comhaireamh síos} soicind","Ag dí-roinnt an fhéilire i {comhaireamh síos} soicind","Ag dí-roinnt an fhéilire i {comhaireamh síos} soicind","Ag dí-roinnt an fhéilire i {comhaireamh síos} soicind","Ag dí-roinnt an fhéilire i {comhaireamh síos} soicind"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["An liosta á scriosadh i {countdown} soicind","An liosta á scriosadh i {countdown} soicind","An liosta á scriosadh i {countdown} soicind","An liosta á scriosadh i {countdown} soicind","An liosta á scriosadh i {countdown} soicind"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Ag díroinnt an liosta i {countdown} soicind","Ag díroinnt an liosta i {countdown} soicind","Ag díroinnt an liosta i {countdown} soicind","Ag díroinnt an liosta i {countdown} soicind","Ag díroinnt an liosta i {countdown} soicind"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas","Roinnte le {num} eintiteas"],
    "Share this calendar" : "Roinn an féilire seo",
    "Share this list" : "Roinn an liosta seo",
    "Calendar link copied to clipboard." : "Cóipeáladh an nasc féilire chuig an ngearrthaisce.",
    "List link copied to clipboard." : "Cóipeáladh nasc an liosta chuig an ngearrthaisce.",
    "Calendar link could not be copied to clipboard." : "Níorbh fhéidir nasc féilire a chóipeáil chuig an ngearrthaisce.",
    "List link could not be copied to clipboard." : "Níorbh fhéidir nasc an liosta a chóipeáil chuig an ngearrthaisce.",
    "The name \"{calendar}\" is already used." : "Tá an t-ainm \"{ calendar}\" in úsáid cheana féin.",
    "An empty name is not allowed." : "Ní cheadaítear ainm folamh.",
    "An error occurred, unable to delete the calendar." : "Tharla earráid, níorbh fhéidir an féilire a scriosadh.",
    "An error occurred, unable to delete the list." : "Tharla earráid, níorbh fhéidir an liosta a scriosadh.",
    "Edit" : "Cuir in eagar",
    "Copy private link" : "Cóipeáil nasc príobháideach",
    "Copied" : "Cóipeáladh",
    "Cannot copy" : "Ní féidir cóip a dhéanamh",
    "Export" : "Easpórtáil",
    "Delete" : "Scrios",
    "Unshare" : "Díroinnte",
    "List name" : "Ainm an liosta",
    "Untitled task" : "Tasc gan teideal",
    "Untitled event" : "Imeacht gan teideal",
    "Untitled journal" : "Dialann gan teideal",
    "Untitled item" : "Mír gan teideal",
    "Unknown calendar" : "Féilire anaithnid",
    "Could not load deleted calendars and objects" : "Níorbh fhéidir féilirí agus oibiachtaí scriosta a lódáil",
    "Could not delete calendar or event" : "Níorbh fhéidir féilire nó imeacht a scriosadh",
    "Could not restore calendar or event" : "Níorbh fhéidir féilire nó imeacht a chur ar ais",
    "Do you really want to empty the trash bin?" : "Ar mhaith leat an bosca bruscair a fholmhú?",
    "Empty trash bin" : "Bruscar folamh",
    "Trash bin" : "Bruscar",
    "Loading deleted calendars, tasks and events." : "Féilirí, tascanna agus imeachtaí scriosta á lódáil.",
    "You do not have any deleted calendars, tasks or events." : "Níl aon fhéilirí, tascanna nó imeachtaí scriosta agat.",
    "Name" : "Ainm",
    "Deleted" : "Scriosta",
    "Restore" : "Athchóirigh",
    "Delete permanently" : "Scrios go buan",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Scriostar na heilimintí sa bhosca bruscair tar éis {numDays} lá","Scriostar na heilimintí sa bhosca bruscair tar éis {numDays} laethanta","Scriostar na heilimintí sa bhosca bruscair tar éis {numDays} laethanta","Scriostar na heilimintí sa bhosca bruscair tar éis {numDays} laethanta","Scriostar na heilimintí sa bhosca bruscair tar éis {numDays} laethanta"],
    "Create reminder" : "Cruthaigh meabhrúchán",
    "Update reminder" : "Meabhrúchán a nuashonrú",
    "Set a reminder at a custom date and time:" : "Socraigh meabhrúchán ar dháta agus am saincheaptha:",
    "Cancel" : "Cealaigh",
    "This is a todo reminder." : "Is meabhrúchán tado é seo.",
    "No reminders" : "Socraigh meabhrúchán ar dháta agus am saincheaptha:",
    "Notification" : "Fógraí",
    "Email" : "Ríomhphost",
    "Audio notification" : "Fógra fuaime",
    "Other notification" : "Fógra eile",
    "Edit time" : "Cuir am in eagar",
    "Remove reminder" : "Bain meabhrúchán",
    "Add reminder" : "Cuir meabhrúchán leis",
    "Before the task starts" : "Sula dtosaíonn an tasc",
    "Before the task is due" : "Sula mbeidh an tasc dlite",
    "Select date and time" : "Roghnaigh dáta agus am",
    "Go back" : "Dul ar ais",
    "Do you want to keep related reminders?" : "Ar mhaith leat meabhrúcháin ghaolmhara a choinneáil?",
    "Discard reminders" : "Scrios meabhrúcháin",
    "Keep reminders" : "Coinnigh meabhrúcháin",
    "Set a reminder relative to your tasks start date:" : "Socraigh meabhrúchán maidir le dáta tosaithe do thascanna:",
    "Set a reminder relative to your tasks due date:" : "Socraigh meabhrúchán maidir le dáta dlite do thascanna:",
    "before at" : "roimh ag",
    "_second_::_seconds_" : ["soicind","soicind","soicind","soicind","soicind"],
    "_minute_::_minutes_" : ["nóiméad","nóiméad","nóiméad","nóiméad","nóiméad"],
    "_hour_::_hours_" : ["uair an chloig","uair an chloig","uair an chloig","uair an chloig","uair an chloig"],
    "_day_::_days_" : ["lá","laethanta","laethanta","laethanta","laethanta"],
    "_week_::_weeks_" : ["seachtain","seachtaine","seachtaine","seachtaine","seachtaine"],
    "Select a calendar" : "Roghnaigh féilire",
    "No calendar matches the search." : "Ní thagann aon fhéilire leis an gcuardach.",
    "Set date" : "Socraigh dáta",
    "Set time" : "Socraigh am",
    "Delete date" : "Scrios dáta",
    "Click here to add a note." : "Cliceáil anseo chun nóta a chur leis.",
    "Set value" : "Socraigh luach",
    "Delete value" : "Scrios luach",
    "Add this as a new tag" : "Cuir é seo mar chlib nua",
    "No tag available. Create one!" : "Níl clib ar fáil. Cruthaigh ceann!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "Cuireadh {numberOfTasks} tasc le \"{calendar}\"",
    "Create new tasks" : "Cruthaigh tascanna nua",
    "Create {numberOfTasks} tasks from pasted text" : "Cruthaigh {numberOfTasks} tasc ó théacs greamaithe",
    "Create tasks" : "Cruthaigh tascanna",
    "Creating new tasks…" : "Tascanna nua á gcruthú…",
    "Close" : "Dún",
    "Delete all completed tasks." : "Scrios gach tasc críochnaithe.",
    "Delete completed tasks." : "Scrios tascanna críochnaithe.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Scriosadh gach tasc críochnaithe ón bhféilire \"{calendar}\".",
    "No errors" : "Uimh earráidí",
    "Open your browser console for more details" : "Oscail do chonsól brabhsálaí le haghaidh tuilleadh sonraí",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Scriosfaidh sé seo {taskCount} tasc críochnaithe agus a chuid fothascanna ón bhféilire \"{calendar}\".","Scriosfaidh sé seo {taskCount} tascanna críochnaithe agus a bhfothascanna ón bhféilire \"{calendar}\".","Scriosfaidh sé seo {taskCount} tascanna críochnaithe agus a bhfothascanna ón bhféilire \"{calendar}\".","Scriosfaidh sé seo {taskCount} tascanna críochnaithe agus a bhfothascanna ón bhféilire \"{calendar}\".","Scriosfaidh sé seo {taskCount} tascanna críochnaithe agus a bhfothascanna ón bhféilire \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Níorbh fhéidir tasc {failedCount} a scriosadh.","Níorbh fhéidir tascanna {failedCount} a scriosadh.","Níorbh fhéidir tascanna {failedCount} a scriosadh.","Níorbh fhéidir tascanna {failedCount} a scriosadh.","Níorbh fhéidir tascanna {failedCount} a scriosadh."],
    "Active filter" : "Scagaire gníomhach",
    "Filter by tags" : "Scag le clibeanna",
    "Select tags to filter by" : "Roghnaigh clibeanna le scagadh de réir",
    "Reset filter" : "Athshocraigh scagaire",
    "Add an important task to \"{calendar}\"…" : "Cuir tasc tábhachtach le \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Cuir tasc atá dlite inniu le \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Cuir tasc reatha le \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Cuir tasc le \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Íoslódáil na tascanna críochnaithe de gach liosta.",
    "Loading the completed tasks of all lists might slow down the app." : "D'fhéadfadh sé go gcuirfí moille ar an aip má lódáileann tú tascanna críochnaithe na liostaí go léir.",
    "Load the completed tasks of list \"{calendar}\"." : "Luchtaigh na tascanna críochnaithe den liosta \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "D'fhéadfadh sé go gcuirfeadh lódáil na dtascanna críochnaithe moill ar an aip.",
    "Relevance" : "Ábharthacht",
    "Sort by completed state, due date, priority, start date and summary." : "Sórtáil de réir staid chríochnaithe, dáta dlite, tosaíochta, dáta tosaithe agus achoimre.",
    "Start date" : "Dáta tosaigh",
    "Sort by start date, priority and summary." : "Sórtáil de réir dáta tosaithe, tosaíochta agus achoimre.",
    "Due date" : "Dáta dlite",
    "Sort by due date, priority and summary." : "Sórtáil de réir dáta dlite, tosaíochta agus achoimre.",
    "Created date" : "Dáta cruthaithe",
    "Sort by created date, priority and summary." : "Sórtáil de réir dáta cruthaithe, tosaíochta agus achoimre.",
    "Last modified" : "Athraithe go deireanach",
    "Sort by last-modified date, priority and summary." : "Sórtáil de réir dáta, tosaíochta agus achoimre arna mionathrú.",
    "Completed date" : "Dáta críochnaithe",
    "Sort by completed date, priority and summary." : "Sórtáil de réir dáta críochnaithe, tosaíochta agus achoimre.",
    "Priority" : "Tosaíocht",
    "Sort by priority and summary." : "Sórtáil de réir tosaíochta agus achoimre.",
    "Alphabetically" : "In ord aibítre",
    "Sort by summary and priority." : "Sórtáil de réir achoimre agus tosaíochta.",
    "Tags" : "Clibeanna",
    "Sort by tags." : "Sórtáil de réir clibeanna.",
    "Manually" : "Láimh",
    "Sort by manual order." : "Sórtáil de réir ordú láimhe.",
    "Change sort order" : "Athraigh ord sórtála",
    "[Yesterday]" : "[Inné]",
    "[Today]" : "[Inniu]",
    "[Tomorrow]" : "[Amárach]",
    "[Completed yesterday]" : "[Críochnaithe inné]",
    "[Completed today]" : "[Críochnaithe inniu]",
    "[Completed tomorrow]" : "[Críochnaithe amárach]",
    "[Yesterday at] LT" : "[Inné ag] LT",
    "[Today at] LT" : "[Inniu ag] LT",
    "[Tomorrow at] LT" : "[Amárach ag] LT",
    "L [at] LT" : "L[ag]LT",
    "[Completed yesterday at] LT" : "[Críochnaithe inné ag] LT",
    "[Completed today at] LT" : "[Críochnaithe inniu ag] LT",
    "[Completed tomorrow at] LT" : "[Críochnaithe amárach ag] LT",
    "[Completed] L [at] LT" : "[Críochnaithe] L[ag]LT",
    "Add a subtask to \"{task}\"…" : "Cuir fothasc le \"{task}\"…",
    "Task has hidden subtasks" : "Tá subtascanna folaithe ag Task",
    "Task is pinned" : "Tá tasc pinn",
    "Task has a note" : "Tá nóta ag Tasc",
    "{complete} % completed" : "{complete} % críochnaithe",
    "Add subtask" : "Cuir fothasc leis",
    "Show subtasks" : "Taispeáin subtascanna",
    "Hide subtasks" : "Folaigh na subtascanna",
    "Show closed subtasks" : "Taispeáin subtascanna dúnta",
    "Hide closed subtasks" : "Folaigh na subtascanna dúnta",
    "Delete task" : "Scrios tasc",
    "Toggle starred" : "Scoránaigh le réalta",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Tá meabhrúchán amháin ag Tasc","Tá {n} meabhrúchán ag Tasc","Tá {n} meabhrúchán ag Tasc","Tá {n} meabhrúchán ag Tasc","Tá {n} meabhrúchán ag Tasc"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["An tasc á scriosadh i {countdown} soicind","An tasc á scriosadh i {countdown} soicind","An tasc á scriosadh i {countdown} soicind","An tasc á scriosadh i {countdown} soicind","An tasc á scriosadh i {countdown} soicind"],
    "Task is cancelled" : "Tá an tasc curtha ar ceal",
    "Task is completed" : "Tá an tasc críochnaithe",
    "Task is read-only" : "Tá an tasc inléite amháin",
    "Task is not completed" : "Níl an tasc críochnaithe",
    "\"{task}\" was added to \"{calendar}\"" : "Cuireadh \"{task}\" le \"{ calendar}\"",
    "Create a new task" : "Cruthaigh tasc nua",
    "Task summary" : "Achoimre tasc",
    "Create task" : "Cruthaigh tasc",
    "Creating the new task…" : "An tasc nua á chruthú…",
    "Open task" : "Tasc oscailte",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tasc Críochnaithe","%n Tascanna Críochnaithe","%n Tascanna Críochnaithe","%n Tascanna Críochnaithe","%n Tascanna Críochnaithe"],
    "Tomorrow" : "Amárach",
    "An error occurred, unable to create the list." : "Tharla earráid, níorbh fhéidir an liosta a chruthú.",
    "Add List…" : "Cuir Liosta leis…",
    "New list" : "Liosta nua",
    "When shared show full event" : "Nuair a chomhroinntear taispeáin imeacht iomlán",
    "When shared show only busy" : "Nuair a bheidh an seó roinnte ach gnóthach",
    "When shared hide this event" : "Nuair a bheidh tú roinnte cuir an t-imeacht seo i bhfolach",
    "[Completed] L" : "[Críochnaithe] L",
    "[Completed last] dddd [at] LT" : "[Críochnaithe go deireanach] dddd [ag] LT",
    "[Completed] dddd [at] LT" : "[Críochnaithe] dddd [ag] LT",
    "[Last modified yesterday at] LT" : "[Modhnaithe inné ag] LT",
    "[Last modified today at] LT" : "[Athraithe go deireanach inniu ag] LT",
    "[Last modified] L" : "[Athraithe go deireanach] L",
    "[Last modified last] dddd [at] LT" : "[Athraithe go deireanach] dddd [ag] LT",
    "[Last modified] dddd [at] LT" : "[Athraithe go deireanach] dddd [ag] LT",
    "[Created yesterday at] LT" : "[Cruthaithe inné ag] LT",
    "[Created today at] LT" : "[Cruthaithe inniu ag] LT",
    "[Created] L" : "[Cruthaithe] L",
    "[Created last] dddd [at] LT" : "[Cruthaíodh go deireanach] dddd [ag] LT",
    "[Created] dddd [at] LT" : "[Cruthaithe] dddd [ag] LT",
    "Needs action" : "Teastaíonn gníomh",
    "In process" : "Ar siúl",
    "Canceled" : "Ar ceal",
    "Clear status" : "Stádas soiléir",
    "Loading task from server." : "Tasc á lódáil ón bhfreastalaí.",
    "Task not found!" : "Níor aimsíodh an tasc!",
    "Set start date" : "Socraigh dáta tosaithe",
    "Set due date" : "Socraigh dáta dlite",
    "Priority {priority}: low" : "Tosaíocht {priority}: íseal",
    "Priority {priority}: medium" : "Tosaíocht {priority}: meánach",
    "Priority {priority}: high" : "Tosaíocht {priority}: ard",
    "No priority assigned" : "Níl aon tosaíocht sannta",
    "{percent} % completed" : "{percent} % críochnaithe",
    "All day" : "An lá ar fad",
    "Unpin" : "Díbhioráil",
    "Pin" : "Bioráil",
    "Show in Calendar" : "Taispeáin i bhFéilire",
    "Show in Deck" : "Taispeáin sa Deic",
    "Edit summary" : "Cuir achoimre in eagar",
    "Details" : "Sonraí",
    "Selecting a classification is forbidden, because the task was shared with you." : "Tá cosc ​​ar aicmiú a roghnú, toisc gur roinneadh an tasc leat.",
    "Select a classification" : "Roghnaigh aicmiú",
    "Select a status" : "Roghnaigh stádas",
    "Set a location" : "Socraigh suíomh",
    "Set a URL" : "Socraigh URL",
    "Select tags" : "Roghnaigh clibeanna",
    "Notes" : "Nótaí",
    "Mark as done" : "Marcáil mar a rinneadh",
    "No due date assigned" : "Níl aon dáta dlite sannta",
    "[Due yesterday]" : "[dlite inné]",
    "[Due today]" : "[dlite inniu]",
    "[Due tomorrow]" : "[dlite amárach]",
    "[Due] L" : "[Dlite] L",
    "[Due yesterday at] LT" : "[Dlite inné ag] LT",
    "[Due today at] LT" : "[Dlite inniu ag] LT",
    "[Due tomorrow at] LT" : "[Dlite amárach ag] LT",
    "[Due] L [at] LT" : "[Dlite] L[ag]LT",
    "No upcoming tasks" : "Níl aon tascanna le teacht",
    "upcoming tasks" : "tascanna atá le teacht",
    "No tasks today" : "Uimh tascanna inniu",
    "Completion date must be in the past." : "Caithfidh an dáta críochnaithe a bheith san am atá thart.",
    "Successfully created the task." : "D'éirigh leis an tasc a chruthú.",
    "Could not delete the task." : "Níorbh fhéidir an tasc a scriosadh.",
    "Synchronizing to the server." : "Sioncrónú leis an bhfreastalaí.",
    "Task successfully saved to server." : "D'éirigh leis an tasc a shábháil ar an bhfreastalaí.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Níorbh fhéidir an tasc a nuashonrú toisc gur athraíodh é ar an bhfreastalaí. Cliceáil le do thoil chun é a athnuachan, cuirfear deireadh le hathruithe áitiúla.",
    "Could not update the task." : "Níorbh fhéidir an tasc a nuashonrú.",
    "Successfully updated the task." : "D'éirigh leis an tasc a nuashonrú.",
    "Task successfully moved to new calendar." : "D'éirigh leis an tasc a aistriú go féilire nua.",
    "An error occurred" : "Tharla earráid",
    "Create a task" : "Cruthaigh tasc",
    "Message from {author} in {conversationName}" : "Teachtaireacht ó {author} in {conversationName}",
    "[Due on] LL" : "[Dlite ar] LL",
    "[Was due yesterday]" : "[Bhí sé dlite inné]",
    "[Was due on] LL" : "[Bhí sé dlite ar] LL",
    "[Was due today at] LT" : "[Bhí sé dlite inniu ag] LT",
    "[Due on] LL [at] LT" : "[Dlite ar] LL [ag] LT",
    "[Was due yesterday at] LT" : "[Bhí sé dlite inné ag] LT",
    "[Was due on] LL [at] LT" : "[Bhí sé dlite ar] LL [ag] LT",
    "[Starts today]" : "[Tosaíonn inniu]",
    "[Starts tomorrow]" : "[Tosaíonn sé amárach]",
    "[Starts on] LL" : "[Tosaíonn ar] LL",
    "[Started yesterday]" : "[Thosaigh inné]",
    "[Started on] LL" : "[Tosaithe ar] LL",
    "[Started today at] LT" : "[Tosaithe inniu ag] LT",
    "[Starts today at] LT" : "[Tosaíonn inniu ag] LT",
    "[Starts tomorrow at] LT" : "[Tosaíonn sé amárach ag] LT",
    "[Starts on] LL [at] LT" : "[Tosaíonn ar] LL [ag] LT",
    "[Started yesterday at] LT" : "[Thosaigh inné ag] LT",
    "[Started on] LL [at] LT" : "[Tosaíodh ar] LL [ag] LT",
    "Midnight on the day the task starts" : "Meán oíche ar an lá a thosaíonn an tasc",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n lá roimh an tasc ag {formattedHourMinute}","%n laethanta roimh an tasc ag {formattedHourMinute}","%n laethanta roimh an tasc ag {formattedHourMinute}","%n laethanta roimh an tasc ag {formattedHourMinute}","%n laethanta roimh an tasc ag {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n seachtain roimh an tasc ag {formattedHourMinute}","%n seachtainí roimh an tasc ag {formattedHourMinute}","%n seachtainí roimh an tasc ag {formattedHourMinute}","%n seachtainí roimh an tasc ag {formattedHourMinute}","%n seachtainí roimh an tasc ag {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "ar lá an taisc ag {formattedHourMinute}",
    "at the task's start" : "ag tús an taisc",
    "when the task is due" : "nuair a bhíonn an tasc dlite",
    "{time} before the task starts" : "{time} sula dtosaíonn an tasc",
    "{time} before the task is due" : "{time} sula mbeidh an tasc dlite",
    "{time} after the task starts" : "{time} tar éis tosú ar an tasc",
    "{time} after the task is due" : "{time} tar éis an tasc dlite"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
