OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Pròximes tasques",
    "Important" : "Important",
    "Today" : "Avui",
    "Week" : "Aquesta setmana",
    "All" : "Totes",
    "Current" : "Actuals",
    "Completed" : "Completades",
    "Tasks" : "Tasques",
    "The Tasks app for Nextcloud" : "L'aplicació Tasques per Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Un cop habilitat, apareixerà un nou menú Tasques al menú Aplicacions de Nextcloud. Des d'allà podeu afegir i suprimir tasques, editar el títol, descripció, dates d'inici i de venciment i marcar-les com a importants. Les tasques es poden compartir entre usuaris. Les tasques es poden sincronitzar utilitzant CalDav (cada llista de tasques està enllaçada a un calendari Nextcloud, per sincronitzar-lo amb el vostre client local: Thunderbird, Evolution, KDE Kontact, iCal, … - només cal afegir el calendari com a calendari remot al vostre client). Podeu baixar les vostres tasques com a fitxers ICS mitjançant el botó de baixada de cada calendari.",
    "Hidden" : "Ocult",
    "Visible" : "Visible",
    "Automatic" : "Automàtic",
    "Tasks settings" : "Paràmetres de Tasques",
    "Default list" : "Llista per defecte",
    "Visibility of Smart Collections" : "Visibilitat de les col·leccions intel·ligents",
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "No users or groups" : "No hi ha usuaris ni grups",
    "Unable to delete the share." : "No s'ha pogut suprimir la compartició.",
    "Unable to change permissions." : "No s'han pogut canviar els permisos.",
    "Can edit" : "Pot editar",
    "Unshare with {displayName}" : "S'ha deixat de compartir amb {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Això suprimirà el calendari \"{calendar}\" i tots els esdeveniments i tasques corresponents.",
    "This will unshare the calendar \"{calendar}\"." : "Això deixa de comparteix el calendari \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Aquesta acció suprimirà la llista \"{list}\" i totes les tasques corresponents.",
    "This will unshare the list \"{list}\"." : "Aquesta acció farà que la llista \"{list}\" deixi d'estar compartida.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Supressió del calendari en {countdown} segon","Supressió dels calendaris en {countdown} segons"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segon","Deixant de compartir els calendaris en {countdown} segons"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Suprimint d'aquí a {countdown} segon","Suprimint d’aquí a {countdown} segons"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segon","Deixant de compartir el calendari en {countdown} segons"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartit amb {num} entitats","Compartit amb {num} entitats"],
    "Share this calendar" : "Comparteix aquest calendari",
    "Share this list" : "Comparteix aquesta llista",
    "Calendar link copied to clipboard." : "S'ha copiat l'enllaç del calendari al porta-retalls.",
    "List link copied to clipboard." : "Enllaç a la llista copiada al porta-retalls.",
    "Calendar link could not be copied to clipboard." : "No s'ha copiat l'enllaç del calendari al porta-retalls.",
    "List link could not be copied to clipboard." : "No s'ha copiat l'enllaç de la llista al porta-retalls.",
    "The name \"{calendar}\" is already used." : "El nom \"{calendar}\" ja està usat.",
    "An empty name is not allowed." : "No es permet un nom buit.",
    "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
    "An error occurred, unable to delete the list." : "S'ha produït un error, no es pot suprimir la llista.",
    "Edit" : "Edita",
    "Copy private link" : "Copia l'enllaç privat",
    "Copied" : "Copiat",
    "Cannot copy" : "No s'ha pogut copiar",
    "Export" : "Exporta",
    "Delete" : "Suprimeix",
    "Unshare" : "Deixa de compartir",
    "List name" : "Nom de la llista",
    "Untitled task" : "Tasca sense títol",
    "Untitled event" : "Esdeveniment sense títol",
    "Untitled journal" : "Diari sense títol",
    "Untitled item" : "Element sense títol",
    "Unknown calendar" : "Calendari desconegut",
    "Could not load deleted calendars and objects" : "No s'han pogut carregar els calendaris i els objectes suprimits",
    "Could not delete calendar or event" : "No s'ha pogut suprimir el calendari o l'esdeveniment",
    "Could not restore calendar or event" : "No s'ha pogut restaurar el calendari o l'esdeveniment",
    "Do you really want to empty the trash bin?" : "Realment voleu buidar la paperera?",
    "Empty trash bin" : "Buida la paperera",
    "Trash bin" : "Paperera",
    "Loading deleted calendars, tasks and events." : "Carregant calendaris, tasques i esdeveniments suprimits.",
    "You do not have any deleted calendars, tasks or events." : "No teniu cap calendari, tasca o esdeveniment suprimit.",
    "Name" : "Cognom",
    "Deleted" : "S'ha suprimit",
    "Restore" : "Restaura",
    "Delete permanently" : "Suprimeix de manera permanent",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Els elements de la paperera se suprimeixen al cap de {numDays} dia","Els elements de la paperera se suprimeixen al cap de {numDays} dies"],
    "Create reminder" : "Crea un recordatori",
    "Update reminder" : "Actualitza el recordatori",
    "Set a reminder at a custom date and time:" : "Estableix un recordatori en una data i hora personalitzades:",
    "Cancel" : "Cancel·la",
    "This is a todo reminder." : "Aquest és un recordatori de tasques pendents.",
    "No reminders" : "Sense recordatoris",
    "Notification" : "Notificació",
    "Email" : "Adreça de correu",
    "Audio notification" : "Notificació d`àudio",
    "Other notification" : "Altres notificacions",
    "Edit time" : "Edició d'hora",
    "Remove reminder" : "Suprimeix el recordatori",
    "Add reminder" : "Afegeix un recordatori",
    "Before the task starts" : "Abans que comenci la tasca",
    "Before the task is due" : "Abans que s'acabi la tasca",
    "Select date and time" : "Selecciona la data i l'hora",
    "Go back" : "Torna",
    "Set a reminder relative to your tasks start date:" : "Estableix un recordatori relatiu a la data d'inici de les tasques:",
    "Set a reminder relative to your tasks due date:" : "Estableix un recordatori relatiu a la data de venciment de les teves tasques:",
    "before at" : "abans a les",
    "_second_::_seconds_" : ["segon","segons"],
    "_minute_::_minutes_" : ["minut","minuts"],
    "_hour_::_hours_" : ["hora","hores"],
    "_day_::_days_" : ["dia","dies"],
    "_week_::_weeks_" : ["setmana","setmanes"],
    "Select a calendar" : "Selecciona un calendari",
    "No calendar matches the search." : "Cap calendari coincideix amb la cerca.",
    "Set date" : "Estableix la data",
    "Set time" : "Ajusta l'hora",
    "Delete date" : "Suprimeix la data",
    "Click here to add a note." : "Feu clic aquí per afegir una nota.",
    "Set value" : "Establir valor",
    "Delete value" : "Suprimeix el valor",
    "Add this as a new tag" : "Afegeix-ho com a etiqueta nova",
    "No tag available. Create one!" : "No hi ha cap etiqueta disponible. Crea'n un!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "S'han afegit {numberOfTasks} tasques a \"{calendar}\"",
    "Create new tasks" : "Crea tasques noves",
    "Create {numberOfTasks} tasks from pasted text" : "Creació de {numberOfTasks} tasques a partir de text enganxat",
    "Create tasks" : "Creació de tasques",
    "Creating new tasks…" : "S'estan creant tasques noves…",
    "Close" : "Tanca",
    "Delete all completed tasks." : "Suprimeix totes les tasques completades.",
    "Delete completed tasks." : "Suprimeix les tasques completades.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "S'han suprimit totes les tasques completades del calendari \"{calendar}\".",
    "No errors" : "Sense errors",
    "Open your browser console for more details" : "Obriu la consola del navegador per veure més detalls",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Això esborrarà {taskCount} tasques i subtasques completades del calendari \"{calendar}\".","This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} tasques no s'han pogut esborrar..","No s'han pogut suprimit {failedCount} tasques."],
    "Active filter" : "Filtre actiu",
    "Filter by tags" : "Filtra per etiquetes",
    "Select tags to filter by" : "Seleccioneu les etiquetes per filtrar per",
    "Reset filter" : "Reinicia el filtre",
    "Add an important task to \"{calendar}\"…" : "Afegeix una tasca important a \"{calendar}”…",
    "Add a task due today to \"{calendar}\"…" : "Afegeix un tasca per a avui a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Afegeix una tasca en curs a \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Afegeix una tasca a \"{calendar}”…",
    "Load the completed tasks of all lists." : "Carrega les tasques completades de totes les llistes.",
    "Loading the completed tasks of all lists might slow down the app." : "Carregant les tasques completades de totes les llistes pot alentir l'aplicació.",
    "Load the completed tasks of list \"{calendar}\"." : "Carrega les tasques completades de la llista «{calendar}».",
    "Loading the completed tasks might slow down the app." : "La càrrega de les tasques completades pot alentir l'aplicació.",
    "Relevance" : "Rellevància",
    "Sort by completed state, due date, priority, start date and summary." : "Ordena per estat de completat, data de caducitat, prioritat, data d'inici i resum.",
    "Start date" : "Data d'inici",
    "Sort by start date, priority and summary." : "Ordena per data d'inici, prioritat i resum.",
    "Due date" : "Per data de caducitat",
    "Sort by due date, priority and summary." : "Ordena per data de caducitat, prioritat i resum.",
    "Created date" : "Data de creació",
    "Sort by created date, priority and summary." : "Ordena per data de creació, prioritat i resum.",
    "Last modified" : "Darrera modificació",
    "Sort by last-modified date, priority and summary." : "Ordena per data de darrera modificació, prioritat i resum.",
    "Completed date" : "Data de completat",
    "Sort by completed date, priority and summary." : "Ordena per data de finalització, prioritat i resum.",
    "Priority" : "Prioritat",
    "Sort by priority and summary." : "Ordena per prioritat i resum.",
    "Alphabetically" : "Alfabèticament",
    "Sort by summary and priority." : "Ordena per resum i prioritat.",
    "Tags" : "Etiquetes",
    "Sort by tags." : "Ordena per etiquetes.",
    "Manually" : "Manualment",
    "Sort by manual order." : "Ordena manualment.",
    "Change sort order" : "Canvia l'ordre",
    "[Yesterday]" : "[Ahir]",
    "[Today]" : "[Avui]",
    "[Tomorrow]" : "[Demà]",
    "[Completed yesterday]" : "[Completada ahir]",
    "[Completed today]" : "[Completada avui]",
    "[Completed tomorrow]" : "[Completada demà]",
    "[Yesterday at] LT" : "[Ahir a] LT",
    "[Today at] LT" : "[Avui a] LT",
    "[Tomorrow at] LT" : "[Demà a] LT",
    "L [at] LT" : "L [a] LT",
    "[Completed yesterday at] LT" : "[Completada ahir a] LT",
    "[Completed today at] LT" : "[Completada avui a] LT",
    "[Completed tomorrow at] LT" : "[Completada demà a] LT",
    "[Completed] L [at] LT" : "[Completada] L [a] LT",
    "Add a subtask to \"{task}\"…" : "Afegeix una subtasca a \"{task}”…",
    "Task has hidden subtasks" : "La tasca té subtasques amagades",
    "Task is pinned" : "La tasca està fixada",
    "Task has a note" : "La tasca té una nota",
    "{complete} % completed" : "{complete} % completat",
    "Add subtask" : "Afegeix subtasca",
    "Show subtasks" : "Mostra subtasques",
    "Hide subtasks" : "Amaga subtasques",
    "Show closed subtasks" : "Mostra les subtasques tancades",
    "Hide closed subtasks" : "Amaga les subtasques tancades",
    "Delete task" : "Suprimeix la tasca",
    "Toggle starred" : "Commuta l'estrella",
    "_Task has one reminder_::_Task has {n} reminders_" : ["La tasca té un recordatori","La tasca té {n} recordatoris"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Supressió de la tasca en {countdown} segon","Supressió de les tasques en {countdown} segons"],
    "Task is cancelled" : "S'ha cancel·lat la tasca",
    "Task is completed" : "Completat",
    "Task is read-only" : "La tasca és només de lectura",
    "Task is not completed" : "La tasca no s'ha completat",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" s'ha afegit a \"{calendar}\"",
    "Create a new task" : "Crea una tasca nova",
    "Task summary" : "Resum de la tasca",
    "Create task" : "Crea una tasca",
    "Creating the new task…" : "S'està creant la nova tasca…",
    "Open task" : "Tasca oberta",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tasca Completada","%n Tasques Completades"],
    "Tomorrow" : "Demà",
    "An error occurred, unable to create the list." : "S'ha produït un error, no s'ha pogut crear la llista.",
    "Add List…" : "Afegeix una llista…",
    "New list" : "Llista nova",
    "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
    "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
    "When shared hide this event" : "Quan es comparteix, amaga aquest esdeveniment",
    "[Completed] L" : "[Completat] L",
    "[Completed last] dddd [at] LT" : "[Completat l'últim] dddd [at] LT",
    "[Completed] dddd [at] LT" : "[Completat] dddd [a] LT",
    "[Last modified yesterday at] LT" : "[Darrera modificació ahir a] LT",
    "[Last modified today at] LT" : "[Darrera modificació avui a] LT",
    "[Last modified] L" : "[Darrera modificació] L",
    "[Last modified last] dddd [at] LT" : "[Última modificació] dddd [at] LT",
    "[Last modified] dddd [at] LT" : "[Darrera modificació] dddd [a] LT",
    "[Created yesterday at] LT" : "[Creat ahir a] LT",
    "[Created today at] LT" : "[Creat avui a] LT",
    "[Created] L" : "[Creat] L",
    "[Created last] dddd [at] LT" : "[Creat darrer] dddd [a] LT",
    "[Created] dddd [at] LT" : "[Creat] dddd [a] LT",
    "Needs action" : "Cal una acció",
    "In process" : "En procés",
    "Canceled" : "Cancel·lat",
    "Clear status" : "Esborra l'estat",
    "Loading task from server." : "Carregant la tasca del servidor.",
    "Task not found!" : "No s'ha trobat la tasca!",
    "Set start date" : "Assigna una data d'inici",
    "Set due date" : "Estableix la data de caducitat",
    "Priority {priority}: low" : "Prioritat {priority}: baixa",
    "Priority {priority}: medium" : "Prioritat {priority}: mitjana",
    "Priority {priority}: high" : "Prioritat {priority}: alta",
    "No priority assigned" : "Sense prioritat assignada",
    "{percent} % completed" : "{percent} % completat",
    "All day" : "Tot el dia",
    "Unpin" : "No fixis",
    "Pin" : "Ancorar",
    "Show in Calendar" : "Mostra al calendari",
    "Show in Deck" : "Mostra a Targetes",
    "Edit summary" : "Edició del resum",
    "Details" : "Detalls",
    "Selecting a classification is forbidden, because the task was shared with you." : "És prohibit seleccionar una classificació, perquè la tasca s'ha compartit amb tu.",
    "Select a classification" : "Selecciona una classificació",
    "Select a status" : "Seleccioneu un estat",
    "Set a location" : "Estableix una ubicació",
    "Set a URL" : "Estableix un URL",
    "Select tags" : "Selecciona etiquetes",
    "Notes" : "Notes",
    "Mark as done" : "Marcat com a fet",
    "No due date assigned" : "No s'ha assignat cap data de caducitat",
    "[Due yesterday]" : "[Esperada ahir]",
    "[Due today]" : "[Per avui]",
    "[Due tomorrow]" : "[Per demà]",
    "[Due] L" : "[Esperada] L",
    "[Due yesterday at] LT" : "[Esperada ahir a] LT",
    "[Due today at] LT" : "[Ha finalitzat avui a les] LT",
    "[Due tomorrow at] LT" : "[Finalitzarà demà a les] LT",
    "[Due] L [at] LT" : "[Esperada] L [a] LT",
    "No upcoming tasks" : "No hi ha tasques properes",
    "upcoming tasks" : "properes tasques",
    "No tasks today" : "Sense tasques avui",
    "Completion date must be in the past." : "La data de finalització ha de ser anterior.",
    "Successfully created the task." : "S'ha creat correctament la tasca.",
    "Could not delete the task." : "No s'ha pogut suprimir la tasca.",
    "Synchronizing to the server." : "Sincronitzant amb el servidor.",
    "Task successfully saved to server." : "Tasca desada correctament al servidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No s'ha pogut actualitzar la tasca perquè aquesta ha canviat al servidor. Si us plau refresqueu la tasca, es perdran els canvis locals.",
    "Could not update the task." : "No s'ha pogut actualitzar la tasca.",
    "Successfully updated the task." : "S'ha actualitzat correctament la tasca.",
    "Task successfully moved to new calendar." : "S’ha mogut correctament la tasca al calendari nou.",
    "An error occurred" : "S'ha produït un error",
    "Create a task" : "Crea una tasca",
    "Message from {author} in {conversationName}" : "Missatge de {author} a {conversationName}",
    "[Due on] LL" : "[Finalitza el] LL",
    "[Was due yesterday]" : "[Va finalitzar ahir]",
    "[Was due on] LL" : "[Va finalitzar el] LL",
    "[Was due today at] LT" : "[Ha finalitzat avui a les] LT",
    "[Due on] LL [at] LT" : "[Finalitza el] LL [a les] LT",
    "[Was due yesterday at] LT" : "[Va finalitzar ahir a les] LT",
    "[Was due on] LL [at] LT" : "[Va finalitzar el] LL [a les] LT",
    "[Starts today]" : "[Comença avui]",
    "[Starts tomorrow]" : "[Comença demà]",
    "[Starts on] LL" : "[Comença el] LL",
    "[Started yesterday]" : "[Començat ahir]",
    "[Started on] LL" : "[Va començar el] LL",
    "[Started today at] LT" : "[Ha començat avui a les] LT",
    "[Starts today at] LT" : "[Comença avui a les] LT",
    "[Starts tomorrow at] LT" : "[Començarà demà a les] LT",
    "[Starts on] LL [at] LT" : "[Comença] LL [a les] LT",
    "[Started yesterday at] LT" : "[Va començar ahir a les]  LT",
    "[Started on] LL [at] LT" : "[Va començar el] LL [a les] LT",
    "Midnight on the day the task starts" : "Mitjanit el dia que comença la tasca",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n dia abans de la tasca a les {formattedHourMinute}","%n dies abans de la tasca a les {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n setmana abans de la tasca a les {formattedHourMinute}","%n setmanes abans de la tasca a les {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "el dia abans de la tasca a les {formattedHourMinute}",
    "at the task's start" : "a l'inici de la tasca",
    "when the task is due" : "quan s'acabi la tasca",
    "{time} before the task starts" : "{time} abans que comenci la tasca",
    "{time} before the task is due" : "{time} abans del termini de la tasca",
    "{time} after the task starts" : "{time} després que comenci la tasca",
    "{time} after the task is due" : "{time} després del termini de la tasca"
},
"nplurals=2; plural=(n != 1);");
