#modal-inner[data-v-e688878b]{display:flex;flex-direction:column;padding:20px}#modal-inner .loading-overlay[data-v-e688878b]{position:absolute;top:calc(50% - 20px);left:calc(50% - 20px);z-index:1000}#modal-inner .empty-content[data-v-e688878b]{margin:10vh 0}#modal-inner .empty-content[data-v-e688878b] .empty-content__action{display:flex}.property__item[data-v-e688878b]{border-bottom:none;margin-bottom:3px}.property__item[data-v-e688878b] .multiselect .multiselect__tags{border:2px solid var(--color-border-dark)}.property[data-v-e688878b]{position:relative}.property .material-design-icon[data-v-e688878b]{position:absolute;top:14px;left:14px}.property input[data-v-e688878b],.property textarea[data-v-e688878b]{width:100%;padding-left:44px!important}.property input[data-v-e688878b]{height:44px!important;margin:0}.property textarea[data-v-e688878b]{min-width:100%;max-width:100%;min-height:100px}.modal-buttons[data-v-e688878b]{display:flex;justify-content:flex-end}[data-v-e688878b] .calendar-picker-option__label,[data-v-e688878b] .property__item .multiselect__tags input.multiselect__input{font-weight:400}
