OC.L10N.register(
    "tasks",
    {
    "Important" : "গুরুত্বপূর্ণ",
    "Today" : "আজ",
    "Week" : "সপ্তাহ",
    "All" : "সবাই",
    "Current" : "বর্তমান",
    "Completed" : "সুসম্পন্ন",
    "Tasks" : "কর্ম",
    "Hidden" : "লুকনো",
    "Visible" : "দর্শনযোগ্য",
    "Automatic" : "স্বয়ংক্রিয়",
    "Visibility of Smart Collections" : "চটপট সংগ্রহের দর্শনযোগ্যতা",
    "Can edit" : "Can edit",
    "An empty name is not allowed." : "একটি শুন্য নাম গ্রহণযোগ্য নয়।",
    "Edit" : "সম্পাদনা",
    "Export" : "রপ্তানি",
    "Delete" : "মুছে",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "Name" : "নাম",
    "Deleted" : "মুছে ফেলা",
    "Restore" : "ফিরিয়ে দাও",
    "Cancel" : "বাতিল",
    "Notification" : "নোটিফিকেশন ",
    "Email" : "ইমেইল",
    "Go back" : "ফিরে যাও",
    "Close" : "বন্ধ",
    "Tags" : "ট্যাগ",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n সুসম্পন্ন কাজ","%n সুসম্পন্ন কাজ"],
    "Tomorrow" : "আগামীকাল",
    "Set start date" : "আরম্ভের তারিখ নির্ধারণ করুন",
    "Set due date" : "কার্যকারিতার তারিখ নির্ধারণ করুন",
    "Details" : "বিসতারিত",
    "Notes" : "নোট"
},
"nplurals=2; plural=(n != 1);");
