.task-icon[data-v-b78bc47d]{display:flex;align-self:center;justify-self:center;align-items:center;justify-content:center}#tasks_panel .calendar-dot{height:1rem;width:1rem;margin-top:.2rem;border-radius:50%;min-width:1rem;min-height:1rem}.center-button{display:flex;justify-content:center;margin-top:10px}
