OC.L10N.register(
    "tasks",
    {
    "Today" : "Այսօր",
    "Week" : "Շաբաթ",
    "Current" : "Ընթացիկ",
    "Completed" : "Ավարտվեց",
    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
    "Can edit" : "Can edit",
    "Edit" : "Խմբագրել",
    "Export" : "Արտահանում",
    "Delete" : "Ջնջել",
    "Unshare" : "Չկիսվել",
    "Name" : "Անուն",
    "Deleted" : "Ջնջված",
    "Restore" : "Վերականգնել",
    "Delete permanently" : "Ջնջել ընդմիշտ",
    "Cancel" : "Չեղարկել",
    "Notification" : "Ծանուցում",
    "Email" : "Էլ․փոստ",
    "Close" : "Փակել",
    "Details" : "Մանրամասներ",
    "Notes" : "Notes"
},
"nplurals=2; plural=(n != 1);");
