OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Предстоящи задачи",
    "Important" : "Важно",
    "Today" : "Днес",
    "Week" : "Седмица",
    "All" : "Всички",
    "Current" : "Текущ",
    "Completed" : "Завършено",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Задачи за NextCloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "След като бъде активирано, в менюто ви с приложения Nextcloud ще се появи ново меню Задачи. Оттам можете да добавяте и изтривате задачи, да редактирате тяхното заглавие, описание, начални и крайни дати и да ги маркирате като важни. Задачите могат да се споделят между потребителите. Задачите могат да се синхронизират с помощта на CalDav (всеки списък със задачи е свързан с календар Nextcloud, за да се синхронизира с вашия локален клиент: Thunderbird, Evolution, KDE Kontact, iCal, ... - просто добавете календар, като отдалечен календар във вашия клиент). Можете да изтеглите задачите си като ICS файлове, като използвате бутон за изтегляне за всеки календар.",
    "Hidden" : "Скрито",
    "Visible" : "Видимо",
    "Automatic" : "Автоматично",
    "Tasks settings" : "Настройки на задачите",
    "Default list" : "Списък по подразбиране",
    "Visibility of Smart Collections" : "Видимост на \"Smart\" колекции",
    "Share with users or groups" : "Сподели с потребители или групи",
    "No users or groups" : "Няма потребители или групи",
    "Unable to delete the share." : "Неуспешно изтриване на споделянето.",
    "Unable to change permissions." : "Неуспешна промяна на права.",
    "Can edit" : "Може да се редактира",
    "Unshare with {displayName}" : "Прекратява споделянето с {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Това ще изтрие календара \"{calendar}\" и всички съпътстващи събития и задачи.",
    "This will unshare the calendar \"{calendar}\"." : "Това ще откаже споделянето на календара \"{calendar}\"",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Това ще изтрие списъкът \"{list}\" и всички съпътстващи задачи.",
    "This will unshare the list \"{list}\"." : "Това ще откаже споделянето насписъка \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Изтриване на календар след {countdown} секундии","Изтриване на календар след {countdown} секундии"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Прекратяване на споделянето на календар след {countdown} секунди","Прекратяване на споделянето на календар след {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Изтриване на списък след {countdown} секундии","Изтриване на списък след {countdown} секундии"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Прекратяване на споделянето на списък след {countdown} секунди","Прекратяване на споделянето на списък след {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено с {num} обекта","Споделено с {num} обекта"],
    "Share this calendar" : "Споделяне на този календар",
    "Share this list" : "Споделяне на този списък",
    "Calendar link copied to clipboard." : "Копирано в клипборда",
    "List link copied to clipboard." : "Връзката към списъка е копирана в клипборда.",
    "Calendar link could not be copied to clipboard." : "Връзката за Календар не може да се копира в клипборда",
    "List link could not be copied to clipboard." : "Връзката към списъка не може да се копира в клипборда.",
    "The name \"{calendar}\" is already used." : "Името \"{calendar}\"  вече е използвано.",
    "An empty name is not allowed." : "Празно име не е разрешено.",
    "An error occurred, unable to delete the calendar." : "Възникна грешка, невъзможност да се изтрие календар.",
    "An error occurred, unable to delete the list." : "Възникна грешка, невъзможност да се изтрие списък.",
    "Edit" : "Редакция",
    "Copy private link" : "Копирай скритата връзка",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Export" : "Експорт /изнасям/",
    "Delete" : "Изтриване",
    "Unshare" : "Прекрати споделянето",
    "List name" : "Име на списък",
    "Untitled task" : "Задача без заглавие",
    "Untitled event" : "Събитие без заглавие",
    "Untitled journal" : "Журнал без заглавие",
    "Untitled item" : "Неозаглавен елемент",
    "Unknown calendar" : "Неизвестен календар",
    "Could not load deleted calendars and objects" : "Не можаха да се заредят изтритите календари и обекти",
    "Could not delete calendar or event" : "Не можа да се изтрие календар или събитие",
    "Could not restore calendar or event" : "Не можа да се възстанови календар или събитие",
    "Do you really want to empty the trash bin?" : "Наистина ли искате да изпразните кошчето?",
    "Empty trash bin" : "Изпразни кошчето",
    "Trash bin" : "Кошче",
    "Loading deleted calendars, tasks and events." : "Зареждане на изтрити календари, задачи и събития.",
    "You do not have any deleted calendars, tasks or events." : "Нямате изтрити календари, задачи или събития.",
    "Name" : "Име",
    "Deleted" : "Изтрито",
    "Restore" : "Възстановяне",
    "Delete permanently" : "Изтрий завинаги",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
    "Cancel" : "Отказ",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "Audio notification" : "Звуково известие",
    "Other notification" : "Друго известие",
    "Edit time" : "Редакирай времето",
    "Remove reminder" : "Премахни напомнянето",
    "Add reminder" : "Добавяне на напомняне",
    "Go back" : "Назад",
    "before at" : "преди в",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часове"],
    "_day_::_days_" : ["дни","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "Select a calendar" : "Избор на календар",
    "No calendar matches the search." : "Няма календар, който да отговаря на търсенето.",
    "Set date" : "Задаване на дата",
    "Set time" : "Задаване на час",
    "Delete date" : "Дата на изтриване",
    "Click here to add a note." : "Щракнете тук, за да добавите бележка.",
    "Set value" : "Задаване на стойност",
    "Delete value" : " Изтриване на стойност",
    "Add this as a new tag" : "Добавяне на това, като нов етикет",
    "No tag available. Create one!" : "Няма наличен етикет. Създайте един!",
    "Close" : "Затваряне",
    "Delete all completed tasks." : "Изтрива всички завършени задачи.",
    "Delete completed tasks." : "Изтрива всички задачи.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Всички изпълнени задачи бяха изтрити от календар \"{calendar}\".",
    "No errors" : "Няма грешки",
    "Open your browser console for more details" : "Отворете конзолата на браузъра си за повече подробности",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Това ще изтрие {taskCount} завършените задачи и техните подзадачи от календара \"{calendar}\".","Това ще изтрие {taskCount} завършени задачи и техните подзадачи от календара \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Задачите от {failedCount} не можаха да бъдат изтрити.","Задачите от {failedCount} не можаха да бъдат изтрити."],
    "Select tags to filter by" : "Филтриране по етикет",
    "Add an important task to \"{calendar}\"…" : "Добавя важна задача към \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Добавя задача с днешна дата на изпълнение към \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Добавя текуща задача към \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Добавя задача към \"{calendar}\"...",
    "Load the completed tasks of all lists." : "Зареждане на завършените задачи от всички списъци.",
    "Loading the completed tasks of all lists might slow down the app." : "Зареждането на завършените задачи от всички списъци, може да забави работата на приложението.",
    "Load the completed tasks of list \"{calendar}\"." : "Зареждане на завършените задачи от списък „{calendar}“.",
    "Relevance" : " Съответствие",
    "Sort by completed state, due date, priority, start date and summary." : "Сортиране по състояние на завършеност , краен срок, приоритет, начална дата и обобщение.",
    "Start date" : "Начална дата",
    "Sort by start date, priority and summary." : "Сортиране по начална дата, приоритет и обобщение.",
    "Due date" : "Крайна дата",
    "Sort by due date, priority and summary." : "Сортиране по краен срок, приоритет и обобщение.",
    "Created date" : "Създадена",
    "Sort by created date, priority and summary." : "Сортиране по дата на създаване, приоритет и обобщение.",
    "Last modified" : "Променена",
    "Sort by last-modified date, priority and summary." : "Сортиране по дата на последна промяна, приоритет и обобщение.",
    "Completed date" : "Дата на завършване",
    "Sort by completed date, priority and summary." : "Сортиране по дата на завършване, приоритет и обобщение.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Сортиране поприоритет и обобщение.",
    "Alphabetically" : "По азбучен ред",
    "Sort by summary and priority." : "Сортиране по обобщение и приоритет.",
    "Tags" : "Етикети",
    "Manually" : "Ръчно",
    "Sort by manual order." : "Сортиране по ръчна поръчка.",
    "Change sort order" : "Промени подредбата",
    "[Yesterday]" : "[вчера]",
    "[Today]" : "[днес]",
    "[Tomorrow]" : "[утре]",
    "[Completed yesterday]" : "[Завършен вчера]",
    "[Completed today]" : "[Завършен днес]",
    "[Completed tomorrow]" : "[Завършен утре]",
    "[Yesterday at] LT" : "[Вчера в] LT ",
    "[Today at] LT" : "[Днес в]  LT",
    "[Tomorrow at] LT" : "[Утре в]  LT ",
    "L [at] LT" : "L [в] LT ",
    "[Completed yesterday at] LT" : "[Завършен вчера в] LT",
    "[Completed today at] LT" : "[Завършен днес в] LT ",
    "[Completed tomorrow at] LT" : "[Завършен утре в] LT ",
    "[Completed] L [at] LT" : "[Завършен] L [at] LT",
    "Add a subtask to \"{task}\"…" : "Добави подзадача към \"{task}\"...",
    "Task has hidden subtasks" : "Задачата има скрити подзадачи",
    "Task is pinned" : "Задачата е закачена",
    "Task has a note" : "Задачата има бележка",
    "{complete} % completed" : "{complete} % завършени",
    "Add subtask" : "Добавя подзадача",
    "Show subtasks" : "Показване на подзадачите",
    "Hide subtasks" : "Скриване на подзадачите",
    "Show closed subtasks" : "Показване на затворени подзадачи",
    "Hide closed subtasks" : "Скриване на затворени подзадачи",
    "Delete task" : "Изтрива задача",
    "Toggle starred" : "Означено със звезда",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Изтриване на задача след {countdown} секундии","Изтриване на задача след {countdown} секундии"],
    "Task is cancelled" : "Задачата е отказана",
    "Task is completed" : "Задачата е завършена",
    "Task is read-only" : "Задачата е само за четене",
    "Task is not completed" : "Задачата не е завършена",
    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ беше добавено към „{calendar}“",
    "Create a new task" : "Създаване на нова задача",
    "Task summary" : " Обобщение на задачата",
    "Create task" : "Създаване на задача",
    "Creating the new task…" : "Създаване на новата задача ...",
    "Open task" : "Отваряне на задача",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завършена задача","%n Завършени задачи"],
    "Tomorrow" : "Утре",
    "Add List…" : "Добави списък",
    "New list" : "Нов списък",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "[Completed] L" : "[Завършен] L",
    "[Completed last] dddd [at] LT" : "[Завършен последно] дддд [в] LT",
    "[Completed] dddd [at] LT" : "[Завършен] дддд [в] LT",
    "[Last modified yesterday at] LT" : "[Последна промяна вчера в] LT",
    "[Last modified today at] LT" : "[Последна промяна днес в] LT",
    "[Last modified] L" : "[Последна промяна] L",
    "[Last modified last] dddd [at] LT" : "[Окончателна последна промяна] дддд [в] LT",
    "[Last modified] dddd [at] LT" : "[Последна промяна] дддд [в] LT",
    "[Created yesterday at] LT" : "[Създадено вчера в] LT",
    "[Created today at] LT" : "[Създадено днес в] LT",
    "[Created] L" : "[Създадено] L",
    "[Created last] dddd [at] LT" : "[Създадено последно] дддд [в] LT",
    "[Created] dddd [at] LT" : "[Създадено] дддд [в] LT",
    "Needs action" : "Необходимо е действие",
    "In process" : "В процес",
    "Canceled" : "Отказано",
    "Clear status" : "Изчистване на състоянието",
    "Loading task from server." : "Зарежда се задача от сървъра.",
    "Task not found!" : "Задачата не е намерена!",
    "Set start date" : "Начална дата",
    "Set due date" : "Крайна дата",
    "Priority {priority}: low" : "Приоритет {priority}: нисък",
    "Priority {priority}: medium" : "Приоритет {priority}: среден",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Няма определен приоритет",
    "{percent} % completed" : "{complete} % завършени",
    "All day" : "Цял ден",
    "Unpin" : "Отмяна на закачване",
    "Pin" : " Закачване",
    "Show in Calendar" : "Показване в Календар",
    "Show in Deck" : "Покажи в Deck",
    "Details" : "Подробности",
    "Selecting a classification is forbidden, because the task was shared with you." : "Избирането на класификация е забранено, тъй като задачата е била споделена с вас.",
    "Select a classification" : "Избор на класификация",
    "Select a status" : "Избор на състояние",
    "Select tags" : "Избор на етикети",
    "Notes" : "Бележки",
    "Mark as done" : "Маркирай като готово",
    "No due date assigned" : "Не е определен краен срок",
    "[Due yesterday]" : "[Краен срок, вчера]",
    "[Due today]" : "[Краен срок днес]",
    "[Due tomorrow]" : "[Краен срок утре]",
    "[Due] L" : "[Краен срок] L",
    "[Due yesterday at] LT" : "[Краен срок, вчера в] LT",
    "[Due today at] LT" : "[Краен срок днес в] LT",
    "[Due tomorrow at] LT" : "[Краен срок утре в] LT",
    "[Due] L [at] LT" : "[Краен срок] L [в] LT",
    "No upcoming tasks" : "Няма предстоящи задачи",
    "upcoming tasks" : "предстоящи задачи",
    "No tasks today" : "Днес няма задачи",
    "Successfully created the task." : "Успешно създаване на задачата.",
    "Could not delete the task." : "Задачата не можа да се изтрие.",
    "Synchronizing to the server." : "Синхронизиране със сървъра.",
    "Task successfully saved to server." : "Задачата е успешно запазена на сървъра.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Задачата не можа да се актуализира, защото беше променена на сървъра. Моля, кликнете, за да го опресните, местните промени ще бъдат отхвърлени.",
    "Could not update the task." : "Задачата не можа да се актуализира.",
    "Successfully updated the task." : "Успешно актуализиране на задачата.",
    "Task successfully moved to new calendar." : "Задачата беше успешно преместена в нов календар.",
    "An error occurred" : "Възникна грешка",
    "Create a task" : "Създаване на задача",
    "Message from {author} in {conversationName}" : "Съобщение от {author} в {conversationName}",
    "[Due on] LL" : "[Краен срок на] LL",
    "[Was due yesterday]" : "[Крайният срок е бил вчера]",
    "[Was due on] LL" : "[Крайният срок е бил на] LL",
    "[Was due today at] LT" : "[Крайният срок е бил днес в] LT",
    "[Due on] LL [at] LT" : "[Краен срок на] LL [в] LT",
    "[Was due yesterday at] LT" : "[Крайният срок е бил вчера в] LT",
    "[Was due on] LL [at] LT" : "[Крайният срок е бил на] LL [в] LT",
    "[Starts today]" : "[Започва днес]",
    "[Starts tomorrow]" : "[Започва утре]",
    "[Starts on] LL" : "[Започва на]  LL",
    "[Started yesterday]" : "[Започнато вчера]",
    "[Started on] LL" : "[Започнато на]  LL",
    "[Started today at] LT" : "[Започнато днес] LT",
    "[Starts today at] LT" : "[Започва днес в] LT",
    "[Starts tomorrow at] LT" : "[Започва утре в] LT",
    "[Starts on] LL [at] LT" : "[Започва на]  LL  [в] LT",
    "[Started yesterday at] LT" : "[Започнато вчера в] LT",
    "[Started on] LL [at] LT" : "[Започнато на]  LL  [в] LT"
},
"nplurals=2; plural=(n != 1);");
