OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Nadchádzajúce úlohy",
    "Important" : "Dôležité",
    "Today" : "Dnes",
    "Week" : "Týždeň",
    "All" : "Všetky",
    "Current" : "Aktuálne",
    "Completed" : "Dokončené",
    "Tasks" : "Úlohy",
    "The Tasks app for Nextcloud" : "Aplikácia úloh pre Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Po povolení sa objaví nové menu Úlohy v aplikáciách Nextcloud. Odtiaľ možno pridávať a mazať úlohy, upravovať ich názov, popis, dátum začiatku a termín dokončenia, časy upozornení, označovať ich ako dôležité. Úlohy možno zdieľať medzi užívateľmi. Úlohy možno synchronizovať pomocou CalDav (každý zoznam úloh prepojený na kalendár Nextcloud sa dá synchronizovať s lokálnym klientom -Thunderbird, Evolution, KDE Kontact, iCal... - stačí pridať ako vzdialený kalendár v klientovi). Je možné stiahnuť úlohy ako súbory ICS pomocou tlačítka stiahnuť pri každom kalendári",
    "Hidden" : "Skryté",
    "Visible" : "Viditeľné",
    "Automatic" : "Automaticky",
    "Tasks settings" : "Nastavenia úloh",
    "Default list" : "Predvolený zoznam",
    "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
    "Share with users or groups" : "Sprístupniť užívateľom alebo skupinám",
    "No users or groups" : "Žiadni užívatelia alebo skupiny",
    "Unable to delete the share." : "Nepodarilo sa zmazať zdieľanie.",
    "Unable to change permissions." : "Nepodarilo sa zmeniť oprávnenia.",
    "Can edit" : "Môže upravovať",
    "Unshare with {displayName}" : "Zrušiť zdieľanie s {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Táto operácia odstráni kalendár \"{calendar}\" a všetky jeho udalosti a úlohy.",
    "This will unshare the calendar \"{calendar}\"." : "Toto zruší zdieľanie kalendára \"{calendar}\" .",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Táto operácia odstráni zoznam \"{list}\" a všetky príslušné úlohy.",
    "This will unshare the list \"{list}\"." : "Toto zruší zdieľanie zoznamu {list}.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendár bude zmazaný za {countdown} sekundu","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekúnd"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zdieľanie kalendára bude zmazané za {countdown} sekundu","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekúnd"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Zoznam sa odstráni o {countdown} sekundu","Zoznam sa odstráni o {countdown} sekundy","Zoznam sa odstráni o {countdown} sekundy","Zoznam sa odstráni o {countdown} sekúnd"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Zrušenie zdieľania zoznamu o {countdown} sekundu","Zrušenie zdieľania zoznamu o {countdown} sekundy","Zrušenie zdieľania zoznamu o {countdown} sekundy","Zrušenie zdieľania zoznamu o {countdown} sekúnd"],
    "Share this calendar" : "Zdieľať tento kalendár",
    "Share this list" : "Zdieľať tento zoznam",
    "Calendar link copied to clipboard." : "Odkaz na kalendár skopírovaný do schránky.",
    "List link copied to clipboard." : "Odkaz na zoznam bol skopírovaný do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendár nebolo možné  skopírovať do schránky.",
    "List link could not be copied to clipboard." : "Odkaz na zoznam sa nepodarilo skopírovať do schránky.",
    "The name \"{calendar}\" is already used." : "Názov \"{calendar}\" je už použitý.",
    "An empty name is not allowed." : "Prázdny názov nie je povolený",
    "An error occurred, unable to delete the calendar." : "Vyskytla sa chyba, nie je možné zmazať kalendár.",
    "An error occurred, unable to delete the list." : "Vyskytla sa chyba, zoznam sa nepodarilo odstrániť.",
    "Edit" : "Upraviť",
    "Copy private link" : "Kopírovať privátny odkaz",
    "Copied" : "Skopírované",
    "Cannot copy" : "Nemôže kopírovať",
    "Export" : "Export",
    "Delete" : "Zmazať",
    "Unshare" : "Zneprístupniť",
    "List name" : "Názov zoznamu",
    "Untitled task" : "Úloha bez názvu",
    "Untitled event" : "Udalosť bez názvu",
    "Untitled journal" : "Denník bez názvu",
    "Untitled item" : "Položka bez názvu",
    "Unknown calendar" : "Neznámy kalendár",
    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
    "Could not delete calendar or event" : "Nie je možné vymazať kalendár alebo udalosť",
    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
    "Do you really want to empty the trash bin?" : "Naozaj chcete vymazať kôš?",
    "Empty trash bin" : "Vyprázdniť kôš",
    "Trash bin" : "Kôš",
    "Loading deleted calendars, tasks and events." : "Načítavajú sa zmazané kalendáre, úlohy alebo udalosti.",
    "You do not have any deleted calendars, tasks or events." : "Nemáte žiadne zmazané kalendáre, úlohy alebo udalosti.",
    "Name" : "Názov",
    "Deleted" : "Zmazané",
    "Restore" : "Obnoviť",
    "Delete permanently" : "Zmazať  natrvalo",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Položky v odpadkovom koši budú odstránené po {numDays} dni","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch","Položky v odpadkovom koši budú odstránené po {numDays} dňoch"],
    "Create reminder" : "Vytvoriť pripomienku",
    "Update reminder" : "Aktualizovať pipomienku",
    "Set a reminder at a custom date and time:" : "Nastaviť pripomienku a vlastný dátum a čas:",
    "Cancel" : "Zrušiť",
    "This is a todo reminder." : "Toto je pripomienka úloh.",
    "No reminders" : "Žiadne pripomienky",
    "Notification" : "Oznámenie",
    "Email" : "E-mail",
    "Audio notification" : "Hlasový oznam",
    "Other notification" : "Ostatné hlásenia",
    "Edit time" : "Zmeniť čas pripomienky",
    "Remove reminder" : "Odstrániť pripomienku",
    "Add reminder" : "Pridať pripomienku",
    "Before the task starts" : "Predtým než úloha začne",
    "Before the task is due" : "Predtým než je úloha splnená",
    "Select date and time" : "Vybrať dátum a čas",
    "Go back" : "Ísť späť",
    "Set a reminder relative to your tasks start date:" : "Nastavte pripomienku vzhľadom na dátum začatia úloh:",
    "Set a reminder relative to your tasks due date:" : "Nastavte pripomienku vzhľadom na dátum splnenia úloh:",
    "before at" : "pred o",
    "_second_::_seconds_" : ["sekunda","sekundy","sekúnd","sekúnd"],
    "_minute_::_minutes_" : ["minúta","minúty","minút","minút"],
    "_hour_::_hours_" : ["hodina","hodiny","hodín","hodín"],
    "_day_::_days_" : ["deň","dní","dní","dní"],
    "_week_::_weeks_" : ["týždeň","týždne","týždňov","týždňov"],
    "Select a calendar" : "Vybrať kalendár",
    "No calendar matches the search." : "Vyhľadávaniu nezodpovedá žiadny kalendár.",
    "Set date" : "Nastaviť dátum",
    "Set time" : "Nastaviť čas",
    "Delete date" : "Zmazať dátum",
    "Click here to add a note." : "Kliknite sem pre pridanie poznámky.",
    "Set value" : "Nastaviť hodnotu",
    "Delete value" : "Vymazať hodnotu",
    "Add this as a new tag" : "Pridať ako nový štítok",
    "No tag available. Create one!" : "Žiadny štítok. Vytvorte nejaký!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} úloh bolo pridaných do \"{calendar}\"",
    "Create new tasks" : "Vytvoriť nové úlohy",
    "Create {numberOfTasks} tasks from pasted text" : "Vytvoriť {numberOfTasks} úloh z vloženého textu",
    "Create tasks" : "Vytvoriť úlohy",
    "Creating new tasks…" : "Vytváram nové úlohy..",
    "Close" : "Zatvoriť",
    "Delete all completed tasks." : "Zmazať všetky ukončené úlohy",
    "Delete completed tasks." : "Zmazať ukončené úlohy",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Zmazať všetky ukončené úlohy z kalendára \"{calendar}\".",
    "No errors" : "Žiadne chyby",
    "Open your browser console for more details" : "Pre podrobnejšie informácie otvorte konzolu vášho webového prehliadača",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Toto vymaže {taskCount} ukočenú úlohu a jej čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukočené úlohy a ich čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukočených úloh a ich čiastkové úlohy z kalendára \"{calendar}\".","Toto vymaže {taskCount} ukončených úloh a ich čiastkové úlohy z kalendára \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nepodarilo sa zmazať {failedCount} úlohu.","Nepodarilo sa zmazať {failedCount} úlohy.","Nepodarilo sa zmazať {failedCount} úloh.","Nepodarilo sa zmazať {failedCount} úloh."],
    "Active filter" : "Aktívny filter",
    "Filter by tags" : "Filtrovať podľa štítkov",
    "Select tags to filter by" : "Vybrať štítky na filtrovanie",
    "Reset filter" : "Resetovať filter",
    "Add an important task to \"{calendar}\"…" : "Pridať dôležitú úlohu do kalendára \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Pridať úlohu s termínom ukončenia dnes do kalendára \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Pridať aktuálnu úlohu do kalendára \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Pridať úlohu do \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Načítajte dokončené úlohy všetkých zoznamov.",
    "Loading the completed tasks of all lists might slow down the app." : "Načítanie dokončených úloh všetkých zoznamov môže spomaliť aplikáciu.",
    "Load the completed tasks of list \"{calendar}\"." : "Načítať dokončené úlohy zoznamu \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Načítavanie dokončených úloh môže spomaliť aplikáciu.",
    "Relevance" : "Relevantnosť",
    "Sort by completed state, due date, priority, start date and summary." : "Zoradiť podľa stavu dokončenia, termínu dokončenia, priority, dátumu začiatku a súhrnu.",
    "Start date" : "Dátum začatia",
    "Sort by start date, priority and summary." : "Zoradiť podľa počiatočného dátumu, priority a súhrnu.",
    "Due date" : "Termín dokončenia",
    "Sort by due date, priority and summary." : "Zoradiť podľa termínu dokončenia, priority a súhrnu.",
    "Created date" : "Dátum vytvorenia",
    "Sort by created date, priority and summary." : "Zoradiť podľa dátumu vytvorenia, priority a súhrnu.",
    "Last modified" : "Naposledy upravené",
    "Sort by last-modified date, priority and summary." : "Zoradiť podľa dátumu poslednej zmeny, priority a súhrnu.",
    "Completed date" : "Dátum dokončenia",
    "Sort by completed date, priority and summary." : "Zoradiť podľa dátumu dokončenia, priority a súhrnu.",
    "Priority" : "Priorita",
    "Sort by priority and summary." : "Zoradiť podľa priority a súhrnu.",
    "Alphabetically" : "Abecedne",
    "Sort by summary and priority." : "Zoradiť podľa súhrnu a priority.",
    "Tags" : "Štítky",
    "Sort by tags." : "Zoradiť podľa štítkov.",
    "Manually" : "Manuálne",
    "Sort by manual order." : "Zoradiť manuálne.",
    "Change sort order" : "Zmeniť spôsob zoradenia",
    "[Yesterday]" : "[Včera]",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zajtra]",
    "[Completed yesterday]" : "[Dokončené včera]",
    "[Completed today]" : "[Dokončené dnes]",
    "[Completed tomorrow]" : "[Dokončené zajtra]",
    "[Yesterday at] LT" : "[Včera o] LT",
    "[Today at] LT" : "[Dnes o] LT",
    "[Tomorrow at] LT" : "[Zajtra o] LT",
    "L [at] LT" : "L [o] LT",
    "[Completed yesterday at] LT" : "[Dokončené včera o] LT",
    "[Completed today at] LT" : "[Dokončené dnes o] LT",
    "[Completed tomorrow at] LT" : "[Dokončené zajtra o] LT",
    "[Completed] L [at] LT" : "[Dokončené] L [o] LT",
    "Add a subtask to \"{task}\"…" : "Pridať čiastkovú úlohu do  \"{task}\"…",
    "Task has hidden subtasks" : "Úloha ma skryté podúlohy",
    "Task is pinned" : "Úloha je pripnutá",
    "Task has a note" : "Úloha má poznámku",
    "{complete} % completed" : "{complete} % hotovo",
    "Add subtask" : "Pridať čiastkovú úlohu",
    "Show subtasks" : "Zobraziť čiastkové úlohy",
    "Hide subtasks" : "Skryť čiastkové úlohy",
    "Show closed subtasks" : "Zobraziť uzavreté čiastkové úlohy",
    "Hide closed subtasks" : "Skryť uzavreté čiastkové úlohy",
    "Delete task" : "Odstrániť úlohu",
    "Toggle starred" : "Prepnúť na ohviedzičkované",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Úloha má jednu pripomienku","Úloha má {n} pripomienky","Úloha má {n} pripomienok","Úloha má {n} pripomienok"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Odstránenie úlohy o {countdown} sekundu","Odstránenie úlohy o {countdown} sekundy","Odstránenie úlohy o {countdown} sekundy","Odstránenie úlohy o {countdown} sekúnd"],
    "Task is cancelled" : "Úloha je zrušená",
    "Task is completed" : "Úloha je dokončená",
    "Task is read-only" : "Úloha je iba na čítanie",
    "Task is not completed" : "Úloha nie je dokončená",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" bola pridaná do \"{calendar}\"",
    "Create a new task" : "Vytvoriť novú úlohu",
    "Task summary" : "Zhrnutie úlohy",
    "Create task" : "Vytvoriť úlohu",
    "Creating the new task…" : "Vytváram novú úlohu...",
    "Open task" : "Otvoriť úlohu",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
    "Tomorrow" : "Zajtra",
    "An error occurred, unable to create the list." : "Vyskytla sa chyba, zoznam sa nepodarilo vytvoriť.",
    "Add List…" : "Pridať zoznam",
    "New list" : "Nový zoznam",
    "When shared show full event" : "Pri zdieľaní zobraziť udalosť úplne",
    "When shared show only busy" : "Pri zdieľaní zobraziť len zaneprázdnený",
    "When shared hide this event" : "Pri zdieľaní skryť udalosť",
    "[Completed] L" : "[Dokončené] L",
    "[Completed last] dddd [at] LT" : "[Posledné dokončené] dddd [o] LT",
    "[Completed] dddd [at] LT" : "[Dokončené] dddd [o] LT",
    "[Last modified yesterday at] LT" : "[Posledná zmena včera o] LT",
    "[Last modified today at] LT" : "[Posledná zmena dnes o] LT",
    "[Last modified] L" : "[Naposledy zmenené] L",
    "[Last modified last] dddd [at] LT" : "[Posledné naposledy zmenené] dddd [o] LT",
    "[Last modified] dddd [at] LT" : "[Naposledy zmenené] dddd [o] LT",
    "[Created yesterday at] LT" : "[Vytvorené včera o] LT",
    "[Created today at] LT" : "[Vytvorené dnes o] LT",
    "[Created] L" : "[Vytvorené] L",
    "[Created last] dddd [at] LT" : "[Posledné vytvorené] dddd [o] LT",
    "[Created] dddd [at] LT" : "[Vytvorené] dddd [o] LT",
    "Needs action" : "Vyžaduje akciu",
    "In process" : "V priebehu",
    "Canceled" : "Zrušené",
    "Clear status" : "Vyčistiť stav",
    "Loading task from server." : "Nahrať úlohu zo servera.",
    "Task not found!" : "Úloha nebola nájdená!",
    "Set start date" : "Nastaviť dátum začatia",
    "Set due date" : "Nastaviť do dátumu",
    "Priority {priority}: low" : "Priorita {priority}: nízka",
    "Priority {priority}: medium" : "Priorita {priority}: stredná",
    "Priority {priority}: high" : "Priorita {priority}: vysoká",
    "No priority assigned" : "Nepridelená žiadna priorita",
    "{percent} % completed" : "{percent} % hotovo",
    "All day" : "Celý deň",
    "Unpin" : "Odopnúť",
    "Pin" : "Pripnúť",
    "Show in Calendar" : "Zobraziť v Kalendári",
    "Show in Deck" : "Zobraziť v Deck",
    "Edit summary" : "Úprava súhrnu",
    "Details" : "Podrobnosti",
    "Selecting a classification is forbidden, because the task was shared with you." : "Výber klasifikácie je zakázaný, pretože úloha bola s vami zozdieľaná.",
    "Select a classification" : "Vybrať klasifikáciu",
    "Select a status" : "Vybrať status",
    "Set a location" : "Nastaviť polohu",
    "Set a URL" : "Nastaviť URL",
    "Select tags" : "Vyberte štítky",
    "Notes" : "Poznámky",
    "Mark as done" : "Označiť ako dokončené",
    "No due date assigned" : "Nie je priradený žiadny dátum platnosti",
    "[Due yesterday]" : "[Termín včera]",
    "[Due today]" : "[Termín ukončenia dnes]",
    "[Due tomorrow]" : "[Termín ukončenia zajtra]",
    "[Due] L" : "[Termín] L",
    "[Due yesterday at] LT" : "[Termín včera o] LT",
    "[Due today at] LT" : "[Termín ukončenia dnes o] LT",
    "[Due tomorrow at] LT" : "[Termín ukončenia zajtra o] LT",
    "[Due] L [at] LT" : "[Termín] L [o] LT",
    "No upcoming tasks" : "Žiadne nadchádzajúce úlohy",
    "upcoming tasks" : "nadchádzajúce úlohy",
    "No tasks today" : "Dnes žiadne úlohy",
    "Completion date must be in the past." : "Dátum ukončenia musí byť v minulosti.",
    "Successfully created the task." : "Úloha bola úspešne vytvorená.",
    "Could not delete the task." : "Nepodarilo sa zmazať úlohu.",
    "Synchronizing to the server." : "Synchronizácia so serverom.",
    "Task successfully saved to server." : "Úloha úspešne uložená na server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nepodarilo sa upraviť úlohu, pretože bola zmenená na serveri. Kliknite na obnovenie, lokálne vykonané zmeny budú zahodené.",
    "Could not update the task." : "Nepodarilo sa upraviť úlohu.",
    "Successfully updated the task." : "Úloha bola úspešne upravená.",
    "Task successfully moved to new calendar." : "Úloha úspešne presunutá do nového kalendára.",
    "An error occurred" : "Vyskytla sa chyba",
    "Create a task" : "Vytvoriť úlohu",
    "Message from {author} in {conversationName}" : "Správa od {author} v {conversationName}",
    "[Due on] LL" : "[Termín ukončenia] LL",
    "[Was due yesterday]" : "[Termín ukončenia bol včera]",
    "[Was due on] LL" : "[Termín ukončenia bol] LL",
    "[Was due today at] LT" : "[Termín ukončenia bol dnes o] LT",
    "[Due on] LL [at] LT" : "[Termín ukončenia] LL [o] LT",
    "[Was due yesterday at] LT" : "[Termín ukončenia bol včera o] LT",
    "[Was due on] LL [at] LT" : "[Termín ukončenia bol] LL [o] LT",
    "[Starts today]" : "[Začína dnes]",
    "[Starts tomorrow]" : "[Začína zajtra]",
    "[Starts on] LL" : "[Začína] LL",
    "[Started yesterday]" : "[Začalo včera]",
    "[Started on] LL" : "[Začalo] LL",
    "[Started today at] LT" : "[Začalo dnes o] LT",
    "[Starts today at] LT" : "[Začne dnes o] LT",
    "[Starts tomorrow at] LT" : "[Začne zajtra o] LT",
    "[Starts on] LL [at] LT" : "[Začne] LL [o] LT",
    "[Started yesterday at] LT" : "[Začalo včera o] LT",
    "[Started on] LL [at] LT" : "[Začalo] LL [o] LT",
    "Midnight on the day the task starts" : "Najbližšia polnoc deň pred začiatkom úlohy",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n deň pred úlohou o {formattedHourMinute}","%n dni pred úlohou o {formattedHourMinute}","%n dní pred úlohou o {formattedHourMinute}","%n dní pred úlohou o {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n týždeň pred úlohou o {formattedHourMinute}","%n týždne pred úlohou o {formattedHourMinute}","%n týždňov pred úlohou o {formattedHourMinute}","%n týždňov pred úlohou o {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "v dni prebiehajúcej úlohy o {formattedHourMinute}",
    "at the task's start" : "na začiatku úlohy",
    "when the task is due" : "keď je úloha splnená",
    "{time} before the task starts" : "{time} pred začiatkom úlohy",
    "{time} before the task is due" : "{time} pred splnením úlohy",
    "{time} after the task starts" : "{time} po začiatku úlohy",
    "{time} after the task is due" : "{time} po splnení úlohy"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
