import{_ as r,c as t,o as l,a as n,b as o,t as c,m as d}from"./index-Md6Dd2Tg.chunk.mjs";const m={name:"PlusIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},p=["aria-hidden","aria-label"],u=["fill","width","height"],g={d:"M19,13H13V19H11V13H5V11H11V5H13V11H19V13Z"},h={key:0};function f(a,e,i,H,V,k){return l(),t("span",d(a.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon plus-icon",role:"img",onClick:e[0]||(e[0]=s=>a.$emit("click",s))}),[(l(),t("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[n("path",g,[i.title?(l(),t("title",h,c(i.title),1)):o("",!0)])],8,u))],16,p)}const C=r(m,[["render",f]]);export{C as P};
//# sourceMappingURL=Plus-BpYRVs-r.chunk.mjs.map
