OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Найближчі завдання",
    "Important" : "Важливі",
    "Today" : "Сьогодні",
    "Week" : "Тиждень",
    "All" : "Всі",
    "Current" : "Поточні",
    "Completed" : "Виконано",
    "Tasks" : "Завдання",
    "The Tasks app for Nextcloud" : "Застосунок \"Завдання\" (Tasks) для Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Після увімкнення в меню застосунків Nextcloud з’явиться нове меню завдань. Звідти ви можете додавати та видаляти завдання, редагувати їх назву, опис, дати початку й виконання та позначати їх як важливі. Завдання можна розподіляти між користувачами. Завдання можна синхронізувати за допомогою CalDav (кожен список завдань пов’язано з календарем Nextcloud, щоб синхронізувати його з вашим локальним клієнтом: Thunderbird, Evolution, KDE Kontact, iCal… – просто додайте календар як віддалений календар у вашому клієнті). Ви можете звантажити свої завдання як файли ICS за допомогою кнопки звантаження для кожного календаря.",
    "Hidden" : "Прихований",
    "Visible" : "Видимий",
    "Automatic" : "Автоматично",
    "Tasks settings" : "Налаштування",
    "Default list" : "Типовий список",
    "Visibility of Smart Collections" : "Розумне групування",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "No users or groups" : "Жодного користувача або групм",
    "Unable to delete the share." : "Неможливо вилучити спільний елемент.",
    "Unable to change permissions." : "Неможливо змінити права доступу.",
    "Can edit" : "Може редагувати",
    "Unshare with {displayName}" : "Прибрати зі спільного доступу з {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Це призведе до вилучення календаря \"{calendar}\" і всіх відповідних подій і завдань.",
    "This will unshare the calendar \"{calendar}\"." : "Це припинить доступ до календаря \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Це призведе до вилучення списку \"{list}\" і всіх відповідних завдань.",
    "This will unshare the list \"{list}\"." : "Це скасує доступ до списку \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календар буде вилучено через {countdown} секунду","Календар буде вилучено через {countdown} секунди","Календар буде вилучено через {countdown} секунд","Календар буде вилучено через {countdown} секунд"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Скасування доступу до календаря через {countdown} секунду","Скасування доступу до календаря через {countdown} секунд","Скасування доступу до календаря через {countdown} секунд","Скасування доступу до календаря через {countdown} секунд"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Список завдань буде вилучено через {countdown} секунду","Список завдань буде вилучено через {countdown} секунди","Список завдань буде вилучено через {countdown} секунд","Список завдань буде вилучено через {countdown} секунд"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Скасування доступу до списку через {countdown} секунду","Скасування доступу до списку через {countdown} секунд","Скасування доступу до списку через {countdown} секунд","Скасування доступу до списку через {countdown} секунд"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Надано доступ {num} об’єкту","Надано доступ {num} об’єктам","Надано доступ {num} об’єктам","Надано доступ {num} об’єктам"],
    "Share this calendar" : "Поділитися цим календарем",
    "Share this list" : "Поділітися цим списком",
    "Calendar link copied to clipboard." : "Посилання на календар зкопійовано до буфера обміну",
    "List link copied to clipboard." : "Посилання на список скопійовано в буфер обміну.",
    "Calendar link could not be copied to clipboard." : "Посилання на календар не може бути зкопійоване до буфера обміну",
    "List link could not be copied to clipboard." : "Не вдалося скопіювати посилання на список до буфера обміну.",
    "The name \"{calendar}\" is already used." : "Назва \"{календар}\" уже використовується.",
    "An empty name is not allowed." : "Порожнє поле не допускається.",
    "An error occurred, unable to delete the calendar." : "Помилка: не вдалося вилучити календар.",
    "An error occurred, unable to delete the list." : "Помилка: не вдалося вилучити список.",
    "Edit" : "Редагувати",
    "Copy private link" : "Копіювати приватне посилання",
    "Copied" : "Скопійовано",
    "Cannot copy" : "Неможливо скопіювати",
    "Export" : "Експорт",
    "Delete" : "Вилучити",
    "Unshare" : "Закрити доступ",
    "List name" : "Назва списку",
    "Untitled task" : "Завдання без назви",
    "Untitled event" : "Подія без назви",
    "Untitled journal" : "Журнал без назви",
    "Untitled item" : "Елемент без назви",
    "Unknown calendar" : "Невідомий календар",
    "Could not load deleted calendars and objects" : "Не вдалося отримати календарі та об’єкти, які було раніше вилучено",
    "Could not delete calendar or event" : "Не вдалося вилучити календар або подію",
    "Could not restore calendar or event" : "Не вдалося відновити календар або подію",
    "Do you really want to empty the trash bin?" : "Ви дійсно хочете очистити кошик?",
    "Empty trash bin" : "Очистити кошик",
    "Trash bin" : "Кошик",
    "Loading deleted calendars, tasks and events." : "Завантаження календарів, завдань та подій, які було вилучено.",
    "You do not have any deleted calendars, tasks or events." : "У вас немає календарів, завдань або подій, які було вилучено.",
    "Name" : "Ім'я",
    "Deleted" : "Вилучено",
    "Restore" : "Відновити",
    "Delete permanently" : "Вилучити назавжди",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Елементи в кошику буде вилучено за {numDays} день","Елементи в кошику буде вилучено за {numDays} дні","Елементи в кошику буде вилучено за {numDays} днів","Елементи в кошику буде вилучено через {numDays} днів"],
    "Create reminder" : "Створити нагадування",
    "Update reminder" : "Оновити нагадування",
    "Set a reminder at a custom date and time:" : "Встановити нагадування на визначену дату та час:",
    "Cancel" : "Скасувати",
    "This is a todo reminder." : "Це нагадування для виконання дії.",
    "No reminders" : "Відсутні нагадування",
    "Notification" : "Сповіщення",
    "Email" : "Ел.пошта",
    "Audio notification" : "Звукове сповіщення",
    "Other notification" : "Інше сповіщення",
    "Edit time" : "Редагувати час",
    "Remove reminder" : "Прибрати нагадування",
    "Add reminder" : "Додати нагадування",
    "Before the task starts" : "До початку завдання",
    "Before the task is due" : "Перед завершенням завдання",
    "Select date and time" : "Вибрати дату та час",
    "Go back" : "Повернутися назад",
    "Do you want to keep related reminders?" : "Чи ви бажаєте зберегти дотичні нагадування?",
    "Discard reminders" : "Скасувати нагадування",
    "Keep reminders" : "Зберегти нагадування",
    "Set a reminder relative to your tasks start date:" : "Встановити нагадування залежно від дати початку завдання:",
    "Set a reminder relative to your tasks due date:" : "Встановити нагадування залежно від дати виконання завдання:",
    "before at" : "до о",
    "_second_::_seconds_" : ["секунда","секунд","секунд","секунди"],
    "_minute_::_minutes_" : ["хвилина","хвилин","хвилин","хвилини"],
    "_hour_::_hours_" : ["година","годин","годин","години"],
    "_day_::_days_" : ["день","дні","дні","дні"],
    "_week_::_weeks_" : ["тиждень","тижнів","тижнів","тижні"],
    "Select a calendar" : "Вибрати календар",
    "No calendar matches the search." : "Жоден календар не відповідає запиту.",
    "Set date" : "Встановити дату",
    "Set time" : "Встановити час",
    "Delete date" : "Вилучити дату",
    "Click here to add a note." : "Додайте опис",
    "Set value" : "Встановити значення",
    "Delete value" : "Очистити значення",
    "Add this as a new tag" : "Додайте це як нову мітку",
    "No tag available. Create one!" : "Мітки відсутні. Додайте зараз!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "Додано {numberOfTasks} завдань до календаря \"{calendar}\"",
    "Create new tasks" : "Створити нові завдання",
    "Create {numberOfTasks} tasks from pasted text" : "Створити {numberOfTasks} завдань зі скопійованого тексту",
    "Create tasks" : "Створити завдання",
    "Creating new tasks…" : "Створення нових завдань...",
    "Close" : "закрити",
    "Delete all completed tasks." : "Вилучити усі виконані завдання.",
    "Delete completed tasks." : "Вилучити виконані завдання.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Вилучено усі виконані завдання з календаря \"{calendar}\".",
    "No errors" : "Без помилок",
    "Open your browser console for more details" : "Відкрийте консоль браузера для докладної інформації",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Це призведе до вилучення {taskCount} виконаного завдання та підзавдань з календаря \"{calendar}\".","Це призведе до вилучення {taskCount} виконаних завдань та підзавдань з календаря \"{calendar}\".","Це призведе до вилучення {taskCount} виконаних завдань та підзавдань з календаря \"{calendar}\".","Це призведе до вилучення {taskCount} виконаних завдань та підзавдань з календаря \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Не вдалося вилучити {failedCount} завдання.","Не вдалося вилучити {failedCount} завдання.","Не вдалося вилучити {failedCount} завдань.","Не вдалося вилучити {failedCount} завдань."],
    "Active filter" : "Активний фільтр",
    "Filter by tags" : "Фільтр міток",
    "Select tags to filter by" : "Фільтр вибору мітки за",
    "Reset filter" : "Скинути фільтр",
    "Add an important task to \"{calendar}\"…" : "Додати важливе завдання до \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Додати завдання до \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Додати це завдання до \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Додати завдання до \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Завантаження виконаних завдань зі всіх списків.",
    "Loading the completed tasks of all lists might slow down the app." : "Завантаження виконаних завдань зі всіх списків може уповільнити роботу застосунку.",
    "Load the completed tasks of list \"{calendar}\"." : "Завантаження виконаних завдань зі списку \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Завантаження завершених завдань може сповільнити роботу застосунку.",
    "Relevance" : "Відповідність",
    "Sort by completed state, due date, priority, start date and summary." : "Впорядкувати за станом, терміном виконання, пріоритетом, датою початку та підсумком.",
    "Start date" : "Дата початку",
    "Sort by start date, priority and summary." : "Впорядкувати за датою початку, пріоритетом та описом.",
    "Due date" : "Дата виконання",
    "Sort by due date, priority and summary." : "Впорядкувати за датою запланованого виконання, пріоритетом та описом.",
    "Created date" : "Дата створення",
    "Sort by created date, priority and summary." : "Впорядкувати за датою створення, пріоритетом та описом.",
    "Last modified" : "Останні зміни",
    "Sort by last-modified date, priority and summary." : "Впорядкувати за датою змін, пріоритетом та підсумками.",
    "Completed date" : "Виконано",
    "Sort by completed date, priority and summary." : "Впорядкувати за датою виконання, пріоритетом та описом.",
    "Priority" : "Пріоритет",
    "Sort by priority and summary." : "Впорядкувати за пріоритетом та описом.",
    "Alphabetically" : "Назва",
    "Sort by summary and priority." : "Впорядкувати за описом та пріоритетом.",
    "Tags" : "Мітки",
    "Sort by tags." : "Впорядковувати за мітками.",
    "Manually" : "Вручну",
    "Sort by manual order." : "Впорядкувати вручну.",
    "Change sort order" : "Впорядкувати",
    "[Yesterday]" : "[Вчора]",
    "[Today]" : "[Сьогодні]",
    "[Tomorrow]" : "[Завтра]",
    "[Completed yesterday]" : "[Виконано вчора]",
    "[Completed today]" : "[Виконано сьогодні]",
    "[Completed tomorrow]" : "[Буде виконано завтра]",
    "[Yesterday at] LT" : "[Вчора о] LT",
    "[Today at] LT" : "[Сьогодні о] LT",
    "[Tomorrow at] LT" : "[Завтра о] LT",
    "L [at] LT" : "L [,] LT",
    "[Completed yesterday at] LT" : "[Виконано вчора о] LT",
    "[Completed today at] LT" : "[Виконано сьогодні о] LT",
    "[Completed tomorrow at] LT" : "[Буде виконано завтра о] LT",
    "[Completed] L [at] LT" : "[Виконано] L [о] LT",
    "Add a subtask to \"{task}\"…" : "Додати підзавдання до \"{task}\"…",
    "Task has hidden subtasks" : "Завдання має приховані підзадачі",
    "Task is pinned" : "Завдання закріплено",
    "Task has a note" : "Завдання має опис",
    "{complete} % completed" : "{complete}% виконання",
    "Add subtask" : "Додати підзавдання",
    "Show subtasks" : "Показати підзавдання",
    "Hide subtasks" : "Приховати підзавдання",
    "Show closed subtasks" : "Показати закриті підзавдання",
    "Hide closed subtasks" : "Приховати закриті підзавдання",
    "Delete task" : "Вилучити завдання",
    "Toggle starred" : "Перемкнути зірочку",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Завдання має одне нагадування","Завдання має {n} нагадування","Завдання має {n} нагадувань","Завдання має {n} нагадувань"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Завдання буде вилучено через {countdown} секунду","Завдання буде вилучено через {countdown} секунди","Завдання буде вилучено через {countdown} секунд","Завдання буде вилучено через {countdown} секунд"],
    "Task is cancelled" : "Завдання скасовано",
    "Task is completed" : "Завдання виконано",
    "Task is read-only" : "Завдання доступне лише для читання",
    "Task is not completed" : "Завдання не виконано",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" додано до \"{calendar}\"",
    "Create a new task" : "Створіть нове завдання",
    "Task summary" : "Конспект завдання",
    "Create task" : "Створити завдання",
    "Creating the new task…" : "Створення нового завдання…",
    "Open task" : "Відкрити завдання",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань","%n виконаних завдань"],
    "Tomorrow" : "Завтра",
    "An error occurred, unable to create the list." : "Помилка під час створення списку.",
    "Add List…" : "Додати список",
    "New list" : "Новий список",
    "When shared show full event" : "Показувати подію повністю",
    "When shared show only busy" : "Показувати тільки зайнятість",
    "When shared hide this event" : "Приховати цю подію",
    "[Completed] L" : "[Виконано] L",
    "[Completed last] dddd [at] LT" : "[Востаннє виконано] dddd [о] LT",
    "[Completed] dddd [at] LT" : "[Виконано] dddd [о] LT",
    "[Last modified yesterday at] LT" : "[Востаннє оновлено о] LT",
    "[Last modified today at] LT" : "[Востаннє оновлено сьогодні о] LT",
    "[Last modified] L" : "[Востаннє оновлено] L",
    "[Last modified last] dddd [at] LT" : "[Востаннє оновлено] dddd [о] LT",
    "[Last modified] dddd [at] LT" : "[Востаннє оновлено] dddd [о] LT",
    "[Created yesterday at] LT" : "[Створено вчора о] LT",
    "[Created today at] LT" : "[Створено сьогодні о] LT",
    "[Created] L" : "[Створено] L",
    "[Created last] dddd [at] LT" : "[Востаннє створено] dddd [о] LT",
    "[Created] dddd [at] LT" : "[Створено] dddd [о] LT",
    "Needs action" : "Потрібна дія",
    "In process" : "В процесі",
    "Canceled" : "Скасовано",
    "Clear status" : "Очистити статус",
    "Loading task from server." : "Завантаження завдання з сервера.",
    "Task not found!" : "Завдання не знайдено!",
    "Set start date" : "Дата початку",
    "Set due date" : "Дата виконання",
    "Priority {priority}: low" : "Пріоритет {priority}: низький",
    "Priority {priority}: medium" : "Пріоритет {priority}: середній",
    "Priority {priority}: high" : "Пріоритет {priority}: високий",
    "No priority assigned" : "Пріоритет не визначено",
    "{percent} % completed" : "{percent}% виконання",
    "All day" : "Весь день",
    "Unpin" : "Відкріпити",
    "Pin" : "Закріпити",
    "Show in Calendar" : "Показати в Календарі",
    "Show in Deck" : "Показати у застосунку Deck",
    "Edit summary" : "Редагувати назву",
    "Details" : "Деталі",
    "Selecting a classification is forbidden, because the task was shared with you." : "Неможливо вибрати категорію, оскільки цим завданням поділилися з вами.",
    "Select a classification" : "Виберіть класифікацію",
    "Select a status" : "Виберіть статус",
    "Set a location" : "Додати розташування",
    "Set a URL" : "Додати посилання",
    "Select tags" : "Виберіть мітку",
    "Notes" : "Опис",
    "Mark as done" : "Позначити як виконане",
    "No due date assigned" : "Термін виконання не визначено",
    "[Due yesterday]" : "[До вчора]",
    "[Due today]" : "[До сьогодні]",
    "[Due tomorrow]" : "[До завтра]",
    "[Due] L" : "[До] L",
    "[Due yesterday at] LT" : "[До вчора о] LT",
    "[Due today at] LT" : "[До сьогодні о] LT",
    "[Due tomorrow at] LT" : "[До завтра о] LT",
    "[Due] L [at] LT" : "[До] L [,] LT",
    "No upcoming tasks" : "Немає майбутніх завдань",
    "upcoming tasks" : "майбутні завдання",
    "No tasks today" : "На сьогодні відсутні завдання",
    "Completion date must be in the past." : "Дата завершення має бути ранішою",
    "Successfully created the task." : "Успішно додано завдання.",
    "Could not delete the task." : "Не вдалося вилучити завдання.",
    "Synchronizing to the server." : "Синхронізація з сервером.",
    "Task successfully saved to server." : "Завдання успішно збережено на сервері.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не вдалося оновити завдання, оскільки його було змінено на сервері. Натисніть, щоб оновити його, локальні зміни буде відхилено.",
    "Could not update the task." : "Не вдалося оновити завдання.",
    "Successfully updated the task." : "Завдання успішно оновлено.",
    "Task successfully moved to new calendar." : "Завдання успішно переміщено в новий календар.",
    "An error occurred" : "Виникла помилка",
    "Create a task" : "Додати завдання",
    "Message from {author} in {conversationName}" : "Повідомлення від {author} у {conversationName}",
    "[Due on] LL" : "[До] LL",
    "[Was due yesterday]" : "[Було до вчора]",
    "[Was due on] LL" : "[Було до] LL",
    "[Was due today at] LT" : "[Було до сьогодні о] LT",
    "[Due on] LL [at] LT" : "[До] LL [,] LT",
    "[Was due yesterday at] LT" : "[Було до вчора о] LT",
    "[Was due on] LL [at] LT" : "[Було до] LL [,] LT",
    "[Starts today]" : "[Почнеться сьогодні]",
    "[Starts tomorrow]" : "[Почнеться завтра]",
    "[Starts on] LL" : "[Починається] LL",
    "[Started yesterday]" : "[Розпочато вчора]",
    "[Started on] LL" : "[Розпочато] LL",
    "[Started today at] LT" : "[Розпочато сьогодні о] LT",
    "[Starts today at] LT" : "[Почнеться сьогодні о] LT",
    "[Starts tomorrow at] LT" : "[Почнеться завтра о] LT",
    "[Starts on] LL [at] LT" : "[Починається] LL [о] LT",
    "[Started yesterday at] LT" : "[Розпочато вчора о] LT",
    "[Started on] LL [at] LT" : "[Розпочато] LL [о] LT",
    "Midnight on the day the task starts" : "Опівночі у день початку завдання",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n день перед початком завдання о {formattedHourMinute}","%n дні перед початком завдання о {formattedHourMinute}","%n днів перед початком завдання о {formattedHourMinute}","%n днів перед початком завдання о {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n тиждень перед початком завдання о {formattedHourMinute}","%n тижня перед початком завдання о {formattedHourMinute}","%n тижнів перед початком завдання о {formattedHourMinute}","%n тижнів перед початком завдання о {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "у день виконання завдання о {formattedHourMinute}",
    "at the task's start" : "перед початком завдання",
    "when the task is due" : "після дати завершення завдання",
    "{time} before the task starts" : "{time} перед початком завдання",
    "{time} before the task is due" : "{time} перед завершенням завдання",
    "{time} after the task starts" : "{time} після початку завдання",
    "{time} after the task is due" : "{time} після завершення завдання"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
