OC.L10N.register(
    "tasks",
    {
    "Today" : "ມື້ນີ້",
    "Current" : "ປັດຈຸບັນ",
    "Completed" : "ສຳເລັດ",
    "Can edit" : "ແກ້ໄຂໄດ້",
    "Edit" : "ແກ້ໄຂ",
    "Delete" : "ລຶບ",
    "Unshare" : "ຍົກເລີກການແບ່ງປັນ",
    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
    "Name" : "ຊື່",
    "Deleted" : "ລືບ",
    "Restore" : "ການກຸ້ຄຶນ",
    "Cancel" : "ຍົກເລີກ",
    "Close" : "ປິດ",
    "Tags" : "ປ້າຍກຳກັບ",
    "Details" : "ລາຍລະອຽດ"
},
"nplurals=1; plural=0;");
