OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Tulevased ülesanded",
    "Important" : "Tähtis",
    "Today" : "Täna",
    "Week" : "Nädal",
    "All" : "Kõik",
    "Current" : "Praegune",
    "Completed" : "Lõpetatud",
    "Tasks" : "Ülesanded",
    "The Tasks app for Nextcloud" : "Nextcloudi ülesannete rakendus",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Selle rakenduse kasutuselevõtmisel tekib Nextcloudi rakenduste menüüsse uus valik Ülesanded. Sealt saad lisada ja kustutada ülesandeid, muuta nende pealkirja, kirjeldust, algust ja tähtaega ning märkida olulisust. Nagu Nextcloudis tavaks, siis ülesandeid saad jagada teiste kasutajatega. Ülesandeid saad ka sünkroniseerida CalDAV-i protokolli abil (iga ülesannete loend on seotud Nextcloudi kalendriga ja see on sünkroniseeritav kohaliku kliendiga: Thunderbird, Evolution, KDE Kontact, iCal … - lihtsalt lisa ta oma rakendusse kaugkalendrina). Iga kalendri puhul saad kõik ülesanded vastavast nupust laadida alla ka ICS-failidena.",
    "Hidden" : "Peidetud",
    "Visible" : "Nähtav",
    "Automatic" : "Automaatne",
    "Tasks settings" : "Ülesannete rakenduse seadistused",
    "Default list" : "Vaikimisi nimekiri",
    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "Unable to delete the share." : "Jagamise kustutamine ebaõnnestus.",
    "Unable to change permissions." : "Õiguste muutmine ebaõnnestus.",
    "Can edit" : "Võib muuta",
    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Järgnevaga kustutad „{calendar}“ kalendri ja kõik selle sündmused ja ülesanded.",
    "This will unshare the calendar \"{calendar}\"." : "Järgnevaga lõppeb „{calendar}“ kalendri jagamine.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Järgnevaga kustutad „{list}“ loendi ja kõik selle ülesanded.",
    "This will unshare the list \"{list}\"." : "Järgnevaga lõppeb „{list}“ loendi jagamine.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kustutan kalendri {countdown} sekundi möödumisel","Kustutan kalendri {countdown} sekundi möödumisel"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Lõpetan kalendri jagamise {countdown} sekundi möödumisel","Lõpetan kalendri jagamise {countdown} sekundi möödumisel"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Loend saab kustutatud {countdown} sekundi möödumisel","Loend saab kustutatud {countdown} sekundi möödumisel"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Loendi jagamine lõppeb {countdown} sekundi möödumisel","Loendi jagamine lõppeb {countdown} sekundi möödumisel"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jagatud {num} osapoolega","Jagatud {num} osapoolega"],
    "Share this calendar" : "Jaga seda kalendrit",
    "Share this list" : "Jaga seda nimekirja",
    "Calendar link copied to clipboard." : "Kalendri link kopeeriti lõikelauale.",
    "List link copied to clipboard." : "Nimekirja link kopeeriti lõikelauale.",
    "Calendar link could not be copied to clipboard." : "Kalendri linki ei õnnestunud lõikelauale kopeerida",
    "List link could not be copied to clipboard." : "Loendi linki ei õnnestunud lõikelauale kopeerida.",
    "The name \"{calendar}\" is already used." : "Nimi \"{calendar}\" on juba kasutuses.",
    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
    "An error occurred, unable to delete the calendar." : "Tekkis viga ja kalendri kustutamine pole võimalik.",
    "An error occurred, unable to delete the list." : "Tekkis viga ja loendi kustutamine pole võimalik.",
    "Edit" : "Muuda",
    "Copy private link" : "Kopeeri privaatne link",
    "Copied" : "Kopeeritud",
    "Cannot copy" : "Kopeerimine ebaõnnestus",
    "Export" : "Ekspordi",
    "Delete" : "Kustuta",
    "Unshare" : "Lõpeta jagamine",
    "List name" : "Nimekirja nimi",
    "Untitled task" : "Ilma nimeta pealkiri",
    "Untitled event" : "Ilma nimeta sündmus",
    "Untitled journal" : "Ilma nimeta päevik",
    "Untitled item" : "Tundmatu kirje",
    "Unknown calendar" : "Tundmatu kalender",
    "Could not load deleted calendars and objects" : "Kustutatud kalendrite ja objektide laadimine ei õnnestunud",
    "Could not delete calendar or event" : "Kalendri või sündmuse kustutamine ei õnnestunud",
    "Could not restore calendar or event" : "Kalendri või sündmuse taastamine ei õnnestunud",
    "Do you really want to empty the trash bin?" : "Oled sa kindel, et soovid prügikasti tühjendada?",
    "Empty trash bin" : "Tühjenda prügikast",
    "Trash bin" : "Prügikast",
    "Loading deleted calendars, tasks and events." : "Laadin kustutatud kalendreid, ülesandeid ja sündmusi.",
    "You do not have any deleted calendars, tasks or events." : "Sule pole kustutatud kalendreid, ülesandeid ja sündmusi.",
    "Name" : "Nimi",
    "Deleted" : "Kustutatud",
    "Restore" : "Taasta",
    "Delete permanently" : "Kustuta jäädavalt",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Prügikasti sisu saab kustutatud {numDays} päeva möödumisel","Prügikasti sisu saab kustutatud {numDays} päeva möödumisel"],
    "Create reminder" : "Koosta meeldetuletus",
    "Update reminder" : "Uuenda meeldetuletust",
    "Set a reminder at a custom date and time:" : "Säti meeldetuletus valitud kuupäevaks ja ajaks:",
    "Cancel" : "Katkesta",
    "This is a todo reminder." : "See on ülesande meeldetuletus.",
    "No reminders" : "Meeldetuletusi pole",
    "Notification" : "Teavitus",
    "Email" : "E-post",
    "Audio notification" : "Heliteavitus",
    "Other notification" : "Muu teavitus",
    "Edit time" : "Muuda aega",
    "Remove reminder" : "Eemalda meeldetuletus",
    "Add reminder" : "Lisa meeldetuletus",
    "Before the task starts" : "Enne ülesande algust",
    "Before the task is due" : "Enne ülesande tähtaega",
    "Select date and time" : "Vali kuupäev ja kellaaeg",
    "Go back" : "Mine tagasi",
    "Do you want to keep related reminders?" : "Kas sa soovid asjakohased meeldetuletused säilitada?",
    "Discard reminders" : "Loobu meeldetuletustest",
    "Keep reminders" : "Säilita meeldetuletused",
    "Set a reminder relative to your tasks start date:" : "Lisa meeldetuletus, mis on suhteline sinu ülesande alguskuupäeva suhtes:",
    "Set a reminder relative to your tasks due date:" : "Lisa meeldetuletus, mis on suhteline sinu ülesande tähtaja suhtes:",
    "before at" : "enne",
    "_second_::_seconds_" : ["sekund","sekundit"],
    "_minute_::_minutes_" : ["minut","minutit"],
    "_hour_::_hours_" : ["tund","tundi"],
    "_day_::_days_" : ["päev","päeva"],
    "_week_::_weeks_" : ["nädal","nädalat"],
    "Select a calendar" : "Vali kalender",
    "No calendar matches the search." : "Sinu otsingule ei vasta ühtegi kalendrit",
    "Set date" : "Määra kuupäev",
    "Set time" : "Määra kellaaeg",
    "Delete date" : "Kustuta kuupäev",
    "Click here to add a note." : "Kliki siia, et lisada märkus.",
    "Set value" : "Määra väärtus",
    "Delete value" : "Kustuta väärtus",
    "Add this as a new tag" : "Lisa see uue sildina",
    "No tag available. Create one!" : "Silte ei leidu. Palun lisa mõni!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} ülesannet on lisatud „{calendar}“ kalendrisse",
    "Create new tasks" : "Koosta uued ülesanded",
    "Create {numberOfTasks} tasks from pasted text" : "Koosta asetatud tekstist {numberOfTasks} ülesannet",
    "Create tasks" : "Koosta ülesandeid",
    "Creating new tasks…" : "Uued ülesanded on koostamisel...",
    "Close" : "Sulge",
    "Delete all completed tasks." : "Kustuta kõik lõpetatud ülesanded.",
    "Delete completed tasks." : "Kustuta lõpetatud ülesanded.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Kustutasin kõik lõpetatud ülesanded „{calendar}“ kalendrist.",
    "No errors" : "Vigu pole",
    "Open your browser console for more details" : "Lisateavet leiad oma veebibrauseri konsoolist",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Sellega kustutad „{calendar}“ kalendrist {taskCount} täidetud ülesande koos alamülesannetega.","Sellega kustutad „{calendar}“ kalendrist {taskCount} täidetud ülesannet koos alamülesannetega."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} ülesande kustutamine ei õnnestunud.","{failedCount} ülesande kustutamine ei õnnestunud."],
    "Active filter" : "Aktiveeri filter",
    "Filter by tags" : "Filtreeri siltide järgi",
    "Select tags to filter by" : "Vali sildid, mille järgi filtreerida",
    "Reset filter" : "Nulli filter",
    "Add an important task to \"{calendar}\"…" : "Lisa oluline ülesanne „{calendar}“ kalendrisse...",
    "Add a task due today to \"{calendar}\"…" : "Lisa „{calendar}“ kalendrisse oluline ülesanne, mille tähtaeg on täna ...",
    "Add a current task to \"{calendar}\"…" : "Lisa praegune ülesanne „{calendar}“ kalendrisse...",
    "Add a task to \"{calendar}\"…" : "Lisa ülesanne „{calendar}“ kalendrisse...",
    "Load the completed tasks of all lists." : "Laadi lõpetatud ülesanded kõikidest loenditest.",
    "Loading the completed tasks of all lists might slow down the app." : "Kõikidest loenditest lõpetatud ülesannete laadimine võib rakenduse tööd märgatavalt aeglustada.",
    "Load the completed tasks of list \"{calendar}\"." : "Laadi lõpetatud ülesanded kõikidest „{calendar}“ kalendrist.",
    "Loading the completed tasks might slow down the app." : "Lõpetatud ülesannete laadimine võib rakenduse tööd märgatavalt aeglustada.",
    "Relevance" : "Asjakohasus",
    "Sort by completed state, due date, priority, start date and summary." : "Järjesta lõpetamise oleku, tähtaja, olulisuse, alguskuupäeva ja kokkuvõtte alusel.",
    "Start date" : "Alguskuupäev",
    "Sort by start date, priority and summary." : "Järjesta alguskuupäeva, olulisuse ja kokkuvõtte alusel.",
    "Due date" : "Tähtaeg",
    "Sort by due date, priority and summary." : "Järjesta tähtaja, olulisuse ja kokkuvõtte alusel.",
    "Created date" : "Koostamise kuupäev",
    "Sort by created date, priority and summary." : "Järjesta koostamiskuupäeva, olulisuse ja kokkuvõtte alusel.",
    "Last modified" : "Viimati muudetud",
    "Sort by last-modified date, priority and summary." : "Järjesta viimase muutmise kuupäeva, olulisuse ja kokkuvõtte alusel.",
    "Completed date" : "Lõpetamise kuupäev",
    "Sort by completed date, priority and summary." : "Järjesta lõpetamise kuupäeva, olulisuse ja kokkuvõtte alusel.",
    "Priority" : "Olulisus",
    "Sort by priority and summary." : "Järjesta olulisuse ja kokkuvõtte alusel.",
    "Alphabetically" : "Tähestiku järjekorras",
    "Sort by summary and priority." : "Järjesta kokkuvõtte ja olulisuse alusel.",
    "Tags" : "Sildid",
    "Sort by tags." : "Järjesta siltide alusel.",
    "Manually" : "Käsitsi",
    "Sort by manual order." : "Järjesta käsitsi.",
    "Change sort order" : "Muuda järjestust",
    "[Yesterday]" : "[Eile]",
    "[Today]" : "[Täna]",
    "[Tomorrow]" : "[Homme]",
    "[Completed yesterday]" : "[Lõpetatud eile]",
    "[Completed today]" : "[Lõpetatud täna]",
    "[Completed tomorrow]" : "[Lõpetatud homme]",
    "[Yesterday at] LT" : "[Eile kell] LT",
    "[Today at] LT" : "[Täna kell] LT",
    "[Tomorrow at] LT" : "[Eile kell] LT",
    "L [at] LT" : "L [kell] LT",
    "[Completed yesterday at] LT" : "[Lõpetatud eile kell] LT",
    "[Completed today at] LT" : "[Lõpetatud täna kell] LT",
    "[Completed tomorrow at] LT" : "[Lõpetatud homme kell] LT",
    "[Completed] L [at] LT" : "[Lõpetatud] L [kell] LT",
    "Add a subtask to \"{task}\"…" : "Lisa alamülesanne „{task}“ ülesandele…",
    "Task has hidden subtasks" : "Ülesandel on peidetud alamülesandeid",
    "Task is pinned" : "Ülesanne on tõstetud esile",
    "Task has a note" : "Ülesandel on märge",
    "{complete} % completed" : "{complete}% valmis",
    "Add subtask" : "Lisa alamülesanne",
    "Show subtasks" : "Näita alamülesandeid",
    "Hide subtasks" : "Peida alamülesanded",
    "Show closed subtasks" : "Näita suletud alamülesandeid",
    "Hide closed subtasks" : "Peida suletud alamülesanded",
    "Delete task" : "Kustuta ülesanne",
    "Toggle starred" : "Lülita tähega märgitud sisse/välja",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Ülesandel on üks meeldetuletus","Ülesandel on {n} meeldetuletust"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Ülesanne saab kustutatud {countdown} sekundi möödumisel","Ülesanne saab kustutatud {countdown} sekundi möödumisel"],
    "Task is cancelled" : "Ülesanne on tühistatud",
    "Task is completed" : "Ülesanne on tehtud",
    "Task is read-only" : "Ülesanne on ainult loetud",
    "Task is not completed" : "Ülesanne pole lõpetatud",
    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ ülesanne on lisatud „{calendar}“ kalendrisse",
    "Create a new task" : "Koosta uus ülesanne",
    "Task summary" : "Ülesande kokkuvõte",
    "Create task" : "Koosta ülesanne",
    "Creating the new task…" : "Uus ülesanne on koostamisel...",
    "Open task" : "Ava ülesanne",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lõpetatud ülesanne","%n lõpetatud ülesannet"],
    "Tomorrow" : "Homme",
    "An error occurred, unable to create the list." : "Tekkis viga ja loendi koostamine pole võimalik.",
    "Add List…" : "Lisa loend...",
    "New list" : "Uus loend",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "[Completed] L" : "[Lõpetatud] L",
    "[Completed last] dddd [at] LT" : "[Lõpetatud eelmisel] dddd [kell] LT",
    "[Completed] dddd [at] LT" : "[Lõpetatud] dddd [kell] LT",
    "[Last modified yesterday at] LT" : "[Viimati muudetud eile kell] LT",
    "[Last modified today at] LT" : "[Viimati muudetud täna kell] LT",
    "[Last modified] L" : "[Viimati muudetud] L",
    "[Last modified last] dddd [at] LT" : "[Viimati muudetud eelmisel] dddd [kell] LT",
    "[Last modified] dddd [at] LT" : "[Viimati muudetud] dddd [kell] LT",
    "[Created yesterday at] LT" : "[Koostatud eile] LT",
    "[Created today at] LT" : "[Koostatud täna] LT",
    "[Created] L" : "[Koostatud] L",
    "[Created last] dddd [at] LT" : "[Koostatud eelmisel] dddd [kell] LT",
    "[Created] dddd [at] LT" : "[Koostatud] dddd [kell] LT",
    "Needs action" : "Vajab tegevust",
    "In process" : "Töös",
    "Canceled" : "Tühistatud",
    "Clear status" : "Kustuta olek",
    "Loading task from server." : "Ülesande laadimine serverist.",
    "Task not found!" : "Ülesannet ei leidu!",
    "Set start date" : "Määra alguse kuupäev",
    "Set due date" : "Määra tähtaeg",
    "Priority {priority}: low" : "Olulisus {priority}: madal",
    "Priority {priority}: medium" : "Olulisus {priority}: keskmine",
    "Priority {priority}: high" : "Olulisus {priority}: kõrge",
    "No priority assigned" : "Olulisus on määramata",
    "{percent} % completed" : "{percent} % valmis",
    "All day" : "Kogu päev",
    "Unpin" : "Eemalda kinnitus",
    "Pin" : "Kinnita",
    "Show in Calendar" : "Näita kalendris",
    "Show in Deck" : "Näita Kanbani rakenduses",
    "Edit summary" : "Muuda kokkuvõtet",
    "Details" : "Üksikasjad",
    "Selecting a classification is forbidden, because the task was shared with you." : "Kuna ülesanne on sinuga jagatud, siis klassifikatsiooni jagamine on keelatud.",
    "Select a classification" : "Vali klassifikatsioon",
    "Select a status" : "Vali olek",
    "Set a location" : "Määra asukoht",
    "Set a URL" : "Määra URL",
    "Select tags" : "Vali sildid",
    "Notes" : "Märkmed",
    "Mark as done" : "Märgi tehtuks",
    "No due date assigned" : "Tähtaega pole määratud",
    "[Due yesterday]" : "[Tähtaeg oli eile]",
    "[Due today]" : "[Tähtaeg on täna]",
    "[Due tomorrow]" : "[Tähtaeg on homme]",
    "[Due] L" : "[Tähtaeg] L",
    "[Due yesterday at] LT" : "[Tähtaeg oli eile] LT",
    "[Due today at] LT" : "[Tähtaeg on täna] LT",
    "[Due tomorrow at] LT" : "[Tähtaeg on homme] LT",
    "[Due] L [at] LT" : "[Tähtaeg on] L [kell] LT",
    "No upcoming tasks" : "Järgmisi ülesandeid pole",
    "upcoming tasks" : "järgmised ülesanded",
    "No tasks today" : "Täna pole ülesandeid",
    "Completion date must be in the past." : "Valmissaamise kuupäev peab olema minevikus.",
    "Successfully created the task." : "Ülesande koostamine õnnestus.",
    "Could not delete the task." : "Ei õnnestunud kustutada ülesannet.",
    "Synchronizing to the server." : "Sünkroniseerin serveriga.",
    "Task successfully saved to server." : "Ülesande salvestamine serverisse õnnestus.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Kuna ülesanne oli serveris muutunud, siis teda ei olnud võimalik uuendada. Andmete uuendamiseks palun klõpsi ja sellega kaovad ka kohalikus seadmes tehtud muudatused.",
    "Could not update the task." : "Ei õnnestunud uuendada ülesannet.",
    "Successfully updated the task." : "Ülesande uuendamine õnnestus.",
    "Task successfully moved to new calendar." : "Ülesande teisaldamine teise kalendrisse õnnestus.",
    "An error occurred" : "Tekkis viga",
    "Create a task" : "Koosta ülesanne",
    "Message from {author} in {conversationName}" : "Sõnum kasutajalt „{author}“ „{conversationName}“ vestluses",
    "[Due on] LL" : "[Tähtajaga] LL",
    "[Was due yesterday]" : "[Tähtaeg oli eile]",
    "[Was due on] LL" : "[Tähtaeg oli] LL",
    "[Was due today at] LT" : "[Tähtaeg on täna] LT",
    "[Due on] LL [at] LT" : "[Tähtaeg on] LL [kell] LT",
    "[Was due yesterday at] LT" : "[Tähtaeg oli eile] LT",
    "[Was due on] LL [at] LT" : "[Tähtaeg oli] LL [kell] LT",
    "[Starts today]" : "[Algab täna]",
    "[Starts tomorrow]" : "[Algab homme]",
    "[Starts on] LL" : "[Algab] LL",
    "[Started yesterday]" : "[Algas eile]",
    "[Started on] LL" : "[Algas] LL",
    "[Started today at] LT" : "[Algas täna kell] LT",
    "[Starts today at] LT" : "[Algab täna kell] LT",
    "[Starts tomorrow at] LT" : "[Algab homme kell] LT",
    "[Starts on] LL [at] LT" : "[Algab] LL [kell] LT",
    "[Started yesterday at] LT" : "[Algas eile kell] LT",
    "[Started on] LL [at] LT" : "[Algas] LL [kell] LT",
    "Midnight on the day the task starts" : "Ülesande alguspäeva keskööl",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n päev enne ülesande algust kell {formattedHourMinute}","%n päeva enne ülesande algust kell {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n nädal enne ülesande algust kell {formattedHourMinute}","%n nädalat enne ülesande algust kell {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "ülesande alguspäeval kell {formattedHourMinute}",
    "at the task's start" : "ülesande algamisel",
    "when the task is due" : "ülesande tähtajal",
    "{time} before the task starts" : "{time} enne ülesande algust",
    "{time} before the task is due" : "{time} enne ülesande tähtaega",
    "{time} after the task starts" : "{time} peale ülesande algust",
    "{time} after the task is due" : "{time} peale ülesande tähtaega"
},
"nplurals=2; plural=(n != 1);");
