OC.L10N.register(
    "tasks",
    {
    "Today" : "өнөөдөр",
    "Week" : "Долоо хоног",
    "All" : "бүх",
    "Current" : "Одоогийн",
    "Completed" : "Гүйцэтгэгдсэн",
    "Tasks" : "Даалгавар",
    "Hidden" : "Далд",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "Can edit" : "Can edit",
    "Edit" : "засварлах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Export" : "Экспорт",
    "Delete" : "устгах",
    "Unshare" : "Түгээлтийг зогсоох",
    "Name" : "Нэр",
    "Deleted" : "Устгагдсан",
    "Restore" : "Сэргээх",
    "Delete permanently" : "бүр мөсөн устгах",
    "Cancel" : "цуцлах",
    "Go back" : "Буцах",
    "Close" : "Хаах",
    "Select tags to filter by" : "Хайлт хийх tag-үүдийг сонгоно уу",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Tags" : "Tag-үүд",
    "Tomorrow" : "маргааш",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Details" : "Дэлгэрэнгүй",
    "Notes" : "Шинэ "
},
"nplurals=2; plural=(n != 1);");
