OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Prihajajoče naloge",
    "Important" : "Pomembno",
    "Today" : "Danes",
    "Week" : "Teden",
    "All" : "Vse",
    "Current" : "Trenutno",
    "Completed" : "Končano",
    "Tasks" : "Naloge",
    "The Tasks app for Nextcloud" : "Program Tasks za Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Ko je program omogočen, se v orodni vrstici Nextcloud pojavi nov meni Naloge. V programu je mogoče dodajati, urejati in brisati naslove, opise, datum začetka in konca naloge, mogoče jih je tudi označiti kot pomembne. Naloge je mogoče tudi dodeliti uporabnikom. Usklajevanje nalog poteka z uporabo CalDav (vsak seznam nalog je povezan s koledarjem, zato je mogoče usklajevanje tudi z namiznimi programi – v programu je treba nastaviti oddaljen koledar). Naloge je mogoče tudi prenesti na napravo kot datoteke ICS za vsak koledar.",
    "Hidden" : "Skrito",
    "Visible" : "Vidno",
    "Automatic" : "Samodejno",
    "Tasks settings" : "Nastavitve nalog",
    "Default list" : "Privzeti seznam",
    "Visibility of Smart Collections" : "Vidnost pametnih zbirk",
    "Share with users or groups" : "Souporaba z uporabniki in skupinami",
    "No users or groups" : "Ni uporabnikov oziroma skupin",
    "Unable to delete the share." : "Ni mogoče izbrisati souporabe.",
    "Unable to change permissions." : "Ni mogoče spremeniti dovoljenj.",
    "Can edit" : "Lahko ureja",
    "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Izbrisali boste koledar »{calendar}« in vse pripadajoče dogodke in naloge.",
    "This will unshare the calendar \"{calendar}\"." : "S tem bo onemogočena souporaba koledarja »{calendar}«.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Izbrisali boste seznam »{list}« in vse pripadajoče naloge.",
    "This will unshare the list \"{list}\"." : "S tem bo onemogočena souporaba seznama »{list}«.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Koledar bo izbrisan čez {countdown} sekundo.","Koledar bo izbrisan čez {countdown} sekundi.","Koledar bo izbrisan čez {countdown} sekunde.","Koledar bo izbrisan čez {countdown} sekund."],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Souporaba koledarja bo onemogočena čez {countdown} sekundo.","Souporaba koledarja bo onemogočena čez {countdown} sekundi.","Souporaba koledarja bo onemogočena čez {countdown} sekunde.","Souporaba koledarja bo onemogočena čez {countdown} sekund."],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Seznam bo izbrisan čez {countdown} sekundo.","Seznam bo izbrisan čez {countdown} sekundi.","Seznam bo izbrisan čez {countdown} sekunde.","Seznam bo izbrisan čez {countdown} sekund."],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Souporaba seznama bo onemogočena čez {countdown} sekundo.","Souporaba seznama bo onemogočena čez {countdown} sekundi.","Souporaba seznama bo onemogočena čez {countdown} sekunde.","Souporaba seznama bo onemogočena čez {countdown} sekund."],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["V souporabi s skupno {num} odjemalcem","V souporabi s skupno {num} odjemalcema","V souporabi s skupno {num} odjemalci","V souporabi s skupno {num} odjemalci"],
    "Share this calendar" : "Souporaba koledarja",
    "Share this list" : "Souporaba seznama",
    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
    "List link copied to clipboard." : "Povezava seznama je kopirana v odložišče.",
    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
    "List link could not be copied to clipboard." : "Povezave seznama ni mogoče kopirati v odložišče.",
    "The name \"{calendar}\" is already used." : "Ime »{calendar}« je že v uporabi.",
    "An empty name is not allowed." : "Prazno polje imena ni dovoljeno.",
    "An error occurred, unable to delete the calendar." : "Prišlo je do napake, koledarja ni mogoče izbrisati.",
    "An error occurred, unable to delete the list." : "Prišlo je do napake, seznama ni mogoče izbrisati.",
    "Edit" : "Uredi",
    "Copy private link" : "Kopiraj zasebno povezavo",
    "Copied" : "Kopirano!",
    "Cannot copy" : "Predmeta ni mogoče kopirati",
    "Export" : "Izvozi",
    "Delete" : "Izbriši",
    "Unshare" : "Prekini souporabo",
    "List name" : "Ime seznama",
    "Untitled task" : "Neimenovana naloga",
    "Untitled event" : "Neimenovan dogodek",
    "Untitled journal" : "Neimenovan dnevnik",
    "Untitled item" : "Neimenovan predmet",
    "Unknown calendar" : "Neznan koledar",
    "Could not load deleted calendars and objects" : "Ni mogoče naložiti izbrisanih koledarjev in predmetov",
    "Could not delete calendar or event" : "Ni mogoče izbrisati koledarja ali dogodka",
    "Could not restore calendar or event" : "Ni mogoče obnoviti koledarja ali dogodka",
    "Do you really want to empty the trash bin?" : "Ali zares želite izprazniti smetnjak?",
    "Empty trash bin" : "Izprazni smeti",
    "Trash bin" : "Smetnjak",
    "Loading deleted calendars, tasks and events." : "Poteka nalaganje koledarjev, nalog in dogodkov.",
    "You do not have any deleted calendars, tasks or events." : "Ni nobenih izbrisanih koledarjev, nalog ali dogodkov",
    "Name" : "Ime",
    "Deleted" : "Izbrisano",
    "Restore" : "Obnovi",
    "Delete permanently" : "Izbriši trajno",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Predmeti v smetnjaku se izbrišejo po {numDays} dnevu.","Predmeti v smetnjaku se izbrišejo po {numDays} dneh.","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih.","Predmeti v smetnjaku se izbrišejo po {numDays} dnevih."],
    "Cancel" : "Prekliči",
    "Notification" : "Obvestilo",
    "Email" : "Elektronski naslov",
    "Audio notification" : "Zvočno obvestilo",
    "Other notification" : "Drugo obvestilo",
    "Edit time" : "Uredi čas",
    "Remove reminder" : "Odstrani opomnik",
    "Add reminder" : "Dodaj opomnik",
    "Go back" : "Skoči nazaj",
    "before at" : "prej ob",
    "_second_::_seconds_" : ["sekunda","sekundi","sekunde","sekund"],
    "_minute_::_minutes_" : ["minuta","minuti","minute","minut"],
    "_hour_::_hours_" : ["ura","uri","ure","ur"],
    "_day_::_days_" : ["dan","dneva","dni","dni"],
    "_week_::_weeks_" : ["teden","tedna","tedne","tednov"],
    "Select a calendar" : "Izbor koledarja",
    "No calendar matches the search." : "Ni koledarja, skladnega z iskalnim nizom.",
    "Set date" : "Nastavi datum",
    "Set time" : "Nastavi čas",
    "Delete date" : "Izbriši datum",
    "Click here to add a note." : "Kliknite za dodajanje sporočila.",
    "Set value" : "Nastavi vrednost",
    "Delete value" : "Izbriši vrednost",
    "Add this as a new tag" : "Dodaj kot novo oznako",
    "No tag available. Create one!" : "Ni razpoložljivih oznak. Ustvarite jih!",
    "Close" : "Zapri",
    "Delete all completed tasks." : "Izbriši vse končane naloge.",
    "Delete completed tasks." : "Izbriši končane naloge.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Iz koledarja »{calendar}« so izbrisane vse končane naloge.",
    "No errors" : "Ni zaznanih napak",
    "Open your browser console for more details" : "Več podrobnosti je izpisanih v konzoli brskalnika",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Iz koledarja »{calendar}« boste zbrisali {taskCount} končano nalogo z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končani nalogi z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končane naloge z vsemi podrejenimi.","Iz koledarja »{calendar}« boste zbrisali {taskCount} končanih nalog z vsemi podrejenimi."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ni mogoče izbrisati {failedCount} naloge.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog.","Ni mogoče izbrisati {failedCount} nalog."],
    "Filter by tags" : "Filtriranje po oznakah",
    "Select tags to filter by" : "Izbor oznak za filtriranje",
    "Add an important task to \"{calendar}\"…" : "Dodaj pomembno nalogo v koledar »{calendar}« ...",
    "Add a task due today to \"{calendar}\"…" : "Dodaj nalogo, ki poteče danes, v koledar »{calendar}« ...",
    "Add a current task to \"{calendar}\"…" : "Dodaj trenutno nalogo v koledar »{calendar}« ...",
    "Add a task to \"{calendar}\"…" : "Dodaj nalogo v koledar »{calendar}« ...",
    "Relevance" : "Pomembnost",
    "Sort by completed state, due date, priority, start date and summary." : "Razvrsti po stanju opravljenosti, po datumu konca, prednosti, začetku in povzetku.",
    "Start date" : "Datum začetka",
    "Due date" : "Datum zapadlosti",
    "Created date" : "Ustvarjeno na",
    "Last modified" : "Nazadnje spremenjeno",
    "Completed date" : "Datum končanja",
    "Priority" : "Prednost",
    "Sort by priority and summary." : "Razvrsti po prednosti, nato po povzetku.",
    "Alphabetically" : "Abecedno",
    "Sort by summary and priority." : "Razvrsti po povzetku, nato po prednosti.",
    "Tags" : "Oznake",
    "Manually" : "Ročno",
    "Sort by manual order." : "Razvrsti ročno",
    "Change sort order" : "Spremeni vrstni red razvrščanja",
    "[Yesterday]" : "[Včeraj]",
    "[Today]" : "[Danes]",
    "[Tomorrow]" : "[Jutri]",
    "[Completed yesterday]" : "[Končano včeraj]",
    "[Completed today]" : "[Končano  danes]",
    "[Completed tomorrow]" : "[Konča se jutri]",
    "[Yesterday at] LT" : "[Včeraj ob] LT",
    "[Today at] LT" : "[Danes ob] LT",
    "[Tomorrow at] LT" : "[Jutri ob] LT",
    "L [at] LT" : "L [ob] LT",
    "[Completed yesterday at] LT" : "[Končano včeraj ob] LT",
    "[Completed today at] LT" : "[Končano danes ob] LT",
    "[Completed tomorrow at] LT" : "[Konča se jutri ob] LT",
    "[Completed] L [at] LT" : "[Končano] L [ob] LT",
    "Add a subtask to \"{task}\"…" : "Dodaj podrejeno nalogo k nalogi »{task}« ...",
    "Task has hidden subtasks" : "Naloga ima skrite podrejene naloge",
    "Task is pinned" : "Naloga je pripeta na vrh",
    "Task has a note" : "Naloga ima vpisano opombo",
    "{complete} % completed" : "Končano je {complete} % naloge",
    "Add subtask" : "Dodaj podrejeno nalogo",
    "Show subtasks" : "Pokaži podrejene naloge",
    "Hide subtasks" : "Skrij podrejene naloge",
    "Show closed subtasks" : "Pokaži zaprte podrejene naloge",
    "Hide closed subtasks" : "Skrij zaprte podrejene naloge",
    "Delete task" : "Izbriši nalogo",
    "Toggle starred" : "Preklopi oznako z zvezdico",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Naloga bo izbrisana čez {countdown} sekundo","Naloga bo izbrisana čez {countdown} sekundi","Naloga bo izbrisana čez {countdown} sekunde","Naloga bo izbrisana čez {countdown} sekund"],
    "Task is cancelled" : "Naloga je preklicana",
    "Task is completed" : "Naloga je zaključena",
    "Task is read-only" : "Naloga je le za branje",
    "Task is not completed" : "Naloga ni končana",
    "\"{task}\" was added to \"{calendar}\"" : "Naloga »{task}« je dodana v koledar »{calendar}«.",
    "Create a new task" : "Ustvari novo nalogo",
    "Task summary" : "Povzetek naloge",
    "Create task" : "Ustvari nalogo",
    "Creating the new task…" : "Poteka ustvarjanje nove naloge ...",
    "Open task" : "Odpri nalogo",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n končana naloga","%n končani nalogi","%n končane naloge","%n končanih nalog"],
    "Tomorrow" : "Jutri",
    "Add List…" : "Dodaj seznam ...",
    "When shared show full event" : "V souporabi pokaži poln dogodek",
    "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
    "When shared hide this event" : "V souporabi skrij ta dogodek",
    "[Completed] L" : "[Končano:] L",
    "[Completed last] dddd [at] LT" : "[Končano:] dddd [ob] LT",
    "[Completed] dddd [at] LT" : "[Končano:] dddd [ob] LT",
    "[Last modified yesterday at] LT" : "[Nazadnje spremenjeno včeraj ob] LT",
    "[Last modified today at] LT" : "[Nazadnje spremenjeno danes ob] LT",
    "[Last modified] L" : "[Nazadnje spremenjeno:] L",
    "[Last modified last] dddd [at] LT" : "[Nazadnje spremenjeno:] dddd [ob] LT",
    "[Last modified] dddd [at] LT" : "[Nazadnje spremenjeno:] dddd [ob] LT",
    "[Created yesterday at] LT" : "[Ustvarjeno včeraj ob] LT",
    "[Created today at] LT" : "[Ustvarjeno danes ob] LT",
    "[Created] L" : "[Ustvarjeno:] L",
    "[Created last] dddd [at] LT" : "[Ustvarjeno:] dddd [ob] LT",
    "[Created] dddd [at] LT" : "[Ustvarjeno:] dddd [ob] LT",
    "Needs action" : "Zahteva odziv",
    "In process" : "V obdelavi",
    "Canceled" : "Preklicano",
    "Clear status" : "Počisti stanje",
    "Loading task from server." : "Poteka nalaganje nalog s strežnika.",
    "Task not found!" : "Naloge ni mogoče najti!",
    "Set start date" : "Nastavi datum začetka",
    "Set due date" : "Nastavi datum preteka",
    "Priority {priority}: low" : "Prednost {priority}: nizka",
    "Priority {priority}: medium" : "Prednost {priority}: običajna",
    "Priority {priority}: high" : "Prednost {priority}: visoka",
    "No priority assigned" : "Ni dodeljene prednosti",
    "{percent} % completed" : "Končano je {percent} % naloge",
    "All day" : "Ves dan",
    "Unpin" : "Odpni",
    "Pin" : "Pripni",
    "Show in Calendar" : "Pokaži v koledarju",
    "Details" : "Podrobnosti",
    "Select a classification" : "Izbor preikaza",
    "Select a status" : "Izbor stanja",
    "Select tags" : "Izbor oznak",
    "Notes" : "Opombe",
    "Mark as done" : "Označi kot končano",
    "No due date assigned" : "Ni dodeljenega datuma preteka",
    "[Due yesterday]" : "[Preteklo včeraj]",
    "[Due today]" : "[Poteče danes]",
    "[Due tomorrow]" : "[Poteče jutri]",
    "[Due] L" : "[Poteče na] L",
    "[Due yesterday at] LT" : "[Poteklo je včeraj ob] LT",
    "[Due today at] LT" : "[Poteče danes ob] LT",
    "[Due tomorrow at] LT" : "[Poteče jutri ob] LT",
    "[Due] L [at] LT" : "[Poteče na] L [ob] LT",
    "No upcoming tasks" : "Ni prihajajočih nalog",
    "upcoming tasks" : "prihajajoče naloge",
    "No tasks today" : "Za danes ni dodeljenih nalog",
    "Successfully created the task." : "Naloga je uspešno ustvarjena.",
    "Could not delete the task." : "Naloge ni mogoče izbrisati.",
    "Synchronizing to the server." : "Poteka usklajevanje s strežnikom.",
    "Task successfully saved to server." : "Naloga je uspešno shranjena na strežnik.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Naloge ni mogoče posodobiti, ker je bila spremenjena na strežniku. Nalogo je treba osvežiti, vse krajevne spremembe pa bodo izgubljene.",
    "Could not update the task." : "Naloge ni mogoče posodobiti.",
    "Successfully updated the task." : "Naloga je uspešno posodobljena.",
    "Task successfully moved to new calendar." : "Naloga je uspešno premaknjena v nov koledar.",
    "An error occurred" : "Prišlo je do napake.",
    "Create a task" : "Ustvari nalogo",
    "Message from {author} in {conversationName}" : "{author} objavi sporočilo v pogovoru {conversationName}",
    "[Due on] LL" : "[Poteče na] LL",
    "[Was due yesterday]" : "[Poteklo je včeraj]",
    "[Was due on] LL" : "[Poteklo je na] LL",
    "[Was due today at] LT" : "[Poteklo je danes ob] LT",
    "[Due on] LL [at] LT" : "[Poteče na] LL [ob] LT",
    "[Was due yesterday at] LT" : "[Poteklo je včeraj ob] LT",
    "[Was due on] LL [at] LT" : "[Poteklo je na] LL [ob] LT",
    "[Starts today]" : "[Začne se danes]",
    "[Starts tomorrow]" : "[Začne se jutri]",
    "[Starts on] LL" : "[Začne se na] LL",
    "[Started yesterday]" : "[Začeto včeraj]",
    "[Started on] LL" : "[Začeto na] LL",
    "[Started today at] LT" : "[Začelo se je danes ob] LT",
    "[Starts today at] LT" : "[Začne se danes ob] LT",
    "[Starts tomorrow at] LT" : "[Začne se jutri ob] LT",
    "[Starts on] LL [at] LT" : "[Začne se na] LL [ob] LT",
    "[Started yesterday at] LT" : "[Začelo se je včeraj ob] LT",
    "[Started on] LL [at] LT" : "[Začeto na] LL [ob] LT"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
