OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "곧 있을 작업",
    "Important" : "중요",
    "Today" : "오늘",
    "Week" : "주",
    "All" : "모두",
    "Current" : "현재",
    "Completed" : "완료됨",
    "Tasks" : "작업",
    "The Tasks app for Nextcloud" : "Nextcloud 작업 앱",
    "Hidden" : "숨김",
    "Visible" : "보임",
    "Automatic" : "자동",
    "Default list" : "기본 리스트",
    "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
    "Unable to change permissions." : "권한을 변경할 수 없습니다.",
    "Can edit" : "편집 허용",
    "Unshare with {displayName}" : "{displayName}와(과) 공유 중단",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "이 동작은 달력 \"{calendar}\"과(와) 관련된 일정 및 작업을 삭제할 것입니다.",
    "This will unshare the calendar \"{calendar}\"." : "이 동작은 달력 \"{calendar}\"의 공유를 중단할 것입니다.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "이 동작은 목록 \"{list}\"과(와) 관련된 작업을 삭제할 것입니다.",
    "This will unshare the list \"{list}\"." : "이 동작은 목록 \"{list}\"의 공유를 중단할 것입니다.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 삭제"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 공유 해제"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["{countdown}초 후 목록 삭제"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["{countdown}초 후 목록 공유 해제"],
    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
    "List link copied to clipboard." : "목록의 링크를 클립보드에 복사했습니다.",
    "Calendar link could not be copied to clipboard." : "달력의 링크를 클립보드에 복사할 수 없습니다.",
    "List link could not be copied to clipboard." : "목록의 링크를 클립보드에 복사할 수 없습니다.",
    "The name \"{calendar}\" is already used." : "이름 \"{calendar}\"이(가) 이미 사용 중입니다.",
    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
    "An error occurred, unable to delete the list." : "오류가 발생하여 목록을 삭제할 수 없습니다.",
    "Edit" : "편집",
    "Copy private link" : "개인 링크 주소 복사",
    "Copied" : "복사됨",
    "Cannot copy" : "복사할 수 없음",
    "Export" : "내보내기",
    "Delete" : "삭제",
    "Unshare" : "공유 해제",
    "List name" : "리스트 추가",
    "Untitled task" : "제목없는 작업",
    "Untitled event" : "제목없는 일정",
    "Untitled item" : "제목 없는 항목",
    "Unknown calendar" : "제목 없는 달력",
    "Could not load deleted calendars and objects" : "삭제된 달력과 요소들을 불러올 수 없음",
    "Could not restore calendar or event" : "달력과 일정을 복구할 수 없음",
    "Do you really want to empty the trash bin?" : "휴지통을 정말 비웁니까?",
    "Empty trash bin" : "휴지통 비우기",
    "Trash bin" : "휴지통",
    "Name" : "이름",
    "Deleted" : "삭제됨",
    "Restore" : "복원",
    "Delete permanently" : "영구히 삭제",
    "Cancel" : "취소",
    "Email" : "이메일",
    "Audio notification" : "소리 알림",
    "Other notification" : "다른 알림",
    "Edit time" : "시간 편집",
    "Remove reminder" : "알림 삭제",
    "Add reminder" : "알림 추가",
    "Go back" : "뒤로 가기",
    "before at" : "다음 이전에: ",
    "_second_::_seconds_" : ["초"],
    "_minute_::_minutes_" : ["분"],
    "_hour_::_hours_" : ["시"],
    "_day_::_days_" : ["일"],
    "_week_::_weeks_" : ["주"],
    "Set date" : "날짜 설정",
    "Set time" : "시간 설정",
    "Delete date" : "날싸 지우기",
    "Click here to add a note." : "여기를 눌러 메모를 추가하십시오",
    "Set value" : "값 지정",
    "Delete value" : "값 삭제",
    "Add this as a new tag" : "새 태그로 추가하기",
    "No tag available. Create one!" : "사용 가능한 태그가 없습니다. 생성하십시오.",
    "Close" : "닫기",
    "Delete all completed tasks." : "모든 완료된 일 지우기",
    "Delete completed tasks." : "완료된 일 지우기",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" 달력의 모든 완료된 일 지우기",
    "No errors" : "오류 없음",
    "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여세요.",
    "Active filter" : "활성 필터",
    "Filter by tags" : "태그로 필터링",
    "Select tags to filter by" : "필터링할 태그 선택",
    "Reset filter" : "필터 초기화",
    "Relevance" : "관련된",
    "Start date" : "시작 날짜",
    "Due date" : "마감 날짜",
    "Created date" : "생성된 날짜",
    "Last modified" : "수정한 날짜",
    "Completed date" : "완료된 날짜",
    "Priority" : "우선 순위",
    "Sort by priority and summary." : "우선순위와 요약으로 정렬",
    "Alphabetically" : "가나다순",
    "Tags" : "태그",
    "Manually" : "수동으로",
    "Change sort order" : "정렬 순서 변경",
    "[Yesterday]" : "[어제]",
    "[Today]" : "[오늘]",
    "[Tomorrow]" : "[내일]",
    "Delete task" : "결과 삭제",
    "Task is completed" : "작업이 완료됨",
    "Create task" : "작업 만들기",
    "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
    "Tomorrow" : "내일",
    "Add List…" : "리스트 더하기...",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Canceled" : "취소됨",
    "Task not found!" : "작업을 찾을 수 없습니다!",
    "Set start date" : "시작 날짜 지점",
    "Set due date" : "만료 기한 설정",
    "All day" : "하루 종일",
    "Details" : "세부사항",
    "Select tags" : "태그 선택",
    "Notes" : "Notes",
    "Mark as done" : "완료된 것으로 표시",
    "An error occurred" : "오류가 발생함",
    "Message from {author} in {conversationName}" : "{conversationName}에서 {author}가 보낸 메시지"
},
"nplurals=1; plural=0;");
