OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Престојни задачи",
    "Important" : "Важно",
    "Today" : "Денес",
    "Week" : "Седмица",
    "All" : "Сите",
    "Current" : "Моменталлни",
    "Completed" : "Завршено",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Апликација за задачи за Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Откако ќе се овозможи, ново мени Задачи ќе се појави во менито за апликации. Од таму можете да додавате и бришете задачи, да го уредувате нивниот наслов, опис, датумот на започнување и крајниот рок и да ги означите како важни. Задачите можат да се споделуваат помеѓу корисниците. Задачите може да се синхронизираат со помош на CalDav (секој список со задачи е поврзан со календар, за да го синхронизирате со вашиот локален клиент - Thunderbird, Evolution, KDE Kontact, iCal,… - само додадете го календарот како далечински календар во вашиот клиент). Можете да ги преземете вашите задачи како ICS-датотеки со помош на копчето за преземање за секој календар.",
    "Hidden" : "Сокриен",
    "Visible" : "Видлив",
    "Automatic" : "Автоматски",
    "Tasks settings" : "Параметри за задачи",
    "Default list" : "Стандардна листа",
    "Visibility of Smart Collections" : "Видливост на паметни колекции",
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "Unable to delete the share." : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions." : "Неможе да се променат дозволите.",
    "Can edit" : "Може да се уредува",
    "Unshare with {displayName}" : "Не споделувај со {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ова ќе го избрише календарот \"{calendar}\" и сите настани и задачи во него.",
    "This will unshare the calendar \"{calendar}\"." : "Ова ќе направи да не се споделува повеќе календарот \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ова ќе ја избрише листата  \"{list}\" и сите задачи во неа.",
    "This will unshare the list \"{list}\"." : "Ова ќе направи да не се споделува повеќе листата \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришење на календарот за {countdown} секунда","Бришење на календарот за {countdown} секунди"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за {countdown} секунда","Отстранување на споделување на календар за {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Бришење на листата за {countdown} секунда","Бришење на листата за {countdown} секунди"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Отстранување на споделување на листа за {countdown} секунда","Отстранување на споделување на листа за {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено со 1 лице","Споделено со {num} лица"],
    "Share this calendar" : "Сподели го овој календар",
    "Share this list" : "Сподели ја оваа листа",
    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
    "List link copied to clipboard." : "Линкот до листата е копиран во клипборд.",
    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
    "List link could not be copied to clipboard." : "Линк до листата неможе да се копира во клипборд.",
    "The name \"{calendar}\" is already used." : "Името \"{calendar}\" е веќе искористено.",
    "An empty name is not allowed." : "Празно име не е дозволено.",
    "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
    "An error occurred, unable to delete the list." : "Настана грешка, неможе да се избрише листата.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватен линк",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Export" : "Извези",
    "Delete" : "Избриши",
    "Unshare" : "Отстрани споделување",
    "List name" : "Име на листа",
    "Untitled task" : "Неименувана задача",
    "Untitled event" : "Неименуван настан",
    "Untitled journal" : "Неименуван дневник",
    "Untitled item" : "Неименуваи работи",
    "Unknown calendar" : "Непознат календар",
    "Could not load deleted calendars and objects" : "Неможат да се вчитаат избришаните календари и елементи",
    "Could not delete calendar or event" : "Неможе да избришете календар или настан",
    "Could not restore calendar or event" : "Неможе да се врати календар или настан",
    "Do you really want to empty the trash bin?" : "Дали навистина сакате да ја испразните kорпаta за отпадоци?",
    "Empty trash bin" : "Испразни ја корпата со отпадоци",
    "Trash bin" : "Корпа за отпадоци",
    "Loading deleted calendars, tasks and events." : "Вчитување на избришани календари, задачи и настани.",
    "You do not have any deleted calendars, tasks or events." : "Немате избришани календари, задачи или настани.",
    "Name" : "Име",
    "Deleted" : "Избришани",
    "Restore" : "Врати",
    "Delete permanently" : "Избриши",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Елементите од корпата за отпадоци ќе бидат избришани после 1 ден","Елементите од корпата за отпадоци ќе бидат избришани после  {numDays} дена"],
    "Create reminder" : "Креирај потсетник",
    "Update reminder" : "Ажурирај потсетник",
    "Set a reminder at a custom date and time:" : "Постави потсетник на сопствен датум и време:",
    "Cancel" : "Откажи",
    "This is a todo reminder." : "Ова е потсетник за задача.",
    "No reminders" : "Нема потсетници",
    "Notification" : "Известување",
    "Email" : "Е-пошта",
    "Audio notification" : "Аудио известување",
    "Other notification" : "Друго и звестување",
    "Edit time" : "Удери време",
    "Remove reminder" : "Отстрани потсетник",
    "Add reminder" : "Додади потсетник",
    "Before the task starts" : "Пред да започне задачата",
    "Before the task is due" : "Пред рокот на задачата",
    "Select date and time" : "Избери датум и време",
    "Go back" : "Назад",
    "Do you want to keep related reminders?" : "Дали сакаш да ги задржиш поврзаните потсетници?",
    "Discard reminders" : "Отфрли потсетници",
    "Keep reminders" : "Задржи потсетници",
    "Set a reminder relative to your tasks start date:" : "Постави потсетник во однос на датумот на почеток на задачата:",
    "Set a reminder relative to your tasks due date:" : "Постави потсетник во однос на рокот на задачата:",
    "before at" : "пред",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часа"],
    "_day_::_days_" : ["ден","дена"],
    "_week_::_weeks_" : ["недела","недели"],
    "Select a calendar" : "Избери календар",
    "No calendar matches the search." : "Ниту еден календар не одговара на пребарувањето.",
    "Set date" : "Постави датум",
    "Set time" : "Постави време",
    "Delete date" : "Избриши датум",
    "Click here to add a note." : "Кликни овде за да додадеш белешка.",
    "Set value" : "Постави вредност",
    "Delete value" : "Избриши вредност",
    "Add this as a new tag" : "Додади ја како нова ознака",
    "No tag available. Create one!" : "Нема достапна ознака. Направи една!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} задачи се додадени во \"{calendar}\"",
    "Create new tasks" : "Креирај нови задачи",
    "Create {numberOfTasks} tasks from pasted text" : "Креирај {numberOfTasks} задачи од залепен текст",
    "Create tasks" : "Креирај задачи",
    "Creating new tasks…" : "Се создаваат нови задачи…",
    "Close" : "Затвори",
    "Delete all completed tasks." : "Избриши ги сите завршени задачи.",
    "Delete completed tasks." : "Избриши завршени задачи.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Избриши ги сите завршени задали од календарот \"{calendar}\".",
    "No errors" : "Нема грешки",
    "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ова ќе избрише {taskCount} завршена задачи и подзадачи од календарот \"{calendar}\".","Ова ќе избрише {taskCount} завршени задачи и подзадачи од календарот \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Неможе да се избрише {failedCount} задача.","Неможе да се избришат {failedCount} задачи."],
    "Active filter" : "Активен филтер",
    "Filter by tags" : "Филтрирај по ознаки",
    "Select tags to filter by" : "Изберете филтер за ознака",
    "Reset filter" : "Ресетирај филтер",
    "Add an important task to \"{calendar}\"…" : "Додади важна задача во \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Додади краен рон на задачите во \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Додади моментална задача во \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Додади задача во \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Вчитај ги завршените задачи од сите листи.",
    "Loading the completed tasks of all lists might slow down the app." : "Вчитување на сите завршени задачи од сите листи може да ја забави апликацијата.",
    "Load the completed tasks of list \"{calendar}\"." : "Вчитај ги завршените задачи од листата \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Вчитувањето на завршените задачи може да ја забави апликацијата.",
    "Relevance" : "Релевантност",
    "Sort by completed state, due date, priority, start date and summary." : "Подреди по завршена состојба, краен рок, приоритет, датум на започнување и резиме.",
    "Start date" : "Датум на започнување",
    "Sort by start date, priority and summary." : "Подреди по датум на започнување и резиме.",
    "Due date" : "До датум",
    "Sort by due date, priority and summary." : "Подреди по краен рок, приоритет и резиме.",
    "Created date" : "Датум на креирање",
    "Sort by created date, priority and summary." : "Подреди по датум на креирање, приоритет и резиме.",
    "Last modified" : "Последно изменето",
    "Sort by last-modified date, priority and summary." : "Подреди по датум на последна промена, приоритет и резиме.",
    "Completed date" : "Датум на завршување",
    "Sort by completed date, priority and summary." : "Подреди по датум на комплетирање, приоритет и резиме.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Подреди по приоритет и резиме.",
    "Alphabetically" : "Азбучно",
    "Sort by summary and priority." : "Подреди по резиме и приоритет.",
    "Tags" : "Ознаки",
    "Sort by tags." : "Подреди по ознаки.",
    "Manually" : "Рачно",
    "Sort by manual order." : "Подреди по рачен редослед.",
    "Change sort order" : "Променете го редоследот",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Денес]",
    "[Tomorrow]" : "[Утре]",
    "[Completed yesterday]" : "[Завршено вчера]",
    "[Completed today]" : "[Завршено денес]",
    "[Completed tomorrow]" : "[Завршено утре]",
    "[Yesterday at] LT" : "[Вчера во] LT",
    "[Today at] LT" : "[Денес во] LT",
    "[Tomorrow at] LT" : "[Утре во] LT",
    "L [at] LT" : "L [во] LT",
    "[Completed yesterday at] LT" : "[Завршено вчера во] LT",
    "[Completed today at] LT" : "[Завршено денес во] LT",
    "[Completed tomorrow at] LT" : "[Завршено утре во] LT",
    "[Completed] L [at] LT" : "[Завршено] L [во] LT",
    "Add a subtask to \"{task}\"…" : "Додади подзадача во \"{task}\"…",
    "Task has hidden subtasks" : "Задачата има скриена подзадача",
    "Task is pinned" : "Задачата е пинувана",
    "Task has a note" : "Задачата има белешка",
    "{complete} % completed" : "{complete} % завршено",
    "Add subtask" : "Додади подзадача",
    "Show subtasks" : "Прикажи подзадачи",
    "Hide subtasks" : "Сокриј подзадачи",
    "Show closed subtasks" : "Прикажи затворени подзадачи",
    "Hide closed subtasks" : "Сокриј затворени подзадачи",
    "Delete task" : "Избриши задача",
    "Toggle starred" : "Вклучи омилени",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Задачата има еден потсетник","Задачата има {n} потсетници"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Бришење на задачата за {countdown} секунда","Бришење на задачата за {countdown} секунди"],
    "Task is cancelled" : "Задачата е откажана",
    "Task is completed" : "Задачата е завршена",
    "Task is read-only" : "Задачата е само за читање",
    "Task is not completed" : "Задачата не е комплетирана",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" е додадена во \"{calendar}\"",
    "Create a new task" : "Креирај нова задача",
    "Task summary" : "Резиме на задачи",
    "Create task" : "Креирај задача",
    "Creating the new task…" : "Креирање нова задача...",
    "Open task" : "Отвори задача",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завршена задача","%n Завршени задачи"],
    "Tomorrow" : "Утре",
    "An error occurred, unable to create the list." : "Се појави грешка, не може да се создаде листата.",
    "Add List…" : "Додади листа...",
    "New list" : "Нова листа",
    "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
    "When shared show only busy" : "Кога е споделен, прикажи зафатено",
    "When shared hide this event" : "Кога е споделен, сокриј го настанот",
    "[Completed] L" : "[Завршено] L",
    "[Completed last] dddd [at] LT" : "[Завршено] dddd [во] LT",
    "[Completed] dddd [at] LT" : "[Завршено] dddd [во] LT",
    "[Last modified yesterday at] LT" : "[Последно изменето вчера во] LT",
    "[Last modified today at] LT" : "[Последно изменето денес во] LT",
    "[Last modified] L" : "[Последно изменето] L",
    "[Last modified last] dddd [at] LT" : "[Последно изменето во] dddd [во] LT",
    "[Last modified] dddd [at] LT" : "[Последно изменето] dddd [во] LT",
    "[Created yesterday at] LT" : "[Создадено вчера во] LT",
    "[Created today at] LT" : "[Создадено денес во] LT",
    "[Created] L" : "[Создадено] L",
    "[Created last] dddd [at] LT" : "[Создадено во] dddd [во] LT",
    "[Created] dddd [at] LT" : "[Создадено] dddd [во] LT",
    "Needs action" : "Потребна е акција",
    "In process" : "Во тек",
    "Canceled" : "Откажано",
    "Clear status" : "Исчисти статус",
    "Loading task from server." : "Вчитување на задачите од серверот.",
    "Task not found!" : "Задачата не е пронајдена!",
    "Set start date" : "Постави почетен датум",
    "Set due date" : "Постави краен рок",
    "Priority {priority}: low" : "Приоритет {priority}: низок",
    "Priority {priority}: medium" : "Приоритет {priority}: среден",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Нема дадено приоритет",
    "{percent} % completed" : "{percent} % завршено",
    "All day" : "Цели денови",
    "Unpin" : "Од-ппинувај",
    "Pin" : "Пинувај",
    "Show in Calendar" : "Прикажи во календар",
    "Show in Deck" : "Прикажи во Deck",
    "Edit summary" : "Уреди резиме",
    "Details" : "Детали",
    "Selecting a classification is forbidden, because the task was shared with you." : "Изборот на класификација е забранет бидејќи задачата е споделена со тебе.",
    "Select a classification" : "Избери класификација",
    "Select a status" : "Избери статус",
    "Set a location" : "Постави локација",
    "Set a URL" : "Постави URL",
    "Select tags" : "Избери ознаки",
    "Notes" : "Белешки",
    "Mark as done" : "Означи како готово",
    "No due date assigned" : "Нема додадено датум за краен рок",
    "[Due yesterday]" : "[Рок вчера]",
    "[Due today]" : "[До денес]",
    "[Due tomorrow]" : "[До утре]",
    "[Due] L" : "[Рок] L",
    "[Due yesterday at] LT" : "[Рок вчера во] LT",
    "[Due today at] LT" : "[До денес во] LT",
    "[Due tomorrow at] LT" : "[До утре во] LT",
    "[Due] L [at] LT" : "[Рок] L [во] LT",
    "No upcoming tasks" : "Нема престојни задачи",
    "upcoming tasks" : "престојни задачи",
    "No tasks today" : "Нема задачи за денеска",
    "Completion date must be in the past." : "Датумот на завршување мора да биде во минатото.",
    "Successfully created the task." : "Успешно креирана задача.",
    "Could not delete the task." : "Неможе да се избрише задачата.",
    "Synchronizing to the server." : "Синхронизација со серверот.",
    "Task successfully saved to server." : "Задачата е успешно зачувана на серверот.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Неможе да се ажурира задачата бидејќи постои некој промена во задачата на серверот. Кликете на освежи, локалните промени ќе се отфрлат.",
    "Could not update the task." : "Неможе да се ажурира задачата.",
    "Successfully updated the task." : "Успешно ажурирање на задачата.",
    "Task successfully moved to new calendar." : "Задачата е успешно преместена во нов календар.",
    "An error occurred" : "Настана грешка",
    "Create a task" : "Креирај задача",
    "Message from {author} in {conversationName}" : "Порака од {author} во {conversationName}",
    "[Due on] LL" : "[До] LL",
    "[Was due yesterday]" : "[Требаше вчера]",
    "[Was due on] LL" : "[Требаше до] LL",
    "[Was due today at] LT" : "[Требаше до денес во] LT",
    "[Due on] LL [at] LT" : "[До] LL [во] LT",
    "[Was due yesterday at] LT" : "[Требаше вчера во] LT",
    "[Was due on] LL [at] LT" : "[Требаше до] LL [во] LT",
    "[Starts today]" : "[Започнува денес]",
    "[Starts tomorrow]" : "[Започнува утре]",
    "[Starts on] LL" : "[Започнува на] LL",
    "[Started yesterday]" : "[Започна вчера]",
    "[Started on] LL" : "[Започна на] LL",
    "[Started today at] LT" : "[Започна денес во] LT",
    "[Starts today at] LT" : "[Започнува денес во] LT",
    "[Starts tomorrow at] LT" : "[Започнува утре во] LT",
    "[Starts on] LL [at] LT" : "[Започнува на] LL [во] LT",
    "[Started yesterday at] LT" : "[Започна вчера во] LT",
    "[Started on] LL [at] LT" : "[Започна на] LL [во] LT",
    "Midnight on the day the task starts" : "На полноќ во денот кога започнува задачата",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n ден пред задачата во {formattedHourMinute}","%n дена пред задачата во {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n недела пред задачата во {formattedHourMinute}","%n недели пред задачата во {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "на денот на задачата во {formattedHourMinute}",
    "at the task's start" : "при започнување на задачата",
    "when the task is due" : "кога задачата има рок",
    "{time} before the task starts" : "{time} пред започнување на задачата",
    "{time} before the task is due" : "{time} пред рокот на задачата",
    "{time} after the task starts" : "{time} по започнување на задачата",
    "{time} after the task is due" : "{time} по рокот на задачата"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
