OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Xeres próximes",
    "Important" : "Importante",
    "Today" : "Güei",
    "Week" : "Selmana",
    "All" : "Too",
    "Current" : "Actual",
    "Completed" : "Completóse",
    "Tasks" : "Xeres",
    "The Tasks app for Nextcloud" : "L'aplicación Xeres pa Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Namás que s'active, Xeres va apaecer nel menú d'aplicaciones de Nextcloud. Dende ehí pues amestar y desaniciar xeres, marcales como importantes, editar el so títulu, descripción, dates de comienzu y fin. Los usuarios puen compartir les xeres colos demás y sincronizales con CalDAV (cada llista de xeres enlláciase con un calendariu de Nextcloud. pa sincronizalu con un veceru: Thinderbird, Evolution, KDE Kontact, iCal… Namás amiesta'l calendariu como calendariu remotu nel veceru). Pues baxar les xeres en ficheros ICS col botón de descarga qu'hai en cada calendariu.",
    "Hidden" : "Anubrióse",
    "Visible" : "Visible",
    "Automatic" : "Automáticu",
    "Tasks settings" : "Configuración de les xeres",
    "Default list" : "Llista predeterminada",
    "Visibility of Smart Collections" : "Visibilidá de les coleiciones intelixentes",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "Nun hai nengún usuariu nin grupu",
    "Unable to delete the share." : "Nun ye posible desaniciar la compartición.",
    "Unable to change permissions." : "Nun ye posible camudar los permisos.",
    "Can edit" : "Pue editar",
    "Unshare with {displayName}" : "Dexar de compartir con {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Esta aición va desaniciar el calendariu «{calendar}» y tolos eventos y xeres correspondientes.",
    "This will unshare the calendar \"{calendar}\"." : "Esta aición va dexar de compartir el calendariu «{calendar}».",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Esta aición va desaniciar la llista «{list}» y les xeres correspondientes.",
    "This will unshare the list \"{list}\"." : "Esta aición va dexar de compartir la llista «{list}».",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Va desaniciase'l calendariu en {countdown} segundu","Va desaniciase'l calendariu en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Va dexar de compartise'l calendariu en {countdown} segundu","Va dexar de compartise'l calendariu en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Va desaniciase la llista en {countdown} segundu","Va desaniciase la llista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Va dexar de compartise la llista en {countdown} segundu","Va dexar de compartise la llista  en {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartióse con {num} entidá","Compartióse con {num} entidaes"],
    "Share this calendar" : "Compartir esti calendariu",
    "Share this list" : "Compartir esta llista",
    "Calendar link copied to clipboard." : "L'enllaz del calendariu copióse nel cartafueyu.",
    "List link copied to clipboard." : "L'enllaz de la llista copióse nel cartafueyu.",
    "Calendar link could not be copied to clipboard." : "L'enllaz del calendariu nun se pudo copiar nel cartafueyu.",
    "List link could not be copied to clipboard." : "L'enllaz de la llista nun se pudo copiar nel cartafueyu.",
    "The name \"{calendar}\" is already used." : "El nome «{calendar}» yá ta n'usu.",
    "An empty name is not allowed." : "Nun se permite nengún nome baleru.",
    "An error occurred, unable to delete the calendar." : "Prodúxose un error, nun ye posible desaniciar el calendariu",
    "An error occurred, unable to delete the list." : "Prodúxose un error, nun ye posible desaniciar la llista.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar l'enllaz priváu",
    "Copied" : "Copióse",
    "Cannot copy" : "Nun se pue copiar",
    "Export" : "Esportar",
    "Delete" : "Desaniciar",
    "Unshare" : "Dexar de compartir",
    "List name" : "Nome de la llista",
    "Untitled task" : "Xera ensin títulu",
    "Untitled event" : "Eventu ensin títulu",
    "Untitled journal" : "Diariu ensin títulu",
    "Untitled item" : "Elementu ensin nome",
    "Unknown calendar" : "Calendariu desconocíu",
    "Could not load deleted calendars and objects" : "Nun se pudieron desaniciar los calendarios y los oxetos",
    "Could not delete calendar or event" : "Nun se pudo desaniciar el calendariu o l'eventu",
    "Could not restore calendar or event" : "Nun se pudo restaurar el calendariu o l'eventu",
    "Do you really want to empty the trash bin?" : "¿De xuru que quies balerar la papelera de reciclaxe?",
    "Empty trash bin" : "Balerar la papelera",
    "Trash bin" : "Papelera",
    "Loading deleted calendars, tasks and events." : "Cargando los calendarios, les xeres y los eventos desaniciaos.",
    "You do not have any deleted calendars, tasks or events." : "Nun tienes nengún calendariu, xera o eventu desaniciáu.",
    "Name" : "Nome",
    "Deleted" : "Desanicióse",
    "Restore" : "Restaurar",
    "Delete permanently" : "Desaniciar permanentemente",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Los elementos de la papalera desaníciense dempués de {numDays} día","Los elementos de la papalera desaníciense dempués de {numDays} díes"],
    "Cancel" : "Encaboxar",
    "Notification" : "Avisu",
    "Email" : "Direición de corréu electrónicu",
    "Audio notification" : "Avisu d'audiu",
    "Other notification" : "Otru avisu",
    "Edit time" : "Editar la hora",
    "Remove reminder" : "Quitar el recordatoriu",
    "Go back" : "Dir p'atrás",
    "_second_::_seconds_" : ["segundu","segundos"],
    "_minute_::_minutes_" : ["minutu","minutos"],
    "_hour_::_hours_" : ["hora","hores"],
    "_day_::_days_" : ["día","díes"],
    "_week_::_weeks_" : ["selmana","selmanes"],
    "Select a calendar" : "Seleicionar un calendariu",
    "No calendar matches the search." : "Nun hai nengún calendariu que concase cola busca.",
    "Set date" : "Afitar la data",
    "Set time" : "Afitar la hora",
    "Delete date" : "Desaniciar la data",
    "Click here to add a note." : "Calca p'amestar una nota.",
    "Set value" : "Afitar un valor",
    "Delete value" : "Desaniciar el valor",
    "Add this as a new tag" : "Amestar esto como una etiqueta nueva",
    "No tag available. Create one!" : "Nun hai nenguna etiqueta disponible. ¡Crea una!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "Amestáronse {numberOfTasks} a «{calendar}»",
    "Create new tasks" : "Crear xeres nueves",
    "Create {numberOfTasks} tasks from pasted text" : "Crear {numberOfTasks} xeres del testu apegáu",
    "Create tasks" : "Crear les xeres",
    "Creating new tasks…" : "Creando les xeres nueves…",
    "Close" : "Zarrar",
    "Delete all completed tasks." : "Desanicia toles xeres completaes.",
    "Delete completed tasks." : "Desanicia les xeres completaes.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Desaniciáronse toles xeres completaes del calendariu «{calendar}».",
    "No errors" : "Nun hai nengún error",
    "Open your browser console for more details" : "Abri'l la consola del restolador pa consiguir más detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Esta aición va desaniciar {taskCount} xera completa y les sos soxeres del calendariu «{calendar}».","Esta aición va desaniciar {taskCount} xeres completaes y les sos soxeres del calendariu «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nun se pudo desaniciar {failedCount} xera.","Nun se pudieron desaniciar {failedCount} xeres."],
    "Active filter" : "Peñera activa",
    "Filter by tags" : "Peñerar por etiquetes",
    "Select tags to filter by" : "Seleiciona les etiquetes poles que quies peñerar",
    "Reset filter" : "Reafitar la peñera",
    "Add an important task to \"{calendar}\"…" : "Amestar una xera importante a «{calendar}»…",
    "Add a task due today to \"{calendar}\"…" : "Amestar una xera pa güei en «{calendar}»…",
    "Add a current task to \"{calendar}\"…" : "Amestar una xera actual a «{calendar}»…",
    "Add a task to \"{calendar}\"…" : "Amestar una xera a «{calendar}»…",
    "Load the completed tasks of all lists." : "Carga les xeres completaes de toles llistes.",
    "Loading the completed tasks of all lists might slow down the app." : "La carga de les xeres completaes de toles llistes quiciabes amenorgue la velocidá de l'aplicación.",
    "Load the completed tasks of list \"{calendar}\"." : "Carga les llistes completaes de la llista «{calendar}».",
    "Loading the completed tasks might slow down the app." : "La carga de les xeres completaes quiciabes amenorgue la velocidá de l'aplicación.",
    "Relevance" : "Relevancia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordena pol estáu de completáu, la data de caducida, pol resume, la prioridá y la data d'aniciu.",
    "Start date" : "Data de comienzu",
    "Sort by start date, priority and summary." : "Ordena pola data d'aniciu, el resume y la prioridá.",
    "Due date" : "Data de fin",
    "Sort by due date, priority and summary." : "Ordena pola data de caducidá, el sumariu y la prioridá.",
    "Created date" : "Data de creación",
    "Sort by created date, priority and summary." : "Ordena pola data de creación, el sumariu y la prioridá",
    "Last modified" : "Última modificación",
    "Sort by last-modified date, priority and summary." : "Ordena pola data de la última modificación, el resume y la prioridá.",
    "Completed date" : "Data de completáu",
    "Sort by completed date, priority and summary." : "Ordena pola data de completáu, el resume y la prioridá.",
    "Priority" : "Prioridá",
    "Sort by priority and summary." : "Ordena pola prioridá y el resume.",
    "Alphabetically" : "Alfabéticamente",
    "Sort by summary and priority." : "Ordena pol resume y la prioridá.",
    "Tags" : "Etiquetes",
    "Manually" : "Manualmente",
    "Sort by manual order." : "Ordena pola clasificación manual",
    "Change sort order" : "Camudar l'orde de clasificación",
    "[Yesterday]" : "[Ayeri]",
    "[Today]" : "[Güei]",
    "[Tomorrow]" : "[Mañana]",
    "[Completed yesterday]" : "[Completóse ayeri]",
    "[Completed today]" : "[Completóse güei]",
    "[Completed tomorrow]" : "[Completóse mañana]",
    "[Yesterday at] LT" : "[Ayeri:] LT",
    "[Today at] LT" : "[Güei:] LT",
    "[Tomorrow at] LT" : "[Mañana:] LT",
    "L [at] LT" : "L [:] LT",
    "[Completed yesterday at] LT" : "[Completóse ayeri:] LT",
    "[Completed today at] LT" : "[Completóse güei:] LT",
    "[Completed tomorrow at] LT" : "[Completóse mañana:] LT",
    "[Completed] L [at] LT" : "[Completóse] L [:] LT",
    "Add a subtask to \"{task}\"…" : "Amestar una soxera a «{task}»…",
    "Task has hidden subtasks" : "La xera anubrió les soxeres",
    "Task is pinned" : "La xera ta fixada",
    "Task has a note" : "La xera tien una nota",
    "{complete} % completed" : "{complete} % completada",
    "Add subtask" : "Amestar una soxera",
    "Show subtasks" : "Amosar les soxeres",
    "Hide subtasks" : "Anubrir les soxeres",
    "Show closed subtasks" : "Amosar les soxeres zarraes",
    "Hide closed subtasks" : "Anubrir les soxeres zarraes",
    "Delete task" : "Desaniciar la xera",
    "Toggle starred" : "Alternar la estrella",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Va desaniciase la xera en {countdown} segundu","Va desaniciase la xera en {countdown} segundos"],
    "Task is cancelled" : "La xera ta anulada",
    "Task is completed" : "La xera ta completada",
    "Task is read-only" : "La xera ye de namás llectura",
    "Task is not completed" : "La xera nun ta completada",
    "\"{task}\" was added to \"{calendar}\"" : "«{task}» amestóse a «{calendar}»",
    "Create a new task" : "Crear una xera",
    "Task summary" : "Resume de la xera",
    "Create task" : "Crear la xera",
    "Creating the new task…" : "Creando una xera…",
    "Open task" : "Abrir la xera",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n xera completada","%n xeres completaes"],
    "Tomorrow" : "Mañana",
    "Add List…" : "Amestar una llista…",
    "New list" : "Llista nueva",
    "When shared show full event" : "Cuando se comparta amosar l'eventu completu",
    "When shared show only busy" : "Cuando se comparta amosar namás si ta ocupáu",
    "When shared hide this event" : "Cuando se comparta anubrir l'eventu",
    "[Completed] L" : "[Completóse] L",
    "[Completed last] dddd [at] LT" : "[Completóse per última vegada'l] dddd [:] LT",
    "[Completed] dddd [at] LT" : "[Completóse'l] dddd [:] LT",
    "[Last modified yesterday at] LT" : "[Modificóse per última vegada ayeri:] LT",
    "[Last modified today at] LT" : "[Modificóse per última vegada güei:] LT",
    "[Last modified] L" : "[Mordificóse per última vegada] L",
    "[Last modified last] dddd [at] LT" : "[Modificóse per última vegada ayeri'l] dddd [:] LT",
    "[Last modified] dddd [at] LT" : "[Modificóse per última vegada'l] dddd [:] LT",
    "[Created yesterday at] LT" : "[Creóse ayeri:] LT",
    "[Created today at] LT" : "[Creóse güei:] LT",
    "[Created] L" : "[Creóse'l] L",
    "[Created last] dddd [at] LT" : "[Creóse per última vegada] dddd [:] LT",
    "[Created] dddd [at] LT" : "[Creóse'l] dddd [:] LT",
    "Needs action" : "Precisa aición",
    "In process" : "En cursu",
    "Canceled" : "Anulóse",
    "Clear status" : "Borrar l'estáu",
    "Loading task from server." : "Cargando la xera del sirvidor.",
    "Task not found!" : "¡Nun s'atopó la xera!",
    "Set start date" : "Afitar la data d'aniciu",
    "Set due date" : "Afitar la data de caducidá",
    "Priority {priority}: low" : "Prioridá «{priority}»: baxa",
    "Priority {priority}: medium" : "Prioridá «{priority}»: media",
    "Priority {priority}: high" : "Prioridá «{priority}»: alta",
    "No priority assigned" : "Nun s'asignó nenguna prioridá",
    "{percent} % completed" : "{percent} % completada",
    "All day" : "Tol día",
    "Unpin" : "Lliberar",
    "Pin" : "Fixar",
    "Show in Calendar" : "Amosar en Calendariu",
    "Show in Deck" : "Amosar en Tarxeteru",
    "Edit summary" : "Editar el resume",
    "Details" : "Detalles",
    "Selecting a classification is forbidden, because the task was shared with you." : "Prohíbese la seleición de clasificaciones porque la xera ta compartida contigo.",
    "Select a classification" : "Seleicionar una clasificación",
    "Select a status" : "Seleicionar un estáu",
    "Set a location" : "Afitar un llugar",
    "Set a URL" : "Afitar una URL",
    "Select tags" : "Seleicionar etiquetes",
    "Notes" : "Notes",
    "Mark as done" : "Marcar como fecha",
    "No due date assigned" : "Nun s'asignó nenguna data de caducidá",
    "[Due yesterday]" : "[Caduca mañana]",
    "[Due today]" : "[Caduca güei]",
    "[Due tomorrow]" : "[Caduca mañana]",
    "[Due] L" : "[Caduca'l] L",
    "[Due yesterday at] LT" : "[Caduca mañana:] LT",
    "[Due today at] LT" : "[Caduca güei:] LT",
    "[Due tomorrow at] LT" : "[Caduca mañana] LT",
    "[Due] L [at] LT" : "[Caduca'l] L [:] LT",
    "No upcoming tasks" : "Nun hai nenguna xera próxima",
    "upcoming tasks" : "xeres próximes",
    "No tasks today" : "Güei nun hai nenguna xera",
    "Successfully created the task." : "La xera creóse correutamente.",
    "Could not delete the task." : "Nun se pudo desaniciar la xera.",
    "Synchronizing to the server." : "Sincronizando col sirvidor.",
    "Task successfully saved to server." : "La xera guardóse correutamente nel sirvidor.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nun se pudo anovar la xera porque camudó nel sirvidor. Calca p'anovala, van escartase los cambeos llocales.",
    "Could not update the task." : "Nun se pudo anovar la xera.",
    "Successfully updated the task." : "La xera copióse correutamente.",
    "Task successfully moved to new calendar." : "La xera movióse correutamente al calendariu nuevu.",
    "An error occurred" : "Prodúxose un error",
    "Create a task" : "Crear una xera",
    "Message from {author} in {conversationName}" : "Mensaxe de {author} en {conversationName}",
    "[Due on] LL" : "[Caduca'l] LL",
    "[Was due yesterday]" : "[Caducó ayeri]",
    "[Was due on] LL" : "[Caducó'l] LL",
    "[Was due today at] LT" : "[Caducó güei:] LT",
    "[Due on] LL [at] LT" : "[Caduca'l] LL [:] LT",
    "[Was due yesterday at] LT" : "[Caducó ayeri:] LT",
    "[Was due on] LL [at] LT" : "[Caducó'l] LL [:] LT",
    "[Starts today]" : "[Comienza güei]",
    "[Starts tomorrow]" : "[Comienza mañana]",
    "[Starts on] LL" : "[Comienza'l] LL",
    "[Started yesterday]" : "[Comenzó ayeri]",
    "[Started on] LL" : "[Comenzó'l] LL",
    "[Started today at] LT" : "[Comenzó güei:] LT",
    "[Starts today at] LT" : "[Comienza güei:] LT",
    "[Starts tomorrow at] LT" : "[Comienza mañana:] LT",
    "[Starts on] LL [at] LT" : "[Comienza'l] LL [:] LT",
    "[Started yesterday at] LT" : "[Comenzó ayeri:] LT",
    "[Started on] LL [at] LT" : "[Comienza'l] LL [:] LT"
},
"nplurals=2; plural=(n != 1);");
