OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Hurrengo zereginak",
    "Important" : "Garrantzitsua",
    "Today" : "Gaur",
    "Week" : "Astea",
    "All" : "Denak",
    "Current" : "Unekoa",
    "Completed" : "Osatua",
    "Tasks" : "Zereginak",
    "The Tasks app for Nextcloud" : "Nextcloudeko Zereginak aplikazioa",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Gaitutakoan Zereginak izeneko menu berria agertuko da Nexcloudeko aplikazioen menuan. Bertan zereginak gehitu eta ezabatu ahal izango dituzu, baita izenburua, deskribapena, hasiera-data eta epemuga aldatu eta garrantzitsu bezala markatu ere. Zereginak erabiltzaileen artean partekatu daitezke. Zereginak CalDav erabiliz sinkronizatu daitezke (zeregin zerrenda bakoitza Nextcloud egutegi bati lotuta dago, zure bezero lokalarekin Thunderbird, Evolution, KDE Kontact, iCal ... - sinkronizatzeko nahikoa da bezeroan egutegia urruneko egutegi bezala gehitzea). Zure zereginak ICS fitxategi bezala deskargatu ditzakezu, egutegi bakoitzaren deskargatu botoia erabiliz.",
    "Hidden" : "Ezkutuan",
    "Visible" : "Ikusgai",
    "Automatic" : "Automatikoa",
    "Tasks settings" : "Zereginen ezarpenak",
    "Default list" : "Zerrenda lehenetsia",
    "Visibility of Smart Collections" : "Bilduma adimendunen ikusgaitasuna",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edo talderik",
    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
    "Can edit" : "Editatu dezake",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Honek \"{calendar}\" egutegia eta bere gertaera eta zeregin guztiak ezabatuko ditu.",
    "This will unshare the calendar \"{calendar}\"." : "Honek \"{calendar}\" egutegia partekatzea etengo du.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Honek \"{list}\" zerrenda eta bere zeregin guztiak ezabatuko ditu.",
    "This will unshare the list \"{list}\"." : "Honek \"{list}\" zerrenda partekatzea etengo du.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatuko da {countdown} segundo barru","Egutegia ezabatuko da {countdown} segundo barru"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Egutegia partekatzea kenduko da {countdown} segundo barru","Egutegia partekatzea kenduko da {countdown} segundo barru"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Zerrenda ezabatzen segundu {countdown}ean","Zerrenda ezabatzen {countdown} segundutan"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Zerrenda partekatzea kenduko da {countdown} segundo barru ","Zerrenda partekatzea kenduko da {countdown} segundo barru "],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatua","{num} entitaterekin partekatua"],
    "Share this calendar" : "Partekatu egutegi hau",
    "Share this list" : "Partekatu zerrenda hau",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "List link copied to clipboard." : "Zerrenda esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "List link could not be copied to clipboard." : "Ezin izan da zerrenda esteka arbelera kopiatu.",
    "The name \"{calendar}\" is already used." : "\"{calendar}\" izena badago dagoeneko.",
    "An empty name is not allowed." : "Ez da izen hutsik onartzen.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "An error occurred, unable to delete the list." : "Errore bat gertatu da, ezin izan da zerrenda ezabatu.",
    "Edit" : "Editatu",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Copied" : "Kopiatuta",
    "Cannot copy" : "Ezin da kopiatu",
    "Export" : "Esportatu",
    "Delete" : "Ezabatu",
    "Unshare" : "Ez partekatu",
    "List name" : "Zerrendaren izena",
    "Untitled task" : "Izenik gabeko zeregina",
    "Untitled event" : "Izenik gabeko gertaera",
    "Untitled journal" : "Izenik gabeko egunkaria",
    "Untitled item" : "Izen gabeko elementua",
    "Unknown calendar" : "Egutegi ezezaguna",
    "Could not load deleted calendars and objects" : "Ezin izan dira ezabatutako egutegi eta elementuak kargatu",
    "Could not delete calendar or event" : "Ezin izan da egutegi edo gertaera ezabatu",
    "Could not restore calendar or event" : "Ezin izan da egutegia edo gertaera berezarri",
    "Do you really want to empty the trash bin?" : "Ziur zaude zakarrontzia hustu nahi duzula?",
    "Empty trash bin" : "Hustu zakarrontzia",
    "Trash bin" : "Zakarrontzia",
    "Loading deleted calendars, tasks and events." : "Ezabatutako egutegi, zeregin eta gertaerak kargatzen.",
    "You do not have any deleted calendars, tasks or events." : "Ez duzu ezabatutako egutegi, zeregin edo gertaerarik.",
    "Name" : "Izena",
    "Deleted" : "Ezabatuta",
    "Restore" : "Berezarri",
    "Delete permanently" : "Ezabatu betirako",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Zakarrontziko elementuak egun {numDays} igaro ondoren ezabatzen dira","Zakarrontziko elementuak {numDays} egun igaro ondoren ezabatzen dira"],
    "Cancel" : "Ezeztatu",
    "Notification" : "Jakinarazpena",
    "Email" : "Posta elektronikoa",
    "Audio notification" : "Audio jakinarazpena",
    "Other notification" : "Bestelako jakinarazpena",
    "Edit time" : "Editatu ordua",
    "Remove reminder" : "Kendu gogorarazpena",
    "Add reminder" : "Gehitu gogorarazpena",
    "Go back" : "Atzera",
    "before at" : "lehenago hemen",
    "_second_::_seconds_" : ["segundo","segundo"],
    "_minute_::_minutes_" : ["minutu","minutu"],
    "_hour_::_hours_" : ["ordu","ordu"],
    "_day_::_days_" : ["egun","egun"],
    "_week_::_weeks_" : ["aste","aste"],
    "Select a calendar" : "Hautatu egutegi bat",
    "No calendar matches the search." : "Ez dago bilaketarekin bat datorren egutegirik.",
    "Set date" : "Ezarri data",
    "Set time" : "Ezarri denbora",
    "Delete date" : "Ezabatu data",
    "Click here to add a note." : "Egin klik hemen nota bat gehitzeko.",
    "Set value" : "Ezarri balioa",
    "Delete value" : "Ezabatu balioa",
    "Add this as a new tag" : "Gehitu hau etiketa berri bezala",
    "No tag available. Create one!" : "Ez dago etiketarik eskuragarri. Sortu bat!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} zeregin gehitu dira \"{calendar}\"(e)ra",
    "Create new tasks" : "Sortu zeregin berriak",
    "Create {numberOfTasks} tasks from pasted text" : "Sortu {numberOfTasks} zeregin itsatsitako testutik",
    "Create tasks" : "Sortu zereginak",
    "Creating new tasks…" : "Zeregin berriak sortzen...",
    "Close" : "Itxi",
    "Delete all completed tasks." : "Ezabatu osatutako zeregin guztiak.",
    "Delete completed tasks." : "Ezabatu osatutako zereginak.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" egutegiko osatutako zeregin guztiak ezabatu dira.",
    "No errors" : "Errorerik ez",
    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Honek osatutako zeregin {taskCount} eta beren azpi-zereginak ezabatuko ditu \"{calendar}\" egutegitik.","Honek osatutako {taskCount} zeregin eta beren azpizereginak ezabatuko ditu \"{calendar}\" egutegitik."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Ezin izan da zeregin {failedCount} ezabatu.","Ezin izan dira {failedCount} zeregin ezabatu."],
    "Active filter" : "Iragazki aktiboa",
    "Filter by tags" : "Iragazi etiketen arabera",
    "Select tags to filter by" : "Hautatu etiketak iragazteko",
    "Reset filter" : "Berrezarri iragazkia",
    "Add an important task to \"{calendar}\"…" : "Gehitu zeregin garrantzitsu bat \"{calendar}\" egutegiari…",
    "Add a task due today to \"{calendar}\"…" : "Gehitu gaurko epemuga bat duen zeregin bat \"{calendar}\" egutegiari…",
    "Add a current task to \"{calendar}\"…" : "Gehitu uneko zeregin bat \"{calendar}\" egutegiari…",
    "Add a task to \"{calendar}\"…" : "Gehitu zeregin bat \"{calendar}\" egutegiari…",
    "Load the completed tasks of all lists." : "Kargatu osatutako zeregin guztiak, zerrenda guztietakoak.",
    "Loading the completed tasks of all lists might slow down the app." : "Zerrenda guztietako osatutako zeregin guztiak kargatzeak aplikazioa mantsotu dezake.",
    "Load the completed tasks of list \"{calendar}\"." : "Kargatu osatutako zeregin guztiak \"{calendar}\" zerrendatik.",
    "Loading the completed tasks might slow down the app." : "Osaturiko zereginak kargatzeak aplikazioa moteldu dezake.",
    "Relevance" : "Garrantzia",
    "Sort by completed state, due date, priority, start date and summary." : "Ordenatu osatutako egoera, epemuga, lehentasuna, hasiera-data eta laburpenaren arabera.",
    "Start date" : "Hasiera-data",
    "Sort by start date, priority and summary." : "Ordenatu hasiera-data, lehentasuna eta laburpenaren arabera.",
    "Due date" : "Epemuga",
    "Sort by due date, priority and summary." : "Ordenatu osatze-data, lehentasuna eta laburpenaren arabera.",
    "Created date" : "Sortze-data",
    "Sort by created date, priority and summary." : "Ordenatu sortze-data, lehentasuna eta laburpenaren arabera.",
    "Last modified" : "Azken aldaketa",
    "Sort by last-modified date, priority and summary." : "Ordenatu azken aldatze-data, lehentasuna eta laburpenaren arabera.",
    "Completed date" : "Osatze-data",
    "Sort by completed date, priority and summary." : "Ordenatu osatze-data, lehentasuna eta laburpenaren arabera.",
    "Priority" : "Lehentasuna",
    "Sort by priority and summary." : "Ordenatu lehentasuna eta laburpenaren arabera.",
    "Alphabetically" : "Alfabetikoki",
    "Sort by summary and priority." : "Ordenatu laburpena eta lehentasunaren arabera.",
    "Tags" : "Etiketak",
    "Manually" : "Eskuz",
    "Sort by manual order." : "Ordenatu eskuz.",
    "Change sort order" : "Aldatu ordenatzeko irizpidea",
    "[Yesterday]" : "[Atzo]",
    "[Today]" : "[Gaur]",
    "[Tomorrow]" : "[Bihar]",
    "[Completed yesterday]" : "[Completed yesterday]",
    "[Completed today]" : "[Completed today]",
    "[Completed tomorrow]" : "[Bihar bukatuta]",
    "[Yesterday at] LT" : "[Atzo ordu honetan] LT",
    "[Today at] LT" : "[Gaur ordu honetan] LT",
    "[Tomorrow at] LT" : "[Bihar ordu honetan] LT",
    "L [at] LT" : "L [ordu honetan] LT",
    "[Completed yesterday at] LT" : "[Bukatuta atzo ordu honetan] LT",
    "[Completed today at] LT" : "[Gaur bukatuta ordu honetan] LT",
    "[Completed tomorrow at] LT" : "[Bihar bukatuta ordu honetan] LT",
    "[Completed] L [at] LT" : "[Bukatuta] L [ordu honetan] LT",
    "Add a subtask to \"{task}\"…" : "Gehitu azpizeregin bat \"{task}\" zereginari…",
    "Task has hidden subtasks" : "Zereginak ezkutuko azpizereginak ditu",
    "Task is pinned" : "Zeregina ainguratuta dago",
    "Task has a note" : "Zereginak ohar bat du",
    "{complete} % completed" : "% {complete} osatuta",
    "Add subtask" : "Gehitu azpizeregina",
    "Show subtasks" : "Erakutsi azpizereginak",
    "Hide subtasks" : "Ezkutatu azpizereginak",
    "Show closed subtasks" : "Erakutsi itxitako azpizereginak",
    "Hide closed subtasks" : "Ezkutatu itxitako azpizereginak",
    "Delete task" : "Ezabatu zeregina",
    "Toggle starred" : "Txandakatu izardunak",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Zeregina ezabatuko da {countdown} segundo barru","Zeregina ezabatuko da {countdown} segundo barru"],
    "Task is cancelled" : "Zeregina bertan behera utzi da",
    "Task is completed" : "Zeregina osatuta",
    "Task is read-only" : "Zeregina irakurtzeko soilik da",
    "Task is not completed" : "Zeregina ez da amaitu",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" \"{calendar}\" atalean gehitu da",
    "Create a new task" : "Sortu zeregin berria",
    "Task summary" : "Zereginaren laburpena",
    "Create task" : "Sortu zeregina",
    "Creating the new task…" : "Zeregin berria sortzen…",
    "Open task" : "Ireki zeregina",
    "_%n Completed Task_::_%n Completed Tasks_" : ["Zeregin %n osatuta","%n zeregin osatuta"],
    "Tomorrow" : "Bihar",
    "Add List…" : "Gehitu zerrenda...",
    "New list" : "Zerrenda berria",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "[Completed] L" : "[Bukatuta] L",
    "[Completed last] dddd [at] LT" : "[Bukatuta azken] dddd [ordu honetan] LT",
    "[Completed] dddd [at] LT" : "[Bukatuta] dddd [ordu honetan] LT",
    "[Last modified yesterday at] LT" : "[Azken aldaketa atzo ordu honetan] LT",
    "[Last modified today at] LT" : "[Azken aldaketa gaur ordu honetan] LT",
    "[Last modified] L" : "[Azken aldaketa] L",
    "[Last modified last] dddd [at] LT" : "[Azken aldaketa] dddd [ordu honetan] LT",
    "[Last modified] dddd [at] LT" : "[Azken aldaketa] dddd [ordu honetan] LT",
    "[Created yesterday at] LT" : "[Atzo sortu zen ordu honetan] LT",
    "[Created today at] LT" : "[Gaur sortu da ordu honetan] LT",
    "[Created] L" : "[Sortua] L",
    "[Created last] dddd [at] LT" : "[Sortua azken] dddd [ordu honetan] LT",
    "[Created] dddd [at] LT" : "[Sortua] dddd [ordu honetan] LT",
    "Needs action" : "Ekintza behar du",
    "In process" : "Abian",
    "Canceled" : "Utzita",
    "Clear status" : "Garbitu egoera",
    "Loading task from server." : "Zeregina zerbitzaritik kargatzen.",
    "Task not found!" : "Ez da zeregina aurkitu!",
    "Set start date" : "Ezarri hasiera-data",
    "Set due date" : "Ezarri epemuga",
    "Priority {priority}: low" : "Lehentasuna {priority}: baxua",
    "Priority {priority}: medium" : "Lehentasuna {priority}: ertaina",
    "Priority {priority}: high" : "Lehentasuna {priority}: altua",
    "No priority assigned" : "Lehentasuna ezarri gabe",
    "{percent} % completed" : "% {percent} osatuta",
    "All day" : "Egun osoa",
    "Unpin" : "Kendu aingura",
    "Pin" : "Ainguratu",
    "Show in Calendar" : "Erakutsi egutegian",
    "Show in Deck" : "Erakutsi Deck aplikazioan",
    "Edit summary" : "Editatu laburpena",
    "Details" : "Xehetasunak",
    "Selecting a classification is forbidden, because the task was shared with you." : "Ezin duzu sailkapen bat aukeratu, zeregina zurekin partekatua delako.",
    "Select a classification" : "Hautatu sailkapen bat",
    "Select a status" : "Hautatu egoera bat",
    "Set a location" : "Ezarri kokapena",
    "Set a URL" : "Ezarri URL bat",
    "Select tags" : "Hautatu etiketak",
    "Notes" : "Oharrak",
    "Mark as done" : "Markatu eginda",
    "No due date assigned" : "Ez da epemuga esleitu",
    "[Due yesterday]" : "[Epemuga atzo]",
    "[Due today]" : "[Epemuga gaur]",
    "[Due tomorrow]" : "[Epemuga bihar]",
    "[Due] L" : "[Epemuga] L",
    "[Due yesterday at] LT" : "[Epemuga atzo ordu honetan] LT",
    "[Due today at] LT" : "[Epemuga gaur ordu honetan] LT",
    "[Due tomorrow at] LT" : "[Epemuga bihar ordu honetan] LT",
    "[Due] L [at] LT" : "[Epemuga] L [ordu honetan] LT",
    "No upcoming tasks" : "Ez dago hurrengo zereginik",
    "upcoming tasks" : "hurrengo zereginak",
    "No tasks today" : "Zereginik ez gaurko",
    "Successfully created the task." : "Zeregina ondo sortu da.",
    "Could not delete the task." : "Ezin izan da zeregina ezabatu.",
    "Synchronizing to the server." : "Zerbitzariarekin sinkronizatzen.",
    "Task successfully saved to server." : "Zeregina behar bezala gorde da zerbitzarian.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Ezin izan da zeregina eguneratu, zerbitzarian aldatua zegoelako. Egin klik freskatzeko, aldaketa lokalak baztertuko dira.",
    "Could not update the task." : "Ezin izan da zeregina eguneratu.",
    "Successfully updated the task." : "Zeregina ondo eguneratu da.",
    "Task successfully moved to new calendar." : "Zeregina ondo eraman da egutegi berrira.",
    "An error occurred" : "Errore bat gertatu da",
    "Create a task" : "Sortu zeregin bat",
    "Message from {author} in {conversationName}" : "{Author} erabiltzailearen mezua {conversationName} atalean",
    "[Due on] LL" : "[Epemuga] LL",
    "[Was due yesterday]" : "[Epemuga atzo]",
    "[Was due on] LL" : "[Epemuga] LL",
    "[Was due today at] LT" : "[Epemuga gaur zen ordu honetan] LT",
    "[Due on] LL [at] LT" : "[Epemuga] LL [ordu honetan] LT",
    "[Was due yesterday at] LT" : "[Epemuga atzo ordu honetan] LT",
    "[Was due on] LL [at] LT" : "[Epemuga] LL [ordu honetan] LT",
    "[Starts today]" : "[Gaur hasten da]",
    "[Starts tomorrow]" : "[Bihar hasten da]",
    "[Starts on] LL" : "LL [hasiko da] ",
    "[Started yesterday]" : "[Atzo hasi zen]",
    "[Started on] LL" : "LL [hasi da]",
    "[Started today at] LT" : "[Gaur hasi da ordu honetan] LT",
    "[Starts today at] LT" : "[Gaur hasten da ordu honetan] LT",
    "[Starts tomorrow at] LT" : "[Bihar hasten da ordu honetan] LT",
    "[Starts on] LL [at] LT" : "LL [hasiko da ordu honetan] LT",
    "[Started yesterday at] LT" : "[Atzo hasi zen ordu honetan] LT",
    "[Started on] LL [at] LT" : "LL [hasi da ordu honetan] LT"
},
"nplurals=2; plural=(n != 1);");
