OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "ئالدىمىزدىكى ۋەزىپىلەر",
    "Important" : "مۇھىم",
    "Today" : "بۈگۈن",
    "Week" : "ھەپتە",
    "All" : "ھەممىسى",
    "Current" : "نۆۋەتتىكى",
    "Completed" : "تاماملاندى",
    "Tasks" : "ۋەزىپەلەر",
    "The Tasks app for Nextcloud" : "Nextcloud نىڭ ۋەزىپە دېتالى",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "قوزغىتىلغاندىن كېيىن ، Nextcloud ئەپ تىزىملىكىدە يېڭى ۋەزىپە تىزىملىكى كۆرۈنىدۇ. ئۇ يەردىن ۋەزىپىلەرنى قوشالايسىز ۋە ئۆچۈرەلەيسىز ، ئۇلارنىڭ ماۋزۇسى ، چۈشەندۈرۈشى ، باشلىنىش ۋاقتى ۋە ۋاقتى قاتارلىقلارنى تەھرىرلەپ ، ئۇلارنى مۇھىم دەپ بەلگە قويالايسىز. ۋەزىپىلەرنى ئىشلەتكۈچىلەر ئورتاقلىشالايدۇ. ۋەزىپە CalDav ئارقىلىق ماس قەدەمدە بولىدۇ (ھەر بىر ۋەزىپە تىزىملىكى Nextcloud كالېندارىغا ئۇلىنىدۇ ، ئۇنى يەرلىك خېرىدارىڭىزغا ماسقەدەملەيدۇ: Thunderbird, Evolution, KDE Kontact, iCal… - پەقەت كالېندارىڭىزنى خېرىدارىڭىزغا يىراقتىكى كالېندار قىلىپ قوشۇڭ). ھەر بىر كالېندارغا چۈشۈرۈش كۇنۇپكىسى ئارقىلىق ۋەزىپىڭىزنى ICS ھۆججىتى سۈپىتىدە چۈشۈرەلەيسىز.",
    "Hidden" : "يۇشۇرۇن",
    "Visible" : "كۆرگىلى بولىدۇ",
    "Automatic" : "ئاپتوماتىك",
    "Tasks settings" : "ۋەزىپە تەڭشىكى",
    "Default list" : "كۆڭۈلدىكى تىزىملىك",
    "Visibility of Smart Collections" : "ئەقلىي ئىقتىدارلىق توپلاملارنىڭ كۆرۈنۈشچانلىقى",
    "Share with users or groups" : "ئىشلەتكۈچىلەر ياكى گۇرۇپپىلار بىلەن ئورتاقلىشىڭ",
    "No users or groups" : "ئىشلەتكۈچى ياكى گۇرۇپپا يوق",
    "Unable to delete the share." : "ھەمبەھىرنى ئۆچۈرەلمىدى.",
    "Unable to change permissions." : "ئىجازەتنى ئۆزگەرتەلمىدى.",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "{displayName} with بىلەن ئورتاقلاشماسلىق",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "بۇ كالېندار «{calendar}» ۋە مۇناسىۋەتلىك بارلىق ئىشلار ۋە ۋەزىپىلەرنى ئۆچۈرۈۋېتىدۇ.",
    "This will unshare the calendar \"{calendar}\"." : "بۇ كالېندار \"{calendar}\" نى ئورتاقلاشمايدۇ.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "بۇ تىزىملىك «{list}» ۋە مۇناسىۋەتلىك بارلىق ۋەزىپىلەرنى ئۆچۈرۈۋېتىدۇ.",
    "This will unshare the list \"{list}\"." : "بۇ «{list}» تىزىملىكىنى ئورتاقلاشتۇرمايدۇ.",
    "Share this calendar" : "بۇ كالېندارنى ھەمبەھىرلەڭ",
    "Share this list" : "بۇ تىزىملىكنى ئورتاقلىشىڭ",
    "Calendar link copied to clipboard." : "كالېندار ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
    "List link copied to clipboard." : "چاپلاش تاختىسىغا كۆچۈرۈلگەن تىزىملىك ئۇلىنىشى.",
    "Calendar link could not be copied to clipboard." : "كالېندار ئۇلىنىشىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "List link could not be copied to clipboard." : "تىزىملىك ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
    "The name \"{calendar}\" is already used." : "«{calendar}» دېگەن ئىسىم ئاللىقاچان ئىشلىتىلگەن.",
    "An empty name is not allowed." : "قۇرۇق ئىسىم رۇخسەت قىلىنمايدۇ.",
    "An error occurred, unable to delete the calendar." : "كالېندارنى ئۆچۈرەلمەي خاتالىق كۆرۈلدى.",
    "An error occurred, unable to delete the list." : "تىزىملىك ئۆچۈرەلمەي خاتالىق كۆرۈلدى.",
    "Edit" : "تەھرىر",
    "Copy private link" : "شەخسىي ئۇلىنىشنى كۆچۈرۈڭ",
    "Copied" : "كۆچۈرۈلگەن",
    "Cannot copy" : "كۆچۈرگىلى بولمايدۇ",
    "Export" : "چىقار",
    "Delete" : "ئۆچۈر",
    "Unshare" : "ھەمبەھىرلىمە",
    "List name" : "تىزىملىك ئىسمى",
    "Untitled task" : "نامسىز ۋەزىپە",
    "Untitled event" : "نامسىز ھادىسە",
    "Untitled journal" : "نامسىز ژۇرنال",
    "Untitled item" : "نامسىز تۈر",
    "Unknown calendar" : "نامەلۇم كالېندار",
    "Could not load deleted calendars and objects" : "ئۆچۈرۈلگەن كالېندار ۋە ئوبيېكتلارنى يۈكلىيەلمىدى",
    "Could not delete calendar or event" : "كالېندار ياكى ۋەقەنى ئۆچۈرەلمىدى",
    "Could not restore calendar or event" : "كالېندار ياكى ھادىسىنى ئەسلىگە كەلتۈرەلمىدى",
    "Do you really want to empty the trash bin?" : "ئەخلەت ساندۇقىنى بوشاتماقچىمۇ؟",
    "Empty trash bin" : "ئەخلەت ساندۇقى",
    "Trash bin" : "ئەخلەت ساندۇقى",
    "Loading deleted calendars, tasks and events." : "ئۆچۈرۈلگەن كالېندار ، ۋەزىپە ۋە ۋەقەلەرنى يۈكلەش.",
    "You do not have any deleted calendars, tasks or events." : "ئۆچۈرۈلگەن كالېندار ، ۋەزىپە ياكى ۋەقەلەر يوق.",
    "Name" : "ئاتى",
    "Deleted" : "ئۆچۈرۈلدى",
    "Restore" : "ئەسلىگە كەلتۈرۈش",
    "Delete permanently" : "مەڭگۈلۈك ئۆچۈر",
    "Cancel" : "ۋاز كەچ",
    "Notification" : "ئۇقتۇرۇش",
    "Email" : "تورخەت",
    "Audio notification" : "ئاۋازلىق ئۇقتۇرۇش",
    "Other notification" : "باشقا ئۇقتۇرۇش",
    "Edit time" : "ۋاقىتنى تەھرىرلەش",
    "Remove reminder" : "ئەسكەرتىشنى ئۆچۈرۈڭ",
    "Add reminder" : "ئەسكەرتىش قوشۇڭ",
    "Go back" : "قايتىڭ",
    "before at" : "before at",
    "Select a calendar" : "كالېندارنى تاللاڭ",
    "No calendar matches the search." : "ھېچقانداق كالېندار ئىزدەشكە ماس كەلمەيدۇ.",
    "Set date" : "چېسلانى بەلگىلەڭ",
    "Set time" : "ۋاقىت بەلگىلەڭ",
    "Delete date" : "چېسلانى ئۆچۈرۈڭ",
    "Click here to add a note." : "بۇ يەرنى چېكىپ خاتىرە قوشۇڭ.",
    "Set value" : "قىممەت بەلگىلەڭ",
    "Delete value" : "قىممەتنى ئۆچۈرۈڭ",
    "Add this as a new tag" : "بۇنى يېڭى بەلگە قىلىپ قوشۇڭ",
    "No tag available. Create one!" : "خەتكۈچ يوق. بىرنى قۇر!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} ۋەزىپە \"{calendar}\" غا قوشۇلدى.",
    "Create new tasks" : "يېڭى ۋەزىپىلەرنى يارىتىڭ",
    "Create {numberOfTasks} tasks from pasted text" : "چاپلانغان تېكىستتىن {numberOfTasks} ۋەزىپىلەرنى قۇر",
    "Create tasks" : "ۋەزىپە قۇرۇش",
    "Creating new tasks…" : "يېڭى ۋەزىپىلەرنى يارىتىش…",
    "Close" : "ياپ",
    "Delete all completed tasks." : "تاماملانغان بارلىق ۋەزىپىلەرنى ئۆچۈرۈڭ.",
    "Delete completed tasks." : "تاماملانغان ۋەزىپىلەرنى ئۆچۈرۈڭ.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "كالېندار \"{calendar}\" دىن تاماملانغان بارلىق ۋەزىپىلەرنى ئۆچۈردى.",
    "No errors" : "خاتالىق يوق",
    "Open your browser console for more details" : "تېخىمۇ كۆپ تەپسىلاتلار ئۈچۈن توركۆرگۈ كونترول سۇپىڭىزنى ئېچىڭ",
    "Active filter" : "ئاكتىپ سۈزگۈچ",
    "Filter by tags" : "خەتكۈچ بويىچە سۈزۈڭ",
    "Select tags to filter by" : "سۈزۈش ئۈچۈن بەلگىلەرنى تاللاڭ",
    "Reset filter" : "سۈزگۈچنى ئەسلىگە كەلتۈرۈش",
    "Add an important task to \"{calendar}\"…" : "\"{calendar}\" غا مۇھىم ۋەزىپە قوشۇڭ…",
    "Add a task due today to \"{calendar}\"…" : "بۈگۈن «{calendar}» to غا تېگىشلىك ۋەزىپە قوشۇڭ…",
    "Add a current task to \"{calendar}\"…" : "نۆۋەتتىكى ۋەزىپە «{calendar}» غا قوشۇڭ…",
    "Add a task to \"{calendar}\"…" : "\"{calendar}\" غا ۋەزىپە قوشۇڭ…",
    "Load the completed tasks of all lists." : "بارلىق تىزىملىكلەرنىڭ تاماملانغان ۋەزىپىلىرىنى يۈكلەڭ.",
    "Loading the completed tasks of all lists might slow down the app." : "بارلىق تىزىملىكلەرنىڭ تاماملانغان ۋەزىپىلىرىنى يۈكلەش ئەپنى ئاستىلىتىشى مۇمكىن.",
    "Load the completed tasks of list \"{calendar}\"." : "تىزىملىكنىڭ تاماملانغان ۋەزىپىلىرىنى «{calendar}» نى يۈكلەڭ.",
    "Loading the completed tasks might slow down the app." : "تاماملانغان ۋەزىپىلەرنى يۈكلەش ئەپنى ئاستىلىتىشى مۇمكىن.",
    "Relevance" : "Relevance",
    "Sort by completed state, due date, priority, start date and summary." : "تاماملانغان ھالەت ، قەرەلى ، ئەۋزەللىكى ، باشلىنىش ۋاقتى ۋە خۇلاسىسى بويىچە تەرتىپلەڭ.",
    "Start date" : "باشلىنىش ۋاقتى",
    "Sort by start date, priority and summary." : "باشلىنىش ۋاقتى ، مۇھىملىقى ۋە خۇلاسىسى بويىچە تەرتىپلەڭ.",
    "Due date" : "قەرەلى توشقان ۋاقىت",
    "Sort by due date, priority and summary." : "قەرەلى ، مۇھىملىقى ۋە خۇلاسىسى بويىچە تەرتىپلەڭ.",
    "Created date" : "قۇرۇلغان ۋاقىت",
    "Sort by created date, priority and summary." : "قۇرۇلغان ۋاقىت ، ئەۋزەللىك ۋە خۇلاسە بويىچە تەرتىپلەڭ.",
    "Last modified" : "ئاخىرقى قېتىم ئۆزگەرتىلگەن",
    "Sort by last-modified date, priority and summary." : "ئاخىرقى ئۆزگەرتىلگەن ۋاقىت ، ئەۋزەللىك ۋە خۇلاسە بويىچە تەرتىپلەڭ.",
    "Completed date" : "تاماملانغان ۋاقىت",
    "Sort by completed date, priority and summary." : "تاماملانغان ۋاقىت ، ئەۋزەللىك ۋە خۇلاسە بويىچە تەرتىپلەڭ.",
    "Priority" : "ھەممىدىن مۇھىم",
    "Sort by priority and summary." : "ئالدىن تاللاش ۋە خۇلاسە بويىچە تەرتىپلەش.",
    "Alphabetically" : "ئېلىپبە شەكلىدە",
    "Sort by summary and priority." : "خۇلاسە ۋە مۇھىم ئورۇنغا ئاساسەن تەرتىپلەڭ.",
    "Tags" : "بەلگەلەر",
    "Sort by tags." : "خەتكۈچ بويىچە تەرتىپلەش.",
    "Manually" : "قولدا",
    "Sort by manual order." : "قولدا تەرتىپ بويىچە تەرتىپلەش.",
    "Change sort order" : "تەرتىپ تەرتىپىنى ئۆزگەرتىش",
    "[Yesterday]" : "[تۈنۈگۈن]",
    "[Today]" : "[بۈگۈن]",
    "[Tomorrow]" : "[ئەتە]",
    "[Completed yesterday]" : "[تۈنۈگۈن تاماملاندى]",
    "[Completed today]" : "[بۈگۈن تاماملاندى]",
    "[Completed tomorrow]" : "[ئەتە تاماملاندى]",
    "[Yesterday at] LT" : "[تۈنۈگۈن] LT",
    "[Today at] LT" : "[بۈگۈن] LT",
    "[Tomorrow at] LT" : "[ئەتە] LT",
    "L [at] LT" : "L [at] LT",
    "[Completed yesterday at] LT" : "[تۈنۈگۈن] LT دا تاماملاندى",
    "[Completed today at] LT" : "[بۈگۈن تاماملاندى] LT",
    "[Completed tomorrow at] LT" : "[ئەتە تاماملاندى] LT",
    "[Completed] L [at] LT" : "[تاماملاندى] L [at] LT",
    "Add a subtask to \"{task}\"…" : "\"{task}\" غا تارماق بەت قوشۇڭ…",
    "Task has hidden subtasks" : "ۋەزىپە يوشۇرۇن تارماق پروگراممىلارنى يوشۇرۇپ قويدى",
    "Task is pinned" : "ۋەزىپە باغلانغان",
    "Task has a note" : "ۋەزىپە خاتىرىسى بار",
    "{complete} % completed" : "{complete}% تاماملاندى",
    "Add subtask" : "Subtask نى قوشۇڭ",
    "Show subtasks" : "تارماق پروگراممىلارنى كۆرسەت",
    "Hide subtasks" : "تارماق پروگراممىلارنى يوشۇرۇش",
    "Show closed subtasks" : "يېپىق تارماق پروگراممىلارنى كۆرسەت",
    "Hide closed subtasks" : "يېپىق تارماق پروگراممىلارنى يوشۇرۇش",
    "Delete task" : "ۋەزىپىنى ئۆچۈرۈڭ",
    "Toggle starred" : "Toggle باش رول ئالدى",
    "Task is cancelled" : "ۋەزىپە ئەمەلدىن قالدۇرۇلدى",
    "Task is completed" : "ۋەزىپە تاماملاندى",
    "Task is read-only" : "ۋەزىپە پەقەت ئوقۇشقىلا بولىدۇ",
    "Task is not completed" : "ۋەزىپە تاماملانمىدى",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" \"{calendar}\" غا قوشۇلدى",
    "Create a new task" : "يېڭى ۋەزىپە قۇرۇڭ",
    "Task summary" : "ۋەزىپە خۇلاسىسى",
    "Create task" : "ۋەزىپە قۇرۇش",
    "Creating the new task…" : "يېڭى ۋەزىپە يارىتىش…",
    "Open task" : "ئوچۇق ۋەزىپە",
    "Tomorrow" : "ئەتە",
    "An error occurred, unable to create the list." : "خاتالىق كۆرۈلدى ، تىزىملىك قۇرالمىدى.",
    "Add List…" : "تىزىملىك قوشۇش…",
    "New list" : "يېڭى تىزىملىك",
    "When shared show full event" : "ھەمبەھىرلەنگەندە تولۇق پائالىيەتنى كۆرسىتىدۇ",
    "When shared show only busy" : "ئورتاقلاشقاندا پەقەت ئالدىراش",
    "When shared hide this event" : "ئورتاقلاشقاندا بۇ پائالىيەتنى يوشۇرۇڭ",
    "[Completed] L" : "[تاماملاندى] L.",
    "[Completed last] dddd [at] LT" : "[تاماملاندى] dddd [at] LT",
    "[Completed] dddd [at] LT" : "[تاماملاندى] dddd [at] LT",
    "[Last modified yesterday at] LT" : "[ئەڭ ئاخىرقى قېتىم تۈنۈگۈن LT]",
    "[Last modified today at] LT" : "[بۈگۈن ئەڭ ئاخىرقى قېتىم ئۆزگەرتىلدى] LT",
    "[Last modified] L" : "[ئاخىرقى قېتىم ئۆزگەرتىلگەن] L.",
    "[Last modified last] dddd [at] LT" : "[ئاخىرقى قېتىم ئۆزگەرتىلگەن] dddd [at] LT",
    "[Last modified] dddd [at] LT" : "[ئاخىرقى قېتىم ئۆزگەرتىلگەن] dddd [at] LT",
    "[Created yesterday at] LT" : "[تۈنۈگۈن] LT دا قۇرۇلدى",
    "[Created today at] LT" : "[بۈگۈن] LT دا قۇرۇلدى",
    "[Created] L" : "[ئىجاد قىلىنغان] L.",
    "[Created last] dddd [at] LT" : "[ئاخىرقى قېتىم] dddd [at] LT",
    "[Created] dddd [at] LT" : "[ئىجاد قىلىنغان] dddd [at] LT",
    "Needs action" : "ھەرىكەتكە موھتاج",
    "In process" : "جەرياندا",
    "Canceled" : "ئەمەلدىن قالدۇرۇلدى",
    "Clear status" : "ئېنىق ھالەت",
    "Loading task from server." : "مۇلازىمېتىردىن ۋەزىپە يۈكلەش.",
    "Task not found!" : "ۋەزىپە تېپىلمىدى!",
    "Set start date" : "باشلىنىش ۋاقتىنى بەلگىلەڭ",
    "Set due date" : "بەلگىلەنگەن ۋاقىتنى بەلگىلەڭ",
    "Priority {priority}: low" : "مۇھىملىقى {priority}: تۆۋەن",
    "Priority {priority}: medium" : "مۇھىملىق {priority}: ئوتتۇراھال",
    "Priority {priority}: high" : "مۇھىملىقى {priority}: يۇقىرى",
    "No priority assigned" : "ئالدىن ئېتىبار بېرىلمەيدۇ",
    "{percent} % completed" : "{percent}% تاماملاندى",
    "All day" : "پۈتۈن كۈن",
    "Unpin" : "Unpin",
    "Pin" : "Pin",
    "Show in Calendar" : "كالېنداردا كۆرسىتىڭ",
    "Show in Deck" : "پالۋاندا كۆرسىتىش",
    "Edit summary" : "خۇلاسە تەھرىرلەش",
    "Details" : "تەپسىلاتى",
    "Selecting a classification is forbidden, because the task was shared with you." : "تۈرگە ئايرىش چەكلەنگەن ، چۈنكى ۋەزىپە سىز بىلەن ئورتاقلاشقان.",
    "Select a classification" : "تۈرگە ئايرىشنى تاللاڭ",
    "Select a status" : "ھالەتنى تاللاڭ",
    "Set a location" : "ئورۇن بەلگىلەڭ",
    "Set a URL" : "URL بەلگىلەڭ",
    "Select tags" : "خەتكۈچلەرنى تاللاڭ",
    "Notes" : "ئىزاھاتلار",
    "Mark as done" : "تاماملانغاندەك بەلگە",
    "No due date assigned" : "قەرەلى توشمىغان",
    "[Due yesterday]" : "[تۈنۈگۈن]",
    "[Due today]" : "[بۈگۈن]",
    "[Due tomorrow]" : "[ئەتە]",
    "[Due] L" : "[تېگىشلىك] L.",
    "[Due yesterday at] LT" : "[تۈنۈگۈن] LT",
    "[Due today at] LT" : "[بۈگۈن] LT",
    "[Due tomorrow at] LT" : "[ئەتە] LT",
    "[Due] L [at] LT" : "[تېگىشلىك] L [at] LT",
    "No upcoming tasks" : "ئالدىمىزدىكى ۋەزىپىلەر يوق",
    "upcoming tasks" : "ئالدىمىزدىكى ۋەزىپىلەر",
    "No tasks today" : "بۈگۈن ھېچقانداق ۋەزىپە يوق",
    "Successfully created the task." : "ۋەزىپىنى مۇۋەپپەقىيەتلىك قۇردى.",
    "Could not delete the task." : "ۋەزىپىنى ئۆچۈرەلمىدى.",
    "Synchronizing to the server." : "مۇلازىمېتىرغا ماسقەدەملەش.",
    "Task successfully saved to server." : "ۋەزىپە مۇۋەپپەقىيەتلىك ھالدا مۇلازىمېتىرغا ساقلاندى.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "مۇلازىمېتىردا ئۆزگەرتىلگەنلىكى ئۈچۈن ۋەزىپىنى يېڭىلىيالمىدى. ئۇنى يېڭىلاش ئۈچۈن چېكىڭ ، يەرلىك ئۆزگەرتىشلەر تاشلىۋېتىلىدۇ.",
    "Could not update the task." : "ۋەزىپىنى يېڭىلىيالمىدى.",
    "Successfully updated the task." : "ۋەزىپىنى مۇۋەپپەقىيەتلىك يېڭىلىدى.",
    "Task successfully moved to new calendar." : "ۋەزىپە مۇۋەپپەقىيەتلىك ھالدا يېڭى كالېندارغا يۆتكەلدى.",
    "An error occurred" : "خاتالىق كۆرۈلدى",
    "Create a task" : "بىر ۋەزىپە قۇر",
    "Message from {author} in {conversationName}" : "{سۆھبەت} ئىسمى {دىكى} {ئاپتور} نىڭ ئۇچۇرى",
    "[Due on] LL" : "LL",
    "[Was due yesterday]" : "[تۈنۈگۈن]",
    "[Was due on] LL" : "[قەرەلى توشقان] LL",
    "[Was due today at] LT" : "[بۈگۈن] LT دا ئۆتكۈزۈلدى",
    "[Due on] LL [at] LT" : "LL [at] LT",
    "[Was due yesterday at] LT" : "[تۈنۈگۈن] LT دا ئۆتكۈزۈلدى",
    "[Was due on] LL [at] LT" : "LT [at] LT دا ئىدى",
    "[Starts today]" : "[بۈگۈندىن باشلىنىدۇ]",
    "[Starts tomorrow]" : "[ئەتە باشلىنىدۇ]",
    "[Starts on] LL" : "[باشلىنىدۇ] LL",
    "[Started yesterday]" : "[تۈنۈگۈن باشلاندى]",
    "[Started on] LL" : "[باشلاندى] LL",
    "[Started today at] LT" : "[بۈگۈندىن باشلاپ] LT",
    "[Starts today at] LT" : "[بۈگۈندىن باشلاپ] LT",
    "[Starts tomorrow at] LT" : "[ئەتە باشلىنىدۇ] LT",
    "[Starts on] LL [at] LT" : "[باشلىنىدۇ] LL [at] LT",
    "[Started yesterday at] LT" : "[تۈنۈگۈن] LT دا باشلاندى",
    "[Started on] LL [at] LT" : "[باشلاندى] LL [at] LT"
},
"nplurals=2; plural=(n != 1);");
