OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Kommende oppgaver",
    "Important" : "Viktig",
    "Today" : "I dag",
    "Week" : "Uke",
    "All" : "Alle",
    "Current" : "Nåværende",
    "Completed" : "Ferdig",
    "Tasks" : "Oppgaver",
    "The Tasks app for Nextcloud" : "Oppgave-appen for Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Når den er aktivert, vises en ny oppgavemeny i Nextcloud-appmenyen. Derfra kan du legge til og slette oppgaver, redigere tittel, beskrivelse, start- og forfallsdatoer og merke dem som viktige. Oppgaver kan deles mellom brukere. Oppgaver kan synkroniseres ved hjelp av CalDav (hver oppgaveliste er knyttet til en Nextcloud-kalender, for å synkronisere den til din lokale klient: Thunderbird, Evolution, KDE Kontact, iCal ... - bare legg til kalenderen som en ekstern kalender i klienten din). Du kan laste ned oppgavene dine som ICS-filer ved å bruke nedlastingsknappen for hver kalender.",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Tasks settings" : "Innstillinger for oppgaver",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Synlighet for smarte samlinger",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kunne ikke endre rettigheter.",
    "Can edit" : "Kan redigere",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Dette sletter kalender \"{calendar}\" og alle hendelser og oppgaver i denne.",
    "This will unshare the calendar \"{calendar}\"." : "Dette vil oppheve delingen av kalenderen \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Dette vil slette listen \"{list}\" og alle korresponderende oppgaver.",
    "This will unshare the list \"{list}\"." : "Dette vil oppheve delingen av listen \"{list}\"",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Sletter kalenderen om {countdown} sekund","Sletter kalenderen om {countdown} sekunder"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Fjerner deling av kalenderen om {countdown} sekund","Fjerner deling av kalenderen om {countdown} sekunder"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sletter listen om {countdown} sekund","Sletter listen om {countdown} sekunder"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Fjerner deling av listen om {countdown} sekund","Fjerner deling av listen om {countdown} sekunder"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} entitet","Delt med {num} entiteter"],
    "Share this calendar" : "Del denne kalenderen",
    "Share this list" : "Del denne listen",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "List link copied to clipboard." : "Lenke kopiert til utklippstavlen.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "List link could not be copied to clipboard." : "Lenke kunne ikke kopieres til utklippstavlen.",
    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
    "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
    "An error occurred, unable to delete the calendar." : "En feil oppsto, kan ikke slette kalenderen. ",
    "An error occurred, unable to delete the list." : "En feil oppsto, kunne ikke slette listen.",
    "Edit" : "Rediger",
    "Copy private link" : "Kopier privat lenke",
    "Copied" : "Kopiert",
    "Cannot copy" : "Kan ikke kopiere",
    "Export" : "Eksporter",
    "Delete" : "Slett",
    "Unshare" : "Opphev deling",
    "List name" : "Listenavn",
    "Untitled task" : "Oppgave uten tittel",
    "Untitled event" : "Hendelse uten tittel",
    "Untitled journal" : "Tidsskrift uten tittel",
    "Untitled item" : "Element uten navn",
    "Unknown calendar" : "Ukjent kalender",
    "Could not load deleted calendars and objects" : "Kunne ikke laste slettede kalendere og objekter",
    "Could not delete calendar or event" : "Kunne ikke slette kalender eller hendelse",
    "Could not restore calendar or event" : "Kunne ikke gjenopprette kalender eller hendelse",
    "Do you really want to empty the trash bin?" : "Vil du virkelig slette papirkurven?",
    "Empty trash bin" : "Tøm papirkurv",
    "Trash bin" : "Papirkurv",
    "Loading deleted calendars, tasks and events." : "Laster slettede kalendere, oppgaver og hendelser.",
    "You do not have any deleted calendars, tasks or events." : "Du har ikke noen slettede kalendere, oppgaver eller hendelser.",
    "Name" : "Navn",
    "Deleted" : "Slettet",
    "Restore" : "Gjenoprett",
    "Delete permanently" : "Slett permament",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elementer i papirkurven slettes etter {numDays} dag","Elementer i papirkurven slettes etter {numDays} dager"],
    "Cancel" : "Avbryt",
    "Email" : "E-post",
    "Audio notification" : "Lydvarsel",
    "Other notification" : "Andre varsel",
    "Edit time" : "Rediger tidspunkt",
    "Remove reminder" : "Fjern påminnelse",
    "Add reminder" : "Legg til påminnelse",
    "Go back" : "Gå tilbake",
    "before at" : "før ved",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minutt","minutter"],
    "_hour_::_hours_" : ["time","timer"],
    "_day_::_days_" : ["dag","dager"],
    "_week_::_weeks_" : ["uke","uker"],
    "Select a calendar" : "Velg en kalender",
    "No calendar matches the search." : "Ingen kalendere samsvarer med søket.",
    "Set date" : "Angi dato",
    "Set time" : "Angi tidspunkt",
    "Delete date" : "Slett dato",
    "Click here to add a note." : "Klikk her for å legge til et notat.",
    "Set value" : "Angi verdi",
    "Delete value" : "Slett verdi",
    "Add this as a new tag" : "Legg til dette som et nytt merke",
    "No tag available. Create one!" : "Ingen merke tilgjengelig. Opprett et!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} oppgaver er lagt til \"{calendar}\"",
    "Create new tasks" : "Opprett nye oppgaver",
    "Create {numberOfTasks} tasks from pasted text" : "Opprett {numberOfTasks} oppgaver fra innlimt tekst",
    "Create tasks" : "Opprett oppgaver",
    "Creating new tasks…" : "Oppretter nye oppgaver...",
    "Close" : "Lukk",
    "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
    "Delete completed tasks." : "Slett fullførte oppgaver.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
    "No errors" : "Ingen feil",
    "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Dette vil slette {taskCount} fullført oppgave og underoppgavene fra kalenderen \"{calendar}\".","Dette vil slette {taskCount} fullførte oppgaver og deres underoppgaver fra kalenderen \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunne ikke slette {failedCount} oppgave.","Kunne ikke slette {failedCount} oppgaver."],
    "Active filter" : "Aktiv filter",
    "Filter by tags" : "Filtrer etter merker",
    "Select tags to filter by" : "Velg merkelapper å filtrere etter",
    "Reset filter" : "Nullstill filter",
    "Add an important task to \"{calendar}\"…" : "Legg til en viktig oppgave til \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Legg til en oppgave med forfall i dag til \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Legg til en gjeldende oppgave til \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Legg til en oppgave til \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Last inn de fullførte oppgavene for alle lister.",
    "Loading the completed tasks of all lists might slow down the app." : "Innlasting av de fullførte oppgavene for alle lister kan redusere ytelsen til appen.",
    "Load the completed tasks of list \"{calendar}\"." : "Last inn de fullførte oppgavene på listen \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Lasting av de fullførte oppgavene kan gjøre appen tregere.",
    "Relevance" : "Relevans",
    "Sort by completed state, due date, priority, start date and summary." : "Sorter etter fullført tilstand, forfallsdato, prioritet, startdato og sammendrag.",
    "Start date" : "Startdato",
    "Sort by start date, priority and summary." : "Sorter etter startdato, prioritet og sammendrag.",
    "Due date" : "Forfallsdato",
    "Sort by due date, priority and summary." : "Sorter etter forfallsdato, prioritet og sammendrag.",
    "Created date" : "Opprettelsesdato",
    "Sort by created date, priority and summary." : "Sorter etter opprettelsesdato, prioritet og sammendrag.",
    "Last modified" : "Sist redigert",
    "Sort by last-modified date, priority and summary." : "Sorter etter sist-endret dato, prioritet og sammendrag.",
    "Completed date" : "Fullført dato",
    "Sort by completed date, priority and summary." : "Sorter etter gjennomført dato, prioritet og sammendrag.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Sorter etter prioritet og sammendrag.",
    "Alphabetically" : "Alfabetisk",
    "Sort by summary and priority." : "Sorter etter sammendrag og prioritet.",
    "Tags" : "Merkelapper",
    "Manually" : "Manuelt",
    "Sort by manual order." : "Sorter etter manuell rekkefølge.",
    "Change sort order" : "Endre sorteringsrekkefølge",
    "[Yesterday]" : "[Yesterday]",
    "[Today]" : "[Today]",
    "[Tomorrow]" : "[Tomorrow]",
    "[Completed yesterday]" : "[Fullført i går]",
    "[Completed today]" : "[Fullført i dag]",
    "[Completed tomorrow]" : "[Fullført i morgen]",
    "[Yesterday at] LT" : "[I går kl.] LT",
    "[Today at] LT" : "[I dag kl.] LT",
    "[Tomorrow at] LT" : "[I morgen kl.] LT",
    "L [at] LT" : "L [kl.] LT",
    "[Completed yesterday at] LT" : "[Fullført i går kl.] LT",
    "[Completed today at] LT" : "[Fullført i dag kl.] LT",
    "[Completed tomorrow at] LT" : "[Fullført i morgen kl.] LT",
    "[Completed] L [at] LT" : "[Fullført] L [kl.] LT",
    "Add a subtask to \"{task}\"…" : "Legg til en underoppgave i \"{task}\"...",
    "Task has hidden subtasks" : "Oppgaven har skjulte underoppgaver",
    "Task is pinned" : "Oppgaven er festet",
    "Task has a note" : "Oppgaven har et notat",
    "{complete} % completed" : "{complete} % utført",
    "Add subtask" : "Legg til underoppgave",
    "Show subtasks" : "Vis underoppgaver",
    "Hide subtasks" : "Skjul underoppgaver",
    "Show closed subtasks" : "Vis lukkede underoppgaver",
    "Hide closed subtasks" : "Skjul lukkede underoppgaver",
    "Delete task" : "Slett oppgave",
    "Toggle starred" : "Veksle stjernemerket",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Sletter oppgaven om {countdown} sekund","Sletter oppgaven om {countdown} sekunder"],
    "Task is cancelled" : "Oppgaven er kansellert",
    "Task is completed" : "Oppgaven er fullført",
    "Task is read-only" : "Oppgaven er skrivebeskyttet",
    "Task is not completed" : "Oppgaven er ikke fullført",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" ble lagt til \"{calendar}\"",
    "Create a new task" : "Opprett en ny oppgave",
    "Task summary" : "Oppgavesammendrag",
    "Create task" : "Opprett oppgave",
    "Creating the new task…" : "Oppretter den nye oppgaven...",
    "Open task" : "Åpne oppgaven",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n utført oppgave","%n avsluttede oppgaver"],
    "Tomorrow" : "I morgen",
    "An error occurred, unable to create the list." : "Det oppstod en feil, kan ikke opprette listen.",
    "Add List…" : "Legg til liste...",
    "New list" : "Ny liste",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "[Completed] L" : "[Fullført] L",
    "[Completed last] dddd [at] LT" : "[Fullført sist] dddd [kl.] LT",
    "[Completed] dddd [at] LT" : "[Fullført] dddd [kl.] LT",
    "[Last modified yesterday at] LT" : "[Sist endret i går kl.] LT",
    "[Last modified today at] LT" : "[Sist endret i dag kl.] LT",
    "[Last modified] L" : "[Sist endret] L",
    "[Last modified last] dddd [at] LT" : "[Sist endret sist] dddd [kl.] LT",
    "[Last modified] dddd [at] LT" : "[Sist endret] dddd [kl.] LT",
    "[Created yesterday at] LT" : "[Opprettet i går kl.] LT",
    "[Created today at] LT" : "[Opprettet i dag kl.] LT",
    "[Created] L" : "[Opprettet] L",
    "[Created last] dddd [at] LT" : "[Opprettet sist] dddd [kl.] LT",
    "[Created] dddd [at] LT" : "[Opprettet] dddd [kl.] LT",
    "Needs action" : "Krever handling",
    "In process" : "Pågår",
    "Canceled" : "Avbrutt",
    "Clear status" : "Tøm status",
    "Loading task from server." : "Laster oppgaver fra serveren.",
    "Task not found!" : "Oppgaven ble ikke funnet!",
    "Set start date" : "Sett startdato",
    "Set due date" : "Sett forfallsdato",
    "Priority {priority}: low" : "Prioritet {priority}: lav",
    "Priority {priority}: medium" : "Prioritet {priority}: middels",
    "Priority {priority}: high" : "Prioritet {priority}: høy",
    "No priority assigned" : "Ingen tildelt prioritet",
    "{percent} % completed" : "{percent} % utført",
    "All day" : "Hele dagen",
    "Unpin" : "Løsne",
    "Pin" : "Fest",
    "Show in Calendar" : "Vis i kalender",
    "Show in Deck" : "Vis i Deck",
    "Edit summary" : "Rediger sammendrag",
    "Details" : "Detaljer",
    "Selecting a classification is forbidden, because the task was shared with you." : "Det er forbudt å velge en klassifisering, fordi oppgaven ble delt med deg.",
    "Select a classification" : "Velg en klassifisering",
    "Select a status" : "Velg en status",
    "Set a location" : "Angi en plassering",
    "Set a URL" : "Angi en URL",
    "Select tags" : "Velg merkelapper",
    "Notes" : "Notater",
    "Mark as done" : "Marker som fullført",
    "No due date assigned" : "Ingen tilknyttet forfallsdato",
    "[Due yesterday]" : "[Forfall i går]",
    "[Due today]" : "[Forfaller i dag]",
    "[Due tomorrow]" : "[Forfaller i morgen]",
    "[Due] L" : "[Forfaller] L",
    "[Due yesterday at] LT" : "[Forfalt i går kl.] LT",
    "[Due today at] LT" : "[Forfaller i dag kl.] LT",
    "[Due tomorrow at] LT" : "[Forfaller i morgen kl.] LT",
    "[Due] L [at] LT" : "[Forfaller] L [kl.] LT",
    "No upcoming tasks" : "Ingen kommende oppgaver",
    "upcoming tasks" : "kommende oppgaver",
    "No tasks today" : "Ingen oppgaver i dag",
    "Successfully created the task." : "Opprettet oppgaven.",
    "Could not delete the task." : "Kunne ikke slette oppgaven.",
    "Synchronizing to the server." : "Synkroniserer til serveren.",
    "Task successfully saved to server." : "Oppgaven lagret på serveren.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Kan ikke oppdatere oppgaven fordi den ble endret på serveren. Vennligst klikk for å oppdatere den, lokale endringer vil bli forkastet.",
    "Could not update the task." : "Kunne ikke oppdatere oppgaven.",
    "Successfully updated the task." : "Oppdaterte oppgaven.",
    "Task successfully moved to new calendar." : "Oppgaven flyttet til ny kalender.",
    "An error occurred" : "En feil oppsto",
    "Create a task" : "Opprett en oppgave",
    "Message from {author} in {conversationName}" : "Melding fra {author} i {conversationName}",
    "[Due on] LL" : "[Forfaller den] LL",
    "[Was due yesterday]" : "[Forfalt i går]",
    "[Was due on] LL" : "[Forfalt den] LL",
    "[Was due today at] LT" : "[Forfalt i dag kl.] LT",
    "[Due on] LL [at] LT" : "[Forfaller den] LL [kl.] LT",
    "[Was due yesterday at] LT" : "[Forfalt i går kl.] LT",
    "[Was due on] LL [at] LT" : "[Forfalt den] LL [kl.] LT",
    "[Starts today]" : "[Starter i dag]",
    "[Starts tomorrow]" : "[Starter i morgen]",
    "[Starts on] LL" : "[Starter den]LL",
    "[Started yesterday]" : "[Startet i går]",
    "[Started on] LL" : "[Startet den]LL",
    "[Started today at] LT" : "[Startet i dag kl.] LT",
    "[Starts today at] LT" : "[Starter i dag kl.] LT",
    "[Starts tomorrow at] LT" : "[Starter i morgen kl.] LT",
    "[Starts on] LL [at] LT" : "[Starter den] LL [kl.] LT",
    "[Started yesterday at] LT" : "[Startet i går kl.] LT",
    "[Started on] LL [at] LT" : "[Startet den] LL [kl.] LT"
},
"nplurals=2; plural=(n != 1);");
