OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Verkefni á næstunni",
    "Important" : "Mikilvægt",
    "Today" : "Í dag",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "Tasks" : "Verkefni",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Þegar búið er að virkja þetta, mun ný Verkefni-valmynd birtast í Nextcloud-forritavalmyndinni þinni. Úr henni getur þú bætt við og eytt verkefnum, breytt titli þeirra, lýsingu, upphafs- og lokatíma, og merkt þau sem mikilvæg. Verkefnum er hægt að deila milli notenda. Verkefni geta verið samstillt í gegnum CalDav (hver verkefnalisti er tengdur Nextcloud-dagatali; til að samstilla það við forritið sem þú notar, t.d. Thunderbird, Evolution, KDE Kontact, iCal … þarftu bara að bæta dagatalinu við sem fjartengdu dagatali í forritinu). Þú getur líka náð í verkefnin þín sem ICS-skrár með því að nota niðurhalshnappinn fyrir hvert dagatal.",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Tasks settings" : "Stillingar verkefnis",
    "Default list" : "Sjálfgefinn listi",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "Unable to delete the share." : "Get ekki eytt sameigninni.",
    "Unable to change permissions." : "Tekst ekki að breyta heimildum.",
    "Can edit" : "Getur breytt",
    "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Þetta mun eyða dagatalinu \"{calendar}\" og öllum samsvarandi atburðum og verkefnum.",
    "This will unshare the calendar \"{calendar}\"." : "Þetta mun taka dagatalið \"{calendar}\" úr deilingu.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Þetta mun eyða listanum \"{list}\" og öllum samsvarandi verkefnum.",
    "This will unshare the list \"{list}\"." : "Þetta mun taka listann \"{list}\" úr deilingu.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eyði dagatalinu eftir {countdown} sekúndu","Eyði dagatalinu eftir {countdown} sekúndur"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Hætti að deila dagatalinu eftir {countdown} sekúndu","Hætti að deila dagatalinu eftir {countdown} sekúndur"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eyði listanum eftir {countdown} sekúndu","Eyði listanum eftir {countdown} sekúndur"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Hætti að deila listanum eftir {countdown} sekúndu","Hætti að deila listanum eftir {countdown} sekúndur"],
    "Share this calendar" : "Deila þessu dagatali",
    "Share this list" : "Deila þessum lista",
    "Calendar link copied to clipboard." : "Tengill dagatals afritaður á klippispjald.",
    "List link copied to clipboard." : "Tengill lista afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "List link could not be copied to clipboard." : "Ekki var hægt að afrita tengil lista á klippispjald.",
    "The name \"{calendar}\" is already used." : "Heitið \"{calendar}\" er þegar í notkun.",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
    "An error occurred, unable to delete the list." : "Villa kom upp, gat ekki eytt listanum.",
    "Edit" : "Breyta",
    "Copy private link" : "Afrita einkatengil",
    "Copied" : "Afritað",
    "Cannot copy" : "Get ekki afritað",
    "Export" : "Flytja út",
    "Delete" : "Eyða",
    "Unshare" : "Hætta deilingu",
    "List name" : "Heiti á lista",
    "Untitled task" : "Ónefnt verkefni",
    "Untitled event" : "Ónefndur atburður",
    "Untitled journal" : "Ónefnd dagbók",
    "Untitled item" : "Ónefnt atriði",
    "Unknown calendar" : "Óþekkt dagatal",
    "Could not load deleted calendars and objects" : "Gat ekki hlaðið inn eyddum dagatölum og hlutum",
    "Could not delete calendar or event" : "Gat ekki eytt dagatali eða atburði",
    "Could not restore calendar or event" : "Gat ekki endurheimt dagatal eða atburð",
    "Do you really want to empty the trash bin?" : "Viltu örugglega tæma ruslið?",
    "Empty trash bin" : "Tæma ruslið",
    "Trash bin" : "Ruslafata",
    "Loading deleted calendars, tasks and events." : "Hleð inn eyddum dagatölum, verkefnum og atburðum.",
    "You do not have any deleted calendars, tasks or events." : "Þú ert ekki með nein eydd dagatöl, verkefni eða atburði.",
    "Name" : "Heiti",
    "Deleted" : "Eytt",
    "Restore" : "Endurheimta",
    "Delete permanently" : "Eyða varanlega",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Atriðum í ruslinu er eytt eftir {numDays} dag","Atriðum í ruslinu er eytt eftir {numDays} daga"],
    "Create reminder" : "Útbúa áminningu",
    "Update reminder" : "Uppfæra áminningu",
    "Set a reminder at a custom date and time:" : "Stilla áminningu fyrir sérsniðna dagsetningu og tíma:",
    "Cancel" : "Hætta við",
    "This is a todo reminder." : "Þetta er áminning vegna verkþáttar.",
    "No reminders" : "Engar áminningar",
    "Notification" : "Tilkynning",
    "Email" : "Tölvupóstur",
    "Audio notification" : "Hljóðáminning",
    "Other notification" : "Önnur áminning",
    "Edit time" : "Breyta tíma",
    "Remove reminder" : "Fjarlægja áminningu",
    "Add reminder" : "Bæta við áminningu",
    "Before the task starts" : "Áður en verkið hefst",
    "Before the task is due" : "Áður en verkinu á að vera lokið",
    "Select date and time" : "Veldu dagsetningu og tíma",
    "Go back" : "Fara til baka",
    "Set a reminder relative to your tasks start date:" : "Stilla áminningu út frá upphafsdagsetningu verks:",
    "Set a reminder relative to your tasks due date:" : "Stilla áminningu út frá lokadagsetningu verks:",
    "before at" : "á undan klukkan",
    "_second_::_seconds_" : ["sekúnda","sekúndur"],
    "_minute_::_minutes_" : ["mínúta","mínútur"],
    "_hour_::_hours_" : ["klukkustund","klukkustundir"],
    "_day_::_days_" : ["dagur","dagar"],
    "_week_::_weeks_" : ["vika","vikur"],
    "Select a calendar" : "Veldu dagatal",
    "No calendar matches the search." : "Ekkert dagatal samsvarar leitinni.",
    "Set date" : "Stilla dagsetningu",
    "Set time" : "Stilla tíma",
    "Delete date" : "Eyða dagsetningu",
    "Click here to add a note." : "Smelltu hér til að bæta við minnispunkti.",
    "Set value" : "Setja gildi",
    "Delete value" : "Eyða gildi",
    "Add this as a new tag" : "Bæta þessu við sem nýju merki",
    "No tag available. Create one!" : "Ekkert merki tiltækt. Búðu til eitt slíkt!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} verkefnum hefur verið bætt við \"{calendar}\"",
    "Create new tasks" : "Búa til ný verkefni",
    "Create {numberOfTasks} tasks from pasted text" : "Búa til {numberOfTasks} verkefni úr límdum texta",
    "Create tasks" : "Búa til verkefni",
    "Creating new tasks…" : "Bý til ný verkefni…",
    "Close" : "Loka",
    "Delete all completed tasks." : "Eyða öllum loknum verkum.",
    "Delete completed tasks." : "Eyða loknum verkum.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eyddi öllum loknum verkefnum úr dagatalinu {calendar}\".",
    "No errors" : "Engar villur",
    "Open your browser console for more details" : "Opnaðu stjórnborð vafrans þíns til að sjá frekari upplýsingar",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Þetta mun eyða {taskCount} loknu verkefni og undirverkefnum þess úr dagatalinu {calendar}.","Þetta mun eyða {taskCount} loknum verkefnum og undirverkefnum þeirra úr dagatalinu {calendar}."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Gat ekki eytt {failedCount} verkefni.","Gat ekki eytt {failedCount} verkefnum."],
    "Active filter" : "Virk sía",
    "Filter by tags" : "Sía eftir merkjum",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "Reset filter" : "Endurstilla síu",
    "Add an important task to \"{calendar}\"…" : "Bæta mikilvægu verkefni við \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Bæta verkefni sem á að klára í dag við \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Bæta fyrirliggjandi verkefni við \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Bæta verkefni við \"{calendar}\"...",
    "Load the completed tasks of all lists." : "Hlaða inn loknum verkefnum úr öllum listum.",
    "Loading the completed tasks of all lists might slow down the app." : "Að hlaða inn loknum verkefnum úr öllum listum getur hægt á forritinu.",
    "Load the completed tasks of list \"{calendar}\"." : "Hlaða inn loknum verkefnum úr listanum \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Að hlaða inn loknum verkefnum getur hægt á forritinu.",
    "Relevance" : "Samsvörun",
    "Sort by completed state, due date, priority, start date and summary." : "Raða eftir framvindustöðu, skiladegi, forgangi, upphafsdagsetningu og yfirliti.",
    "Start date" : "Upphafsdagur",
    "Sort by start date, priority and summary." : "Raða eftir upphafsdagsetningu, forgangi og yfirliti.",
    "Due date" : "Skiladagur",
    "Sort by due date, priority and summary." : "Raða eftir skiladegi, forgangi og yfirliti.",
    "Created date" : "Búið til",
    "Sort by created date, priority and summary." : "Raða eftir upprunadagsetningu, forgangi og yfirliti.",
    "Last modified" : "Síðast breytt",
    "Sort by last-modified date, priority and summary." : "Raða eftir dagsetningu þegar var síðast breytt, forgangi og yfirliti.",
    "Completed date" : "Lokadagsetning",
    "Sort by completed date, priority and summary." : "Raða eftir lokadegi, forgangi og yfirliti.",
    "Priority" : "Forgangur",
    "Sort by priority and summary." : "Raða eftir forgangi og yfirliti.",
    "Alphabetically" : "Í stafrófsröð",
    "Sort by summary and priority." : "Raða eftir yfirliti og forgangi.",
    "Tags" : "Merki",
    "Sort by tags." : "Raða eftir merkjum.",
    "Manually" : "Handvirkt",
    "Sort by manual order." : "Raða eftir handvirkri röð.",
    "Change sort order" : "Breyta röðun",
    "[Yesterday]" : "[Í gær]",
    "[Today]" : "[Í dag]",
    "[Tomorrow]" : "[Á morgun]",
    "[Completed yesterday]" : "[Lokið í gær]",
    "[Completed today]" : "[Lokið í dag]",
    "[Completed tomorrow]" : "[Lokið á morgun]",
    "[Yesterday at] LT" : "[Í gær klukkan] LT",
    "[Today at] LT" : "[Í dag klukkan] LT",
    "[Tomorrow at] LT" : "[Á morgun klukkan] LT",
    "L [at] LT" : "L [klukkan] LT",
    "[Completed yesterday at] LT" : "[Lokið í gær klukkan] LT",
    "[Completed today at] LT" : "[Lokið í dag klukkan] LT",
    "[Completed tomorrow at] LT" : "[Lokið á morgun klukkan] LT",
    "[Completed] L [at] LT" : "[Lokið] L [klukkan] LT",
    "Add a subtask to \"{task}\"…" : "Bæta undirverkefni við \"{task}\"...",
    "Task has hidden subtasks" : "Verkefnið er með falin undirverkefni",
    "Task is pinned" : "Verkefnið er fest",
    "Task has a note" : "Verkefnið er með minnispunkt",
    "{complete} % completed" : "{complete} % lokið",
    "Add subtask" : "Bæta við undirverkefni",
    "Show subtasks" : "Sýna undirverkefni",
    "Hide subtasks" : "Fela undirverkefni",
    "Show closed subtasks" : "Sýna lokuð undirverkefni",
    "Hide closed subtasks" : "Fela lokuð undirverkefni",
    "Delete task" : "Eyða verki",
    "Toggle starred" : "Víxla stjörnumerkingu af/á",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Verkið er með eina áminningu","Verkið er með {n} áminningar"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Eyði verkefnininu eftir {countdown} sekúndu","Eyði verkefnininu eftir {countdown} sekúndur"],
    "Task is cancelled" : "Hætt við verkefni",
    "Task is completed" : "Verkefni er lokið",
    "Task is read-only" : "Verkefni er ritvarið",
    "Task is not completed" : "Verkefni er ekki lokið",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" var bætt í \"{calendar}\"",
    "Create a new task" : "Búa til nýtt verkefni",
    "Task summary" : "Samantekt verkefnis",
    "Create task" : "Búa til verkefni",
    "Creating the new task…" : "Bý til nýja verkefnið…",
    "Open task" : "Opna verkefni",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verkefni","%n lokin verkefni"],
    "Tomorrow" : "Á morgun",
    "An error occurred, unable to create the list." : "Villa kom upp, gat ekki búið til listann.",
    "Add List…" : "Bæta við lista...",
    "New list" : "Nýr listi",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "[Completed] L" : "[Lokið] L",
    "[Completed last] dddd [at] LT" : "[Lokið síðasta] dddd [klukkan] LT",
    "[Completed] dddd [at] LT" : "[Lokið] dddd [klukkan] LT",
    "[Last modified yesterday at] LT" : "[Síðast breytt í gær klukkan] LT",
    "[Last modified today at] LT" : "[Síðast breytt í dag klukkan] LT",
    "[Last modified] L" : "[Síðast breytt] L",
    "[Last modified last] dddd [at] LT" : "[Síðast breytt síðasta] dddd [klukkan] LT",
    "[Last modified] dddd [at] LT" : "[Síðast breytt] dddd [klukkan] LT",
    "[Created yesterday at] LT" : "[Búið til í gær klukkan] LT",
    "[Created today at] LT" : "[Búið til í dag klukkan] LT",
    "[Created] L" : "[Búið til] L",
    "[Created last] dddd [at] LT" : "[Búið til síðasta] dddd [klukkan] LT",
    "[Created] dddd [at] LT" : "[Búið til] dddd [klukkan] LT",
    "Needs action" : "Þarfnast aðgerða",
    "In process" : "í vinnslu",
    "Canceled" : "Hætt við",
    "Clear status" : "Hreinsa stöðu",
    "Loading task from server." : "Hleð verkefni inn frá netþjóni.",
    "Task not found!" : "Verkefn fannst ekki!",
    "Set start date" : "Setja upphafsdag",
    "Set due date" : "Setja skiladag",
    "Priority {priority}: low" : "Forgangur {priority}: lítill",
    "Priority {priority}: medium" : "Forgangur {priority}: miðlungs",
    "Priority {priority}: high" : "Forgangur {priority}: mikill",
    "No priority assigned" : "Enginn forgangur settur",
    "{percent} % completed" : "{percent} % lokið",
    "All day" : "Heilsdagsviðburður",
    "Unpin" : "Losa",
    "Pin" : "Festa",
    "Show in Calendar" : "Birta í dagatali",
    "Show in Deck" : "Sýna í Deck",
    "Edit summary" : "Breyta samantekt",
    "Details" : "Details",
    "Selecting a classification is forbidden, because the task was shared with you." : "Val á flokkun er bannað, því verkefninu var deilt með þér.",
    "Select a classification" : "Veldu flokkun",
    "Select a status" : "Veldu stöðu",
    "Set a location" : "Setja staðsetningu",
    "Set a URL" : "Setja slóð",
    "Select tags" : "Veldu merki",
    "Notes" : "Minnispunktar",
    "Mark as done" : "Merkja sem lokið",
    "No due date assigned" : "Enginn skiladagur settur",
    "[Due yesterday]" : "[Átti að ljúka í gær]",
    "[Due today]" : "[Á að ljúka í dag]",
    "[Due tomorrow]" : "[Á að ljúka á morgun]",
    "[Due] L" : "[Á að ljúka] LL",
    "[Due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
    "[Due today at] LT" : "[Á að ljúka í dag klukkan] LT",
    "[Due tomorrow at] LT" : "[Á að ljúka á morgun klukkan] LT",
    "[Due] L [at] LT" : "[Á að ljúka] L [klukkan] LT",
    "No upcoming tasks" : "Engin verkefni á næstunni",
    "upcoming tasks" : "verkefni á næstunni",
    "No tasks today" : "Engin verkefni í dag",
    "Completion date must be in the past." : "Dagur verkloka verður að vera í fortíðinni.",
    "Successfully created the task." : "Tókst að búa til verkefnið.",
    "Could not delete the task." : "Gat ekki eytt verkefninu.",
    "Synchronizing to the server." : "Samstilli við netþjóninn.",
    "Task successfully saved to server." : "Tókst að vista verkefnið á þjóninn.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Gat ekki uppfært verkefnið vegna þess að því var breytt á þjóninum. Smelltu til að endurlesa það, breytingum hjá þér verður hent.",
    "Could not update the task." : "Gat ekki uppfært verkefnið.",
    "Successfully updated the task." : "Tókst að uppfæra verkefnið.",
    "Task successfully moved to new calendar." : "Tókst að flytja verkefni í nýtt dagatal.",
    "An error occurred" : "Villa kom upp",
    "Create a task" : "Búa til verkefni",
    "Message from {author} in {conversationName}" : "Skilaboð frá {author} í {conversationName}",
    "[Due on] LL" : "[Á að ljúka þann] LL",
    "[Was due yesterday]" : "[Átti að ljúka í gær]",
    "[Was due on] LL" : "[Átti að ljúka þann] LL",
    "[Was due today at] LT" : "[Átti að ljúka í dag klukkan] LT",
    "[Due on] LL [at] LT" : "[Á að ljúka þann] LL [klukkan] LT",
    "[Was due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
    "[Was due on] LL [at] LT" : "[Átti að ljúka þann] LL [klukkan] LT",
    "[Starts today]" : "[Byrjar í dag]",
    "[Starts tomorrow]" : "[Byrjar á morgun]",
    "[Starts on] LL" : "[Byrjar þann] LL",
    "[Started yesterday]" : "[Byrjaði í gær]",
    "[Started on] LL" : "[Byrjar þann] LL",
    "[Started today at] LT" : "[Byrjaði í dag klukkan] LT",
    "[Starts today at] LT" : "[Byrjar í dag klukkan] LT",
    "[Starts tomorrow at] LT" : "[Byrjar í á morgun klukkan] LT",
    "[Starts on] LL [at] LT" : "[Byrjar þann] LL [klukkan] LT",
    "[Started yesterday at] LT" : "[Byrjaði í gær klukkan] LT",
    "[Started on] LL [at] LT" : "[Byrjaði þann] LL [klukkan] LT",
    "Midnight on the day the task starts" : "Miðnætti dagsins sem verkið hefst",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n degi fyrir verkið kl. {formattedHourMinute}","%n dögum fyrir verkið kl. {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n viku fyrir verkið kl. {formattedHourMinute}","%n vikum fyrir verkið kl. {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "dagsins sem verkið hefst kl. {formattedHourMinute}",
    "at the task's start" : "við upphaf verks",
    "when the task is due" : "þegar verkinu á að vera lokið",
    "{time} before the task starts" : "{time} áður en verk hefst",
    "{time} before the task is due" : "{time} áður en verkinu á að vera lokið",
    "{time} after the task starts" : "{time} eftir að verk hefst",
    "{time} after the task is due" : "{time} eftir að verkinu á að vera lokið"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
