OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tareas",
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "The Tasks app for Nextcloud" : "Una aplicación de Tareas para Nextcloud",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Tasks settings" : "Configuraciones de Tareas",
    "Default list" : "Lista predeterminada",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "Sin usuarios ni grupos",
    "Unable to delete the share." : "No se pudo eliminar el recurso compartido.",
    "Unable to change permissions." : "No se pudieron cambiar los permisos.",
    "Can edit" : "Puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Esto eliminará el calendario \"{calendar}\" y todos los eventos y tareas correspondientes.",
    "This will unshare the calendar \"{calendar}\"." : "Esto dejará de compartir el calendario \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Esto eliminará la lista \"{list}\" y todas las tareas correspondientes.",
    "This will unshare the list \"{list}\"." : "Esto dejará de compartir la lista \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Eliminando la lista en {countdown} segundo","Eliminando la lista en {countdown} segundos","Eliminando la lista en {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Dejando de compartir la lista en {countdown} segundo","Dejando de compartir la lista en {countdown} segundos","Dejando de compartir la lista en {countdown} segundos"],
    "Share this calendar" : "Compartir este calendario",
    "Share this list" : "Compartir esta lista",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "List link copied to clipboard." : "Enlace de la lista copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
    "List link could not be copied to clipboard." : "No se pudo copiar el enlace de la lista al portapapeles.",
    "The name \"{calendar}\" is already used." : "El nombre \"{calendar}\" ya está en uso.",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "An error occurred, unable to delete the calendar." : "Ocurrió un error, no se pudo eliminar el calendario.",
    "An error occurred, unable to delete the list." : "Ocurrió un error, no se puede eliminar la lista.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar enlace privado",
    "Copied" : "Copiado",
    "Cannot copy" : "No se puede copiar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "List name" : "Nombre de lista",
    "Untitled task" : "Tarea sin título",
    "Untitled event" : "Evento sin título",
    "Untitled journal" : "Diario sin título",
    "Untitled item" : "Elemento sin título",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No se pudieron cargar los calendarios y objetos eliminados",
    "Could not delete calendar or event" : "No se pudo eliminar el calendario o el evento",
    "Could not restore calendar or event" : "No se pudo restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿Realmente desea vaciar la papelera?",
    "Empty trash bin" : "Vaciar la papelera de reciclaje",
    "Trash bin" : "Papelera",
    "Loading deleted calendars, tasks and events." : "Cargando calendarios, tareas y eventos eliminados.",
    "You do not have any deleted calendars, tasks or events." : "No tienes ningún calendario, tarea o evento eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera se eliminan después de {numDays} día","Los elementos en la papelera se eliminan después de {numDays} días","Los elementos en la papelera se eliminan después de {numDays} días"],
    "Cancel" : "Cancelar",
    "Email" : "Correo electrónico",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otra notificación",
    "Edit time" : "Editar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "Add reminder" : "Añadir recordatorio",
    "Go back" : "Regresar",
    "before at" : "antes de las",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Select a calendar" : "Seleccionar un calendario",
    "No calendar matches the search." : "Ningún calendario coincide con la búsqueda.",
    "Set date" : "Establecer fecha",
    "Set time" : "Establecer hora",
    "Delete date" : "Eliminar fecha",
    "Click here to add a note." : "Haz clic aquí para agregar una nota.",
    "Set value" : "Establecer valor",
    "Delete value" : "Eliminar valor",
    "Add this as a new tag" : "Agregar esto como una nueva etiqueta",
    "No tag available. Create one!" : "No hay etiquetas disponibles. ¡Crea una!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} tareas han sido agregadas al calendario \"{calendar}\"",
    "Create new tasks" : "Crear tareas nuevas",
    "Create {numberOfTasks} tasks from pasted text" : "Crear {numberOfTasks} tareas desde el texto pegado",
    "Create tasks" : "Crear tareas",
    "Creating new tasks…" : "Creando tareas nuevas…",
    "Close" : "Cerrar",
    "Delete all completed tasks." : "Eliminar todas las tareas completadas.",
    "Delete completed tasks." : "Eliminar tareas completadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Eliminadas todas las tareas completadas del calendario \"{calendar}\".",
    "No errors" : "Sin errores",
    "Open your browser console for more details" : "Abre la consola de tu navegador para obtener más detalles",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Esto eliminará {taskCount} tarea completada y sus subtareas del calendario \"{calendar}\".","Esto eliminará {taskCount} tareas completadas y sus subtareas del calendario \"{calendar}\".","Esto eliminará {taskCount} tareas completadas y sus subtareas del calendario \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No se pudo eliminar {failedCount} tarea.","No se pudieron eliminar {failedCount} tareas.","No se pudieron eliminar {failedCount} tareas."],
    "Active filter" : "Filtro activo",
    "Filter by tags" : "Filtrar por etiquetas",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Reset filter" : "Restablecer filtro",
    "Add an important task to \"{calendar}\"…" : "Agregar una tarea importante a \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Agregar una tarea con vencimiento para hoy a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Agregar una tarea actual a \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Agregar una tarea a \"{calendar}\"…",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Tags" : "Etiquetas",
    "Manually" : "Manualmente",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "[Yesterday]" : "[Ayer]",
    "[Today]" : "[Hoy]",
    "[Tomorrow]" : "[Mañana]",
    "Delete task" : "Eliminar tarea",
    "Task is completed" : "La tarea ha sido completada",
    "Create a new task" : "Crear una tarea nueva",
    "Create task" : "Crear tarea",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Add List…" : "Crear Lista...",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Canceled" : "Cancelada",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Mark as done" : "Marcar como hecho",
    "No due date assigned" : "Fecha de vencimiento sin especificar",
    "No upcoming tasks" : "No hay tareas próximas",
    "upcoming tasks" : "tareas próximas",
    "Synchronizing to the server." : "Sincronizando con el servidor.",
    "An error occurred" : "Ha ocurrido un error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
