OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Επερχόμενες εργασίες",
    "Important" : "Σημαντικό ",
    "Today" : "Σήμερα",
    "Week" : "Εβδομάδα",
    "All" : "Όλες",
    "Current" : "Τρέχουσα",
    "Completed" : "Ολοκληρωμένες",
    "Tasks" : "Εργασίες",
    "The Tasks app for Nextcloud" : "Η εφαρμογή Εργασίες για το Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Μόλις ενεργοποιηθεί, θα εμφανιστεί ένα νέο μενού Εργασίες στο μενού εφαρμογών του Nextcloud. Από εκεί μπορείτε να προσθέσετε και να διαγράψετε εργασίες, να επεξεργαστείτε τον τίτλο, την περιγραφή, τις ημερομηνίες έναρξης και λήξης και να τις επισημάνετε ως σημαντικές. Οι εργασίες μπορούν να μοιράζονται μεταξύ των χρηστών. Οι εργασίες μπορούν να συγχρονιστούν χρησιμοποιώντας το CalDav (κάθε λίστα εργασιών συνδέεται με ένα ημερολόγιο Nextcloud, για να το συγχρονίσετε με την εφαρμογή σας: Thunderbird, Evolution, KDE Kontact, iCal… - απλώς προσθέστε το ημερολόγιο ως απομακρυσμένο ημερολόγιο στην εφαρμογή σας). Μπορείτε να κάνετε λήψη των εργασιών σας ως αρχεία ICS χρησιμοποιώντας το κουμπί λήψης για κάθε ημερολόγιο.",
    "Hidden" : "Κρυφό",
    "Visible" : "Ορατό",
    "Automatic" : "Αυτόματο",
    "Tasks settings" : "Ρυθμίσεις εργασιών",
    "Default list" : "Προεπιλεγμένη λίστα",
    "Visibility of Smart Collections" : "Ορατότητα Έξυπνων Συλλογών",
    "Share with users or groups" : "Κοινή χρήση με χρήστες ή ομάδες",
    "No users or groups" : "Δεν υπάρχουν χρήστες ή ομάδες",
    "Unable to delete the share." : "Αδυναμία διαγραφής κοινόχρηστου.",
    "Unable to change permissions." : "Αδυναμία αλλαγής δικαιωμάτων.",
    "Can edit" : "Μπορεί να επεξεργαστεί",
    "Unshare with {displayName}" : "Κατάργηση κοινής χρήσης με {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Θα διαγραφεί το ημερολόγιο \"{calendar}\" και όλα τα σχετικά γεγονότα και εργασίες.",
    "This will unshare the calendar \"{calendar}\"." : "Αυτό θα καταργήσει την κοινή χρήση του ημερολογίου \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Αυτό θα διαγράψει τη λίστα \"{list}\" και όλες τις αντίστοιχες εργασίες.",
    "This will unshare the list \"{list}\"." : "Αυτό θα καταργήσει την κοινή χρήση της λίστας \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Διαγραφή ημερολογίου σε {countdown} δεύτερα","Διαγραφή ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Κατάργηση κοινής χρήσης ημερολογίου σε {countdown} δεύτερα","Κατάργηση κοινής χρήσης ημερολογίου σε {countdown} δευτερόλεπτα"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Διαγραφή λίστας σε {countdown} δεύτερα","Διαγραφή λίστας σε {countdown} δευτερόλεπτα"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Κατάργηση κοινής χρήσης λίστας σε {countdown} δεύτερα","Κατάργηση κοινής χρήσης λίστας σε {countdown} δευτερόλεπτα"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Κοινη χρήση με {num} οντότητα","Κοινη χρήση με {num} οντότητες"],
    "Share this calendar" : "Διαμοιραστείτε αυτό το ημερολόγιο",
    "Share this list" : "Διαμοιραστείτε αυτή τη λίστα",
    "Calendar link copied to clipboard." : "Ο σύνδεσμος του ημερολογίου αντιγράφηκε στο πρόχειρο.",
    "List link copied to clipboard." : "Ο σύνδεσμος λίστας αντιγράφηκε στο πρόχειρο.",
    "Calendar link could not be copied to clipboard." : "Αδυναμία αντιγραφής συνδέσμου ημερολογίου στο πρόχειρο.",
    "List link could not be copied to clipboard." : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου λίστας στο πρόχειρο.",
    "The name \"{calendar}\" is already used." : "Το όνομα \"{calendar}\" είναι σε χρήση.",
    "An empty name is not allowed." : "Δεν επιτρέπεται κενό όνομα.",
    "An error occurred, unable to delete the calendar." : "Παρουσιάστηκε σφάλμα, δεν δύναται να διαγραφεί το ημερολόγιο.",
    "An error occurred, unable to delete the list." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η διαγραφή της λίστας.",
    "Edit" : "Επεξεργασία",
    "Copy private link" : "Αντιγραφή ιδιωτικού συνδέσμου",
    "Copied" : "Αντιγράφηκε",
    "Cannot copy" : "Δεν είναι δυνατή η αντιγραφή",
    "Export" : "Εξαγωγή",
    "Delete" : "Διαγραφή",
    "Unshare" : "Αναίρεση διαμοιρασμού",
    "List name" : "Όνομα λίστας",
    "Untitled task" : "Εργασία χωρίς όνομα",
    "Untitled event" : "Συμβάν χωρίς όνομα",
    "Untitled journal" : "Μπλοκ σημειώσεων χωρίς τίτλο",
    "Untitled item" : "Στοιχείο χωρίς όνομα",
    "Unknown calendar" : "Άγνωστο ημερολόγιο",
    "Could not load deleted calendars and objects" : "Δεν ήταν δυνατή η φόρτωση διαγραμμένων ημερολογίων και αντικειμένων",
    "Could not delete calendar or event" : "Δεν ήταν δυνατή η διαγραφή ημερολογίου ή συμβάντος",
    "Could not restore calendar or event" : "Δεν ήταν δυνατή η επαναφορά ημερολογίου ή συμβάντος",
    "Do you really want to empty the trash bin?" : "Θέλετε πραγματικά να αδειάσετε τον κάδο απορριμμάτων;",
    "Empty trash bin" : "Άδειασμα κάδου",
    "Trash bin" : "Κάδος απορριμμάτων",
    "Loading deleted calendars, tasks and events." : "Φόρτωση διαγραμμένων ημερολογίων, εργασιών και συμβάντων.",
    "You do not have any deleted calendars, tasks or events." : "Δεν έχετε διαγραμμένα ημερολόγια, εργασίες ή συμβάντα.",
    "Name" : "Όνομα",
    "Deleted" : "Διαγραμμένα",
    "Restore" : "Επαναφορά",
    "Delete permanently" : "Διαγραφή οριστικά",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Θέλετε πραγματικά να αδειάσετε τον κάδο απορριμμάτων;","Τα περιεχόμενα στον κάδο απορριμάτων θα διαγραφούν μετά από {numDays} ημέρα"],
    "Create reminder" : "Δημιουργία υπενθύμισης",
    "Update reminder" : "Ενημέρωση υπενθύμισης",
    "Set a reminder at a custom date and time:" : "Ορισμός υπενθύμισης σε προσαρμοσμένη ημερομηνία και ώρα:",
    "Cancel" : "Ακύρωση",
    "This is a todo reminder." : "Αυτή είναι μια υπενθύμιση εργασίας.",
    "No reminders" : "Δεν υπάρχουν υπενθυμίσεις",
    "Notification" : "Ειδοποίηση",
    "Email" : "Email",
    "Audio notification" : "Ηχητική ειδοποίηση",
    "Other notification" : "Άλλη ειδοποίηση",
    "Edit time" : "Επεξεργασία ώρας",
    "Remove reminder" : "Αφαίρεση υπενθύμισης",
    "Add reminder" : "Προσθήκη υπενθύμισης",
    "Before the task starts" : "Πριν από την έναρξη της εργασίας",
    "Before the task is due" : "Πριν από την προθεσμία της εργασίας",
    "Select date and time" : "Επιλογή ημερομηνίας και ώρας",
    "Go back" : "Επιστροφή",
    "Set a reminder relative to your tasks start date:" : "Ορισμός υπενθύμισης σε σχέση με την ημερομηνία έναρξης των εργασιών σας:",
    "Set a reminder relative to your tasks due date:" : "Ορισμός υπενθύμισης σε σχέση με την ημερομηνία προθεσμίας των εργασιών σας:",
    "before at" : "πριν από το",
    "_second_::_seconds_" : ["δευτερόλεπτο","δευτερόλεπτα"],
    "_minute_::_minutes_" : ["λεπτό","λεπτά"],
    "_hour_::_hours_" : ["ώρα","ώρες"],
    "_day_::_days_" : ["ημέρα","ημέρες"],
    "_week_::_weeks_" : ["εβδομάδα","εβδομάδες"],
    "Select a calendar" : "Επιλέξτε ένα ημερολόγιο",
    "No calendar matches the search." : "Κανένα ημερολόγιο δεν ταιριάζει με την αναζήτηση.",
    "Set date" : "Ορισμός ημερομηνίας",
    "Set time" : "Ορισμός ώρας",
    "Delete date" : "Διαγραφή ημερομηνίας",
    "Click here to add a note." : "Κάντε κλικ εδώ για να προσθέσετε μια σημείωση.",
    "Set value" : "Ορισμός τιμής",
    "Delete value" : "Διαγραφή τιμής",
    "Add this as a new tag" : "Προσθήκη ως νέα ετικέτα",
    "No tag available. Create one!" : "Δεν υπάρχει διαθέσιμη ετικέτα. Δημιουργήστε μια!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} εργασίες έχουν προστεθεί στο \"{calendar}\"",
    "Create new tasks" : "Δημιουργία νέων εργασιών",
    "Create {numberOfTasks} tasks from pasted text" : "Δημιουργία {numberOfTasks} εργασιών από επικολλημένο κείμενο",
    "Create tasks" : "Δημιουργία εργασιών",
    "Creating new tasks…" : "Δημιουργία νέων εργασιών…",
    "Close" : "Κλείσιμο",
    "Delete all completed tasks." : "Διαγραφή όλων των ολοκληρωμένων εργασιών.",
    "Delete completed tasks." : "Διαγραφή ολοκληρωμένων εργασιών.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Διαγραφή όλων των ολοκληρωμένων εργασιών από το ημερολόγιο \"{calendar}\".",
    "No errors" : "Κανένα σφάλμα",
    "Open your browser console for more details" : "Ανοίξτε την κονσόλα του περιηγητή για περισσότερες λεπτομέρειες",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Θα διαγραφή η ολοκληρωμένη εργασία του {taskCount} και των υπο εργασιών από το ημερολόγιο \"{calendar}\".","Θα διαγραφούν ολοκληρωμένες εργασίες του {taskCount} και των υπο εργασιών από το ημερολόγιο \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Αδυναμία διαγραφής εργασίας {failedCount}.","Αδυναμία διαγραφής εργασιών {failedCount}."],
    "Active filter" : "Ενεργό φίλτρο",
    "Filter by tags" : "Φιλτράρισμα με ετικέτες",
    "Select tags to filter by" : "Επιλογή ετικετών για φιλτράρισμα με",
    "Reset filter" : "Επαναφορά φίλτρου",
    "Add an important task to \"{calendar}\"…" : "Προσθήκη σημαντικής εργασίας στο \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Προσθέστε εργασία για σήμερα στο \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Προσθήκη τρέχουσας εργασίας στο \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Προσθήκη εργασίας στο \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Φόρτωση των ολοκληρωμένων εργασιών όλων των λιστών.",
    "Loading the completed tasks of all lists might slow down the app." : "Η φόρτωση των ολοκληρωμένων εργασιών όλων των λιστών μπορεί να επιβραδύνει την εφαρμογή.",
    "Load the completed tasks of list \"{calendar}\"." : "Φόρτωση των ολοκληρωμένων εργασιών της λίστας \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Η φόρτωση των ολοκληρωμένων εργασιών μπορεί να επιβραδύνει την εφαρμογή.",
    "Relevance" : "Συνάφεια",
    "Sort by completed state, due date, priority, start date and summary." : "Ταξινόμηση κατά ολοκληρωμένη κατάσταση, ημερομηνία λήξης, προτεραιότητα, ημερομηνία έναρξης και σύνοψη.",
    "Start date" : "Ημερομηνία έναρξης",
    "Sort by start date, priority and summary." : "Ταξινόμηση κατά ημερομηνία έναρξης, προτεραιότητα και σύνοψη.",
    "Due date" : "Ημερομηνία λήξης",
    "Sort by due date, priority and summary." : "Ταξινόμηση κατά ημερομηνία λήξης, προτεραιότητα και σύνοψη.",
    "Created date" : "Ημερομηνία δημιουργίας",
    "Sort by created date, priority and summary." : "Ταξινόμηση κατά ημερομηνία δημιουργίας, προτεραιότητα και σύνοψη.",
    "Last modified" : "Τελευταία τροποποίηση",
    "Sort by last-modified date, priority and summary." : "Ταξινόμηση κατά ημερομηνία τελευταίας τροποποίησης, προτεραιότητα και σύνοψη.",
    "Completed date" : "Ημερομηνία ολοκλήρωσης",
    "Sort by completed date, priority and summary." : "Ταξινόμηση κατά ημερομηνία ολοκλήρωσης, προτεραιότητα και σύνοψη.",
    "Priority" : "Προτεραιότητα",
    "Sort by priority and summary." : "Ταξινόμηση κατά προτεραιότητα και σύνοψη.",
    "Alphabetically" : "Αλφαβητικά",
    "Sort by summary and priority." : "Ταξινόμηση κατά σύνοψη και προτεραιότητα.",
    "Tags" : "Ετικέτες",
    "Sort by tags." : "Ταξινόμηση κατά ετικέτες.",
    "Manually" : "Χειροκίνητα",
    "Sort by manual order." : "Ταξινόμηση με χειροκίνητη σειρά.",
    "Change sort order" : "Αλλαγή σειράς ταξινόμησης",
    "[Yesterday]" : "[Χθες]",
    "[Today]" : "[Σήμερα]",
    "[Tomorrow]" : "[Αύριο]",
    "[Completed yesterday]" : "[Ολοκληρώθηκε εχθές]",
    "[Completed today]" : "[Ολοκληρώθηκε σήμερα]",
    "[Completed tomorrow]" : "[Ολοκληρώνεται αύριο]",
    "[Yesterday at] LT" : "[Χθες στις] LT",
    "[Today at] LT" : "[Σήμερα στις] LT",
    "[Tomorrow at] LT" : "[Αύριο στις] LT",
    "L [at] LT" : "L [στις] LT",
    "[Completed yesterday at] LT" : "[Ολοκληρώθηκε χθές στις] LT",
    "[Completed today at] LT" : "[Ολοκληρώθηκε σήμερα στις] LT",
    "[Completed tomorrow at] LT" : "[Ολοκληρώνεται αύριο στις] LT",
    "[Completed] L [at] LT" : "[Ολοκληρώθηκε] L [στις] LT",
    "Add a subtask to \"{task}\"…" : "Προσθήκη υποέργου σε \"{task}\"…",
    "Task has hidden subtasks" : "Η εργασίας έχει κρυφές δευτερεύουσες υποεργασίες",
    "Task is pinned" : "Η εργασία είναι καρφιτσωμένη",
    "Task has a note" : "Η εργασία έχει μια σημείωση",
    "{complete} % completed" : "Ολοκληρώθηκε το {complete} %",
    "Add subtask" : "Προσθήκη υποεργασίας",
    "Show subtasks" : "Εμφάνιση υποεργασιών",
    "Hide subtasks" : "Απόκρυψη υποεργασιών",
    "Show closed subtasks" : "Εμφάνιση ολοκληρωμένων υποεργασιών",
    "Hide closed subtasks" : "Απόκρυψη ολοκληρωμένων υποεργασιών",
    "Delete task" : "Διαγραφή εργασίας",
    "Toggle starred" : "Εναλλαγή αστεριού",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Η εργασία έχει μία υπενθύμιση","Η εργασία έχει {n} υπενθυμίσεις"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Διαγραφή εργασίας σε {countdown} δευτερόλεπτο","Διαγραφή εργασίας σε {countdown} δευτερόλεπτα"],
    "Task is cancelled" : "Η εργασία ακυρώθηκε",
    "Task is completed" : "Η εργασία ολοκληρώθηκε",
    "Task is read-only" : "Η εργασία είναι μόνο για ανάγνωση",
    "Task is not completed" : "Η εργασία δεν ολοκληρώθηκε",
    "\"{task}\" was added to \"{calendar}\"" : "Το \"{task}\" προστέθηκε στο \"{calendar}\"",
    "Create a new task" : "Δημιουργία νέας εργασίας",
    "Task summary" : "Περίληψη εργασίας",
    "Create task" : "Δημιουργία εργασίας",
    "Creating the new task…" : "Δημιουργία νέας εργασίας...",
    "Open task" : "Άνοιγμα εργασίας",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Ολοκληρωμένη Εργασία","%n Ολοκληρωμένες Εργασίες"],
    "Tomorrow" : "Αύριο",
    "An error occurred, unable to create the list." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία της λίστας.",
    "Add List…" : "Προσθήκη λίστας…",
    "New list" : "Νέα λίστα",
    "When shared show full event" : "Όταν είναι σε κοινή χρήση να προβάλλεται το πλήρες συμβάν",
    "When shared show only busy" : "Όταν είναι σε κοινή χρήση να προβάλλονται μόνο απασχολημένοι",
    "When shared hide this event" : "Απόκρυψη, όταν είναι σε κοινή χρήση",
    "[Completed] L" : "[Ολοκληρώθηκε] L",
    "[Completed last] dddd [at] LT" : "[Ολοκληρώθηκε τελευταία] dddd [στις] LT",
    "[Completed] dddd [at] LT" : "[Ολοκληρώθηκε] dddd [στις] LT",
    "[Last modified yesterday at] LT" : "[Τελευταία τροποποίηση χθες στις] LT",
    "[Last modified today at] LT" : "[Τελευταία τροποποίηση σήμερα στις] LT",
    "[Last modified] L" : "[Τελευταία τροποποίηση] L",
    "[Last modified last] dddd [at] LT" : "[Τελευταία τροποποίηση την προηγούμενη] dddd [στις] LT",
    "[Last modified] dddd [at] LT" : "[Τελευταία τροποποίηση] dddd [στις] LT",
    "[Created yesterday at] LT" : "[Δημιουργήθηκε χθες στις] LT",
    "[Created today at] LT" : "[Δημιουργήθηκε σήμερα στις] LT",
    "[Created] L" : "[Δημιουργήθηκε] L",
    "[Created last] dddd [at] LT" : "[Δημιουργήθηκε την τελευταία] dddd [στις] LT",
    "[Created] dddd [at] LT" : "[Δημιουργήθηκε] dddd [στις] LT",
    "Needs action" : "Χρειάζεται ενέργεια",
    "In process" : "Σε εξέλιξη",
    "Canceled" : "Ακυρώθηκε",
    "Clear status" : "Εκκαθάριση κατάστασης",
    "Loading task from server." : "Φόρτωση εργασίας από διακομιστή.",
    "Task not found!" : "Δεν βρέθηκε εργασία!",
    "Set start date" : "Ορισμός ημερομηνίας έναρξης",
    "Set due date" : "Ορισμός ημερομηνίας λήξης",
    "Priority {priority}: low" : "Προτεραιότητα {priority}: χαμηλή",
    "Priority {priority}: medium" : "Προτεραιότητα {priority}: μεσαία",
    "Priority {priority}: high" : "Προτεραιότητα {priority}: υψηλή",
    "No priority assigned" : "Δεν έχει οριστεί προτεραιότητα",
    "{percent} % completed" : "{percent} % ολοκληρωμένο",
    "All day" : "Ολοήμερο",
    "Unpin" : "Ξεκαρφίτσωμα",
    "Pin" : "Καρφίτσωμα",
    "Show in Calendar" : "Εμφάνιση στο ημερολόγιο",
    "Show in Deck" : "Εμφάνιση στο Deck",
    "Edit summary" : "Επεξεργασία περίληψης",
    "Details" : "Λεπτομέρειες",
    "Selecting a classification is forbidden, because the task was shared with you." : "Η επιλογή ταξινόμησης απαγορεύεται, επειδή η εργασία κοινοποιήθηκε με εσάς.",
    "Select a classification" : "Επιλέξτε μια ταξινόμηση",
    "Select a status" : "Επιλέξτε κατάσταση",
    "Set a location" : "Ορισμός τοποθεσίας",
    "Set a URL" : "Ορισμός URL",
    "Select tags" : "Επιλέξτε ετικέτες",
    "Notes" : "Σημειώσεις",
    "Mark as done" : "Σήμανση ως ολοκληρωμένου",
    "No due date assigned" : "Δεν έχει οριστεί ημερομηνία λήξης",
    "[Due yesterday]" : "[Έληξε χθες]",
    "[Due today]" : "[Λήγει σήμερα]",
    "[Due tomorrow]" : "[Λήγει αύριο]",
    "[Due] L" : "[Λήγει] L",
    "[Due yesterday at] LT" : "[Έληξε χθες στις] LT",
    "[Due today at] LT" : "[Λήγει σήμερα στις] LT",
    "[Due tomorrow at] LT" : "[Λήγει αύριο στις] LT",
    "[Due] L [at] LT" : "[Λήγει] L [στις] LT",
    "No upcoming tasks" : "Δεν υπάρχουν επερχόμενες εργασίες",
    "upcoming tasks" : "επερχόμενες εργασίες",
    "No tasks today" : "Δεν υπάρχουν εργασίες σήμερα",
    "Completion date must be in the past." : "Η ημερομηνία ολοκλήρωσης πρέπει να είναι στο παρελθόν.",
    "Successfully created the task." : "Επιτυχής δημιουργία εργασίας.",
    "Could not delete the task." : "Αδυναμία διαγραφής εργασίας.",
    "Synchronizing to the server." : "Συγχρονισμός με τον διακομιστή.",
    "Task successfully saved to server." : "Η εργασία αποθηκεύτηκε επιτυχώς στον διακομιστή.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Δεν ήταν δυνατή η ενημέρωση της εργασίας επειδή άλλαξε στον διακομιστή. Κάντε κλικ για ανανέωση, οι τοπικές αλλαγές θα διαγραφούν.",
    "Could not update the task." : "Αδυναμία ενημέρωσης της εργασίας.",
    "Successfully updated the task." : "Επιτυχής ενημέρωση εργασίας.",
    "Task successfully moved to new calendar." : "Η εργασία μεταφέρθηκε επιτυχώς στο νέο ημερολόγιο.",
    "An error occurred" : "Παρουσιάστηκε σφάλμα",
    "Create a task" : "Δημιουργήστε μια εργασία",
    "Message from {author} in {conversationName}" : "Μήνυμα από {author} σε {conversationName}",
    "[Due on] LL" : "[Έως στις] LL",
    "[Was due yesterday]" : "[Έληγε χθες]",
    "[Was due on] LL" : "[Έληγε στις] LL",
    "[Was due today at] LT" : "[Έληγε σήμερα στις] LT",
    "[Due on] LL [at] LT" : "[Λήγει] LL [στις] LT",
    "[Was due yesterday at] LT" : "[Έληγε χθες στις] LT",
    "[Was due on] LL [at] LT" : "[Έληγε] LL [στις] LT",
    "[Starts today]" : "[Αρχίζει σήμερα]",
    "[Starts tomorrow]" : "[Αρχίζει αύριο]",
    "[Starts on] LL" : "[Ξεκινά] LL",
    "[Started yesterday]" : "[Ξεκίνησε χθες]",
    "[Started on] LL" : "[Ξεκίνησε] LL",
    "[Started today at] LT" : "[Ξεκίνησε σήμερα στις] LT",
    "[Starts today at] LT" : "[Ξεκινά σήμερα στις] LT",
    "[Starts tomorrow at] LT" : "[Ξεκινά αύριο στις] LT",
    "[Starts on] LL [at] LT" : "[Ξεκινά] LL [στις] LT",
    "[Started yesterday at] LT" : "[Ξεκίνησε χθες στις] LT",
    "[Started on] LL [at] LT" : "[Ξεκίνησε] LL [στις] LT",
    "Midnight on the day the task starts" : "Μεσάνυχτα την ημέρα που ξεκινά η εργασία",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n ημέρα πριν από την εργασία στις {formattedHourMinute}","%n ημέρες πριν από την εργασία στις {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n εβδομάδα πριν από την εργασία στις {formattedHourMinute}","%n εβδομάδες πριν από την εργασία στις {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "την ημέρα της εργασίας στις {formattedHourMinute}",
    "at the task's start" : "στην έναρξη της εργασίας",
    "when the task is due" : "όταν η εργασία λήγει",
    "{time} before the task starts" : "{time} πριν από την έναρξη της εργασίας",
    "{time} before the task is due" : "{time} πριν από τη λήξη της εργασίας",
    "{time} after the task starts" : "{time} μετά την έναρξη της εργασίας",
    "{time} after the task is due" : "{time} μετά τη λήξη της εργασίας"
},
"nplurals=2; plural=(n != 1);");
