OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Kommande uppgifter",
    "Important" : "Viktigt",
    "Today" : "Idag",
    "Week" : "Vecka",
    "All" : "Alla",
    "Current" : "Aktuella",
    "Completed" : "Slutförd",
    "Tasks" : "Uppgifter",
    "The Tasks app for Nextcloud" : "En uppgift-app för Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "När den är aktiverad visas en ny uppgiftsmeny i din Nextcloud-appmeny. Därifrån kan du lägga till och ta bort uppgifter, redigera deras titel, beskrivning, start- och förfallodatum och markera dem som viktiga. Uppgifter kan delas mellan användare. Uppgifter kan synkroniseras med CalDav (varje uppgiftslista är länkad till en Nextcloud-kalender för att synkronisera den med din lokala klient - Thunderbird, Evolution, KDE Kontact, iCal ... - lägg bara till kalendern som en fjärrkalender i din klient). Du kan hämta dina uppgifter som ICS-filer med hämtningsknappen för varje kalender.",
    "Hidden" : "Gömd",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Tasks settings" : "Uppgiftinställningar",
    "Default list" : "Standardlista",
    "Visibility of Smart Collections" : "Synlighet av smarta samlingar",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "Unable to delete the share." : "Kan inte ta bort delningen.",
    "Unable to change permissions." : "Kan inte ändra behörigheter.",
    "Can edit" : "Kan ändra",
    "Unshare with {displayName}" : "Sluta dela med {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Detta kommer att radera kalender \"{calendar}\" och alla dess händelser och uppgifter.",
    "This will unshare the calendar \"{calendar}\"." : "Detta kommer att avsluta delning av kalender \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Det här kommer att radera listan \"{list}\" och alla motsvarande uppgifter.",
    "This will unshare the list \"{list}\"." : "Det här kommer att ta bort delning av listan \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Raderar kalendern om {countdown} sekund","Raderar kalendern om {countdown} sekunder"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Slutar dela kalendern om {countdown} sekund","Slutar dela kalendern om {countdown} sekunder"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Raderar listan om {countdown} sekund","Raderar listan om {countdown} sekunder"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Slutar dela listan om {countdown} sekund","Slutar dela listan om {countdown} sekunder"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
    "Share this calendar" : "Dela denna kalender",
    "Share this list" : "Dela den här listan",
    "Calendar link copied to clipboard." : "Kalenderlänk kopierad till urklipp.",
    "List link copied to clipboard." : "Listlänk kopierad till urklipp.",
    "Calendar link could not be copied to clipboard." : "Kalenderlänk kunde inte kopieras till urklipp.",
    "List link could not be copied to clipboard." : "Listlänken kunde inte kopieras till urklipp.",
    "The name \"{calendar}\" is already used." : "Namnet \"{calendar}\" används redan.",
    "An empty name is not allowed." : "Ett tomt namn är inte tillåtet.",
    "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
    "An error occurred, unable to delete the list." : "Ett fel uppstod, det gick inte att ta bort listan.",
    "Edit" : "Ändra",
    "Copy private link" : "Kopiera privat länk",
    "Copied" : "Kopierad",
    "Cannot copy" : "Kan inte kopieria",
    "Export" : "Exportera",
    "Delete" : "Ta bort",
    "Unshare" : "Sluta dela",
    "List name" : "Namn på lista",
    "Untitled task" : "Namnlös uppgift",
    "Untitled event" : "Namnlös händelse",
    "Untitled journal" : "Namnlös journal",
    "Untitled item" : "Namnlöst objekt",
    "Unknown calendar" : "Okänd kalender",
    "Could not load deleted calendars and objects" : "Kunde inte ladda borttagna kalendrar och objekt",
    "Could not delete calendar or event" : "Det gick inte att ta bort kalender eller händelse",
    "Could not restore calendar or event" : "Kunde inte återställa kalender eller händelse",
    "Do you really want to empty the trash bin?" : "Vill du verkligen tömma papperskorgen?",
    "Empty trash bin" : "Töm papperskorgen",
    "Trash bin" : "Papperskorg",
    "Loading deleted calendars, tasks and events." : "Laddar raderade kalendrar, uppgifter och händelser.",
    "You do not have any deleted calendars, tasks or events." : "Du har inga borttagna kalendrar, uppgifter eller händelser.",
    "Name" : "Namn",
    "Deleted" : "Borttagen",
    "Restore" : "Återställ",
    "Delete permanently" : "Ta bort permanent",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Element i papperskorgen raderas efter {numDays} dag","Element i papperskorgen raderas efter {numDays} dagar"],
    "Create reminder" : "Skapa påminnelse",
    "Update reminder" : "Uppdatera påminnelse",
    "Set a reminder at a custom date and time:" : "Ställ in påminnelse vid anpassat datum och tid:",
    "Cancel" : "Avbryt",
    "This is a todo reminder." : "Detta är en påminnelse om att göra.",
    "No reminders" : "Inga påminnelser",
    "Notification" : "Notifiering",
    "Email" : "E-post",
    "Audio notification" : "Ljudmeddelande",
    "Other notification" : "Annan notifiering",
    "Edit time" : "Ändra tid",
    "Remove reminder" : "Ta bort påminnelse",
    "Add reminder" : "Lägg till påminnelse",
    "Before the task starts" : "Innan uppgiften börjar",
    "Before the task is due" : "Innan uppgiften är klar",
    "Select date and time" : "Välj datum och tid",
    "Go back" : "Gå tillbaks",
    "Do you want to keep related reminders?" : "Vill du behålla relaterade påminnelser?",
    "Discard reminders" : "Ta bort påminnelser",
    "Keep reminders" : "Behåll påminnelser",
    "Set a reminder relative to your tasks start date:" : "Ställ in en påminnelse i förhållande till dina uppgifters startdatum:",
    "Set a reminder relative to your tasks due date:" : "Ställ in en påminnelse i förhållande till dina uppgifters förfallodatum:",
    "before at" : "innan",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minuter"],
    "_hour_::_hours_" : ["timme","timmar"],
    "_day_::_days_" : ["dag","dagar"],
    "_week_::_weeks_" : ["vecka","veckor"],
    "Select a calendar" : "Välj en kalender",
    "No calendar matches the search." : "Ingen kalender matchar sökningen.",
    "Set date" : "Ange datum",
    "Set time" : "Ange tid",
    "Delete date" : "Ta bort datum",
    "Click here to add a note." : "Klicka här för att lägga till en anteckning.",
    "Set value" : "Ange ett värde",
    "Delete value" : "Ta bort värde",
    "Add this as a new tag" : "Lägg till som en ny tagg",
    "No tag available. Create one!" : "Ingen tagg tillgänglig. Skapa en!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} uppgifter har lagts till i \"{calendar}\"",
    "Create new tasks" : "Skapa nya uppgifter",
    "Create {numberOfTasks} tasks from pasted text" : "Skapa {numberOfTasks} uppgifter från inklistrad text",
    "Create tasks" : "Skapa uppgifter",
    "Creating new tasks…" : "Skapar nya uppgifter...",
    "Close" : "Stäng",
    "Delete all completed tasks." : "Ta bort alla slutförda uppgifter.",
    "Delete completed tasks." : "Ta bort slutförda uppgifter.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Ta bort alla slutförda uppgifter från kalender \"{calendar}\".",
    "No errors" : "Inga fel",
    "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Detta kommer att radera {taskCount} slutförd uppgift och dess underuppgifter från kalender \"{calendar}\".","Detta kommer att radera {taskCount} slutförda uppgifter och deras underuppgifter från kalender \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Kunde inte radera {failedCount} uppgift.","Kunde inte radera {failedCount} uppgifter."],
    "Active filter" : "Aktivt filter",
    "Filter by tags" : "Filtrera efter taggar",
    "Select tags to filter by" : "Välj taggar att filtrera efter",
    "Reset filter" : "Återställ filter",
    "Add an important task to \"{calendar}\"…" : "Lägg till en viktig uppgift till \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Lägg till en uppgift som förfaller idag i \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Lägg till en aktuell uppgift i \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Lägg till en uppgift i \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Hämta slutförda uppgifter för alla listor.",
    "Loading the completed tasks of all lists might slow down the app." : "Att ladda de slutförda uppgifterna i alla listor kan sakta ner appen.",
    "Load the completed tasks of list \"{calendar}\"." : "Ladda de slutförda uppgifterna i listan \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Att ladda de slutförda uppgifterna kan sakta ner appen.",
    "Relevance" : "Relevans",
    "Sort by completed state, due date, priority, start date and summary." : "Sortera efter slutförd status, förfallodag, prioritet, startdatum och sammanfattning.",
    "Start date" : "Startdatum",
    "Sort by start date, priority and summary." : "Sortera efter startdatum, prioritet och sammanfattning.",
    "Due date" : "Slutdatum",
    "Sort by due date, priority and summary." : "Sortera efter förfallodatum, prioritet och sammanfattning.",
    "Created date" : "Skapad datum",
    "Sort by created date, priority and summary." : "Sortera efter skapat datum, prioritet och sammanfattning.",
    "Last modified" : "Senast ändrad",
    "Sort by last-modified date, priority and summary." : "Sortera efter senaste ändringsdatum, prioritet och sammanfattning.",
    "Completed date" : "Slutförd datum",
    "Sort by completed date, priority and summary." : "Sortera efter slutfört datum, prioritet och sammanfattning.",
    "Priority" : "Prioritet",
    "Sort by priority and summary." : "Sortera efter prioritering och sammanfattning.",
    "Alphabetically" : "Alfabetisk",
    "Sort by summary and priority." : "Sortera efter sammanfattning och prioritering.",
    "Tags" : "Taggar",
    "Sort by tags." : "Sortera efter taggar.",
    "Manually" : "Manuellt",
    "Sort by manual order." : "Sortera efter manuell ordning.",
    "Change sort order" : "Ändra sorteringsordning",
    "[Yesterday]" : "[Igår]",
    "[Today]" : "[Idag]",
    "[Tomorrow]" : "[Imorgon]",
    "[Completed yesterday]" : "[Slutförd igår]",
    "[Completed today]" : "[Slutförd idag]",
    "[Completed tomorrow]" : "[Slutförd imorgon]",
    "[Yesterday at] LT" : "[Igår kl] LT",
    "[Today at] LT" : "[Idag kl] LT",
    "[Tomorrow at] LT" : "[Imorgon kl] LT",
    "L [at] LT" : "L [kl] LT",
    "[Completed yesterday at] LT" : "[Slutförd igår] LT",
    "[Completed today at] LT" : "[Slutförd idag] LT",
    "[Completed tomorrow at] LT" : "[Slutförd imorgon] LT",
    "[Completed] L [at] LT" : "[Slutförd] L [kl] LT",
    "Add a subtask to \"{task}\"…" : "Lägg till en underuppgift till \"{task}\"…",
    "Task has hidden subtasks" : "Uppgiften har dolda underuppgifter",
    "Task is pinned" : "Uppgiften är fäst",
    "Task has a note" : "Uppgiften har en anteckning",
    "{complete} % completed" : "{complete} % slutfört",
    "Add subtask" : "Lägg till underuppgift",
    "Show subtasks" : "Visa underuppgifter",
    "Hide subtasks" : "Dölj underuppgifter",
    "Show closed subtasks" : "Visa stängda underuppgifter",
    "Hide closed subtasks" : "Göm stängda underuppgifter",
    "Delete task" : "Ta bort uppgift",
    "Toggle starred" : "Växla stjärnmärkt",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Uppgiften har en påminnelse","Uppgiften har {n} påminnelser"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Raderar uppgiften om {countdown} sekund","Raderar uppgiften om {countdown} sekunder"],
    "Task is cancelled" : "Uppgiften är avbruten",
    "Task is completed" : "Uppgiften är slutförd",
    "Task is read-only" : "Uppgiften är skrivskyddad",
    "Task is not completed" : "Uppgiften är inte slutförd",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" lades till i \"{calendar}\"",
    "Create a new task" : "Skapa ny uppgift",
    "Task summary" : "Sammanfattning av uppgift",
    "Create task" : "Skapa uppgift",
    "Creating the new task…" : "Skapar den nya uppgiften...",
    "Open task" : "Öppna uppgift",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n slutförda uppgifter","%n slutförda uppgifter"],
    "Tomorrow" : "Imorgon",
    "An error occurred, unable to create the list." : "Ett fel uppstod, det gick inte att skapa listan.",
    "Add List…" : "Lägg till lista...",
    "New list" : "Ny lista",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "[Completed] L" : "[Slutförd] L",
    "[Completed last] dddd [at] LT" : "[Slutförd senast] dddd [kl] LT",
    "[Completed] dddd [at] LT" : "[Sluförd] dddd [kl] LT",
    "[Last modified yesterday at] LT" : "[Senast ändrad igår kl] LT",
    "[Last modified today at] LT" : "[Senast ändrad idag kl] LT",
    "[Last modified] L" : "[Senast ändrad] L",
    "[Last modified last] dddd [at] LT" : "[Senast ändrad] dddd [kl] LT",
    "[Last modified] dddd [at] LT" : "[Senast ändrad] dddd [kl] LT",
    "[Created yesterday at] LT" : "[Skapades igår kl] LT",
    "[Created today at] LT" : "[Skapades idag kl] LT",
    "[Created] L" : "[Skapad] L",
    "[Created last] dddd [at] LT" : "[Skapad senast] dddd [kl] LT",
    "[Created] dddd [at] LT" : "[Skapad] dddd [kl] LT",
    "Needs action" : "Behöver handling",
    "In process" : "Pågående",
    "Canceled" : "Avbruten",
    "Clear status" : "Rensa status",
    "Loading task from server." : "Läser in uppgiften från servern.",
    "Task not found!" : "Uppgift hittades inte!",
    "Set start date" : "Sätt startdatum",
    "Set due date" : "Sätt slutdatum",
    "Priority {priority}: low" : "Prioritet {priority}: låg",
    "Priority {priority}: medium" : "Prioritet {priority}: medium",
    "Priority {priority}: high" : "Prioritet {priority}: hög",
    "No priority assigned" : "Ingen prioritet tilldelad",
    "{percent} % completed" : "{percent} % slutfört",
    "All day" : "Hela dagen",
    "Unpin" : "Lossa",
    "Pin" : "Fäst",
    "Show in Calendar" : "Visa i kalender",
    "Show in Deck" : "Visa i Deck",
    "Edit summary" : "Redigera sammanfattning",
    "Details" : "Detaljer",
    "Selecting a classification is forbidden, because the task was shared with you." : "Det är förbjudet att välja en klassificering eftersom uppgiften delades med dig.",
    "Select a classification" : "Välj en klassificering",
    "Select a status" : "Välj en status",
    "Set a location" : "Ange en plats",
    "Set a URL" : "Ange en URL",
    "Select tags" : "Välj taggar",
    "Notes" : "Anteckning",
    "Mark as done" : "Markera som klar",
    "No due date assigned" : "Inget förfallodatum tilldelat",
    "[Due yesterday]" : "[Förföll igår]",
    "[Due today]" : "[Förfaller idag]",
    "[Due tomorrow]" : "[Förfaller imorgon]",
    "[Due] L" : "[Förfaller] L",
    "[Due yesterday at] LT" : "[Förföll igår kl] LT",
    "[Due today at] LT" : "[Förfaller idag kl] LT",
    "[Due tomorrow at] LT" : "[Förfaller imorgon kl] LT",
    "[Due] L [at] LT" : "[Förfaller] L [kl] LT",
    "No upcoming tasks" : "Inga kommande uppgifter",
    "upcoming tasks" : "kommande uppgifter",
    "No tasks today" : "Inga uppgifter idag",
    "Completion date must be in the past." : "Slutdatum måste vara i det förflutna.",
    "Successfully created the task." : "Uppgiften skapad.",
    "Could not delete the task." : "Kunde inte radera uppgiften.",
    "Synchronizing to the server." : "Synkroniserar till servern.",
    "Task successfully saved to server." : "Uppgiften sparades i servern.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Det gick inte att uppdatera uppgiften eftersom den ändrades på servern. Klicka för att uppdatera, lokala ändringar kommer att ignoreras.",
    "Could not update the task." : "Kunde inte uppdatera uppgiften.",
    "Successfully updated the task." : "Uppgiften uppdaterad.",
    "Task successfully moved to new calendar." : "Uppgiften flyttad till en ny kalender.",
    "An error occurred" : "Ett fel uppstod",
    "Create a task" : "Skapa en uppgift",
    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}",
    "[Due on] LL" : "[Förfaller på] LL",
    "[Was due yesterday]" : "[Förföll igår]",
    "[Was due on] LL" : "[Förföll] LL",
    "[Was due today at] LT" : "[Förföll idag kl] LT",
    "[Due on] LL [at] LT" : "[Förfaller på] LL [kl] LT",
    "[Was due yesterday at] LT" : "[Förföll igår kl] LT",
    "[Was due on] LL [at] LT" : "[Förföll] LL [kl] LT",
    "[Starts today]" : "[Startar idag]",
    "[Starts tomorrow]" : "[Startar imorgon]",
    "[Starts on] LL" : "[Startar kl] LL",
    "[Started yesterday]" : "[Startade igår]",
    "[Started on] LL" : "[Startade kl] LL",
    "[Started today at] LT" : "[Startade idag kl] LT",
    "[Starts today at] LT" : "[Startar idag kl] LT",
    "[Starts tomorrow at] LT" : "[Startar imorgon kl] LT",
    "[Starts on] LL [at] LT" : "[Startar på] LL [kl] LT",
    "[Started yesterday at] LT" : "[Startade igår kl] LT",
    "[Started on] LL [at] LT" : "[Startade på] LL [kl] LT",
    "Midnight on the day the task starts" : "Midnatt samma dag som uppgiften börjar",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n dag innan uppgiften kl {formattedHourMinute}","%n dagar innan uppgiften kl {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n vecka innan uppgiften kl {formattedHourMinute}","%n veckor innan uppgiften kl {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "på dagen för uppgiften kl {formattedHourMinute}",
    "at the task's start" : "vid uppgiftens start",
    "when the task is due" : "när uppgiften är klar",
    "{time} before the task starts" : "{time} innan uppgiften startar",
    "{time} before the task is due" : "{time} innan uppgiften är klar",
    "{time} after the task starts" : "{time} efter att uppgiften startar",
    "{time} after the task is due" : "{time} efter att uppgiften är klar"
},
"nplurals=2; plural=(n != 1);");
