OC.L10N.register(
    "tasks",
    {
    "Important" : "Viktig",
    "Today" : "I dag",
    "Week" : "Veke",
    "All" : "Alle",
    "Current" : "Gjeldande",
    "Completed" : "Fullført",
    "Tasks" : "Oppgåver",
    "Can edit" : "Can edit",
    "Edit" : "Endra",
    "Export" : "Eksporter",
    "Delete" : "Slett",
    "Unshare" : "Fjern deling",
    "Empty trash bin" : "Tøm søppel korg",
    "Name" : "Namn",
    "Deleted" : "Sletta",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett for godt",
    "Cancel" : "Avbryt",
    "Email" : "Epost",
    "Close" : "Lukk",
    "Last modified" : "Siste endra",
    "Tags" : "Emneord",
    "When shared show full event" : "Når delt, vis heile hendinga",
    "When shared show only busy" : "Når delt, vis berre oppteken",
    "When shared hide this event" : "Når delt, gøym denne hendinga",
    "Details" : "Detaljar",
    "Notes" : "Notat",
    "An error occurred" : "Det oppstod ein feil"
},
"nplurals=2; plural=(n != 1);");
