OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Предстојећи задаци",
    "Important" : "Важно",
    "Today" : "Данас",
    "Week" : "Недеља",
    "All" : "Све",
    "Current" : "Текуће",
    "Completed" : "Завршено",
    "Tasks" : "Задаци",
    "The Tasks app for Nextcloud" : "Некстклауд апликација за задатке",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Када се укључи, у менију Nextcloud апликација ће се појавити нови мени Задаци. Из њега можете да додајете и бришете задатке, уређујете њихов назив, опис, времена почетка и крајњег рока и да их означавате као важне. Корисници могу да деле задатке међусобно. Задаци могу да се синхронизују употребом CalDav (свака листа задатака је везана за Nextcloud календар, да бисте је синхронизовали на ваш локални клијент: Thunderbird, Evolution, KDE Kontact, iCal … - једноставно додајте календар у свој клијент као удаљени календар). Своје задатке можете да преузимате као ICS фајлове користећи дугме за преузимање за сваки календар.",
    "Hidden" : "Сакривен",
    "Visible" : "Видљив",
    "Automatic" : "Аутоматски",
    "Tasks settings" : "Поставке Задатака",
    "Default list" : "Подразумевани списак",
    "Visibility of Smart Collections" : "Видљивост паметних збирки",
    "Share with users or groups" : "Дели са корисницима или групама",
    "No users or groups" : "Нема корисника или група",
    "Unable to delete the share." : "Не могу да обришем дељење.",
    "Unable to change permissions." : "Не могу да променим привилегије.",
    "Can edit" : "Може да уређује",
    "Unshare with {displayName}" : "Уклони дељење са {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Ово ће обрисати календар „{calendar}“ и све догађаје и задатке из њега.",
    "This will unshare the calendar \"{calendar}\"." : "Овим ћете уклонити дељење календара „{calendar}”",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Ово ће обрисати списак „{list}“ и све задатке из њега.",
    "This will unshare the list \"{list}\"." : "Овим ћете уклонити дељење списка „{list}”.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Бришем календар за {countdown} секунду","Бришем календар за {countdown} секунде","Бришем календар за {countdown} секунди"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Уклањам дељење календара за {countdown} секунду","Уклањам дељење календара за {countdown} секунде","Уклањам дељење календара за {countdown} секунди"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Брисање списка за {countdown} секунду","Брисање списка за {countdown} секунде","Брисање списка за {countdown} секунди"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Уклањем дељење списка за {countdown} секунду","Уклањем дељење списка за {countdown} секунде","Уклањем дељење списка за {countdown} секунди"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Дељено са {num} ентитетом","Дељено са {num} ентитета","Дељено са {num} ентитета"],
    "Share this calendar" : "Дели овај календар",
    "Share this list" : "Дели ову листу",
    "Calendar link copied to clipboard." : "Веза календара копирана у оставу.",
    "List link copied to clipboard." : "Веза ка списку копирана у оставу.",
    "Calendar link could not be copied to clipboard." : "Веза календара није могла да се копира у оставу.",
    "List link could not be copied to clipboard." : "Веза ка списку није могла бити копирана у оставу.",
    "The name \"{calendar}\" is already used." : "Име календара „{calendar}“ се већ користи.",
    "An empty name is not allowed." : "Празан назив није дозвољен.",
    "An error occurred, unable to delete the calendar." : "Догодила се грешка, не могу да обришем календар.",
    "An error occurred, unable to delete the list." : "Догодила се грешка, не могу да обришем списак.",
    "Edit" : "Уреди",
    "Copy private link" : "Копирај приватну везу",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Export" : "Извези",
    "Delete" : "Обриши",
    "Unshare" : "Укини дељење",
    "List name" : "Назив листе",
    "Untitled task" : "Неименовани задатак",
    "Untitled event" : "Неименовани догађај",
    "Untitled journal" : "Неименовани журнал",
    "Untitled item" : "Неименована ставка",
    "Unknown calendar" : "Непознати календар",
    "Could not load deleted calendars and objects" : "Обрисани календари и објекти не могу да се учитају.",
    "Could not delete calendar or event" : "Календар или догађај није могао да се обрише",
    "Could not restore calendar or event" : "Календар или догађај није могао да се обнови",
    "Do you really want to empty the trash bin?" : "Да ли заиста желите да испразните корпу за отпатке?",
    "Empty trash bin" : "Испразни корпу за отпатке",
    "Trash bin" : "Корпа за отпатке",
    "Loading deleted calendars, tasks and events." : "Учитавање обрисаних календара, задатака и догађаја.",
    "You do not have any deleted calendars, tasks or events." : "Немате ниједан обрисани календар, задатке или догађаје.",
    "Name" : "Име",
    "Deleted" : "Обрисано",
    "Restore" : "Врати",
    "Delete permanently" : "Обриши заувек",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Елементи у корпи за отпатке се бришу након {numDays} дана","Елементи у корпи за отпатке се бришу након {numDays} дана","Елементи у корпи за отпатке се бришу након {numDays} дана"],
    "Create reminder" : "Креирај подсетник",
    "Update reminder" : "Ажурирај подсетник",
    "Set a reminder at a custom date and time:" : "Постави подсетник на произвољни датум и време:",
    "Cancel" : "Откажи",
    "This is a todo reminder." : "Ово је подсетник за обавезу.",
    "No reminders" : "Нема подсетника",
    "Notification" : "Обавештење",
    "Email" : "Е-пошта",
    "Audio notification" : "Звучно обавештење",
    "Other notification" : "Друго обавештење",
    "Edit time" : "Уреди време",
    "Remove reminder" : "Уклони подсетник",
    "Add reminder" : "Додавање подсетника",
    "Before the task starts" : "Пре почетка задатка",
    "Before the task is due" : "Пре него што задатак треба да буде завршен",
    "Select date and time" : "Изаберите датум и време",
    "Go back" : "Иди назад",
    "Do you want to keep related reminders?" : "Желите ли да задржите одговарајуће подсетнике?",
    "Discard reminders" : "Одбаци подсетнике",
    "Keep reminders" : "Задржи подсетнике",
    "Set a reminder relative to your tasks start date:" : "Поставите подсетник релативно у односу датум почетка задатка:",
    "Set a reminder relative to your tasks due date:" : "Поставите подсетник релативно у односу датум када задатак треба да се заврши:",
    "before at" : "раније у",
    "_second_::_seconds_" : ["секунда","секунде","секунди"],
    "_minute_::_minutes_" : ["минут","минута","минута"],
    "_hour_::_hours_" : ["сат","сата","сати"],
    "_day_::_days_" : ["дан","дана","дана"],
    "_week_::_weeks_" : ["седмица","седмице","седмица"],
    "Select a calendar" : "Одаберите календар",
    "No calendar matches the search." : "Ни један календар не одговара условима претраге.",
    "Set date" : "Постави датум",
    "Set time" : "Постави време",
    "Delete date" : "Обриши датум",
    "Click here to add a note." : "Кликните овде да додате напомену.",
    "Set value" : "Постави вредност",
    "Delete value" : "Обриши вредност",
    "Add this as a new tag" : "Додај ово као нову ознаку",
    "No tag available. Create one!" : "Није доступна ниједна ознака. Креира се!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} задатака је додато у „{calendar}”",
    "Create new tasks" : "Креирај нове задатке",
    "Create {numberOfTasks} tasks from pasted text" : "Креирај {numberOfTasks} задатака од налепљеног текста",
    "Create tasks" : "Креирај задатке",
    "Creating new tasks…" : "Креирање нових задатака…",
    "Close" : "Затвори",
    "Delete all completed tasks." : "Обриши све завршене задатке.",
    "Delete completed tasks." : "Обриши завршене задатке.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Обриши све завршене задатке из календара „{calendar}“.",
    "No errors" : "Нема грешака",
    "Open your browser console for more details" : "Отворите конзолу веб читача за више детаља",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Ово ће обрисати {taskCount} завршени задатак и све његове подзадатке из календара „{calendar}“.","Ово ће обрисати {taskCount} завршена задатка и све њихове подзадатке из календара „{calendar}“.","Ово ће обрисати {taskCount} завршених задатака и све њихове подзадатке из календара „{calendar}“."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Нисам могао да обришем {failedCount} задатак.","Нисам могао да обришем {failedCount} задатка.","Нисам могао да обришем {failedCount} задатака."],
    "Active filter" : "Активни филтер",
    "Filter by tags" : "Филтрирај по ознакама",
    "Select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
    "Reset filter" : "Ресетуј филтер",
    "Add an important task to \"{calendar}\"…" : "Додај важан задатак на календар „{calendar}“…",
    "Add a task due today to \"{calendar}\"…" : "Додај задатак са роком за данас на календар „{calendar}“…",
    "Add a current task to \"{calendar}\"…" : "Додај тренутни задатак на календар „{calendar}“…",
    "Add a task to \"{calendar}\"…" : "Додај задатак на календар „{calendar}“…",
    "Load the completed tasks of all lists." : "Учитај завршене задатке за све листе.",
    "Loading the completed tasks of all lists might slow down the app." : "Учитавање завршених задатака свих листи може да успори апликацију.",
    "Load the completed tasks of list \"{calendar}\"." : "Учитај све завршене задатке листе „{calendar}”.",
    "Loading the completed tasks might slow down the app." : "Учитавање завршених задатака може да успори апликацију.",
    "Relevance" : "Релевантност",
    "Sort by completed state, due date, priority, start date and summary." : "Сортирај по стању завршетка, року, приоритету, датуму почетка и опису.",
    "Start date" : "Датум почетка",
    "Sort by start date, priority and summary." : "Поређај по датуму почетка, приоритету и сажетку.",
    "Due date" : "Рок",
    "Sort by due date, priority and summary." : "Поређај по крајњем року, приоритету и сажетку.",
    "Created date" : "Датум креирања",
    "Sort by created date, priority and summary." : "Поређај по датуму креирања, приоритету и сажетку.",
    "Last modified" : "Последње измењено",
    "Sort by last-modified date, priority and summary." : "Поређај по датуму последње измене, приоритету и сажетку.",
    "Completed date" : "Датум завршетка",
    "Sort by completed date, priority and summary." : "Поређај по датуму завршетка, приоритету и сажетку.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Сортирај по приоритету и опису.",
    "Alphabetically" : "Азбучно",
    "Sort by summary and priority." : "Сортирај по опису и приоритету.",
    "Tags" : "Ознаке",
    "Sort by tags." : "Поређај по ознакама.",
    "Manually" : "Ручно",
    "Sort by manual order." : "Сортирај ручно.",
    "Change sort order" : "Промени сортирање",
    "[Yesterday]" : "[Јуче]",
    "[Today]" : "[Данас]",
    "[Tomorrow]" : "[Сутра]",
    "[Completed yesterday]" : "[Завршено јуче]",
    "[Completed today]" : "[Завршено данас]",
    "[Completed tomorrow]" : "[Завршено сутра]",
    "[Yesterday at] LT" : "[Јуче у] LT",
    "[Today at] LT" : "[Данас у] LT",
    "[Tomorrow at] LT" : "[Сутра у] LT",
    "L [at] LT" : "L [у] LT",
    "[Completed yesterday at] LT" : "[Завршено јуче у] LT",
    "[Completed today at] LT" : "[Завршено данас у] LT",
    "[Completed tomorrow at] LT" : "[Завршено сутра у] LT",
    "[Completed] L [at] LT" : "[Завршено] L [у] LT",
    "Add a subtask to \"{task}\"…" : "Додај подзадатак на задатак „{task}“…",
    "Task has hidden subtasks" : "Задатак има скривене подзадатке",
    "Task is pinned" : "Задатак је прикачен",
    "Task has a note" : "Задатак има напомену",
    "{complete} % completed" : "{complete} % завршено",
    "Add subtask" : "Додај подзадатак",
    "Show subtasks" : "Прикажи подзадатке",
    "Hide subtasks" : "Сакриј подзадатке",
    "Show closed subtasks" : "Прикажи затворене задатке",
    "Hide closed subtasks" : "Сакриј затворене подзадатке",
    "Delete task" : "Обриши задатак",
    "Toggle starred" : "Укљ./Искљ. звездицу",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Задатак има један подсетник","Задатак има {n} подсетника","Задатак има {n} подсетника"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Бришем задатак за {countdown} секунду","Бришем задатак за {countdown} секунде","Бришем задатак за {countdown} секунди"],
    "Task is cancelled" : "Задатак је отказан",
    "Task is completed" : "Задатак завршен",
    "Task is read-only" : "Задатак је само-за-читање",
    "Task is not completed" : "Задатак није завршен",
    "\"{task}\" was added to \"{calendar}\"" : "„{task}” је додат у „{calendar}”",
    "Create a new task" : "Креирај нови задатак",
    "Task summary" : "Сажетак задатка",
    "Create task" : "Креирај задатак",
    "Creating the new task…" : "Креира се нови задатак...",
    "Open task" : "Отвори задатак",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завршен задатак","%n завршена задатка","%n завршених задатака"],
    "Tomorrow" : "сутра",
    "An error occurred, unable to create the list." : "Дошло је до грешке, не може да се креира листа.",
    "Add List…" : "Додај листу…",
    "New list" : "Нова листа",
    "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
    "When shared show only busy" : "Прикажи само да сте заузети када је догађај дељен",
    "When shared hide this event" : "Сакриј догађај када је догађај дељен",
    "[Completed] L" : "[Завршен] L",
    "[Completed last] dddd [at] LT" : "[Завршен дана] dddd [у] LT",
    "[Completed] dddd [at] LT" : "[Завршен] dddd [у] LT",
    "[Last modified yesterday at] LT" : "[Последњи пут измењен јуче у] LT",
    "[Last modified today at] LT" : "[Последњи пут измењен данас у] LT",
    "[Last modified] L" : "[Последњи пут измењен] L",
    "[Last modified last] dddd [at] LT" : "[Последњи пут измењен прошле] dddd [у] LT",
    "[Last modified] dddd [at] LT" : "[Последњи пут промењен] dddd [у] LT",
    "[Created yesterday at] LT" : "[Креиран јуче у] LT",
    "[Created today at] LT" : "[Креиран данас у] LT",
    "[Created] L" : "[Креиран] L",
    "[Created last] dddd [at] LT" : "[Креиран у прошли] dddd [у] LT",
    "[Created] dddd [at] LT" : "[Креиран у] dddd [у] LT",
    "Needs action" : "Акција потребна",
    "In process" : "У процесу",
    "Canceled" : "Отказано",
    "Clear status" : "Обриши статус",
    "Loading task from server." : "Учитавам задатке са сервера.",
    "Task not found!" : "Задатак није пронађен!",
    "Set start date" : "Постави датум почетка",
    "Set due date" : "Постави датум рока",
    "Priority {priority}: low" : "Приоритет {priority}: мали",
    "Priority {priority}: medium" : "Приоритет {priority}: средњи",
    "Priority {priority}: high" : "Приоритет {priority}: висок",
    "No priority assigned" : "Нема додељеног приоритета",
    "{percent} % completed" : "{percent} % завршено",
    "All day" : "Цео дан",
    "Unpin" : "Откачи",
    "Pin" : "Закачи",
    "Show in Calendar" : "Прикажи у календару",
    "Show in Deck" : "Прикажи у Шпилу",
    "Edit summary" : "Уреди сажетак",
    "Details" : "Детаљи",
    "Selecting a classification is forbidden, because the task was shared with you." : "Одабир класификације је забрањен јер је задатак подељен са вама",
    "Select a classification" : "Одаберите класификацију",
    "Select a status" : "Одаберите статус",
    "Set a location" : "Постави локацију",
    "Set a URL" : "Постави URL",
    "Select tags" : "Одабери ознаку",
    "Notes" : "Белешке",
    "Mark as done" : "Означи као завршен",
    "No due date assigned" : "Није додељен крајњи рок",
    "[Due yesterday]" : "[Крајњи рок јуче]",
    "[Due today]" : "[Рок данас]",
    "[Due tomorrow]" : "[Рок сутра]",
    "[Due] L" : "[Крајњи рок] L",
    "[Due yesterday at] LT" : "[Крајњи рок јуче у] LT",
    "[Due today at] LT" : "[Рок до данас у] LT",
    "[Due tomorrow at] LT" : "[Рок сутра у] LT",
    "[Due] L [at] LT" : "[Крајњи рок] L [у] LT",
    "No upcoming tasks" : "Нема предстојећих задатака",
    "upcoming tasks" : "предстојећих задатака",
    "No tasks today" : "Данас нема задатака",
    "Completion date must be in the past." : "Датум довршетка мора да буде у прошлости.",
    "Successfully created the task." : "Задатак успешно избрисан.",
    "Could not delete the task." : "Не могу да обришем задатак.",
    "Synchronizing to the server." : "Синхронизујем са сервером.",
    "Task successfully saved to server." : "Задатак успешно сачуван на серверу.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не могу да ажурирам задатак пошто је промењен на серверу. Кликните да га освежите, а локалне измене ће бити одбачене.",
    "Could not update the task." : "Не могу да ажурирам задатак.",
    "Successfully updated the task." : "Задатак успешно ажуриран.",
    "Task successfully moved to new calendar." : "Задатак успешно померен у нови календар.",
    "An error occurred" : "Догодила се грешка",
    "Create a task" : "Креирај задатак",
    "Message from {author} in {conversationName}" : "Порука од {author} у {conversationName}",
    "[Due on] LL" : "[Рок до] LL",
    "[Was due yesterday]" : "[рок је био јуче]",
    "[Was due on] LL" : "[Рок био до] LL",
    "[Was due today at] LT" : "[Рок био данас у] LT",
    "[Due on] LL [at] LT" : "[Рок до] LL [у] LT",
    "[Was due yesterday at] LT" : "[Рок био јуче у] LT",
    "[Was due on] LL [at] LT" : "[Рок био] LL [у] LT",
    "[Starts today]" : "[Почиње данас]",
    "[Starts tomorrow]" : "[Почиње сутра]",
    "[Starts on] LL" : "[Почиње] LL",
    "[Started yesterday]" : "[Започет јуче]",
    "[Started on] LL" : "[Почео] LL",
    "[Started today at] LT" : "[Почео данас у] LT",
    "[Starts today at] LT" : "[Почиње данас у] LT",
    "[Starts tomorrow at] LT" : "[Почиње сутра у] LT",
    "[Starts on] LL [at] LT" : "[Почиње] LL [у] LT",
    "[Started yesterday at] LT" : "[Почео јуче у] LT",
    "[Started on] LL [at] LT" : "[Почео] LL [у] LT",
    "Midnight on the day the task starts" : "Поноћ на дан почетка задатка",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : [" %n дан пре задатка у {formattedHourMinute}"," %n дана пре задатка у {formattedHourMinute}","%n дана пре задатка у {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n недељу пре задатка у {formattedHourMinute}","%n недеље пре задатка у {formattedHourMinute}","%n недеља пре задатка у {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "на дан задатка у {formattedHourMinute}",
    "at the task's start" : "на почетку задатка",
    "when the task is due" : "када задатак треба да буде завршен",
    "{time} before the task starts" : "{time} пре почетка задатка",
    "{time} before the task is due" : "{time} пре него што задатак треба да буде завршен",
    "{time} after the task starts" : "{time} након почетка задатка",
    "{time} after the task is due" : "{time} након него што задатак треба да буде завршен"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
