OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Предстоящие задачи",
    "Important" : "Важно",
    "Today" : "Сегодня",
    "Week" : "На неделе",
    "All" : "Все",
    "Current" : "Текущие",
    "Completed" : "Завершённые",
    "Tasks" : "Задачи",
    "The Tasks app for Nextcloud" : "Приложение «Задачи» для Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "После включения в меню приложений Nextcloud появится новое меню «Задачи». В нём можно добавлять и удалять задачи, редактировать их название, описание, даты начала и выполнения, а также отмечать их как важные. Задачами можно делиться с другими пользователями. Задачи можно синхронизировать с помощью CalDav (каждый список задач связан с календарём Nextcloud, чтобы синхронизировать его с локальным клиентом: Thunderbird, Evolution, KDE Kontact, iCal... — просто добавьте календарь как удалённый календарь в вашем клиенте). Задачи можно загрузить в виде файлов ICS с помощью кнопки загрузки для каждого календаря.",
    "Hidden" : "Скрывать",
    "Visible" : "Показывать",
    "Automatic" : "Автоматически",
    "Tasks settings" : "Параметры задач",
    "Default list" : "Список по умолчанию:",
    "Visibility of Smart Collections" : "Настройка показа наборов задач:",
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "Unable to delete the share." : "Невозможно закрыть общий доступ.",
    "Unable to change permissions." : "Невозможно изменить права доступа.",
    "Can edit" : "Разрешено редактировать",
    "Unshare with {displayName}" : "Отменить общий доступ для {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Это действие удалит календарь «{calendar}» и все его события и задачи.",
    "This will unshare the calendar \"{calendar}\"." : "Это действие приведёт к закрытию общего доступа к календарю «{calendar}».",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Это действие удалит список «{list}» и все его задачи.",
    "This will unshare the list \"{list}\"." : "Это действие приведёт к закрытию общего доступа к списку «{list}».",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Календарь будет удалён через {countdown} секунду","Календарь будет удалён через {countdown} секунды","Календарь будет удалён через {countdown} секунд","Календарь будет удалён через {countdown} секунд"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Общий доступ к календарю будет закрыт через {countdown} секунду","Общий доступ к календарю будет закрыт через {countdown} секунды","Общий доступ к календарю будет закрыт через {countdown} секунд","Общий доступ к календарю будет закрыт через {countdown} секунд"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Список будет удалён через {countdown} секунду","Список будет удалён через {countdown} секунды","Список будет удалён через {countdown} секунд","Список будет удалён через {countdown} секунд"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Общий доступ к списку будет закрыт {countdown} секунду","Общий доступ к списку будет закрыт {countdown} секунды","Общий доступ к списку будет закрыт {countdown} секунд","Общий доступ к списку будет закрыт {countdown} секунд"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Общий доступ с {num} получателем","Общий доступ с {num} получателями","Общий доступ с {num} получателями","Общий доступ с {num} получателями"],
    "Share this calendar" : "Поделиться этим календарём",
    "Share this list" : "Опубликовать этот список",
    "Calendar link copied to clipboard." : "Ссылка на календарь скопирована в буфер обмена.",
    "List link copied to clipboard." : "Ссылка на список скопирована в буфер обмена.",
    "Calendar link could not be copied to clipboard." : "Не удалось скопировать ссылку на календарь в буфер обмена.",
    "List link could not be copied to clipboard." : "Ссылка на список не может быть скопирована в буфер обмена.",
    "The name \"{calendar}\" is already used." : "Название «{calendar}» уже используется.",
    "An empty name is not allowed." : "Пустые имена не допускаются.",
    "An error occurred, unable to delete the calendar." : "Произошла ошибка, не удалось удалить календарь.",
    "An error occurred, unable to delete the list." : "Произошла ошибка, невозможно удалить список.",
    "Edit" : "Редактировать",
    "Copy private link" : "Скопировать закрытую ссылку",
    "Copied" : "Скопировано",
    "Cannot copy" : "Не удалось скопировать",
    "Export" : "Экспорт",
    "Delete" : "Удалить",
    "Unshare" : "Закрыть доступ",
    "List name" : "Название списка",
    "Untitled task" : "Задача без названия",
    "Untitled event" : "Событие без названия",
    "Untitled journal" : "Журнал без названия",
    "Untitled item" : "Объект без названия",
    "Unknown calendar" : "Неизвестный календарь",
    "Could not load deleted calendars and objects" : "Не удалось загрузить удалённые календари и объекты",
    "Could not delete calendar or event" : "Не удалось удалить календарь или событие",
    "Could not restore calendar or event" : "Не удалось восстановить календарь или событие",
    "Do you really want to empty the trash bin?" : "Подтвердите очистку корзины.",
    "Empty trash bin" : "Очистить корзину",
    "Trash bin" : "Корзина",
    "Loading deleted calendars, tasks and events." : "Загрузка удалённых календарей, задач и событий.",
    "You do not have any deleted calendars, tasks or events." : "У вас нет удалённых календарей, задач или событий.",
    "Name" : "Название",
    "Deleted" : "Удалено",
    "Restore" : "Восстановить",
    "Delete permanently" : "Удалить безвозвратно",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Объекты в корзине будут удалены через {numDays} день","Объекты в корзине будут удалены через {numDays} дня","Объекты в корзине будут удалены через {numDays} дней","Объекты в корзине будут удалены через {numDays} дня"],
    "Create reminder" : "Создать напоминание",
    "Update reminder" : "Обновить напоминание",
    "Set a reminder at a custom date and time:" : "Установить напоминание на настраиваемую дату и время:",
    "Cancel" : "Отмена",
    "This is a todo reminder." : " Это напоминание о задаче.",
    "No reminders" : "Напоминаний нет",
    "Notification" : "Уведомление",
    "Email" : "Электронная почта",
    "Audio notification" : "Звуковое уведомление",
    "Other notification" : "Другое уведомление",
    "Edit time" : "Редактировать время",
    "Remove reminder" : "Удалить напоминание",
    "Add reminder" : "Добавить напоминание",
    "Before the task starts" : "До начала задачи",
    "Before the task is due" : "До срока выполнения задачи",
    "Select date and time" : "Выберите дату и время",
    "Go back" : "Назад",
    "Set a reminder relative to your tasks start date:" : "Установите напоминание относительно даты начала вашей задачи:",
    "Set a reminder relative to your tasks due date:" : " Установите напоминание относительно срока выполнения вашей задачи:",
    "before at" : "ранее в",
    "_second_::_seconds_" : ["секунда","секунды","секунд","секунд"],
    "_minute_::_minutes_" : ["минута","минуты","минут","минут"],
    "_hour_::_hours_" : ["час","часа","часов","часов"],
    "_day_::_days_" : ["день","дня","дней","дней"],
    "_week_::_weeks_" : ["неделя","недели","недель","недель"],
    "Select a calendar" : "Выбрать календарь",
    "No calendar matches the search." : "Ни один календарь не соответствует критерию поиска.",
    "Set date" : "Задать дату",
    "Set time" : "Задать время",
    "Delete date" : "Удалить дату",
    "Click here to add a note." : "Нажмите здесь, чтобы добавить примечание.",
    "Set value" : "Установить значение",
    "Delete value" : "Удалить значение",
    "Add this as a new tag" : "Добавить как новую метку",
    "No tag available. Create one!" : "Пока нет ни одной метки, создайте первую.",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "Задачи: {numberOfTasks} добавлены в \"{calendar}\"",
    "Create new tasks" : "Создать новые задачи",
    "Create {numberOfTasks} tasks from pasted text" : "Создать задачи ({numberOfTasks}) из вставленного текста",
    "Create tasks" : "Создать задачи",
    "Creating new tasks…" : "Создание новых задач…",
    "Close" : "Закрыть",
    "Delete all completed tasks." : "Удалить все завершённые задачи",
    "Delete completed tasks." : "Удалить все завершённые задачи",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Из календаря {calendar} удалены все завершённые задачи.",
    "No errors" : "Выполнено без ошибок.",
    "Open your browser console for more details" : "Подробные сведения приведены в консоли браузера",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Это действие приведёт к удалению {taskCount} завершённой задачи и её подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}».","Это действие приведёт к удалению {taskCount} завершённых задач и их подзадач из календаря «{calendar}»."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Не удалось удалить {failedCount} задачу.","Не удалось удалить {failedCount} задач.","Не удалось удалить {failedCount} задач.","Не удалось удалить {failedCount} задач."],
    "Active filter" : "Активный фильтр",
    "Filter by tags" : "Фильтровать по меткам",
    "Select tags to filter by" : "Выберите метки для отбора",
    "Reset filter" : "Сбросить фильтр",
    "Add an important task to \"{calendar}\"…" : "Добавить в «{calentar}» важную задачу…",
    "Add a task due today to \"{calendar}\"…" : "Добавить в «{calendar}» задачу на сегодня… ",
    "Add a current task to \"{calendar}\"…" : "Добавить в «{calendar}» текущую задачу…",
    "Add a task to \"{calendar}\"…" : "Создать задачу в календаре «{calendar}»…",
    "Load the completed tasks of all lists." : "Загрузить выполненные задачи из всех списков.",
    "Loading the completed tasks of all lists might slow down the app." : "Загрузка выполненных задач из всех списков может замедлить работу приложения.",
    "Load the completed tasks of list \"{calendar}\"." : "Загрузить выполненные задачи из списка \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Загрузка выполненных задач может замедлить работу приложения.",
    "Relevance" : "Актуальность",
    "Sort by completed state, due date, priority, start date and summary." : "Сортировка по состоянию, дате окончания, приоритету, дате начала и описанию.",
    "Start date" : "Дата начала",
    "Sort by start date, priority and summary." : "Сортировка по дате начала, приоритету и сводке.",
    "Due date" : "Дата исполнения",
    "Sort by due date, priority and summary." : "Сортировка по дате выполнения, приоритету и сводке.",
    "Created date" : "Дата создания",
    "Sort by created date, priority and summary." : "Сортировка по дате создания, приоритету и сводке.",
    "Last modified" : "Последнее изменение",
    "Sort by last-modified date, priority and summary." : "Сортировка по дате последнего изменения, приоритету и сводке.",
    "Completed date" : "Дата выполнения",
    "Sort by completed date, priority and summary." : "Сортировка по дате завершения, приоритету и сводке.",
    "Priority" : "Приоритет",
    "Sort by priority and summary." : "Сортировка по приоритету и описанию.",
    "Alphabetically" : "По алфавиту",
    "Sort by summary and priority." : "Сортировка по описанию и приоритету.",
    "Tags" : "Метки",
    "Sort by tags." : "Сортировка по меткам.",
    "Manually" : "Вручную",
    "Sort by manual order." : "Сортировка вручную.",
    "Change sort order" : "Изменение порядка сортировки.",
    "[Yesterday]" : "[Вчера]",
    "[Today]" : "[Сегодня]",
    "[Tomorrow]" : "[Завтра]",
    "[Completed yesterday]" : "[Завершено вчера]",
    "[Completed today]" : "[Завершено сегодня]",
    "[Completed tomorrow]" : "[Завершено завтра]",
    "[Yesterday at] LT" : "[Вчера в] LT",
    "[Today at] LT" : "[Сегодня в] LT",
    "[Tomorrow at] LT" : "[Завтра в] LT",
    "L [at] LT" : "L [в] LT",
    "[Completed yesterday at] LT" : "[Завершено вчера в] LT",
    "[Completed today at] LT" : "[Завершено сегодня в] LT",
    "[Completed tomorrow at] LT" : "[Завершено завтра в] LT",
    "[Completed] L [at] LT" : "[Завершено] L [в] LT",
    "Add a subtask to \"{task}\"…" : "Добавить вложенную задачу в «{task}»…",
    "Task has hidden subtasks" : "Задача содержит скрытые подзадачи",
    "Task is pinned" : "Задача закреплена",
    "Task has a note" : "Задача содержит примечание",
    "{complete} % completed" : "Выполнено {complete}%",
    "Add subtask" : "Добавить вложенную задачу",
    "Show subtasks" : "Показать вложенные задачи",
    "Hide subtasks" : "Скрыть вложенные задачи",
    "Show closed subtasks" : "Показать закрытые подзадачи",
    "Hide closed subtasks" : "Скрыть закрытые подзадачи",
    "Delete task" : "Удалить задачу",
    "Toggle starred" : "Добавить или убрать отметку",
    "_Task has one reminder_::_Task has {n} reminders_" : ["У задачи одно напоминание","У задачи {n} напоминания","У задачи {n} напоминаний","У задачи установлено  {n} напоминаний"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Задача будет удалена через {countdown} секунду","Задача будет удалена через {countdown} секунды","Задача будет удалена через {countdown} секунд","Задача будет удалена через {countdown} секунды"],
    "Task is cancelled" : "Задача отменена",
    "Task is completed" : "Задача завершена",
    "Task is read-only" : "Задача доступна только для чтения",
    "Task is not completed" : "Задача не завершена",
    "\"{task}\" was added to \"{calendar}\"" : "Задача «{task}» добавлена в календарь «{calendar}»",
    "Create a new task" : "Создать задачу",
    "Task summary" : "Сводные данные",
    "Create task" : "Создать задачу",
    "Creating the new task…" : "Создание задачи…",
    "Open task" : "Открыть задачу",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершённая задача","%n завершённых задачи","%n завершённых задач","%n завершённых задач"],
    "Tomorrow" : "Завтра",
    "An error occurred, unable to create the list." : "Произошла ошибка, не удалось создать список.",
    "Add List…" : "Добавить список…",
    "New list" : "Новый список",
    "When shared show full event" : "Показывать подробно при размещении в общем доступе",
    "When shared show only busy" : "Показывать только занятость при размещении в общем доступе",
    "When shared hide this event" : "Скрыть это событие при размещении в общем доступе",
    "[Completed] L" : "[Завершено] L",
    "[Completed last] dddd [at] LT" : "[Completed last] дддд [at] местному времени",
    "[Completed] dddd [at] LT" : "[Завершено] dddd [в] LT",
    "[Last modified yesterday at] LT" : "[Последнее изменение вчера в] LT",
    "[Last modified today at] LT" : "[Последнее изменение сегодня в] LT",
    "[Last modified] L" : "[Последнее изменение] L",
    "[Last modified last] dddd [at] LT" : "[Last modified last] дддд [at] местному времени",
    "[Last modified] dddd [at] LT" : "[Последнее изменение] dddd [в] LT",
    "[Created yesterday at] LT" : "[Создано вчера в] LT",
    "[Created today at] LT" : "[Создано вчера в] LT",
    "[Created] L" : "[Создано] L",
    "[Created last] dddd [at] LT" : "[Дата создания: прошедший ] dddd [в] LT",
    "[Created] dddd [at] LT" : "[Создано] dddd [в] LT",
    "Needs action" : "Требуется действие",
    "In process" : "Выполянется",
    "Canceled" : "Отменено",
    "Clear status" : "Удалить статус",
    "Loading task from server." : "Получение с сервера списка задач.",
    "Task not found!" : "Задача не найдена",
    "Set start date" : "Задать дату начала",
    "Set due date" : "Задать дату исполнения",
    "Priority {priority}: low" : "Приоритет {priority}: низкий",
    "Priority {priority}: medium" : "Приоритет {priority}: средний",
    "Priority {priority}: high" : "Приоритет {priority}: высокий",
    "No priority assigned" : "Приоритет не задан",
    "{percent} % completed" : "Выполнение: {percent}%",
    "All day" : "Весь день",
    "Unpin" : "Открепить",
    "Pin" : "Закрепить",
    "Show in Calendar" : "Показывать в календаре",
    "Show in Deck" : "Показать в колоде",
    "Edit summary" : "Изменить резюме",
    "Details" : "Свойства",
    "Selecting a classification is forbidden, because the task was shared with you." : "Выбор классификации запрещен, так как с вами поделились заданием.",
    "Select a classification" : "Выбрать классификацию",
    "Select a status" : "Выберите состояние",
    "Set a location" : "Установить местоположение",
    "Set a URL" : "Установить URL адрес",
    "Select tags" : "Выбор меток",
    "Notes" : "Заметки",
    "Mark as done" : "Отметить как выполненную",
    "No due date assigned" : "Без назначенной даты",
    "[Due yesterday]" : "[Должно было быть завершено вчера]",
    "[Due today]" : "[Завершение сегодня]",
    "[Due tomorrow]" : "[Завершение завтра]",
    "[Due] L" : "[Должно было быть завершено] L",
    "[Due yesterday at] LT" : "[Должно было быть завершено вчера в] LT",
    "[Due today at] LT" : "[Должно быть завершено сегодня в] LT",
    "[Due tomorrow at] LT" : "[Должно быть завершено завтра в] LT",
    "[Due] L [at] LT" : "[Должно было быть завершено] L [в] LT",
    "No upcoming tasks" : "Приближающиеся задачи отсуствуют",
    "upcoming tasks" : "Ожидающие выполнения",
    "No tasks today" : "На сегодня нет задач",
    "Completion date must be in the past." : "Дата завершения должна быть в прошлом.",
    "Successfully created the task." : "Задача создана.",
    "Could not delete the task." : "Не удалось удалить задачу.",
    "Synchronizing to the server." : "Синхронизация с сервером…",
    "Task successfully saved to server." : "Задача сохранена на сервере.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Не удалось обновить задачу, так как она была изменена на сервере. Нажмите для получения обновлённой задачи с сервера, внесённые изменения не будут сохранены.",
    "Could not update the task." : "Не удалось обновить задачу.",
    "Successfully updated the task." : "Задача обновлена.",
    "Task successfully moved to new calendar." : "Задача перемещена в новый календарь.",
    "An error occurred" : "Произошла ошибка",
    "Create a task" : "Создать задачу",
    "Message from {author} in {conversationName}" : "Сообщение от {author} из беседы «{conversationName}»",
    "[Due on] LL" : "[Завершение] LL",
    "[Was due yesterday]" : "[Должно было быть завершено вчера]",
    "[Was due on] LL" : "[Должно было быть завершено] LL",
    "[Was due today at] LT" : "[Должно было быть завершено сегодня в] LT",
    "[Due on] LL [at] LT" : "[До] LL, LT",
    "[Was due yesterday at] LT" : "[Должно было быть завершено в] LT",
    "[Was due on] LL [at] LT" : "[Должно было быть завершено] LL [в] LT",
    "[Starts today]" : "[Начало сегодня]",
    "[Starts tomorrow]" : "[Начало завтра]",
    "[Starts on] LL" : "[Начало] LL",
    "[Started yesterday]" : "[Начато вчера]",
    "[Started on] LL" : "[Начато] LL",
    "[Started today at] LT" : "[Начало сегодня в] LT",
    "[Starts today at] LT" : "[Начато сегодня в] LT",
    "[Starts tomorrow at] LT" : "[Начало завтра в] LT",
    "[Starts on] LL [at] LT" : "[Начало] LL [в] LT ",
    "[Started yesterday at] LT" : "[Начато вчера в] LT",
    "[Started on] LL [at] LT" : "[Начато] LL [в] LT",
    "Midnight on the day the task starts" : "Полночь в день начала задачи",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["За %n день до задачи в {formattedHourMinute}","За %n дня до задачи в {formattedHourMinute}","За %n дней до задачи в {formattedHourMinute}","За %n дней до задачи в {formattedHourMinute} "],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["За %n неделю до задачи в {formattedHourMinute}","За %n недели до задачи в {formattedHourMinute}","За %n недель до задачи в {formattedHourMinute}","За %n недель до задачи в {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "в день выполнения задачи в {formattedHourMinute}",
    "at the task's start" : "В момент начала задачи",
    "when the task is due" : "В момент срока выполнения задачи",
    "{time} before the task starts" : "{time}мин. до начала задачи",
    "{time} before the task is due" : "{time} до срока выполнения задачи",
    "{time} after the task starts" : "{time} после начала задачи",
    "{time} after the task is due" : "{time} после срока выполнения задачи"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
