OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Gaidāmie uzdevumi",
    "Important" : "Svarīgi",
    "Today" : "Šodien",
    "Week" : "Nedēļa",
    "All" : "Visi",
    "Current" : "Pašreizējais",
    "Completed" : "Pabeigts",
    "Tasks" : "Uzdevumi",
    "The Tasks app for Nextcloud" : "Nextcloud uzdevumu lietotne",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Tiklīdz iespējots, jauns izvēlnes vienums \"Uzdevumi\" parādīsies Nextcloud lietotņu izvēlnē. Tur var pievienot un izdzēst uzdevumus, labot to virsrakstu, parakstu, sākuma un beigu datumus un atzīmēt tos kā svarīgus. Uzdevumus var koplietot ar citiem lietotājiem. Uzdevumus var sinhronizēt ar CalDAV (katra uzdevuma saraksts ir sasaistīts ar Nextcloud kalendāru; lai to sinhronizētu ar vietēju klientu - Thunderbird, Evolution, KDE Kontact, iCAL, ... - kalendārs ir tikai jāpievieno kā attālais kalendārs). Uzdevumus var lejupielādēt kā ICS datnes ar lejupielādes pogu katrā atsevišķajā kalendārā.",
    "Hidden" : "Paslēpts",
    "Visible" : "Redzams",
    "Automatic" : "Automātisks",
    "Tasks settings" : "Uzdevumu iestatījumi",
    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
    "Unable to change permissions." : "Nevar mainīt atļaujas.",
    "Can edit" : "Var labot",
    "Unshare with {displayName}" : "Atcelt kopīgošanu ar {displayName}",
    "Calendar link copied to clipboard." : "Kalendāra saite nokopēta starpliktuvē.",
    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevar nokopēt starpliktuvē.",
    "An empty name is not allowed." : "Nosaukums ir obligāts.",
    "An error occurred, unable to delete the calendar." : "Atgadījās kļūda, nevar izdzēst kalendāru.",
    "Edit" : "Labot",
    "Copied" : "Nokopēts",
    "Export" : "Izgūt",
    "Delete" : "Izdzēst",
    "Unshare" : "Pārtraukt dalīšanos",
    "Untitled task" : "Uzdevums bez nosaukuma",
    "Untitled event" : "Nenosaukts notikums",
    "Untitled item" : "Nenosaukts vienums",
    "Unknown calendar" : "Nezināms kalendārs",
    "Could not load deleted calendars and objects" : "Nevarēja ielādēt dzēstos kalendārus un objektus",
    "Could not restore calendar or event" : "Nevarēja atjaunot kalendāru vai notikumu.",
    "Do you really want to empty the trash bin?" : "Vai tiešām iztukšot atkritni?",
    "Empty trash bin" : "Izdzēst miskastes saturu",
    "Trash bin" : "Miskaste",
    "Name" : "Nosaukums",
    "Deleted" : "Izdzēsts",
    "Restore" : "Atjaunot",
    "Delete permanently" : "Neatgriezeniski izdzēst",
    "Cancel" : "Atcelt",
    "Email" : "E-pasts",
    "Audio notification" : "Skaņas paziņojums",
    "Other notification" : "Cits paziņojums",
    "Edit time" : "Labot laiku",
    "Remove reminder" : "Noņemt atgādinājumu",
    "Add reminder" : "Pievienot atgādinājumu",
    "Go back" : "Atpakaļ",
    "Set a reminder relative to your tasks start date:" : "Iestatīt atgādinājum attiecībā pret uzdevuma sākuma datumu:",
    "Set a reminder relative to your tasks due date:" : "Iestatīt atgādinājumu attiecībā pret uzdevuma izpildes datumu:",
    "before at" : "pirms ",
    "Click here to add a note." : "Klikšķināt šeit, lai pievienotu piezīmi.",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} uzdevumi tika pievienoti \"{calendar}\"",
    "Create new tasks" : "Izveidot jaunus uzdevumus",
    "Create tasks" : "Izveidot uzdevumus",
    "Close" : "Aizvērt",
    "Delete all completed tasks." : "Izdzēst visus pabeigtos uzdevumus.",
    "Delete completed tasks." : "Izdzēst pabeigtos uzdevumus.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Izdzēsti visi pabeigtie uzdevumi kalendārā \"{calendar}\".",
    "No errors" : "Nav kļūdu",
    "Open your browser console for more details" : "Jāatver sava pārlūka konsole, lai uzzinātu vairāk",
    "Select tags to filter by" : "Atlasīt birkas, pēc kurām atsijāt",
    "Add an important task to \"{calendar}\"…" : "Pievienot svarīgu uzdevumu \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Pievienot šodien izpildāmu uzdevumu \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Pievienot pašreizējo uzdevumu \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Pievienot uzdevumu \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Ielādēt visu sarakstu pabeigtos uzdevumus.",
    "Loading the completed tasks of all lists might slow down the app." : "Visu sarakstu pabeigto uzdevumu ielādēšana var palēnināt lietotni.",
    "Load the completed tasks of list \"{calendar}\"." : "Ielādēt saraksta \"{calendar}\" pabeigtos uzdevumus.",
    "Loading the completed tasks might slow down the app." : "Pabeigto uzdevumu ielādēšana var palēnināt lietotni.",
    "Start date" : "Sākuma datums",
    "Due date" : "Izpildes datums",
    "Last modified" : "Pēdējoreiz izmainīts",
    "Sort by last-modified date, priority and summary." : "Kārtot pēc pēdējās izmainīšanas datuma, svarīguma un kopsavilkuma.",
    "Sort by completed date, priority and summary." : "Kārtot pēc pabeigšanas datuma, svarīguma un kopsavilkuma.",
    "Priority" : "Svarīgums",
    "Sort by priority and summary." : "Kārtot pēc svarīguma un kopsavilkuma.",
    "Alphabetically" : "Alfabētiskā secībā",
    "Sort by summary and priority." : "Kārtot pēc kopsavilkuma un svarīguma.",
    "Tags" : "Birkas",
    "Manually" : "Pašrocīgi",
    "Change sort order" : "Mainīt kārtošanas secību",
    "[Today]" : "[Šodien]",
    "[Tomorrow]" : "[Rīt]",
    "[Completed today]" : "[Pabeigts šodien]",
    "[Today at] LT" : "[Šodien] LT",
    "Add a subtask to \"{task}\"…" : "Pievienot apakšuzdevumu \"{task}\"…",
    "{complete} % completed" : "{complete} % pabeigti",
    "Add subtask" : "Pievienot apakšuzdevumu",
    "Hide subtasks" : "Paslēpt apakšuzdevumus",
    "Hide closed subtasks" : "Paslēpt pabeigtos apakšuzdevumus",
    "Task is completed" : "Uzdevums ir pabeigts",
    "Task is not completed" : "Uzdevums nav pabeigts",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" tika pievienots \"{calendar}\"",
    "Open task" : "Atvērt uzdevumu",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n pabeigtu uzdevumu","%n pabeigts uzdevums","%n pabeigti uzvedumi"],
    "Tomorrow" : "Rīt",
    "When shared show full event" : "Ja kopīgots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja kopīgots, tad rādīt tikai aizņemtos",
    "When shared hide this event" : "Paslēpt šo notikumu, kad kopīgots",
    "[Last modified yesterday at] LT" : "[Pēdējoreiz izmainīts vakar] LT",
    "[Last modified today at] LT" : "[Pēdējoreiz izmainīts šodien] LT",
    "[Last modified] L" : "[Pēdējoreiz izmainīts] L",
    "[Last modified last] dddd [at] LT" : "[Pēdējoreiz izmainīts pēdējā] dddd LT",
    "[Last modified] dddd [at] LT" : "[Pēdējoreiz izmainīts] dddd LT",
    "Needs action" : "Nepieciešama darbība",
    "Canceled" : "Atcelts",
    "Task not found!" : "Uzdevums nav atrasts!",
    "Set start date" : "Uzstādīt sākuma datumu",
    "Set due date" : "Uzstādīt beigu datumu",
    "Priority {priority}: low" : "Svarīgums {priority}: zems",
    "Priority {priority}: medium" : "Svarīgums {priority}: vidējs",
    "Priority {priority}: high" : "Svarīgums {priority}: augsts",
    "No priority assigned" : "Nav piešķirts svarīgums",
    "{percent} % completed" : "{percent} % pabeigti",
    "All day" : "Visas dienas",
    "Details" : "Informācija",
    "Select a status" : "Atlasīt stāvokli",
    "Set a location" : "Iestatīt atrašanās vietu",
    "Set a URL" : "Iestatīt URL",
    "Select tags" : "Atlasīt birkas",
    "Notes" : "Piezīmes",
    "[Due today]" : "[Beigsies šodien]",
    "[Due today at] LT" : "[Beigsies šodien] LT",
    "No tasks today" : "Šodien nav uzdevumu",
    "Task successfully moved to new calendar." : "Uzdevums sekmīgi pārvietots uz jaunu kalendāru.",
    "An error occurred" : "Gadījās kļūda",
    "[Was due today at] LT" : "[Beidzās šodien] LT",
    "[Starts today]" : "[Sāksies šodien]",
    "[Starts today at] LT" : "[Sāksies šodien] LT"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
