OC.L10N.register(
    "tasks",
    {
    "Important" : "වැදගත්",
    "Today" : "අද",
    "Week" : "සතිය",
    "All" : "සියල්ල",
    "Completed" : "සම්පුර්ණයි",
    "Tasks" : "කාර්යයන්",
    "Edit" : "සංස්කරණය",
    "Copy private link" : "පුද්ගලික සබැඳිය පිටපත් කරන්න",
    "Name" : "නම",
    "Restore" : "ප්‍රතිෂ්ථාපනය",
    "Cancel" : "අවලංගු කරන්න",
    "Go back" : "ආපසු යන්න",
    "Close" : "වසන්න",
    "Tomorrow" : "හෙට",
    "Details" : "විස්තර",
    "Notes" : "සටහන්"
},
"nplurals=2; plural=(n != 1);");
