OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Prètzfaches venents",
    "Important" : "Important",
    "Today" : "Uèi",
    "Week" : "Aquesta setmana",
    "All" : "Tot",
    "Current" : "En aqueste moment",
    "Completed" : "Acabat",
    "Tasks" : "Prètzfaches",
    "Hidden" : "Amagat",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
    "Can edit" : "Pòt modificar",
    "An empty name is not allowed." : "Un nom void es pas autorizat.",
    "Edit" : "Modificar",
    "Copy private link" : "Copiar lo ligam privat",
    "Copied" : "Copiat",
    "Export" : "Exportar",
    "Delete" : "Suprimir",
    "Unshare" : "Partejar pas mai",
    "Untitled task" : "Prètzfach sens nom",
    "Untitled event" : "Eveniment sens títol",
    "Name" : "Nom",
    "Deleted" : "Suprimit",
    "Restore" : "Restaurar",
    "Delete permanently" : "Suprimir definitivament",
    "Cancel" : "Anullar",
    "Notification" : "Notificacion",
    "Email" : "Adreiça electronica",
    "Audio notification" : "Notificacion àudio",
    "Other notification" : "Autras notificacions",
    "Edit time" : "Modificar l’ora",
    "Remove reminder" : "Suprimir lo rapèl",
    "Go back" : "Revenir en arrière",
    "_second_::_seconds_" : ["segonda","segondas"],
    "_minute_::_minutes_" : ["minuta","minutas"],
    "_hour_::_hours_" : ["ora","oras"],
    "_day_::_days_" : ["jorn","jorns"],
    "_week_::_weeks_" : ["setmana","setmanas"],
    "Close" : "Tampar",
    "Alphabetically" : "Alfabeticament",
    "Tags" : "Etiquetas",
    "[Yesterday]" : "[Ièr]",
    "[Today]" : "[Uèi]",
    "[Tomorrow]" : "[Deman]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
    "Tomorrow" : "Deman",
    "Canceled" : "Anullat",
    "Task not found!" : "Prètzfach pas trobat !",
    "Set start date" : "Especificar la data de començament",
    "Set due date" : "Especificar la data d'escasença",
    "All day" : "Tota la jornada",
    "Details" : "Detalhs",
    "Notes" : "Nòtas",
    "No upcoming tasks" : "Cap de prètzfach venent",
    "upcoming tasks" : "prètzfaches venents",
    "No tasks today" : "Cap de prètzfach uèi",
    "An error occurred" : "Una error s’es producha"
},
"nplurals=2; plural=(n > 1);");
