OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "وظایف آتی",
    "Important" : "مهم",
    "Today" : "امروز",
    "Week" : "هفته",
    "All" : "همه",
    "Current" : "کنونی",
    "Completed" : "نکمیل شده",
    "Tasks" : "وظایف",
    "The Tasks app for Nextcloud" : "برنامه Tasks برای Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "پس از فعال شدن، یک منوی Tasks جدید در منوی برنامه های Nextcloud ظاهر می شود. از آنجا می توانید کارها را اضافه و حذف کنید، عنوان، توضیحات، تاریخ شروع و سررسید آنها را ویرایش کنید و آنها را به عنوان مهم علامت گذاری کنید. وظایف را می توان بین کاربران به اشتراک گذاشت. کارها را می‌توان با استفاده از CalDav همگام‌سازی کرد (هر لیست وظایف به تقویم Nextcloud پیوند داده می‌شود تا آن را با کلاینت محلی شما همگام‌سازی کند: Thunderbird، Evolution، KDE Kontact، iCal… - فقط تقویم را به عنوان یک تقویم راه دور در کلاینت خود اضافه کنید). می توانید وظایف خود را به عنوان فایل ICS با استفاده از دکمه دانلود برای هر تقویم بارگیری کنید.",
    "Hidden" : "مخفی",
    "Visible" : "قابل رویت",
    "Automatic" : "خودکار",
    "Tasks settings" : "تنظیمات وظایف",
    "Default list" : "لیست پیش فرض",
    "Visibility of Smart Collections" : "قابلیت مشاهده مجموعه های هوشمند",
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "Unable to delete the share." : "امکان حذف اشتراک وجود ندارد.",
    "Unable to change permissions." : "امکان تغییر مجوزها وجود ندارد.",
    "Can edit" : "می‌تواند ویرایش کند",
    "Unshare with {displayName}" : "عدم اشتراک گذاری با {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "با این کار، تقویم \"{calendar}\" و همه رویدادها و وظایف مربوطه حذف می شود.",
    "This will unshare the calendar \"{calendar}\"." : "با این کار اشتراک‌گذاری تقویم «{calendar}» لغو می‌شود.",
    "This will delete the list \"{list}\" and all corresponding tasks." : "با این کار لیست \"{list}\" و همه وظایف مربوطه حذف می شود.",
    "This will unshare the list \"{list}\"." : "با این کار اشتراک لیست \"{list}\" لغو می شود.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف تقویم در {countdown} ثانیه","حذف تقویم در {countdown} ثانیه"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["لغو اشتراک‌گذاری تقویم در {countdown} ثانیه","لغو اشتراک‌گذاری تقویم در {countdown} ثانیه"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["حذف لیست در {countdown} ثانیه","حذف لیست در {countdown} ثانیه"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["لغو اشتراک‌گذاری فهرست در {countdown} ثانیه","لغو اشتراک‌گذاری فهرست در {countdown} ثانیه"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["به اشتراک گذاشته شده با {num} نهاد","به اشتراک گذاشته شده با {num} نهاد"],
    "Share this calendar" : "این تقویم را به اشتراک بگذارید",
    "Share this list" : "این لیست را به اشتراک بگذارید",
    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
    "List link copied to clipboard." : "پیوند فهرست در کلیپ بورد کپی شد.",
    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
    "List link could not be copied to clipboard." : "پیوند فهرست در کلیپ بورد کپی نشد.",
    "The name \"{calendar}\" is already used." : "نام \"{تقویم}\" قبلاً استفاده شده است.",
    "An empty name is not allowed." : "نام خالی مجاز نیست.",
    "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
    "An error occurred, unable to delete the list." : "خطایی روی داد، لیست حذف نشد.",
    "Edit" : "ویرایش",
    "Copy private link" : "پیوند خصوصی را کپی کنید",
    "Copied" : "کپی شد",
    "Cannot copy" : "امکان کپی نیست",
    "Export" : "گرفتن خروجی",
    "Delete" : "حذف",
    "Unshare" : "لغو اشتراک",
    "List name" : "نام فهرست",
    "Untitled task" : "کار بدون عنوان",
    "Untitled event" : "رویداد بدون عنوان",
    "Untitled journal" : "مجله بدون عنوان",
    "Untitled item" : "مورد بدون عنوان",
    "Unknown calendar" : "تقویم ناشناخته",
    "Could not load deleted calendars and objects" : "تقویم و اشیاء حذف شده بارگیری نشد",
    "Could not delete calendar or event" : "تقویم یا رویداد حذف نشد",
    "Could not restore calendar or event" : "تقویم یا رویداد بازیابی نشد",
    "Do you really want to empty the trash bin?" : "آیا واقعاً می خواهید سطل زباله را خالی کنید؟",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "Trash bin" : "زباله‌دان",
    "Loading deleted calendars, tasks and events." : "بارگیری تقویم ها، وظایف و رویدادهای حذف شده",
    "You do not have any deleted calendars, tasks or events." : "شما هیچ تقویم، کار یا رویداد حذف شده ای ندارید.",
    "Name" : "نام",
    "Deleted" : "حذف شده",
    "Restore" : "بازیابی",
    "Delete permanently" : "حذف قطعی",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["عناصر موجود در سطل زباله پس از {numDays} روز حذف می شوند","عناصر موجود در سطل زباله پس از {numDays} روز حذف می شوند"],
    "Cancel" : "لغو",
    "Notification" : "آگاهی",
    "Email" : "رایانامه",
    "Audio notification" : "اعلان صوتی",
    "Other notification" : "سایر اعلان ها",
    "Edit time" : "ویرایش زمان",
    "Remove reminder" : "یادآوری را حذف کنید",
    "Add reminder" : "Add reminder",
    "Go back" : "برگرد",
    "before at" : "قبل از در",
    "_second_::_seconds_" : ["ثانیه","ثانیه"],
    "_minute_::_minutes_" : ["دقایق","دقیقه"],
    "_hour_::_hours_" : ["ساعت","ساعت"],
    "_day_::_days_" : ["روز","روز"],
    "_week_::_weeks_" : ["هفته","هفته"],
    "Select a calendar" : "یک تقویم انتخاب کنید",
    "No calendar matches the search." : "هیچ تقویمی با جستجو مطابقت ندارد.",
    "Set date" : "تعیین تاریخ",
    "Set time" : "زمان را تنظیم کنید",
    "Delete date" : "تاریخ را حذف کنید",
    "Click here to add a note." : "برای افزودن یادداشت اینجا را کلیک کنید.",
    "Set value" : "مقدار را تنظیم کنید",
    "Delete value" : "مقدار را حذف کنید",
    "Add this as a new tag" : "این را به عنوان یک برچسب جدید اضافه کنید",
    "No tag available. Create one!" : "هیچ برچسبی در دسترس نیست یکی بساز!",
    "Close" : "بسته",
    "Delete all completed tasks." : "تمام کارهای تکمیل شده را حذف کنید.",
    "Delete completed tasks." : "کارهای تکمیل شده را حذف کنید.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "تمام کارهای تکمیل شده از تقویم \"{calendar}\" حذف شد.",
    "No errors" : "بدون خطا",
    "Open your browser console for more details" : "برای جزئیات بیشتر کنسول مرورگر خود را باز کنید",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["با این کار {taskCount} کار تکمیل شده و وظایف فرعی آن از تقویم \"{calendar}\" حذف می شود.","با این کار {taskCount} کار تکمیل شده و وظایف فرعی آن از تقویم \"{calendar}\" حذف می شود."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} کار حذف نشد.","{failedCount} کار حذف نشد."],
    "Select tags to filter by" : "Select tags to filter by",
    "Add an important task to \"{calendar}\"…" : "یک وظیفه مهم به \"{calendar}\" اضافه کنید…",
    "Add a task due today to \"{calendar}\"…" : "اضافه کردن وظیفه امروز به \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "یک وظیفه فعلی را به \"{calendar}\" اضافه کنید…",
    "Add a task to \"{calendar}\"…" : "اضافه کردن یک وظیفه به \"{calendar}\"…",
    "Load the completed tasks of all lists." : "وظایف تکمیل شده همه لیست ها را بارگیری کنید.",
    "Loading the completed tasks of all lists might slow down the app." : "بارگیری وظایف تکمیل شده همه لیست ها ممکن است برنامه را کند کند.",
    "Load the completed tasks of list \"{calendar}\"." : "وظایف تکمیل شده لیست \"{calendar}\" را بارگیری کنید.",
    "Relevance" : "ارتباط",
    "Sort by completed state, due date, priority, start date and summary." : "مرتب سازی بر اساس وضعیت تکمیل شده، تاریخ سررسید، اولویت، تاریخ شروع و خلاصه.",
    "Start date" : "تاریخ شروع",
    "Sort by start date, priority and summary." : "مرتب سازی بر اساس تاریخ شروع، اولویت و خلاصه.",
    "Due date" : "موعد مقرر",
    "Sort by due date, priority and summary." : "مرتب سازی بر اساس تاریخ مقرر، اولویت و خلاصه.",
    "Created date" : "تاریخ ایجاد",
    "Sort by created date, priority and summary." : "مرتب سازی بر اساس تاریخ ایجاد، اولویت و خلاصه.",
    "Last modified" : "آخرین اصلاح شده",
    "Sort by last-modified date, priority and summary." : "مرتب سازی بر اساس تاریخ آخرین اصلاح، اولویت و خلاصه.",
    "Completed date" : "تاریخ اتمام",
    "Sort by completed date, priority and summary." : "مرتب سازی بر اساس تاریخ تکمیل، اولویت و خلاصه.",
    "Priority" : "اولویت",
    "Sort by priority and summary." : "مرتب سازی بر اساس اولویت و خلاصه.",
    "Alphabetically" : "الفبایی",
    "Sort by summary and priority." : "مرتب سازی بر اساس خلاصه و اولویت.",
    "Tags" : "برچسب ها",
    "Manually" : "به صورت دستی",
    "Sort by manual order." : "مرتب سازی بر اساس سفارش دستی",
    "Change sort order" : "تغییر ترتیب مرتب سازی",
    "[Yesterday]" : "[دیروز]",
    "[Today]" : "[امروز]",
    "[Tomorrow]" : "[فردا]",
    "[Completed yesterday]" : "[دیروز تکمیل شد]",
    "[Completed today]" : "[امروز تکمیل شد]",
    "[Completed tomorrow]" : "[فردا تکمیل شد]",
    "[Yesterday at] LT" : "[دیروز در] LT",
    "[Today at] LT" : "[امروز در] LT",
    "[Tomorrow at] LT" : "[فردا در] LT",
    "L [at] LT" : "L [در] LT",
    "[Completed yesterday at] LT" : "[دیروز در] LT تکمیل شد",
    "[Completed today at] LT" : "[امروز در] LT تکمیل شد",
    "[Completed tomorrow at] LT" : "[فردا در] LT تکمیل شد",
    "[Completed] L [at] LT" : "[تکمیل شده] L [در] LT",
    "Add a subtask to \"{task}\"…" : "اضافه کردن یک کار فرعی به \"{task}\"…",
    "Task has hidden subtasks" : "Task دارای وظایف فرعی پنهان است",
    "Task is pinned" : "وظیفه پین شده است",
    "Task has a note" : "وظیفه یک یادداشت دارد",
    "{complete} % completed" : "{complete} % تکمیل شد",
    "Add subtask" : "کار فرعی را اضافه کنید",
    "Show subtasks" : "نمایش وظایف فرعی",
    "Hide subtasks" : "مخفی کردن وظایف فرعی",
    "Show closed subtasks" : "نمایش وظایف فرعی بسته شده",
    "Hide closed subtasks" : "مخفی کردن وظایف فرعی بسته",
    "Delete task" : "وظیفه را حذف کنید",
    "Toggle starred" : "ستاره دار را تغییر دهید",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["پاک کردن کار در {countdown} ثانیه","پاک کردن کار در {countdown} ثانیه"],
    "Task is cancelled" : "کار لغو شده است",
    "Task is completed" : "کار تکمیل شد",
    "Task is read-only" : "کار فقط خواندنی است",
    "Task is not completed" : "کار تکمیل نشده است",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" به \"{calendar}\" اضافه شد",
    "Create a new task" : "یک کار جدید ایجاد کنید",
    "Task summary" : "خلاصه کار",
    "Create task" : "وظیفه ایجاد کنید",
    "Creating the new task…" : "ایجاد کار جدید…",
    "Open task" : "وظیفه را باز کنید",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n کار تکمیل شده","%n کار تکمیل شده"],
    "Tomorrow" : "فردا",
    "Add List…" : "افزودن لیست…",
    "New list" : "لیست جدید",
    "When shared show full event" : "هنگام اشتراک گذاری ، رویداد کامل را نشان می دهد",
    "When shared show only busy" : "وقتی نمایش اشتراکی فقط مشغول است",
    "When shared hide this event" : "هنگام اشتراک گذاری این رویداد را پنهان کنید",
    "[Completed] L" : "[تکمیل شده] L",
    "[Completed last] dddd [at] LT" : "[آخر تکمیل شد] dddd [در] LT",
    "[Completed] dddd [at] LT" : "[تکمیل شده] dddd [در] LT",
    "[Last modified yesterday at] LT" : "[آخرین تغییر دیروز در] LT",
    "[Last modified today at] LT" : "[آخرین تغییر امروز در] LT",
    "[Last modified] L" : "[آخرین اصلاح] L",
    "[Last modified last] dddd [at] LT" : "[آخرین اصلاح آخرین] dddd [در] LT",
    "[Last modified] dddd [at] LT" : "[آخرین اصلاح] dddd [در] LT",
    "[Created yesterday at] LT" : "[دیروز در] LT ایجاد شد",
    "[Created today at] LT" : "[ایجاد شده امروز در] LT",
    "[Created] L" : "[ایجاد شده] L",
    "[Created last] dddd [at] LT" : "[آخرین ایجاد شده] dddd [در] LT",
    "[Created] dddd [at] LT" : "[ایجاد شده] dddd [در] LT",
    "Needs action" : "نیاز به اقدام دارد",
    "In process" : "در جریان",
    "Canceled" : "لغو شد",
    "Clear status" : "پاک کردن وضعیت",
    "Loading task from server." : "بارگیری کار از سرور",
    "Task not found!" : "کار یافت نشد!",
    "Set start date" : "تنظیم تاریخ شروع",
    "Set due date" : "تعریف سر رسید",
    "Priority {priority}: low" : "اولویت {اولویت}: کم",
    "Priority {priority}: medium" : "اولویت {اولویت}: متوسط",
    "Priority {priority}: high" : "اولویت {اولویت}: زیاد",
    "No priority assigned" : "هیچ اولویتی تعیین نشده است",
    "{percent} % completed" : "{percent} % تکمیل شد",
    "All day" : "تمام روز",
    "Unpin" : "پین را بردارید",
    "Pin" : "Pin",
    "Show in Calendar" : "نمایش در تقویم",
    "Details" : "جزئیات",
    "Selecting a classification is forbidden, because the task was shared with you." : "انتخاب یک طبقه بندی ممنوع است، زیرا کار با شما به اشتراک گذاشته شده است.",
    "Select a classification" : "یک طبقه بندی را انتخاب کنید",
    "Select a status" : "یک وضعیت را انتخاب کنید",
    "Select tags" : "برچسب ها را انتخاب کنید",
    "Notes" : "یادداشت‌ها",
    "Mark as done" : "علامت گذاری به عنوان انجام شده",
    "No due date assigned" : "تاریخ سررسید تعیین نشده است",
    "[Due yesterday]" : "[سررسید دیروز]",
    "[Due today]" : "[باید امروز انجام بشود]",
    "[Due tomorrow]" : "[فردا موعد مقرر]",
    "[Due] L" : "[زمان تحویل] L",
    "[Due yesterday at] LT" : "[سررسید دیروز در] LT",
    "[Due today at] LT" : "[امروز در] LT",
    "[Due tomorrow at] LT" : "[فردا در] LT",
    "[Due] L [at] LT" : "[به دلیل] L [در] LT",
    "No upcoming tasks" : "هیچ کار آتی وجود ندارد",
    "upcoming tasks" : "وظایف آتی",
    "No tasks today" : "امروز هیچ وظیفه ای نیست",
    "Successfully created the task." : "کار با موفقیت ایجاد شد.",
    "Could not delete the task." : "نمی توان کار را حذف کرد.",
    "Synchronizing to the server." : "همگام سازی با سرور",
    "Task successfully saved to server." : "کار با موفقیت در سرور ذخیره شد.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "کار به‌روزرسانی نشد زیرا در سرور تغییر کرده بود. لطفاً برای بازخوانی آن کلیک کنید، تغییرات محلی نادیده گرفته خواهد شد.",
    "Could not update the task." : "کار به‌روزرسانی نشد.",
    "Successfully updated the task." : "کار با موفقیت به روز شد.",
    "Task successfully moved to new calendar." : "کار با موفقیت به تقویم جدید منتقل شد.",
    "An error occurred" : "خطایی روی داد",
    "Create a task" : "یک کار ایجاد کنید",
    "Message from {author} in {conversationName}" : "پیام از {author} در {conversationName}",
    "[Due on] LL" : "[سررسید] LL",
    "[Was due yesterday]" : "[دیروز موعد مقرر بود]",
    "[Was due on] LL" : "[به موعد] LL",
    "[Was due today at] LT" : "[قرار بود امروز در] LT",
    "[Due on] LL [at] LT" : "[در تاریخ] LL [در] LT",
    "[Was due yesterday at] LT" : "[روز گذشته در] LT بود",
    "[Was due on] LL [at] LT" : "[در تاریخ] LL [در] LT",
    "[Starts today]" : "[از امروز شروع می شود]",
    "[Starts tomorrow]" : "[از فردا شروع می شود]",
    "[Starts on] LL" : "[شروع می شود] LL",
    "[Started yesterday]" : "[از دیروز شروع شد]",
    "[Started on] LL" : "[شروع شد] LL",
    "[Started today at] LT" : "[از امروز در] LT شروع شد",
    "[Starts today at] LT" : "[از امروز در] LT شروع می شود",
    "[Starts tomorrow at] LT" : "[از فردا در] LT شروع می شود",
    "[Starts on] LL [at] LT" : "[شروع می شود] LL [در] LT",
    "[Started yesterday at] LT" : "[از دیروز در] LT شروع شد",
    "[Started on] LL [at] LT" : "[شروع در] LL [در] LT"
},
"nplurals=2; plural=(n > 1);");
