OC.L10N.register(
    "tasks",
    {
    "Today" : "An-diugh",
    "Current" : "Làithreach",
    "Completed" : "Coileanta",
    "Edit" : "Deasaich",
    "Delete" : "Sguab às",
    "Unshare" : "Na co-roinn tuilleadh",
    "Empty trash bin" : "Falamhaich an sgudal",
    "Name" : "Ainm",
    "Deleted" : "Chaidh a sguabadh às",
    "Cancel" : "Sguir dheth",
    "Email" : "Post-d",
    "Close" : "Dùin",
    "Tags" : "Tagaichean",
    "Details" : "Mion-fhiosrachadh",
    "Notes" : "Nòtaichean"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
