OC.L10N.register(
    "tasks",
    {
    "Today" : "Today",
    "Week" : "hafta",
    "All" : "All",
    "Tasks" : "Tasks",
    "Hidden" : "Yashirin",
    "Automatic" : "Automatik",
    "Share with users or groups" : "Foydalanuvchilar yoki guruhlar bilan baham ko'ring",
    "No users or groups" : "Foydalanuvchilar yoki guruhlar yo'q",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : " {displayName}bilan ulashishni bekor qilish",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["taqvimni o'chirish {countdown} sekund"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Taqvimni ulashish bekor qilinmoqda {countdown} secund"],
    "Calendar link copied to clipboard." : "Taqvim havolasi vaqtinchalik xotiraga nusxalandi.",
    "Calendar link could not be copied to clipboard." : "Taqvim havolasini vaqtinchalik xotiraga nusxalab bo‘lmadi.",
    "An error occurred, unable to delete the calendar." : "Xatolik yuz berdi, kalendarni oʻchirib boʻlmadi.",
    "Edit" : "Tahrirlash",
    "Export" : "Eksport",
    "Delete" : "O'chirish",
    "Unshare" : "Unshare",
    "Untitled task" : "Nomsiz vazifa",
    "Untitled event" : "Nomsiz tadbir",
    "Untitled item" : "Nomsiz element",
    "Unknown calendar" : "Noma'lum kalendar",
    "Could not load deleted calendars and objects" : "Oʻchirilgan kalendarlar va obyektlarni yuklab boʻlmadi",
    "Could not delete calendar or event" : "Taqvim yoki tadbirni oʻchirib boʻlmadi",
    "Could not restore calendar or event" : "Taqvim yoki tadbirni tiklab bo‘lmadi",
    "Do you really want to empty the trash bin?" : "Haqiqatan ham o`chirilgan fayllar qutisini bo'shatmoqchimisiz?",
    "Empty trash bin" : "Axlat qutisini bo'shatish",
    "Trash bin" : "O`chirilgan fayllar qutisi",
    "Name" : "Name",
    "Deleted" : "O`chirilgan",
    "Restore" : "Qayta tiklangan",
    "Delete permanently" : "Butunlay o'chirish",
    "Cancel" : "Bekor qilish",
    "Notification" : "Bildirishnomalar",
    "Email" : "Email",
    "Audio notification" : "Audio xabarnoma",
    "Other notification" : "Boshqa bildirishnoma",
    "Edit time" : "Vaqtni tahrirlash",
    "Remove reminder" : "Eslatmani olib tashlash",
    "Add reminder" : "+ Eslatma qo'shish",
    "before at" : "oldin",
    "_day_::_days_" : ["kun"],
    "_week_::_weeks_" : ["hafta"],
    "Close" : "Yopish",
    "Due date" : "Muddati",
    "Tags" : "Tags",
    "[Yesterday]" : "[Kecha]",
    "[Today]" : "[Bugun]",
    "[Tomorrow]" : "[Ertaga]",
    "Tomorrow" : "Ertaga",
    "When shared show full event" : "Ulashganda toʻliq tadbir koʻrsatiladi",
    "When shared show only busy" : "Baham ko'rilganda shou faqat band",
    "When shared hide this event" : "Baham ko'rilganda, bu hodisani yashirish",
    "Canceled" : "Bekor qilingan",
    "All day" : "Butun kun",
    "Details" : "Details",
    "Notes" : "Notes",
    "Mark as done" : "Bajarildi deb belgilang"
},
"nplurals=1; plural=0;");
