OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "المهام القادمة",
    "Important" : "مُهِمٌّ",
    "Today" : "اليوم",
    "Week" : "أسبوع",
    "All" : "الكل",
    "Current" : "الحالي",
    "Completed" : "مُكتمِل",
    "Tasks" : "المهام",
    "The Tasks app for Nextcloud" : "تطبيق المهام لنكست كلاود Tasks",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "بمجرد تمكين تطبيق المهام، ستظهر قائمة مهام جديدة في قائمة تطبيقات نكست كلاود. من هناك يمكنك إضافة المهام وحذفها، وتحرير عناوينها ووصفها وتواريخ البدء والاستحقاق ووضع علامة علي المُهِمِّ منها. يمكن مشاركة المهام بين المستخدمين. كما يمكن مزامنة المهام باستخدام CalDav (كل قائمة مهام مرتبطة بتقويم نكست كلاود، لمزامنتها مع عميلك المحلي: Thunderbird ، Evolution ، KDE Kontact ، iCal ... - فقط أضف التقويم كتقويم بعيد في عميلك). يمكنك تنزيل مهامك كملفات ICS باستخدام زر التنزيل لكل تقويم.",
    "Hidden" : "مخفي",
    "Visible" : "مرئيّ",
    "Automatic" : "تلقائي",
    "Tasks settings" : "إعدادات المهام",
    "Default list" : "القائمة الإفتراضية",
    "Visibility of Smart Collections" : "رؤية المجموعات الذكية smart collections",
    "Share with users or groups" : "شارك مع مستخدمين أو مجموعات",
    "No users or groups" : "لا يوجد مستخدمون أو مجموعات",
    "Unable to delete the share." : "تعذر حذف المشاركة",
    "Unable to change permissions." : "تعذّر تعديل أذونات السماح",
    "Can edit" : "يمكن تعديله",
    "Unshare with {displayName}" : "إلغاء المشاركة مع {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "سيؤدّي هذا إلى حذف التقويم \"{calendar}\" و كل الأحداث و المهام المرتبطة به.",
    "This will unshare the calendar \"{calendar}\"." : "سيؤدّي هذا إلى إلغاء مُشاركة التقويم \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "سيؤدّي هذا إلى حذف القائمة \"{list}\" و كل المهام المرتبطة بها.",
    "This will unshare the list \"{list}\"." : "سيؤدّي هذا إلى إلغاء مشاركة القائمة \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثانية","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني","حذف التقويم في {countdown} ثواني"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثانية","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["جار حذف القائمة في {countdown} ثواني","جار حذف القائمة في {countdown} ثانية","جار حذف القائمة في {countdown} ثواني","جار حذف القائمة في {countdown} ثواني","جار حذف القائمة في {countdown} ثواني","جار حذف القائمة في {countdown} ثواني"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["جار إلغاء مشاركة القائمة في {countdown} ثواني","جار إلغاء مشاركة القائمة في {countdown} ثانية","جار إلغاء مشاركة القائمة في {countdown} ثواني","جار إلغاء مشاركة القائمة في {countdown} ثواني","جار إلغاء مشاركة القائمة في {countdown} ثواني","جار إلغاء مشاركة القائمة في {countdown} ثواني"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيان","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات"],
    "Share this calendar" : "شارك هذا التقويم",
    "Share this list" : "شارك هذه القائمة",
    "Calendar link copied to clipboard." : "تمّ نسخ رابط التقويم إلى الحافظة.",
    "List link copied to clipboard." : "تمّ نسخ رابط القائمة إلى الحافظة.",
    "Calendar link could not be copied to clipboard." : "تعذّر نسخ رابط التقويم إلى الحافظة.",
    "List link could not be copied to clipboard." : "تعذّر نسخ رابط القائمة إلى الحافظة.",
    "The name \"{calendar}\" is already used." : "الاسم\"{calendar}\" يستخدم بالفعل.",
    "An empty name is not allowed." : "غير مسموح بإسم فارغ",
    "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
    "An error occurred, unable to delete the list." : "حدث خطأ؛ تعذّر حذف القائمة.",
    "Edit" : "تعديل",
    "Copy private link" : "نسخ الرابط الخاص",
    "Copied" : "نُسخت ",
    "Cannot copy" : "تعذّر النسخ",
    "Export" : "تصدير",
    "Delete" : "حذف ",
    "Unshare" : "إلغاء المشاركة",
    "List name" : "قامة اسماء",
    "Untitled task" : "مهمة بدون اسم",
    "Untitled event" : "فعالية بدون اسم",
    "Untitled journal" : "سجل بدون عنوان",
    "Untitled item" : "بند غير معنون",
    "Unknown calendar" : "تقويم غير معروف",
    "Could not load deleted calendars and objects" : "لم يُمكن تحميل التقاويم أو الكيانات المحذوفة ",
    "Could not delete calendar or event" : "تعذّر حذف التقويم أو الحدث",
    "Could not restore calendar or event" : "تعذرت استعادة تقويم أو حدث",
    "Do you really want to empty the trash bin?" : "هل ترغب حقّاً في تفريغ سلة المهملات؟",
    "Empty trash bin" : "تفريغ سلة المهملات",
    "Trash bin" : "المهملات",
    "Loading deleted calendars, tasks and events." : "تحميل التقاويم و المهام و الأحداث المحذوفة.",
    "You do not have any deleted calendars, tasks or events." : "لا توجد عندك أي تقاويم أو مهام أو أحداث محذوفة.",
    "Name" : "الاسم",
    "Deleted" : "تم حذفه",
    "Restore" : "استعادة ",
    "Delete permanently" : "حذف بشكل دائم",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} يوم","يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام","يتم حذف العناصر الموجودة في سلة المهملات بعد {numDays} أيام"],
    "Create reminder" : "إنشاء تذكير",
    "Update reminder" : "تحديث التذكير",
    "Set a reminder at a custom date and time:" : "تعيين التذكير لوقت وتاريخ معين:",
    "Cancel" : "إلغاء",
    "This is a todo reminder." : "هذا تذكير بمهام واجبة",
    "No reminders" : "لا توجد أي تذكيرات",
    "Notification" : "إشعار",
    "Email" : "البريد الإلكتروني",
    "Audio notification" : "تنبيه صوتي",
    "Other notification" : "تنبيه اخر",
    "Edit time" : "تعديل الوقت",
    "Remove reminder" : "حذف التذكير",
    "Add reminder" : "أضِف تذكيراً",
    "Before the task starts" : "قبل أن تبدأ المهمة",
    "Before the task is due" : "قبل اكتمال المهمة",
    "Select date and time" : "إختَر التاريخ والوقت",
    "Go back" : "عودة",
    "Set a reminder relative to your tasks start date:" : "عيِّن تذكيراً نسبةً لتاريخ بداية المهام.",
    "Set a reminder relative to your tasks due date:" : "عيِّن تذكيراً نسبةً لتاريخ اكتمال المهام:",
    "before at" : "قبل",
    "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثوانٍ"],
    "_minute_::_minutes_" : ["دقائق","دقيقة","دقائق","دقائق","دقائق","دقائق"],
    "_hour_::_hours_" : ["ساعات","ساعة","ساعات","ساعات","ساعات","ساعات"],
    "_day_::_days_" : ["أيام","يوم","أيام","أيام","أيام","أيام"],
    "_week_::_weeks_" : ["أسابيع","أسبوع","أسابيع","أسابيع","أسابيع","أسابيع"],
    "Select a calendar" : "اختر تقويم",
    "No calendar matches the search." : "لم يتطابق البحث مع أي تقويم",
    "Set date" : "تعيين التاريخ",
    "Set time" : "تعيين الوقت",
    "Delete date" : "حذف التاريخ",
    "Click here to add a note." : "اضغط هنا لإضافة ملاحظة.",
    "Set value" : "تعيين القيمة",
    "Delete value" : "حذف القيمة",
    "Add this as a new tag" : "أضف هذا كوسم جديد",
    "No tag available. Create one!" : "لا توجد أي سمة tag حتى الآن. يمكنك إنشاء واحدة!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} مهام تمّت إضافتها إلى \"{calendar}\"",
    "Create new tasks" : "إنشاء مهام جديدة",
    "Create {numberOfTasks} tasks from pasted text" : "إنشاء {numberOfTasks} مهمة من النص الملصق",
    "Create tasks" : "إنشاء مهام",
    "Creating new tasks…" : "جارٍ إنشاء مهام جديدة ...",
    "Close" : "إغلاق",
    "Delete all completed tasks." : "حذف كل المهام المكتملة.",
    "Delete completed tasks." : "حذف المهام المكتملة.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "قد حذفت المهام المكتملة من \"{calendar}\".",
    "No errors" : "لا توجد أخطاء",
    "Open your browser console for more details" : "افتح مِعراض المتصفح للمزيد من التفاصيل",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["سيؤدي هذا إلى حذف {taskCount} مهام مكتملة ومهامه الفرعية من التقويم \"{calendar}\".","سيؤدي هذا إلى حذف {taskCount} مهمة مكتملة ومهامه الفرعية من التقويم \"{calendar}\".","سيؤدي هذا إلى حذف {taskCount} مهام مكتملة ومهامه الفرعية من التقويم \"{calendar}\".","سيؤدي هذا إلى حذف {taskCount} مهام مكتملة ومهامه الفرعية من التقويم \"{calendar}\".","سيؤدي هذا إلى حذف {taskCount} مهام مكتملة ومهامه الفرعية من التقويم \"{calendar}\".","سيؤدي هذا إلى حذف {taskCount} مهام مكتملة ومهامه الفرعية من التقويم \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["تعذر حذف مهام {FailedCount}.","تعذر حذف مهمة {FailedCount}.","تعذر حذف مهام {FailedCount}.","تعذر حذف مهام {FailedCount}.","تعذر حذف مهام {FailedCount}.","تعذر حذف مهام {FailedCount}."],
    "Active filter" : "فِلتَر نَشِط",
    "Filter by tags" : "تصفية بحسب الوسوم",
    "Select tags to filter by" : "حدد الوسوم للترشيح بواسطتها",
    "Reset filter" : "إعادة تعيين الفِلتر",
    "Add an important task to \"{calendar}\"…" : "أضف مهمة هامّة إلى \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "أضف مهمة مُستحَقّة حان موعدها إلى \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "أضف مهمة حالية إلى \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "أضف مهمة إلى \"{calendar}\"…",
    "Load the completed tasks of all lists." : "حمّل المهام المُكتمِلة لجميع القوائم",
    "Loading the completed tasks of all lists might slow down the app." : "تحميل المهام المُكتمِلة لجميع القوائم يُمكن أن يُبطيء التطبيق.",
    "Load the completed tasks of list \"{calendar}\"." : "حمّل المهام المُكتملة للقائمة \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "تحميل المهام المُنجزة يمكن أن يتسبب في تبطئة التطبيق.",
    "Relevance" : "الصلة بالموضوع",
    "Sort by completed state, due date, priority, start date and summary." : "الترتيب بحسب الحالة إن كانت مكتملة أم لا، و تاريخ الاكتمال، و الأولوية، و تاريخ البدء، والملخص.",
    "Start date" : "تاريخ البدء",
    "Sort by start date, priority and summary." : "الترتيب بحسب تاريخ البدء، و الأولوية، والملخص.",
    "Due date" : "تاريخ الاكتمال",
    "Sort by due date, priority and summary." : "الترتيب بحسب تاريخ الاكتمال، و الأولوية، والملخص.",
    "Created date" : "تاريخ الإنشاء",
    "Sort by created date, priority and summary." : "الترتيب بحسب تاريخ الإنشاء، و الأولوية، والملخص.",
    "Last modified" : "آخر تعديل",
    "Sort by last-modified date, priority and summary." : "الترتيب بحسب آخر تعديل، و الأولوية، والملخص.",
    "Completed date" : "تاريخ الإكتمال",
    "Sort by completed date, priority and summary." : "الترتيب بحسب تاريخ الاكتمال، و الأولوية، و الملخص.",
    "Priority" : "الأولوية",
    "Sort by priority and summary." : "الترتيب بحسب الأولوية و الملخص.",
    "Alphabetically" : "أبجديا",
    "Sort by summary and priority." : "الترتيب بحسب الملخص و الأولوية.",
    "Tags" : "وُسُوم",
    "Sort by tags." : "الترتيب بحسب الوسوم.",
    "Manually" : "يدويّاً",
    "Sort by manual order." : "الترتيب بحسب الفرز اليدوي.",
    "Change sort order" : "غيّر ترتيب الفرز",
    "[Yesterday]" : "[امس]",
    "[Today]" : "[اليوم]",
    "[Tomorrow]" : "[الغد]",
    "[Completed yesterday]" : "[إكتملت بالأمس]",
    "[Completed today]" : "[إكتملت اليوم]",
    "[Completed tomorrow]" : "[تكتمل غداً]",
    "[Yesterday at] LT" : "[أمس عند] LT",
    "[Today at] LT" : "[اليوم عند]  LT",
    "[Tomorrow at] LT" : "[غداً عند]  LT",
    "L [at] LT" : "L [عند] LT",
    "[Completed yesterday at] LT" : "[إكتملت أمس عند] LT",
    "[Completed today at] LT" : "[إكتملت اليوم عند] LT",
    "[Completed tomorrow at] LT" : "[تكتمل غداً عند] LT",
    "[Completed] L [at] LT" : "[مُكتملة] L [عند] LT",
    "Add a subtask to \"{task}\"…" : "أضف مهمة فرعية إلى \"{task}\"…",
    "Task has hidden subtasks" : "مهمة بها مهام فرعية مخفية",
    "Task is pinned" : "المهمة مُثبّتة pinned",
    "Task has a note" : "المهمة بها ملاحظة",
    "{complete} % completed" : "{complete} % مكتمل",
    "Add subtask" : "أضف مهمة فرعية",
    "Show subtasks" : "أعرض المهام الفرعية",
    "Hide subtasks" : "إخْفِ المهام الفرعية",
    "Show closed subtasks" : "أعرض المهام الفرعية المغلقة",
    "Hide closed subtasks" : "إخف المهام الفرعية المغلقة",
    "Delete task" : "حذف المهمّة",
    "Toggle starred" : "تبديل التمييز بالنجمة",
    "_Task has one reminder_::_Task has {n} reminders_" : ["المهمة لها {n} تذكيرة","المهمة لها تذكيرة واحدة","المهمة لها {n} تذكيرة","المهمة لها {n} تذكيرات","المهمة لها {n} تذكيرة","المهمة لها {n} تذكيرة"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["حذف المهمة في {countdown} ثواني","حذف المهمة في {countdown} ثانية","حذف المهمة في {countdown} ثواني","حذف المهمة في {countdown} ثواني","حذف المهمة في {countdown} ثواني","حذف المهمة في {countdown} ثواني"],
    "Task is cancelled" : "تمّ إلغاء المهمة",
    "Task is completed" : "المهمة اكتملت",
    "Task is read-only" : "المهمة للقراءة فقط",
    "Task is not completed" : "المهمة غير مكتملة",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" تمّت إضافتها إلى \"{calendar}\"",
    "Create a new task" : "أنشئ مهمّة جديدة",
    "Task summary" : "الملخص المهمة",
    "Create task" : "أنشئ المهمّة",
    "Creating the new task…" : "إنشاء المهمة الجديدة ...",
    "Open task" : "مهمة مفتوحة",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%nمهام مكتملة","%nمهمة مكتملة","%nمهام مكتملة","%nمهام مكتملة","%nمهام مكتملة","%nمهام مكتملة"],
    "Tomorrow" : "غدا",
    "An error occurred, unable to create the list." : "حدث خطأ؛ يتعذّر إنشاء القائمة.",
    "Add List…" : "أضف قائمة ...",
    "New list" : "قائمة جديدة",
    "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
    "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
    "When shared hide this event" : "إخفاء الحدث عند مشاركته",
    "[Completed] L" : "[مُكتمِل] L",
    "[Completed last] dddd [at] LT" : "[مُكتمِل أخير] dddd [في] LT",
    "[Completed] dddd [at] LT" : "[مكتملة] dddd [عند] LT",
    "[Last modified yesterday at] LT" : "[آخر تعديل بالأمس عند] LT",
    "[Last modified today at] LT" : "[آخر تعديل اليوم عند] LT",
    "[Last modified] L" : "[آخر تعديل] L",
    "[Last modified last] dddd [at] LT" : "[آخر تعديل] dddd [عند] LT",
    "[Last modified] dddd [at] LT" : "[آخر تعديل] dddd [عند] LT",
    "[Created yesterday at] LT" : "[أُنشِئت أمس عند] LT",
    "[Created today at] LT" : "[أُنشِئت اليوم عند] LT",
    "[Created] L" : "[أُنشِئت] L",
    "[Created last] dddd [at] LT" : "[أُنشِئت أخير] dddd [عند] LT",
    "[Created] dddd [at] LT" : "[أُنشِئت] dddd [عند] LT",
    "Needs action" : "تحتاج إلى إجراء",
    "In process" : "تحت الإجراء",
    "Canceled" : "ملغي",
    "Clear status" : "محو الحالة",
    "Loading task from server." : "تحميل مهام من الخادم",
    "Task not found!" : "المهمة غير موجودة",
    "Set start date" : "عيّن تاريخ البدء",
    "Set due date" : "تعيين تاريخ اكتمال",
    "Priority {priority}: low" : "الأولوية {priority}: منخفضة",
    "Priority {priority}: medium" : "الأولوية {priority}: متوسطة",
    "Priority {priority}: high" : "الأولوية {priority}: عالية",
    "No priority assigned" : "لم يتم تعيين أي أولوية",
    "{percent} % completed" : "{percent}% مكتمل",
    "All day" : "اليوم بأكمله",
    "Unpin" : "فك التثبيت",
    "Pin" : "تثبيت",
    "Show in Calendar" : "عرض في التقويم",
    "Show in Deck" : "عرض في تطبيق البطاقات",
    "Edit summary" : "تعديل الخُلاصة",
    "Details" : "التفاصيل",
    "Selecting a classification is forbidden, because the task was shared with you." : "إختيار التصنيف ممنوع لأن المهمة مُشارَكةٌ معك.",
    "Select a classification" : "إختيار تصنيف classification",
    "Select a status" : "إختر الحالة status",
    "Set a location" : "تعيين المكان",
    "Set a URL" : "تعيين عنوان الويب",
    "Select tags" : "تحديد الوسوم",
    "Notes" : "الملاحظات",
    "Mark as done" : "تمييز كمُنجز",
    "No due date assigned" : "لم يتم تعيين تاريخ اكتمال",
    "[Due yesterday]" : "[كان مستحقاً بالأمس]",
    "[Due today]" : "[مستحق اليوم]",
    "[Due tomorrow]" : "[مستحقٌ غداً]",
    "[Due] L" : "[مستحقٌ في] L",
    "[Due yesterday at] LT" : "[كان مستحقاً بالأمس عند] LT",
    "[Due today at] LT" : "[مستحق اليوم عند] LT",
    "[Due tomorrow at] LT" : "[مطلوب غداً عند] LT",
    "[Due] L [at] LT" : "[مستحقٌ في] L [عند] LT",
    "No upcoming tasks" : "لا مهام قادمة ",
    "upcoming tasks" : "المهام القادمة",
    "No tasks today" : "لا مهام لليوم",
    "Completion date must be in the past." : "تاريخ إكمال المهمة يجب أن يكون في الماضي.",
    "Successfully created the task." : "تم إنشاء المهمّة بنجاح.",
    "Could not delete the task." : "تعذّر حذف المهمة.",
    "Synchronizing to the server." : "مُزامنة مع الخادم",
    "Task successfully saved to server." : "تم بنجاح حفظ المهمة في الخادم.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "تعذّر تعديل المهمة بسبب أنه تمّ تغييرها على الخادم. رجاءً، إضغط لتحديث العرض. التعديل الذي أجريته على جهازك سيتم تجاهله. ",
    "Could not update the task." : "تعذّر تعديل المهمّة.",
    "Successfully updated the task." : "تمّ تعديل المهمّة بنجاح.",
    "Task successfully moved to new calendar." : "تمّ نقل المهمة بنجاح إلى التقويم الجديد.",
    "An error occurred" : "حدث خطأ!",
    "Create a task" : "أنشئ مهمّة",
    "Message from {author} in {conversationName}" : "رسالة من {author} في {conversationName}",
    "[Due on] LL" : "[مستحق في] LL",
    "[Was due yesterday]" : "[كان مستحق بالأمس]",
    "[Was due on] LL" : "[كان مستحق في] LL",
    "[Was due today at] LT" : "[كان مستحق اليوم عند] LT",
    "[Due on] LL [at] LT" : "[مستحق في] LL [عند] LT",
    "[Was due yesterday at] LT" : "[كان مستحق بالأمس عند] LT",
    "[Was due on] LL [at] LT" : "[كان مستحق في] LL [عند] LT",
    "[Starts today]" : "[تبدأ اليوم]",
    "[Starts tomorrow]" : "[تبدأ غداً]",
    "[Starts on] LL" : "[تبدأ في] LL",
    "[Started yesterday]" : "[بدأت أمس]",
    "[Started on] LL" : "[بدأت في] LL",
    "[Started today at] LT" : "[بدأت اليوم عند] LT",
    "[Starts today at] LT" : "[تبدأ اليوم عند] LT",
    "[Starts tomorrow at] LT" : "[تبدأ غداً عند] LT",
    "[Starts on] LL [at] LT" : "[تبدأ في] LL [عند] LT",
    "[Started yesterday at] LT" : "[بدأت أمس عند] LT",
    "[Started on] LL [at] LT" : "[بدأت في] LL [عند] LT",
    "Midnight on the day the task starts" : "منتصف الليل مباشرةً قبل يوم بداية المهمة ",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n يوم قبل المهمة في {formattedHourMinute}","%n يوم قبل المهمة في {formattedHourMinute}","%n يوم قبل المهمة في {formattedHourMinute}","%n أيام قبل المهمة في {formattedHourMinute}","%n يوم قبل المهمة في {formattedHourMinute}","%n يوم قبل المهمة في {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n أسبوع قبل المهمة في {formattedHourMinute}","%n أسبوع قبل المهمة في {formattedHourMinute}","%n أسبوع قبل المهمة في {formattedHourMinute}","%n أسابيع قبل المهمة في {formattedHourMinute}","%n أسبوع قبل المهمة في {formattedHourMinute}","%n أسبوع قبل المهمة في {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "في يوم المهمة في {formattedHourMinute}",
    "at the task's start" : "عند بداية المهمة",
    "when the task is due" : "عندما تبدأ المهمة",
    "{time} before the task starts" : "{time} قبل أن تبدأ المهمة",
    "{time} before the task is due" : "{time} قبل اكتمال المهمة",
    "{time} after the task starts" : "{time} بعد أن تبدأ المهمة",
    "{time} after the task is due" : "{time} بعد اكتمال المهمة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
