OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Majukumu yajayo",
    "Important" : "Muhimu",
    "Today" : "Leo",
    "Week" : "Wiki",
    "All" : "Zote",
    "Current" : "Ya sasa",
    "Completed" : "Kamilika",
    "Tasks" : "Majukumu",
    "The Tasks app for Nextcloud" : "Programu ya Majukumu ya Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Baada ya kuwezeshwa, mwongozo mpya wa Majukumu utaonekana kwenye mwongozo wa programu ya Nextcloud. Kuanzia hapo unaweza kuongeza na kufuta kazi, kuhariri mada, maelezo, tarehe za kuanza na zinazotarajiwa na uziwekee alama kuwa muhimu. Kazi zinaweza kugawanywa kati ya watumiaji. Majukumu yanaweza kusawazishwa kwa kutumia CalDav (kila orodha ya kazi imeunganishwa na kalenda ya Nextcloud, ili kusawazisha kwa mteja wako wa karibu: Thunderbird, Evolution, KDE Kontact, iCal ... - ongeza tu kalenda kama kalenda ya mbali kwa mteja wako). Unaweza kupakua kazi zako kama faili za ICS kwa kutumia kitufe cha kupakua kwa kila kalenda.",
    "Hidden" : "Iliyofichwa",
    "Visible" : "Inayoonekana",
    "Automatic" : "Automatiki",
    "Tasks settings" : "Mipangilio ya kazi",
    "Default list" : "Orodha ya chaguomsingi",
    "Visibility of Smart Collections" : "Mwonekano wa Mikusanyiko Mahiri",
    "Share with users or groups" : "Shiriki na watumiaji au makundi",
    "No users or groups" : "Hakuna watumiaji au makundi",
    "Unable to delete the share." : "Haiwezi kufuta ushirikishaji",
    "Unable to change permissions." : "Haiwezi kubadili ruhusa",
    "Can edit" : "Inaweza kuhariri",
    "Unshare with {displayName}" : "Acha kushirikisha na {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Hii itafuta kalenda \"{calendar}\" na matukio yote sambamba na mjukumu",
    "This will unshare the calendar \"{calendar}\"." : "Hii haitashirikisha kalenda \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Hii itafuta orodha \"{list}\" sambamba na majukumu yote",
    "This will unshare the list \"{list}\"." : "Hii haitashirikisha orodha \"{list}\"",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Deleting the calendar in {countdown} second","Inafuta kalenda katika sekunde{countdown} "],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Unsharing the calendar in {countdown} second","Haishirikishi kalenda katika sekunde {countdown} "],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Deleting the list in {countdown} second","Inafuta orodha katika sekunde {countdown} "],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Unsharing the list in {countdown} second","Haishirikishi orodha katika sekunde {countdown} "],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Imeshirikishwa na {num} vyombo"],
    "Share this calendar" : "Shirikisha kalenda hii",
    "Share this list" : "Shirikisha orodha hii",
    "Calendar link copied to clipboard." : "Kiungo cha kalenda kimenakiliwa kwenye clipboard.",
    "List link copied to clipboard." : "Kiungo cha orodha kimenakiliwa kwenye ubao wa kunakili.",
    "Calendar link could not be copied to clipboard." : "Kiungo cha kalenda hakikuweza kunakiliwa kwenye clipboard",
    "List link could not be copied to clipboard." : "Kiungo cha orodha hakikuweza kunakiliwa kwenye ubao wa kunakili.",
    "The name \"{calendar}\" is already used." : "Jina \"{calendar}\" limeshatumika",
    "An empty name is not allowed." : "Jina tupu haliruhusiwi",
    "An error occurred, unable to delete the calendar." : "Hitilafu imetokea, haiwezi kufuta kalenda",
    "An error occurred, unable to delete the list." : "Hitilafu imetokea, katisha kufuta orodha",
    "Edit" : "Hariri",
    "Copy private link" : "Nakili kiungio binafsi",
    "Copied" : "Iliyonakiliwa",
    "Cannot copy" : "Haiwezi kunakili",
    "Export" : "Safirisha",
    "Delete" : "Futa",
    "Unshare" : "Usishirikishe",
    "List name" : "Orodhesha majina",
    "Untitled task" : "Kazi zisizo na jina",
    "Untitled event" : "Tukio lisilotajwa",
    "Untitled journal" : "Mwandishi asiyetajwa",
    "Untitled item" : "Kipengele kisichotajwa",
    "Unknown calendar" : "Kalenda isiyojulikana",
    "Could not load deleted calendars and objects" : "Haikuwaza kupakia kalenda na vitu vilivyofutwa",
    "Could not delete calendar or event" : "Haikuweza kufuta kalenda au matukio",
    "Could not restore calendar or event" : "Haikuweza kuhifadhi upya kalenda au matukio",
    "Do you really want to empty the trash bin?" : "Je, unataka kuweka tupu chombo cha takataka?",
    "Empty trash bin" : "Weka tupu chombo cha takataka",
    "Trash bin" : "Chombo cha takataka",
    "Loading deleted calendars, tasks and events." : "Inapakia kalenda, majukumu na matukio yaliyofutwa",
    "You do not have any deleted calendars, tasks or events." : "Huna kalenda, majukumu au matukio yoyote yaliyofutwa",
    "Name" : "Jina",
    "Deleted" : "Vilivyofutwa",
    "Restore" : "Hifadhi upya",
    "Delete permanently" : "Futa moja kwa moja",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elements in the trash bin are deleted after {numDays} day","Vipengele katika pipa la takataka vinafutwa baada ya siku {numDays} "],
    "Create reminder" : "Tengeneza ukumbusho",
    "Update reminder" : "Sasisha ukumbusho",
    "Set a reminder at a custom date and time:" : "Panga ukumbusho katika tarehe na muda mahsusi",
    "Cancel" : "Sitisha",
    "This is a todo reminder." : "Huu ni ukumbusho wa todo",
    "No reminders" : "Hakuna ukumbusho",
    "Notification" : "Taarifa",
    "Email" : "Barua pepe",
    "Audio notification" : "Taarifa ya sauti",
    "Other notification" : "Taarifa zingine",
    "Edit time" : "Hariri muda",
    "Remove reminder" : "Ondoa kikumbushio",
    "Add reminder" : "Ongeza kikumbushio",
    "Before the task starts" : "Kabla ya majukumu kuanza",
    "Before the task is due" : "Kabla jukumu halijafika",
    "Select date and time" : "Chagua tarehe na muda",
    "Go back" : "Rudi nyuma",
    "Set a reminder relative to your tasks start date:" : "Set a reminder relative to your tasks start date:",
    "Set a reminder relative to your tasks due date:" : "Set a reminder relative to your tasks due date:",
    "before at" : "kabla ya katika",
    "_second_::_seconds_" : ["second","sekunde"],
    "_minute_::_minutes_" : ["minute","dakika"],
    "_hour_::_hours_" : ["hour","masaa"],
    "_day_::_days_" : ["day","siku"],
    "_week_::_weeks_" : ["week","wiki"],
    "Select a calendar" : "Chagua kalenda",
    "No calendar matches the search." : "Hakuna kalenda inayolingana na utafutaji.",
    "Set date" : "Panga tarehe",
    "Set time" : "Panga muda",
    "Delete date" : "Futa tarehe",
    "Click here to add a note." : "Bofya hapa ili kuongeza dokezo",
    "Set value" : "Panga thamani",
    "Delete value" : "Futa thamani",
    "Add this as a new tag" : "Ongeza hii kama lebo mpya",
    "No tag available. Create one!" : "Hakuna lebo inayopatikana. Unda moja!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} majukumu yameongezwa kwa  \"{calendar}\"",
    "Create new tasks" : "Tengeneza majukumu mapya",
    "Create {numberOfTasks} tasks from pasted text" : "Tengeneza majukumu {numberOfTasks} kutoka maandishi yaliyopita",
    "Create tasks" : "Tengeneza majukumu",
    "Creating new tasks…" : "Tengeneza majukumu mapya",
    "Close" : "Funga",
    "Delete all completed tasks." : "Futa majukumu yote yaliyokamilishwa",
    "Delete completed tasks." : "Futa majukumu yaliyokamilishwa",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Futa majukumu yote yaliyokamilishwa kutoka katika kalenda \"{calendar}\"",
    "No errors" : "Hakuna hitilafu",
    "Open your browser console for more details" : "Fungua koni ya kivinjari chako kwa maelezo zaidi",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\".","Hatua hii itafuta majukumu {taskCount} yaliyokamilishwa na majukumu yake madogo kwenye kalenda \"{calendar}\""],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Could not delete {failedCount} task.","Haikuweza kufuta mujukumu {failedCount}."],
    "Active filter" : "Kichujio hai",
    "Filter by tags" : "Chuja kwa vitambulisho",
    "Select tags to filter by" : "Chagua vitambulisho vya kuchuja kwa ",
    "Reset filter" : "Pangilia uchujaji",
    "Add an important task to \"{calendar}\"…" : "Ongeza jukumu la muhimu kwa \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Ongeza ukomo wa leo wa jukumu kwa \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Ongeza jukumu la sasa kwa \"{calendar}\"",
    "Add a task to \"{calendar}\"…" : "Ongeza jukumu kwenye \"{calendar}\"...",
    "Load the completed tasks of all lists." : "Pakia kazi zilizokamilishwa za orodha zote.",
    "Loading the completed tasks of all lists might slow down the app." : "Kupakia majukumu yaliyokamilishwa ya orodha zote kunaweza kupunguza kasi ya programu.",
    "Load the completed tasks of list \"{calendar}\"." : "Pakia kazi zilizokamilishwa za orodha \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Kupakia kazi zilizokamilishwa kunaweza kupunguza kasi ya programu.",
    "Relevance" : "Umuhimu",
    "Sort by completed state, due date, priority, start date and summary." : "Teua kulingana na hali iliyokamilishwa, tarehe ya kukamilisha, kipaumbele, tarehe ya kuanza na muhtasari.",
    "Start date" : "Tarehe ya kuanza",
    "Sort by start date, priority and summary." : "Teua kwa tarehe ya kuanza, kipaumbele na muhtasari",
    "Due date" : "Tarehe ya ukomo",
    "Sort by due date, priority and summary." : "Teua kwa tarehe ukomo, kipaumbele na muhtasari",
    "Created date" : "Tarehe iliyotengenezwa",
    "Sort by created date, priority and summary." : "Teua kwa tarehe iliyotengenezwa, kipaumbele na muhtasari",
    "Last modified" : "Iliyoboreshwa mwisho",
    "Sort by last-modified date, priority and summary." : "Teua kwa tarehe iliyokamilika mwisho, kipaumbele na muhtasari",
    "Completed date" : "Tarehe iliyokamilika",
    "Sort by completed date, priority and summary." : "Teua kwa tarehe iliyokamilika, kipaumbele na muhtasari",
    "Priority" : "Kipaumbele",
    "Sort by priority and summary." : "Teua kwa kipaumbele au muhtasari",
    "Alphabetically" : "Kialfabeti",
    "Sort by summary and priority." : "Sort by summary and priority.",
    "Tags" : "Maoni",
    "Sort by tags." : "Teua kwa maoni",
    "Manually" : "ya kawaida",
    "Sort by manual order." : "Teua kwa mpangilio wa kawaida",
    "Change sort order" : "Badilisha mpangilio wa teuzi",
    "[Yesterday]" : "[Jana]",
    "[Today]" : "[Leo]",
    "[Tomorrow]" : "[Kesho]",
    "[Completed yesterday]" : "[Ilikamilika jana]",
    "[Completed today]" : "[Imekamilika leo]",
    "[Completed tomorrow]" : "[Itakamilika kesho]",
    "[Yesterday at] LT" : "[Jana katika] LT",
    "[Today at] LT" : "[Leo katika] LT",
    "[Tomorrow at] LT" : "[Kesho katika] LT",
    "L [at] LT" : "L [katika] LT",
    "[Completed yesterday at] LT" : "[Ilikamilika jana katika] LT",
    "[Completed today at] LT" : "[Imekamilika leo katika] LT",
    "[Completed tomorrow at] LT" : "[Itakamilika kesho katika] LT",
    "[Completed] L [at] LT" : "[Imekamilisha] L [katika] LT",
    "Add a subtask to \"{task}\"…" : "Ongeza majukumu madogo katika \"{task}\"",
    "Task has hidden subtasks" : "Jukumu limeficha majukumu madogo",
    "Task is pinned" : "Jukumu limebandikwa",
    "Task has a note" : "Jukumu lina dokezo",
    "{complete} % completed" : "{complete} % imekamilika",
    "Add subtask" : "Ongeza majukumu madogo",
    "Show subtasks" : "Onesha majukumu madogo",
    "Hide subtasks" : "Ficha majukumu madogo",
    "Show closed subtasks" : "Onesha majukumu madogo yaliyofungwa",
    "Hide closed subtasks" : "Ficha majukumu madogo yaliyofungwa",
    "Delete task" : "Futa jukumu",
    "Toggle starred" : "Geuza yenye nyota",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Task has one reminder","Jukumu lina vikumbusho {n}"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Deleting the task in {countdown} second","Inafuta jukumu katika sekunde {countdown}"],
    "Task is cancelled" : "Jukumu limesitishwa",
    "Task is completed" : "Jukumu lumekamilika",
    "Task is read-only" : "Jukumu ni la kusoma tu",
    "Task is not completed" : "Jukumu halijakamilika",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" liliongezwa kwenye \"{calendar}\"",
    "Create a new task" : "Tengeneza jukumu jipya",
    "Task summary" : "Muhtasari wa jukumu",
    "Create task" : "Tengeneza jukumu",
    "Creating the new task…" : "Inatengeneza jukumu jipya",
    "Open task" : "Fungua jukumu",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n majukumu yaliyokamilika"],
    "Tomorrow" : "Kesho",
    "An error occurred, unable to create the list." : "Hitilafu imetokea, haikuweza kuunda orodha.",
    "Add List…" : "Ongeza orodha...",
    "New list" : "Orodha mpya",
    "When shared show full event" : "Iliyoshirikishwa inapoonesha tukio zima",
    "When shared show only busy" : "Iliyoshirikishwa inapoonesha ubize tu",
    "When shared hide this event" : "Iliyoshirikishwa inapoficha tukio hili",
    "[Completed] L" : "[Imekamilisha] L",
    "[Completed last] dddd [at] LT" : "[Imekamilisha mwisho] dddd [katika] LT",
    "[Completed] dddd [at] LT" : "[Imekamilisha] dddd [katika] LT",
    "[Last modified yesterday at] LT" : "[Mwisho iliboreshwa jana katika] LT",
    "[Last modified today at] LT" : "[Mwisho imeboreshwa leo katika] LT",
    "[Last modified] L" : "[Mwisho iliboresha] L",
    "[Last modified last] dddd [at] LT" : "[Mwisho iliboresha mwisho] dddd [katika] LT",
    "[Last modified] dddd [at] LT" : "[Mwisho iliboresha] dddd [katika] LT",
    "[Created yesterday at] LT" : "[Jana ilitengeneza katika] LT",
    "[Created today at] LT" : "[Imetengeneza leo katika] LT",
    "[Created] L" : "[Imetengeneza] L",
    "[Created last] dddd [at] LT" : "[Mwisho ilitengeneza] dddd [katika] LT",
    "[Created] dddd [at] LT" : "[Ilitengeneza] dddd [katika] LT",
    "Needs action" : "Inahitaji vitendo",
    "In process" : "Inachakata",
    "Canceled" : "Imesitishwa",
    "Clear status" : "Fut wadhifa",
    "Loading task from server." : "Inapakia jukumu kutoka katika seva",
    "Task not found!" : "Jukumu halipo",
    "Set start date" : "Panga tarehe ya kuanza",
    "Set due date" : "Panga tarehe ukomo",
    "Priority {priority}: low" : "Kipaumbele cha chini {priority}",
    "Priority {priority}: medium" : "Kipaumbele cha wastani {priority}",
    "Priority {priority}: high" : "Kipaumbele cha juu {priority}",
    "No priority assigned" : "Hakuna kipaumbele kilichowekwa",
    "{percent} % completed" : "{percent} % imekamilika",
    "All day" : "Siku yote",
    "Unpin" : "Bandua",
    "Pin" : "Bandika",
    "Show in Calendar" : "Onesha katika kalenda",
    "Show in Deck" : "Onesha katika Deck",
    "Edit summary" : "Hariri muhtasari",
    "Details" : "Maelezo ya kina",
    "Selecting a classification is forbidden, because the task was shared with you." : "Kuchagua uainishaji ni marufuku, kwa sababu jukumu lilishirikiwa nawe.",
    "Select a classification" : "Chagua uainishaji",
    "Select a status" : "Chagua wadhifa",
    "Set a location" : "Pangilia eneo",
    "Set a URL" : "Pangilia URL",
    "Select tags" : "Chagua ukumbusho",
    "Notes" : "Madokezo",
    "Mark as done" : "Weka alama kama iliyotendeka",
    "No due date assigned" : "Hakuna tarehe inayofaa iliyowekwa",
    "[Due yesterday]" : "[Ilifaa jana]",
    "[Due today]" : "[Inafaa leo]",
    "[Due tomorrow]" : "[Itafaa kesho]",
    "[Due] L" : "[Inafaa] L",
    "[Due yesterday at] LT" : "[ilifaa jana katika] LT",
    "[Due today at] LT" : "[Inafaa leo katika] LT",
    "[Due tomorrow at] LT" : "[Itafaa kesho katika] LT",
    "[Due] L [at] LT" : "[Inafaa] L [katika] LT",
    "No upcoming tasks" : "Hakuna majukumu yajayo",
    "upcoming tasks" : "Majukumu yajayo",
    "No tasks today" : "Hakuna majukumu leo",
    "Completion date must be in the past." : "Tarehe ya ukamilishaji lazima iwe wakati uliopita",
    "Successfully created the task." : "Imetengeneza jukumu kikamilifu",
    "Could not delete the task." : "Haikuweza kufuta jukumu",
    "Synchronizing to the server." : "Inasawazisha kwenye seva",
    "Task successfully saved to server." : "Jukumu limehifadhiwa kikamilifu kwenye seva",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Haikuweza kusasisha jukumu kwa sababu ilibadilishwa kwenye seva. Tafadhali bofya ili kuonyesha upya, mabadiliko ya ndani yatatupiliwa mbali.",
    "Could not update the task." : "Haikuweza kusasisha jukumu.",
    "Successfully updated the task." : "Imesasisha jukumu kikamilifu.",
    "Task successfully moved to new calendar." : "Jukumu limehamishwa kikamilifu hadi kwenye kalenda mpya.",
    "An error occurred" : "Hitilafu imetokea",
    "Create a task" : "Unda/tengeneza jukumu",
    "Message from {author} in {conversationName}" : "Ujumbe kutoka {author}katika{conversationName}",
    "[Due on] LL" : "[Inafaa katika] LL",
    "[Was due yesterday]" : "[Ilifaa jana]",
    "[Was due on] LL" : "[Ilifaa katika] LL",
    "[Was due today at] LT" : "[Ilifaa jana katika] LT",
    "[Due on] LL [at] LT" : "[inafaa juu ya] LL [katka] LT ",
    "[Was due yesterday at] LT" : "[Ilifaa jana katika] LT",
    "[Was due on] LL [at] LT" : "[Ilifaa juu ya] LL [katika] LT",
    "[Starts today]" : "[Inaanza leo]",
    "[Starts tomorrow]" : "[Itaanza kesho]",
    "[Starts on] LL" : "[Inaanza juu ya] LL",
    "[Started yesterday]" : "[Ilianza jana]",
    "[Started on] LL" : "[Ilianza juu ya] LL",
    "[Started today at] LT" : "[Ilianza leo katika] LT",
    "[Starts today at] LT" : "[Inaanza leo katika] LT",
    "[Starts tomorrow at] LT" : "[Itaanza kesho katika] LT",
    "[Starts on] LL [at] LT" : "[Inaanza juu ya] LL [katika] LT",
    "[Started yesterday at] LT" : "[Iliaanza jana katika] LT",
    "[Started on] LL [at] LT" : "[Inaanza juu ya] LL [katika] LT",
    "Midnight on the day the task starts" : "Usiku wa manane wa siku ya jukumu kuanza",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n day before the task at {formattedHourMinute}","%n siku kabla ya kazi {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n week before the task at {formattedHourMinute}","%nwiki kabla ya kazi katika  {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "katika siku ya jukumu katika {formattedHourMinute}",
    "at the task's start" : "mwanzoni mwa kazi",
    "when the task is due" : "wakati jukumu linafaa",
    "{time} before the task starts" : "{time} kabla ya kazi kuanza",
    "{time} before the task is due" : "{time} kabla ya kazi kufaa",
    "{time} after the task starts" : "{time} baada ya kazi kuanza",
    "{time} after the task is due" : "{time} baada ya kazi kukamilika"
},
"nplurals=2; plural=(n != 1);");
