OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Upcoming tasks",
    "Important" : "Important",
    "Today" : "Today",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Tasks" : "Tasks",
    "The Tasks app for Nextcloud" : "The Tasks app for Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar.",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Tasks settings" : "Tasks settings",
    "Default list" : "Default list",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Share with users or groups" : "Share with users or groups",
    "No users or groups" : "No users or groups",
    "Unable to delete the share." : "Unable to delete the share.",
    "Unable to change permissions." : "Unable to change permissions.",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Unshare with {displayName}",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "This will delete the calendar \"{calendar}\" and all corresponding events and tasks.",
    "This will unshare the calendar \"{calendar}\"." : "This will unshare the calendar \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "This will delete the list \"{list}\" and all corresponding tasks.",
    "This will unshare the list \"{list}\"." : "This will unshare the list \"{list}\".",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Deleting the calendar in {countdown} second","Deleting the calendar in {countdown} seconds"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Unsharing the calendar in {countdown} second","Unsharing the calendar in {countdown} seconds"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Deleting the list in {countdown} second","Deleting the list in {countdown} seconds"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Unsharing the list in {countdown} second","Unsharing the list in {countdown} seconds"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Shared with {num} entities"],
    "Share this calendar" : "Share this calendar",
    "Share this list" : "Share this list",
    "Calendar link copied to clipboard." : "Calendar link copied to clipboard.",
    "List link copied to clipboard." : "List link copied to clipboard.",
    "Calendar link could not be copied to clipboard." : "Calendar link could not be copied to clipboard.",
    "List link could not be copied to clipboard." : "List link could not be copied to clipboard.",
    "The name \"{calendar}\" is already used." : "The name \"{calendar}\" is already used.",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "An error occurred, unable to delete the calendar." : "An error occurred, unable to delete the calendar.",
    "An error occurred, unable to delete the list." : "An error occurred, unable to delete the list.",
    "Edit" : "Edit",
    "Copy private link" : "Copy private link",
    "Copied" : "Copied",
    "Cannot copy" : "Cannot copy",
    "Export" : "Export",
    "Delete" : "Delete",
    "Unshare" : "Unshare",
    "List name" : "List name",
    "Untitled task" : "Untitled task",
    "Untitled event" : "Untitled event",
    "Untitled journal" : "Untitled journal",
    "Untitled item" : "Untitled item",
    "Unknown calendar" : "Unknown calendar",
    "Could not load deleted calendars and objects" : "Could not load deleted calendars and objects",
    "Could not delete calendar or event" : "Could not delete calendar or event",
    "Could not restore calendar or event" : "Could not restore calendar or event",
    "Do you really want to empty the trash bin?" : "Do you really want to empty the trash bin?",
    "Empty trash bin" : "Empty trash bin",
    "Trash bin" : "Trash bin",
    "Loading deleted calendars, tasks and events." : "Loading deleted calendars, tasks and events.",
    "You do not have any deleted calendars, tasks or events." : "You do not have any deleted calendars, tasks or events.",
    "Name" : "Surname",
    "Deleted" : "Deleted",
    "Restore" : "Restore",
    "Delete permanently" : "Delete permanently",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elements in the trash bin are deleted after {numDays} day","Elements in the trash bin are deleted after {numDays} days"],
    "Create reminder" : "Create reminder",
    "Update reminder" : "Update reminder",
    "Set a reminder at a custom date and time:" : "Set a reminder at a custom date and time:",
    "Cancel" : "Cancel",
    "This is a todo reminder." : "This is a todo reminder.",
    "No reminders" : "No reminders",
    "Notification" : "Notification",
    "Email" : "Email",
    "Audio notification" : "Audio notification",
    "Other notification" : "Other notification",
    "Edit time" : "Edit time",
    "Remove reminder" : "Remove reminder",
    "Add reminder" : "Add reminder",
    "Before the task starts" : "Before the task starts",
    "Before the task is due" : "Before the task is due",
    "Select date and time" : "Select date and time",
    "Go back" : "Go back",
    "Do you want to keep related reminders?" : "Do you want to keep related reminders?",
    "Discard reminders" : "Discard reminders",
    "Keep reminders" : "Keep reminders",
    "Set a reminder relative to your tasks start date:" : "Set a reminder relative to your tasks start date:",
    "Set a reminder relative to your tasks due date:" : "Set a reminder relative to your tasks due date:",
    "before at" : "before at",
    "_second_::_seconds_" : ["second","seconds"],
    "_minute_::_minutes_" : ["minute","minutes"],
    "_hour_::_hours_" : ["hour","hours"],
    "_day_::_days_" : ["day","days"],
    "_week_::_weeks_" : ["week","weeks"],
    "Select a calendar" : "Select a calendar",
    "No calendar matches the search." : "No calendar matches the search.",
    "Set date" : "Set date",
    "Set time" : "Set time",
    "Delete date" : "Delete date",
    "Click here to add a note." : "Click here to add a note.",
    "Set value" : "Set value",
    "Delete value" : "Delete value",
    "Add this as a new tag" : "Add this as a new tag",
    "No tag available. Create one!" : "No tag available. Create one!",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} tasks have been added to \"{calendar}\"",
    "Create new tasks" : "Create new tasks",
    "Create {numberOfTasks} tasks from pasted text" : "Create {numberOfTasks} tasks from pasted text",
    "Create tasks" : "Create tasks",
    "Creating new tasks…" : "Creating new tasks…",
    "Close" : "Close",
    "Delete all completed tasks." : "Delete all completed tasks.",
    "Delete completed tasks." : "Delete completed tasks.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Deleted all completed tasks from calendar \"{calendar}\".",
    "No errors" : "No errors",
    "Open your browser console for more details" : "Open your browser console for more details",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\".","This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Could not delete {failedCount} task.","Could not delete {failedCount} tasks."],
    "Active filter" : "Active filter",
    "Filter by tags" : "Filter by tags",
    "Select tags to filter by" : "Select tags to filter by",
    "Reset filter" : "Reset filter",
    "Add an important task to \"{calendar}\"…" : "Add an important task to \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Add a task due today to \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Add a current task to \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Add a task to \"{calendar}\"…",
    "Load the completed tasks of all lists." : "Load the completed tasks of all lists.",
    "Loading the completed tasks of all lists might slow down the app." : "Loading the completed tasks of all lists might slow down the app.",
    "Load the completed tasks of list \"{calendar}\"." : "Load the completed tasks of list \"{calendar}\".",
    "Loading the completed tasks might slow down the app." : "Loading the completed tasks might slow down the app.",
    "Relevance" : "Relevance",
    "Sort by completed state, due date, priority, start date and summary." : "Sort by completed state, due date, priority, start date and summary.",
    "Start date" : "Start date",
    "Sort by start date, priority and summary." : "Sort by start date, priority and summary.",
    "Due date" : "Due date",
    "Sort by due date, priority and summary." : "Sort by due date, priority and summary.",
    "Created date" : "Created date",
    "Sort by created date, priority and summary." : "Sort by created date, priority and summary.",
    "Last modified" : "Last modified",
    "Sort by last-modified date, priority and summary." : "Sort by last-modified date, priority and summary.",
    "Completed date" : "Completed date",
    "Sort by completed date, priority and summary." : "Sort by completed date, priority and summary.",
    "Priority" : "Priority",
    "Sort by priority and summary." : "Sort by priority and summary.",
    "Alphabetically" : "Alphabetically",
    "Sort by summary and priority." : "Sort by summary and priority.",
    "Tags" : "Tags",
    "Sort by tags." : "Sort by tags.",
    "Manually" : "Manually",
    "Sort by manual order." : "Sort by manual order.",
    "Change sort order" : "Change sort order",
    "[Yesterday]" : "[Yesterday]",
    "[Today]" : "[Today]",
    "[Tomorrow]" : "[Tomorrow]",
    "[Completed yesterday]" : "[Completed yesterday]",
    "[Completed today]" : "[Completed today]",
    "[Completed tomorrow]" : "[Completed tomorrow]",
    "[Yesterday at] LT" : "[Yesterday at] LT",
    "[Today at] LT" : "[Today at] LT",
    "[Tomorrow at] LT" : "[Tomorrow at] LT",
    "L [at] LT" : "L [at] LT",
    "[Completed yesterday at] LT" : "[Completed yesterday at] LT",
    "[Completed today at] LT" : "[Completed today at] LT",
    "[Completed tomorrow at] LT" : "[Completed tomorrow at] LT",
    "[Completed] L [at] LT" : "[Completed] L [at] LT",
    "Add a subtask to \"{task}\"…" : "Add a subtask to \"{task}\"…",
    "Task has hidden subtasks" : "Task has hidden subtasks",
    "Task is pinned" : "Task is pinned",
    "Task has a note" : "Task has a note",
    "{complete} % completed" : "{complete} % completed",
    "Add subtask" : "Add subtask",
    "Show subtasks" : "Show subtasks",
    "Hide subtasks" : "Hide subtasks",
    "Show closed subtasks" : "Show closed subtasks",
    "Hide closed subtasks" : "Hide closed subtasks",
    "Delete task" : "Delete task",
    "Toggle starred" : "Toggle starred",
    "_Task has one reminder_::_Task has {n} reminders_" : ["Task has one reminder","Task has {n} reminders"],
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Deleting the task in {countdown} second","Deleting the task in {countdown} seconds"],
    "Task is cancelled" : "Task is cancelled",
    "Task is completed" : "Task is completed",
    "Task is read-only" : "Task is read-only",
    "Task is not completed" : "Task is not completed",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" was added to \"{calendar}\"",
    "Create a new task" : "Create a new task",
    "Task summary" : "Task summary",
    "Create task" : "Create task",
    "Creating the new task…" : "Creating the new task…",
    "Open task" : "Open task",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Tomorrow" : "Tomorrow",
    "An error occurred, unable to create the list." : "An error occurred, unable to create the list.",
    "Add List…" : "Add List…",
    "New list" : "New list",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "[Completed] L" : "[Completed] L",
    "[Completed last] dddd [at] LT" : "[Completed last] dddd [at] LT",
    "[Completed] dddd [at] LT" : "[Completed] dddd [at] LT",
    "[Last modified yesterday at] LT" : "[Last modified yesterday at] LT",
    "[Last modified today at] LT" : "[Last modified today at] LT",
    "[Last modified] L" : "[Last modified] L",
    "[Last modified last] dddd [at] LT" : "[Last modified last] dddd [at] LT",
    "[Last modified] dddd [at] LT" : "[Last modified] dddd [at] LT",
    "[Created yesterday at] LT" : "[Created yesterday at] LT",
    "[Created today at] LT" : "[Created today at] LT",
    "[Created] L" : "[Created] L",
    "[Created last] dddd [at] LT" : "[Created last] dddd [at] LT",
    "[Created] dddd [at] LT" : "[Created] dddd [at] LT",
    "Needs action" : "Needs action",
    "In process" : "In process",
    "Canceled" : "Canceled",
    "Clear status" : "Clear status",
    "Loading task from server." : "Loading task from server.",
    "Task not found!" : "Task not found!",
    "Set start date" : "Set start date",
    "Set due date" : "Set due date",
    "Priority {priority}: low" : "Priority {priority}: low",
    "Priority {priority}: medium" : "Priority {priority}: medium",
    "Priority {priority}: high" : "Priority {priority}: high",
    "No priority assigned" : "No priority assigned",
    "{percent} % completed" : "{percent} % completed",
    "All day" : "All day",
    "Unpin" : "Unpin",
    "Pin" : "Pin",
    "Show in Calendar" : "Show in Calendar",
    "Show in Deck" : "Show in Deck",
    "Edit summary" : "Edit summary",
    "Details" : "Details",
    "Selecting a classification is forbidden, because the task was shared with you." : "Selecting a classification is forbidden, because the task was shared with you.",
    "Select a classification" : "Select a classification",
    "Select a status" : "Select a status",
    "Set a location" : "Set a location",
    "Set a URL" : "Set a URL",
    "Select tags" : "Select tags",
    "Notes" : "Notes",
    "Mark as done" : "Mark as done",
    "No due date assigned" : "No due date assigned",
    "[Due yesterday]" : "[Due yesterday]",
    "[Due today]" : "[Due today]",
    "[Due tomorrow]" : "[Due tomorrow]",
    "[Due] L" : "[Due] L",
    "[Due yesterday at] LT" : "[Due yesterday at] LT",
    "[Due today at] LT" : "[Due today at] LT",
    "[Due tomorrow at] LT" : "[Due tomorrow at] LT",
    "[Due] L [at] LT" : "[Due] L [at] LT",
    "No upcoming tasks" : "No upcoming tasks",
    "upcoming tasks" : "upcoming tasks",
    "No tasks today" : "No tasks today",
    "Completion date must be in the past." : "Completion date must be in the past.",
    "Successfully created the task." : "Successfully created the task.",
    "Could not delete the task." : "Could not delete the task.",
    "Synchronizing to the server." : "Synchronizing to the server.",
    "Task successfully saved to server." : "Task successfully saved to server.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded.",
    "Could not update the task." : "Could not update the task.",
    "Successfully updated the task." : "Successfully updated the task.",
    "Task successfully moved to new calendar." : "Task successfully moved to new calendar.",
    "An error occurred" : "An error occurred",
    "Create a task" : "Create a task",
    "Message from {author} in {conversationName}" : "Message from {author} in {conversationName}",
    "[Due on] LL" : "[Due on] LL",
    "[Was due yesterday]" : "[Was due yesterday]",
    "[Was due on] LL" : "[Was due on] LL",
    "[Was due today at] LT" : "[Was due today at] LT",
    "[Due on] LL [at] LT" : "[Due on] LL [at] LT",
    "[Was due yesterday at] LT" : "[Was due yesterday at] LT",
    "[Was due on] LL [at] LT" : "[Was due on] LL [at] LT",
    "[Starts today]" : "[Starts today]",
    "[Starts tomorrow]" : "[Starts tomorrow]",
    "[Starts on] LL" : "[Starts on] LL",
    "[Started yesterday]" : "[Started yesterday]",
    "[Started on] LL" : "[Started on] LL",
    "[Started today at] LT" : "[Started today at] LT",
    "[Starts today at] LT" : "[Starts today at] LT",
    "[Starts tomorrow at] LT" : "[Starts tomorrow at] LT",
    "[Starts on] LL [at] LT" : "[Starts on] LL [at] LT",
    "[Started yesterday at] LT" : "[Started yesterday at] LT",
    "[Started on] LL [at] LT" : "[Started on] LL [at] LT",
    "Midnight on the day the task starts" : "Midnight on the day the task starts",
    "_%n day before the task at {formattedHourMinute}_::_%n days before the task at {formattedHourMinute}_" : ["%n day before the task at {formattedHourMinute}","%n days before the task at {formattedHourMinute}"],
    "_%n week before the task at {formattedHourMinute}_::_%n weeks before the task at {formattedHourMinute}_" : ["%n week before the task at {formattedHourMinute}","%n weeks before the task at {formattedHourMinute}"],
    "on the day of the task at {formattedHourMinute}" : "on the day of the task at {formattedHourMinute}",
    "at the task's start" : "at the task's start",
    "when the task is due" : "when the task is due",
    "{time} before the task starts" : "{time} before the task starts",
    "{time} before the task is due" : "{time} before the task is due",
    "{time} after the task starts" : "{time} after the task starts",
    "{time} after the task is due" : "{time} after the task is due"
},
"nplurals=2; plural=(n != 1);");
